#pragma TextEncoding = "Windows-1252"
#pragma rtGlobals=3		// Use modern global access method.
//#pragma version=1.17d// decided to not use pragma but a string constant 

//ToF-AMS data processing kit for ToF-AMS analysis Toolkit
//Copyright (C) 2005, 2006, 2007,2008, 2009,2010,2011, 2012, 2013, 2014, 2015, 2016, 2017
//James Allan (SEAES, University of Manchester, UK; DIAC, NCAS, UK)
//Jonathan Crosier (SEAES, University of Manchester, UK)
//Edward Dunlea (CIRES, University of Colorado at Boulder, CO, USA)
//Donna Sueper (CIRES, University of Colorado at Boulder, CO, USA; Aerodyne Research Inc., MA, USA)
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

///////////////////////////////////////////////////////////////////////////////
// CURRENT STATUS
// see Read me file for details.

static constant SQUIRREL_MAXDATA_DEF=0x6400000 	// Maximum acorn size, in bytes
static constant SQUIRREL_MAXFILE_DEF=367001600	 // Maximum file size for intermediate data, in bytes (300MB)
strconstant SQUIRREL_PROC_PREF="AMS_intermediate_" // Prefix for processed data files
//static strconstant SQUIRREL_PROC_PREF="AMS_intermediate_" // Prefix for processed data files
static constant SQUIRREL_CHUNKSIZE=1 				//Chunk size in HDF5 files (rows)


// prototype function
Function squirrel_proto(index_pos,paramstr,acorn,n_acorns) // The format of a squirrel fetch function
	wave index_pos //& 1D wave of positions in 'run_index' that are being operated on
	string paramstr //& Keyword-identified parameter string
	variable acorn //& Number of the 'acorn' being passed
	variable n_acorns //& The total number of 'acorns' that will be passed
End


// The genius of squirrel
// Given a todo wave, function name, and string lists of parameters, perform an operation on data sets.
// This function uses the values in these waves:
//  squirrel_index=root:index:squirrel_index
//  file_index=root:index:file_index
// data_index=root:index:data_index
// run_index=root:index:run_index
// to find out where the data set resides, and extracts chunks (acorns = data set in subsets of todo wave) to operate on until the entire todo wave is complete.
Function squirrel_fetch(todo,func,paramstr,sourcelist)
	wave todo //& 1D list of run numbers
	funcref squirrel_proto func //& Operation to be performed
	string paramstr,sourcelist //& Indexed parameters, list of source data types (e.g. MSSDiff, etc.)
	
	variable idex, j, k, n_runs, n_source, datacount, run_id, tempVar		// 1.44A tempVar added 
	variable n_acorns,acorn_size,file_id,current_file=-1,batch_size,maxdim
	variable load_flag, layflag, chunkflag, loadcol, loadlay, loadchunk, squirrel_maxdata, loadstart, loadcount=0
	variable min_cl,max_cl,min_ly,max_ly,min_ck,max_ck
	variable SetIfNotLoaded//Q for loading subsets of data, set the unloaded portion to this value
	string filename,acornstr ,datastr, dataStrTemp// 1.44A tempVar added 
	string squirrel_error
	variable min_flag=num_or_def(numberbykey(paramstr,"acorn_minsize"),0) // Set acorn size to smallest possible, so no padding is used
	variable  colStart
	variable n_todo, rowMin	//	1.158G
		
	//^ moved to start of function v100b_r02A
	min_cl=num_or_def(numberbykey("min_cl",paramstr),0)
	max_cl=num_or_def(numberbykey("max_cl",paramstr)+1,inf)
	min_ly=num_or_def(numberbykey("min_ly",paramstr),0)
	max_ly=num_or_def(numberbykey("max_ly",paramstr)+1,inf)
	min_ck=num_or_def(numberbykey("min_ck",paramstr),0)
	max_ck=num_or_def(numberbykey("max_ck",paramstr)+1,inf)

	// variables:
	// idex runs over the number of data sets, or sources.  i.e. MSOpen
	// current_file is the index within file_index text wave of the hdf we are working on.
	// file_id is the id number returned by Igor when an HDF5OpenFile call has been executed
	// loadcol=dimsize(hdf5load,1)  dimension of one slab's worth of loaded data from hdf
 	// loadlay=dimsize(hdf5load,2)  dimension of one slab's worth of loaded data from hdf

	svar HdfFileExtension=root:panel:HdfFileExtension  /// 1.52M, default for DAQ files under version 5 = "hdf"

	wave squirrel_index=root:index:squirrel_index
	wave /t file_index=root:index:file_index
	wave /t data_index=root:index:data_index
	wave run_index=root:index:run_index

//	wave squirrel_index=root:tagindex:tag_index
//	wave /t file_index=root:tagindex:tagIntermFile_index
//	wave /t data_index=root:tagindex:tagdata_index
//	wave/I run_index=root:tagindex:tagrun_index
	
	squirrel_maxdata=numvarordefault("root:squirrel_maxdata",SQUIRREL_MAXDATA_DEF)
	n_runs=numpnts(todo)
	n_source=itemsinlist(sourcelist)

		//Q additional progress report for acorns
	variable endtime, starttime = datetime
	sq_ams_stat_upd("",acorns=1)
	sq_ams_prog_upd(0,acorns=1)

	setdatafolder root:
	newdatafolder /o root:hoard
	
//& Find out how big the wave is going to be. Maybe need to streamline this process in the future
	
	sq_ams_stat_upd("Estimating data requirements...")	
	make/free /o/n=(n_source) maxcol,maxlay,maxchunk=0,source_id		// we need one set of these for each source
	maxcol=min_flag?(inf):(0)
	maxlay=maxcol
	if (dimsize(squirrel_index,1)>8) 	// BUG in 1.50H found by Donna - old code had dimension of 2// Prevents an errant 'inf' from getting too far
		maxchunk=maxcol
	endif
	datacount=0

//  For each data set we need the max col, max layer (really rows and cols)
	source_id=finddimlabel(squirrel_index,2,stringfromlist(p,sourcelist))		/// 1.47E change finddimlabel(squirrel_index,2,stringfromlist(p,sourcelist))  // WRONG! fixed back in 1.47E
	// check all data sets
	for (idex=0;idex<n_source;idex+=1)
		if (source_id[idex]==-2)
			squirrel_error="Source ID "+stringfromlist(idex,sourcelist)+" not found in index  - aborting from squirrel_fetch"
			abort squirrel_error			// 1.44B, harsh, but want to prevent the user from continuing
		endif
		run_id=0
		for (k=0;k<n_runs;k+=1)	// within every run for this data set
			findvalue /s=(run_id)/i=(todo[k]) run_index
			if (v_value==-1)
				findvalue /i=(todo[k]) run_index
			endif
			if (v_value>-1)
				run_id=v_value
				if (min_flag) // reverse the logic. Simples!
					maxcol[idex]=min(maxcol[idex],squirrel_index[run_id][4][source_id[idex]])		// [4] refers to number of rows
					maxlay[idex]=min(maxlay[idex],squirrel_index[run_id][5][source_id[idex]])		// [5] refers to number of columns
					if (dimsize(squirrel_index,1)>8)	// BUG in 1.50H found by Donna - old code had dimension of 2
						maxchunk[idex]=min(maxchunk[idex],squirrel_index[run_id][8][source_id[idex]]) //Q edit
					endif
				else
					maxcol[idex]=max(maxcol[idex],squirrel_index[run_id][4][source_id[idex]])		// [4] refers to number of rows
					maxlay[idex]=max(maxlay[idex],squirrel_index[run_id][5][source_id[idex]])		// [5] refers to number of columns
					if (dimsize(squirrel_index,1)>8)		// BUG in 1.50H found by Donna - old code had dimension of 2
						maxchunk[idex]=max(maxchunk[idex],squirrel_index[run_id][8][source_id[idex]]) //Q edit
					endif
				endif
			endif
		endfor
		datacount+=maxcol[idex]*max(maxlay[idex],1)*max(maxchunk[idex],1)*n_runs*4 //& Assumes single-precision floating point, this is the *4
	endfor
	
	if (datacount == 0)
		squirrel_error="No data from "+sourcelist+" to process  - aborting from squirrel_fetch"		// 1.44B
		abort squirrel_error
	endif		
	acorn_size=min(ceil(n_runs/ceil(datacount/squirrel_maxdata)),floor(squirrel_maxdata*n_runs/datacount))	// all acorns will be of approx same size
	n_acorns=ceil(n_runs/acorn_size)
	sq_ams_stat_upd("Acorn 1/"+num2str(n_acorns),acorns=1)
	setifnotloaded = num_or_def(numberbykey("setifnotloaded",paramstr),0) == -1 ? nan : setifnotloaded
	
//& Perform the fetch and parse
//& This section may be expanded if proper caching is used
	make/free /i/o/n=(acorn_size) acorn_index,acorn_refs
	// acorn_index has the real run numbers in it
	// acorn_refs has the index position.  When the squirrel fetch function is called it is this wave, with the index numbers in it, that is passed to the function
//& Set up the slab wave. This will be changed when we optimise the code. //^ ??
	// recall HDF5 slab definitions
	// slab[][%Start] = 0	// Start at zero for all dimensions
	// slab[][%Stride] = 1	// Use a stride of 1 for all dimensions
	// slab[][%Count] = 1	// Use a count of 1 for all dimensions
	// slab[0][%Block] = 6	// Set block size for the dimension 0 to 6
	// slab[1][%Block] = 5	// Set block size for the dimension 1 to 5
	make/free /o/n=(4,4) hdf5slab
	hdf5slab[][0]=0
	hdf5slab[][1,3]=1
//	make /o/n=(dimsize(squirrel_index,2)) cmp_index		// a temporary wave 'compare index' the looks ahead within the middle of an acorn.  The number of points in this wave should probably be either 5 or 7 (the number of columns in squirrel index), but we at most look at element 3
	make/free /o/n=(dimsize(squirrel_index,1)) cmp_index	//1.58G	// a temporary wave 'compare index' the looks ahead within the middle of an acorn.  The number of points in this wave should probably be either 5 or 7 (the number of columns in squirrel index), but we at most look at element 3
	
//& Retrieve and parse data
	sq_ams_stat_upd("Starting fetch")
	n_todo = numpnts(todo)  //1.58G
	variable n_leftover	//1.58G
	variable numRunsExist=dimsize(squirrel_index, 0)//1.58G
	for (idex=0;idex<n_acorns;idex+=1)		// for each acorn
		acorn_index=-1
		// set the runs that are to be dealt with in this acorn.  Store these runs in acorn_index
		n_leftover=n_todo-(idex)*acorn_size - 1
		acorn_index[0,min(acorn_size-1, n_leftover)]=todo[p+(idex*acorn_size)]		// chunk of runs in todo
		if (idex==n_acorns-1 && n_acorns*acorn_size>n_runs)	// set runs to 0 for the last runs of the last acorn (all acorns are the same size)	
			acorn_index[n_runs-(idex*acorn_size),acorn_size-1]=0
		endif
	
		// set the acorn_refs wave,  which tells the place of the runs of acorn_index, within run_index
		for (j=0;j<acorn_size;j+=1)	// for each run in this acorn
			findvalue /s=(max(acorn_refs[max(0,j-1)],0))/i=(acorn_index[j]) run_index		// JDA fix in 1.42A, // fix in 1.58G
			if (v_value==-1)
				findvalue /i=(acorn_index[j]) run_index
			endif
			acorn_refs[j]=v_value
		endfor
		// go through all source data sets
		for (j=0;j<n_source;j+=1)
			
			// make the data set acorn.  The majority of this function fills in this acorn.
			layflag=maxlay[j]>0		// is this data set 2-dimensional
			chunkflag=maxchunk[j]>0
			//& Need to insert code to steamline whole memory fetches
			acornstr="acorn_"+num2str(j)		// acorn_X is the data set for source X
			//Q including chunk flag to make 4D acorns
			if (chunkflag)
				make /o/n=(acorn_size,min(maxcol[j],max_cl)-min_cl,min(maxlay[j],max_ly)-min_ly,min(maxchunk[j],max_ck)-min_ck) root:hoard:$acornstr
			elseif (layflag)
				make/o/n=(acorn_size,min(maxcol[j],max_cl)-min_cl,min(maxlay[j],max_ly)-min_ly) root:hoard:$acornstr  //& Remake each time in case the calling function changes its size
			else
				make/o/n=(acorn_size,min(maxcol[j],max_cl)-min_cl) root:hoard:$acornstr
			endif
			if (idex==0)		// we change the param string only once, at the first acorn
				paramstr=replacestringbykey("acorn_"+num2str(j),paramstr,"root:hoard:"+acornstr)
			endif
	
			wave acorn=root:hoard:$acornstr
			fastop acorn=0		//1.53CE Paola's SP data where 3 runs had larger max mz
			batch_size=0
			sq_ams_stat_upd("Checking index")
		
			// for every run in this data set, in this acorn, start filling things in			
			for (k=0;k<acorn_size;k+=1)
				load_flag=0
				if (acorn_index[k]>0)		// the run number is >0
					if (acorn_refs[k]==-1)	// the run was not fund in the run_index - should we abort?
						//string /g squirrel_error="Non existent run referenced."
						if (chunkflag)
							acorn[k][][][]=nan		//Q include chunk recognition
						elseif (layflag)
							acorn[k][][]=nan
						else
							acorn[k][]=nan
						endif
					else
//& Perform the data retrieval
						switch (squirrel_index[acorn_refs[k]][0][source_id[j]])		// column 0 in the squirrel index indicates what/where data is
							case 0: // Nonexistent data
								if (chunkflag)
									acorn[k][][][]=nan		//Q include chunk recognition
								elseif (layflag)
									acorn[k][][]=nan
								else
									acorn[k][]=nan
								endif
							break
							case 1: // HDF file	(DAQ hdf files, we never write, we just read)
							case 2: // HDF file (writable)
//& Add the current run to the current batch
								batch_size+=1
//& Initialise batch if it is the first
								if (batch_size==1)
									hdf5slab[0][0]=squirrel_index[acorn_refs[k]][3][source_id[j]]

									maxdim=squirrel_index[acorn_refs[k]][4][source_id[j]]
									
									hdf5slab[1][0]=min(maxdim-1,min_cl)
									hdf5slab[1][3]=min(maxdim,max_cl)-hdf5slab[1][0]
									
									maxdim=squirrel_index[acorn_refs[k]][5][source_id[j]]
									if (maxdim>1)
										hdf5slab[2][0]=min(maxdim-1,min_ly)
										hdf5slab[2][3]=min(maxdim,max_ly)-hdf5slab[2][0]
									endif
									
									maxdim=(dimsize(squirrel_index,1)>8)?(squirrel_index[acorn_refs[k]][8][source_id[j]]):(1)
									if (maxdim>1)
										hdf5slab[3][0]=min(maxdim-1,min_ck)
										hdf5slab[3][3]=min(maxdim,max_ck)-hdf5slab[3][0]
									endif
								endif
//& Check to see if a new batch is needed
								if (k==acorn_size-1 || acorn_refs[k+1]==-1)		// at the end of an acorn?
									load_flag=1
								else		// in the middle of an acorn
									// update cmp_index, which is just one row of the squirrel_index, subtracted by its 'next in line' neighbor
									cmp_index=squirrel_index[acorn_refs[k+1]][p][source_id[j]]-squirrel_index[acorn_refs[k]][p][source_id[j]]
									// recall squirrel_index columns: 0 = does data set exist, 1 = functionID, 2 = data set index within data_index, 3 = run number location within file or hdf 
									if (cmp_index[0]!=0 || cmp_index[1]!=0 || cmp_index[2]!=0)	// have any of the 0,1,2 columns within the squirrel_index changed for the next run?
										load_flag=1
									elseif (batch_size==1)		// we are on the first batch of the intermediate file
										// set hdf5slab[0][1], the starting point of this slab
										if (cmp_index[3]>0)
											hdf5slab[0][1]=cmp_index[3]
										else		// this run lives at the 0th location within this file
											hdf5slab[0][1]=1
											load_flag=1
										endif
									elseif (cmp_index[3]!=hdf5slab[0][1])
										load_flag=1
									endif
								endif
//& Perform a load, if required
								if (load_flag)
//& Open a new file, if required								
									sq_ams_stat_upd("Preparing to load from HDF5 file")
									if (squirrel_index[acorn_refs[k]][1][source_id[j]]!=current_file)
										if (current_file>-1)		// previously opened hdf
											hdf5closefile /z file_id
											if (V_flag !=0)		// 1.47A, there was an error in closing this hdf
												hdf5closefile /z/a file_id
												if (V_flag !=0)		// 	try again, with the /a flag
													Abort "File "+filename+" not successfully closed - aborting from squirrel_fetch"
												endif
											endif
										endif
										current_file=squirrel_index[acorn_refs[k]][1][source_id[j]]
										filename=file_index[current_file]
										if(sq_filecheck(filename,current_file))	// see if file moved
											hdf5openfile/z/r file_id as filename
										else
											v_flag=1
										endif
										if (v_flag!=0)
											squirrel_error="File "+filename+" not opened - aborting from squirrel_fetch"
											Abort  squirrel_error		// 1.43I
										endif
									endif
//& Define hyperslab  This entire if statement could have been preformed at the beginning of the if(load_flag) statement		
									if (hdf5slab[0][1]==1)
										hdf5slab[0][2]=1
										hdf5slab[0][3]=batch_size
									else
										hdf5slab[0][2]=batch_size
										hdf5slab[0][3]=1
									endif
//& Perform load and copy data
									// at this point we should have an hdf file opened, so now load in this slab
									datastr=data_index[squirrel_index[acorn_refs[k]][2][source_id[j]]]
									sq_ams_stat_upd("Loading "+datastr+" from "+stringfromlist(itemsinlist(filename,":")-1,filename,":"))
	//								print "Loading "+datastr+" from "+stringfromlist(itemsinlist(filename,":")-1,filename,":"), datastr, hdf5slab		// if squirrel_index is messed up, the hdfslab values could be wrong.

//									//DONNA
//									duplicate/o hdf5slab hdf5slabDUP
									hdf5loaddata /z/q/slab=hdf5slab/o/n=hdf5load file_id,datastr
								
									//^ this section slightly reordered in 1.42D
									datastrTemp=""
									if (v_flag!=0)		// try one more time for non-autosave hdfs, 1.44A
										HDF5ListGroup file_ID, "/"
										V_flag = 1		// set to non 0 , HDF5List group will set V_flag to 0 if successful		1.46A
										tempVar = WhichListItem(lowerstr(datastr), lowerStr(S_HDF5ListGroup), ";" ,0)		// case insensitive
										if (tempVar>=0 && WhichListItem(lowerStr(datastr), lowerStr(S_HDF5ListGroup), ";" ,0)<0)			// case insensitive
											datastrTemp =StringFromList(tempVar,S_HDF5ListGroup)
											STRUCT HDF5DataInfo dataInfo	// Defined in HDF5 Browser.ipf.
											InitHDF5DataInfo(dataInfo)
											HDF5DatasetInfo(file_ID, selectString(strlen(dataStrTemp)>0, dataStr, dataStrTemp), 0, dataInfo)
											tempVar = dataInfo.dims[0] 
											HDF5DatasetInfo(file_ID, "RunInfo", 0, dataInfo)
											if (dataInfo.dims[0] ==1 && tempVar== hdf5slab[1][3] )
												hdf5loaddata/o/n=hdf5load file_id,selectString(strlen(dataStrTemp)>0, dataStr, dataStrTemp)
												if (v_flag==0)
													wave hdf5load 
													redimension/n=(1,tempVar ) hdf5load
												endif
											endif
										endif
									endif
									if (v_flag!=0)
										squirrel_error="Data "+datastr+" in file "+filename+" not loaded - aborting from squirrel_fetch"
										hdf5closefile /a file_id
										killwaves /z hdf5load
										abort squirrel_error		// 1.44B harsher than print statement, but prevents folks from continuing
									endif

									loadcount+=1	// I don't think this value is ever used
									wave hdf5load

									if (numpnts(hdf5load)<=1)		// fix for one run data set, 1.35
//										print "here is the load ",datastr,  hdf5load, hdf5slab
										hdf5loaddata /z/q/o file_id,selectString(strlen(dataStrTemp)>0, dataStr, dataStrTemp)
										// print V_flag, selectString(strlen(dataStrTemp)>0, dataStr, dataStrTemp)
										wave temp = $datastr
										killwaves hdf5load 
										rename temp hdf5load
										wave hdf5load
										Redimension/N=(1,numpnts(hdf5load)) hdf5load
									endif

									loadcol=min(dimsize(hdf5load,1),maxcol[j])
									loadlay=min(dimsize(hdf5load,2),maxlay[j])
									loadchunk=min(dimsize(hdf5load,3),maxchunk[j])
									loadstart=k-batch_size+1		// k is the index of the run in this acorn.  Indicates what row number we are within this acorn
									
										// Q all these are not-relevant after JDA alteration to dimension acorn appropriately... they just return "setifnotloaded"
										// This should be tidied up, along with the equivalent memory fetch functions
									if (chunkflag)
										multithread acorn[loadstart,k][0,loadcol-1][0,loadlay-1][0,loadchunk-1]=hdf5load[p-loadstart][q][r][s]
//										if (loadcol<maxcol[j])
										//	acorn[loadstart,k][loadcol,maxcol[j]-1][][]=SetIfNotLoaded
//										endif
//										if (loadlay<maxlay[j])
										//	acorn[loadstart,k][][loadlay,maxlay[j]-1][]=SetIfNotLoaded
//										endif
//										if (loadchunk<maxchunk[j])
										//	acorn[loadstart,k][][][loadchunk,maxchunk[j]-1]=SetIfNotLoaded
//										endif
									elseif (layflag) // could possibly be optimised with an imagetransform
										multithread acorn[loadstart,k][0,loadcol-1][0,loadlay-1]=hdf5load[p-loadstart][q][r]
//										if (loadcol<maxcol[j])
										//	acorn[loadstart,k][loadcol,maxcol[j]-1][]=SetIfNotLoaded
//										endif
//										if (loadlay<maxlay[j])
										//	acorn[loadstart,k][][loadlay,maxlay[j]-1]=SetIfNotLoaded
//										endif
									else
										multithread acorn[loadstart,k][0,min(dimsize(acorn,1),loadcol)-1]=hdf5load[p-loadstart][q]		//1.59B
//										if (loadcol<maxcol[j])
										//	acorn[loadstart,k][loadcol,maxcol[j]-1]=SetIfNotLoaded
//										endif
									endif
									sq_ams_stat_upd("Checking index")
									batch_size=0
								endif
							break
							case 3: // In memory
//& Use a trimmed down version of the HDF loader
								sq_ams_stat_upd("Preparing for memory fetch")
								//sq_ams_stat_upd("Preparing memory fetch")
								batch_size+=1
								if (k==acorn_size-1 || acorn_refs[k+1]==-1)
									load_flag=1
								else
									cmp_index=squirrel_index[acorn_refs[k+1]][p][source_id[j]]-squirrel_index[acorn_refs[k]][p][source_id[j]]
									if (cmp_index[0]!=0 || cmp_index[2]!=0)
										load_flag=1
									endif
								endif
								if (load_flag)
									sq_ams_stat_upd("Performing memory fetch")
									wave /z source=$data_index[squirrel_index[acorn_refs[k]][2][source_id[j]]]
									if (!waveexists(source))
										squirrel_error=data_index[squirrel_index[acorn_refs[k]][2][source_id[j]]]+" has been deleted from memory. - aborting from squirrel_fetch"
										abort squirrel_error
									endif
									loadcol=min(dimsize(source,1),maxcol[j])
									loadlay=min(dimsize(source,2),maxlay[j])
									loadchunk=min(dimsize(source,3),maxchunk[j])
									loadstart=k-batch_size+1
									colStart=max(0, min_cl)  //	1.51Q
									make/free /o/n=(k+1) index_tmp = -1
									if (dimsize(squirrel_index,2)>=WaveMax(source_id))
										rowMin = min(min(k, numRunsExist-loadstart-1), dimsize(acorn_refs,0)-loadstart - 1 )// 1.59
										index_tmp[0,rowMin]=squirrel_index[acorn_refs[p+loadstart]][3][source_id[j]]
									else
										abort "Something is wrong in the squirrel_index dimension 2"   //1.58G
									endif
									
									if (chunkflag) // & Can we ditch the setifnotloaded bits from here as well?
										acorn[loadstart,k][0,loadcol-1][0,loadlay-1][0,loadchunk-1]=source[index_tmp[p-loadstart]][q][r][s]
										if (loadcol<maxcol[j])
											acorn[loadstart,k][loadcol,maxcol[j]-1][][]=SetIfNotLoaded
										endif
										if (loadlay<maxlay[j])
											acorn[loadstart,k][][loadlay,maxlay[j]-1][]=SetIfNotLoaded
										endif
										if (loadchunk<maxchunk[j])
											acorn[loadstart,k][][][loadchunk,maxchunk[j]-1]=SetIfNotLoaded
										endif
									elseif (layflag) // Probably could be streamlined
										acorn[loadstart,k][0,loadcol-1][0,loadlay-1]=source[index_tmp[p-loadstart]][q][r]
										if (loadcol<maxcol[j])
											acorn[loadstart,k][loadcol,maxcol[j]-1][]=SetIfNotLoaded
										endif
										if (loadlay<maxlay[j])
											acorn[loadstart,k][][loadlay,maxlay[j]-1]=SetIfNotLoaded
										endif
									else // we have no chunks or layers (i.e. MSSDiff_p in memory)
										acorn[loadstart,k][0,min(loadcol, dimsize(acorn,1))-1]=source[index_tmp[p-loadstart]][q+colStart]		//1.59E
										if (loadcol<maxcol[j])
											acorn[loadstart,k][loadcol,maxcol[j]-1]=SetIfNotLoaded
										endif
									endif
									batch_size=0
								endif
							break
						endswitch		//  end switch = where does this data set live, in DAQ hdf, intermediate HDF, or memory
					endif		// 	end if (acorn_refs[k]==-1)	// the run was not found/found in the run_index

//& No data to load
				else
					if (chunkflag)
						acorn[k][][][]=nan
					elseif (layflag)
						acorn[k][][]=nan
					else
						acorn[k][]=nan
					endif
				endif	// end if (acorn_index[k]>0)		// the run number is >0
				//sq_sqprog_upd(100*(idex+((j+((k+1)/acorn_size))/n_source))/n_acorns)
			
			endfor	// end for (k=0;k<acorn_size;k+=1), going through all the runs in this acorn
			
		endfor		// end for (j=0;j<n_source;j+=1)  going through all the source data sets

//& Call function current acorns are ready
		if (current_file>-1)
			hdf5closefile /z file_id
			if (V_flag !=0)		// 1.47A, there was an error in closing this hdf
				hdf5closefile /z/a file_id
				if (V_flag !=0)		// 	try again, with the /a flag
					Abort "File "+filename+" not successfully closed - aborting from squirrel_fetch"
				endif
			endif
		endif
		current_file=-1
		sq_ams_stat_upd("Calling function...")
		func(acorn_refs,paramstr,idex,n_acorns)
			//Q additional progress bar for acorns
		sq_ams_prog_upd(100*(idex+1)/n_acorns,acorns=1)
		endTime = ((datetime - starttime)*n_acorns/(idex+1))+starttime
		sq_ams_stat_upd("Acorn "+num2str(idex+2)+"/"+num2str(n_acorns)+". End "+secs2time(endTime,2)+" "+secs2date(endTime,0), acorns=1)

	endfor		// end 	for (idex=0;idex<n_acorns;idex+=1)		// for each acorn
	
	// clean up 
	sq_ams_prog_upd(100)
	sq_ams_stat_upd("Done.")
	sq_ams_stat_upd("Done.",acorns=1)
	killwaves /z hdf5load,source_id,maxlay,maxcol,maxchunk,acorn_refs,acorn_index,hdf5slab,cmp_index,index_tmp
	killwaves /z index_pos
	killwaves /z root:hoard:M_SumPlanes, root:hoard:M_Transpose
	for (idex=0;idex<n_source;idex+=1)
		killwaves /z root:hoard:$("acorn_"+num2str(idex))
	endfor
	return loadcount		// I don't think this value is ever used

End
		

//& Write processed data to a read-write HDF file
Function squirrel_hdf_write(index_pos,source,dataname)
	wave index_pos,source
	string dataname
	
	variable squirrel_maxfile=numvarordefault("root:squirrel_maxfile",SQUIRREL_MAXFILE_DEF)
	variable i,n_source,col,lay,chk,source_id,n_index,data_count=0,save_flag,write_start,j,r1,r2
	variable current_file=-1,file_id,k,n_files,data_left,appen_start,data_id,n_data,row_size
	variable journal_pri,journal_row, npts
	string squirrel_error
	string filelist,filename,destname
	struct hdf5datainfo di
		
	wave squirrel_index=root:index:squirrel_index
	wave /t file_index=root:index:file_index
	wave /t data_index=root:index:data_index

	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M

//	temp_file_wave is a text wave created below and lists all the file names with an .hdf extension in the processed file path
	// current_file= the index (row) within the text wave file_index of current hdf file

	//1.49H
	string FilePrefix = SQUIRREL_PROC_PREF
	svar/z IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName
	nvar/z IntermFilePrefix_ck = root:panel:IntermFilePrefix_ck
	if (svar_Exists(IntermPrefixExpFileName) && nvar_Exists(IntermFilePrefix_ck) && IntermFilePrefix_ck )
		FilePrefix = IntermPrefixExpFileName
	endif

	if (dimsize(squirrel_index,1)==6) // Backwards compatibility
		insertpoints /m=1 6, 2, squirrel_index
	endif
	journal_pri=sq_journal_isprimary(dataname)
	journal_row=sq_journal_current()

	inithdf5datainfo(di)

// Find the data set id  //& Create a new squirrel entry if it does not already exist	
	source_id=finddimlabel(squirrel_index,2,dataname)
	if (source_id==-2)
		source_id=dimsize(squirrel_index,2)
		insertpoints /m=2 source_id,1, squirrel_index
		setdimlabel 2,source_id,$dataname,squirrel_index
	else
//& If it already exists, make sure it is identical to the saved label (HDF is caps sensitive)
		dataname=getdimlabel(squirrel_index,2,source_id)
//& Prevent the indexing of data that already exists in a file
		i=0
		n_index=dimsize(squirrel_index,0)
//1.47D	normally this is a good idea, but in 1.47 we allow for the ability of the user to move the MSSDiff_p matrix to memory and visa versa
//		do
//			if (squirrel_index[i][0][source_id]==2)
//				break
//			elseif (squirrel_index[i][0][source_id]!=0)
//				Abort dataname+" already exists in another location. File write abort."
//			endif
//		i+=1
//		while (i<n_index)
	endif
	
//& Check the destination folder and its contents
//	sq_ams_stat_upd("Checking path for intermediate data")
//	string /g processed_path
//	if (strlen(processed_path)>0)
//		newpath /o/z/q proc_path, processed_path
//	endif
//	if (v_flag!=0 || strlen(processed_path)==0)	// we need a path for processed files
//		newpath /o/z/q/m="Path for intermediate data" proc_path
//		if (v_flag!=0)
//			Abort "No output path was selected - write aborted"
//		endif
//		pathinfo proc_path		//^
//		string tempPath=s_path
//		pathinfo hdfdirpath
//		if (stringmatch(s_path, tempPath)==1)		//^ users get one chance to change their mind.
////			newpath /o/z/q/m="It is not advisable to use the same directory for the hdf and intermediate files.  Select a path for intermediate data" proc_path
////			if (v_flag!=0)
////				Abort "No output path was selected - write aborted"
////			endif
//		endif
//		pathinfo proc_path		//^
//		processed_path=s_path	
//	endif
	sq_SetProcessedPaths()
	svar processed_path = root:processed_path
	
	//  get text wave of all  files in the processed folder that we care about, temp_file_wave
	filelist=indexedfile(proc_path,-1,"."+HdfFileExtension)
	make/free/o/n=(itemsinlist(filelist))/t temp_file_wave=stringfromlist(p,filelist)
	i=0
	if (itemsinlist(filelist)>0)  //1.61B
		do
			if (strsearch(temp_file_wave[i],FilePrefix,0)>-1)		//1.49H
				i+=1
			else		// if this file does not have the prefix AMS_intermediate... delete it from this list
				deletepoints i,1,temp_file_wave
			endif
		while (i<numpnts(temp_file_wave))	
		sort temp_file_wave,temp_file_wave
	endif
	
//& Peform the write
	n_source=dimsize(source,0)
	col=dimsize(source,1)
	lay=dimsize(source,2)
	chk=dimsize(source,3)	//Q adding for 4D-aware writing
	row_size=col*max(lay,1)*max(chk,1)*4
	//row_size=col*max(lay,1)*4 // Bytes per row
	
	// recall HDF5 slab definitions
	// slab[][%Start] = 0	// Start at zero for all dimensions
	// slab[][%Stride] = 1	// Use a stride of 1 for all dimensions
	// slab[][%Count] = 1	// Use a count of 1 for all dimensions
	// slab[0][%Block] = 6	// Set block size for the dimension 0 to 6
	// slab[1][%Block] = 5	// Set block size for the dimension 1 to 5
//	make /o/n=(3,4) hdf5slab_w		// we put a _w suffix on it to distinguish it from any hdf5slab wave that may have been created in a squirrel fetch function
	make/free/o/n=(4,4) hdf5slab_w	//Q 4D
	hdf5slab_w[1,3][0]=0	//Q 4D betaR1
	hdf5slab_w[1,3][1,2]=1	//Q 4D betaR1
	hdf5slab_w[1][3]=col
	hdf5slab_w[2][3]=max(lay,1)
	hdf5slab_w[3][3]=max(chk,1)	// Q 4D
	
	make/free/o/n=6 cmp_index_w		// a temporary wave 'compare index' the looks ahead within the middle of an acorn.  The number of points in this wave should probably be either 5 or 7 (the number of columns in squirrel index), but we at most look at element 3

	sq_ams_stat_upd("Processing data to save")
	for (i=0;i<n_source;i+=1)		// for all source data sets
		save_flag=0
		if (index_pos[i]<0)
			continue
		endif
		r1=index_pos[min(i+1,n_source-1)]		//1.58G
		r2=index_pos[i]
//& Check to see if the end of a save batch has been reached
		data_count+=1
		if (i==n_source-1 || r1<0)
			save_flag=1
		else
			cmp_index_w=squirrel_index[r1][p][source_id]-squirrel_index[r2][p][source_id]
			if (cmp_index_w[0]!=0 || (squirrel_index[r2][0][source_id]==2 && (cmp_index_w[1]!=0 || cmp_index_w[2]!=0 || cmp_index_w[3]<1)))// || cmp_index_w[4]!=0 || cmp_index_w[5]!=0)))
				save_flag=1
			endif
		endif
		if (save_flag)
			write_start=i+1-data_count
			data_count=0
//			if(squirrel_index[index_pos[i]][0][source_id]==2 && squirrel_index[index_pos[i]][4][source_id]==col && squirrel_index[index_pos[i]][5][source_id]==lay)
				// Q replace with 4D version:
			if(squirrel_index[index_pos[i]][0][source_id]==2 && squirrel_index[index_pos[i]][4][source_id]==col && squirrel_index[index_pos[i]][5][source_id]==lay && (chk==0 ||squirrel_index[index_pos[i]][8][source_id]==chk))
					//& Overwrite existing data in an HDF file - works only if there is currently a run indexed and its columns and layers match the source data
				sq_ams_stat_upd("Preparing to overwrite existing data")
				for (j=write_start;j<=i;j+=1)
					save_flag=0
					data_count+=1
					if (journal_pri)
						squirrel_index[index_pos[j]][6][source_id]=journal_row
						squirrel_index[index_pos[j]][7][source_id]=0
					else
						squirrel_index[index_pos[j]][7][source_id]=journal_row
					endif
					if (j==i)
						save_flag=1
						if (data_count==1)
							hdf5slab_w[0][1]=1
						endif
					else
						r1=index_pos[j+1]
						r2=index_pos[j]
						cmp_index_w=squirrel_index[r1][p][source_id]-squirrel_index[r2][p][source_id]
						if (data_count==1)
							hdf5slab_w[0][1]=cmp_index_w[3]
						elseif (cmp_index_w[3]!=hdf5slab_w[0][1])
							save_flag=1
						endif
					endif
					if (save_flag)
//& Define hyperslab
						hdf5slab_w[0][0]=squirrel_index[index_pos[j+1-data_count]][3][source_id]
						if (hdf5slab_w[0][1]==1)
							hdf5slab_w[0][2]=1
							hdf5slab_w[0][3]=data_count
						else
							hdf5slab_w[0][2]=data_count
							hdf5slab_w[0][3]=1
						endif
//& Make a temporary wave of the subset of data to be saved
						if (chk>0)	// Q 4D
							make/free/o/n=(data_count,col,lay,chk) save_tmp=source[p+j+1-data_count][q][r][s]
						elseif (lay>0)	// Q 4D
							make/free/o/n=(data_count,col,lay) save_tmp=source[p+j+1-data_count][q][r]
						else
							make/free/o/n=(data_count,col) save_tmp=source[p+j+1-data_count][q]
						endif
//& Open the existing file and save the data accordingly
						if (current_file!=squirrel_index[index_pos[j]][1][source_id])
							if (current_file!=-1)
								hdf5closefile /z file_id
								if (V_flag !=0)		// 1.47A, there was an error in closing this hdf
									hdf5closefile /z/a file_id
									if (V_flag !=0)		// 	try again, with the /a flag
										Abort "File "+filename+" not successfully closed - aborting from squirrel_fetch"
									endif
								endif
							endif
							current_file=squirrel_index[index_pos[j]][1][source_id]
							filename=file_index[current_file]
							if (sq_filecheck(filename,current_file))
								hdf5openfile/z file_id as filename
							else
								v_flag=1
							endif
							if (v_flag!=0)
								squirrel_error="File "+file_index[current_file]+" not opened for overwriting.  - aborting from squirrel_fetch"
								abort squirrel_error		// 1.44B harsher, but prevents folks from continuing
							endif
						endif
						sq_ams_stat_upd("Overwriting data")
						hdf5savedata /slab=hdf5slab_w/z save_tmp, file_id, data_index[squirrel_index[index_pos[j]][2][source_id]]
						if (v_flag!=0)		//1.09F
							squirrel_error="Data "+data_index[squirrel_index[index_pos[j]][2][source_id]]+" in file "+ParseFilePath(0, file_index[current_file], ":", 1, 0)+" not overwritten.  - aborting from squirrel_fetch"
							abort squirrel_error		// 1.44B harsher, but prevents folks from continuing
						endif
						data_count=0
					endif
				endfor
			else
//& Save as new data within files
				sq_ams_stat_upd("Preparing to write as new data")
				do
					if (current_file>-1)
//& Is the currently open file suitable? If not, close
						filename=file_index[current_file]
						getfilefolderinfo /q/z filename		// sets v_logeof
						if (v_flag!=0 || squirrel_maxfile<v_logeof+(SQUIRREL_CHUNKSIZE*row_size))
							hdf5closefile /z file_id
							current_file=-1
							if (V_flag !=0)		// 1.47A, there was an error in closing this hdf
								hdf5closefile /z/a file_id
								if (V_flag !=0)		// 	try again, with the /a flag
									Abort "File "+filename+" not successfully closed - aborting from squirrel_fetch"
								endif
							endif
						endif
					endif
					if (current_file==-1)
//& New file needs to be opened
						if (numpnts(temp_file_wave)>0)
							npts = numpnts(temp_file_wave)-1
							filename=processed_path+temp_file_wave[npts]
//& Check last file in directory. If it is in the index and has room left, open.
							n_files=numpnts(file_index)
							for (k=0;k<n_files;k+=1)
								if (cmpstr(file_index[k],filename)==0)
									getfilefolderinfo /q/z filename
									if (v_flag==0 && squirrel_maxfile>v_logeof+(SQUIRREL_CHUNKSIZE*row_size))
										current_file=k
										hdf5openfile /z file_id as filename
										if (v_flag!=0)
											squirrel_error=filename+" not opened for appending  - aborting from squirrel_fetch"
											Abort squirrel_error
										endif
									elseif (v_flag!=0)
										squirrel_error=filename+" acess problem. - aborting from squirrel_fetch - aborting from squirrel_fetch"
										Abort squirrel_error
									endif
									break
								endif
							endfor
						endif
						if (current_file==-1)
//& File still not open - generate unique name and create
							k=0
							do
								sprintf filename,(processed_path+FilePrefix+"%.6u."+HdfFileExtension),k		//1.49H
								getfilefolderinfo /q/z filename
								if (v_flag!=0)
									n_files=(numpnts(file_index))
									current_file=0
									do
										if (cmpstr(file_index[current_file],filename)==0)
											break
										endif
										current_file+=1
									while(current_file<n_files)
									hdf5createfile /z file_id as filename
									if (v_flag!=0)
										squirrel_error=filename+" not created for writing - aborting from squirrel_fetch"
										Abort squirrel_error
									endif
									if (current_file==n_files)
										insertpoints current_file,1,file_index
										file_index[current_file]=filename
									endif
								break
								endif
								k+=1
							while(1)
						endif
					endif
//& Dump in as much data as the file can hold
					getfilefolderinfo /q/z filename
					if (v_flag!=0)
						squirrel_error=filename+" EOF not fetched - aborting from squirrel_fetch"
						Abort squirrel_error
					endif						
					data_left=max(squirrel_maxfile-v_logeof,row_size)
					j=min(write_start+floor(data_left/row_size)-1,i) // The endpoint in the write chunk
//& Make temporary save waves
					if (chk>0)
						make/free/o/n=(j-write_start+1,col,lay,chk) save_tmp=source[p+write_start][q][r][s]	//Q 4D
					elseif (lay>0)// Q 4D
						make/free/o/n=(j-write_start+1,col,lay) save_tmp=source[p+write_start][q][r]
					else
						make/free/o/n=(j-write_start+1,col) save_tmp=source[p+write_start][q]
					endif
					destname=dataname
					appen_start=0
//& Search for any waves of the same name. If the same size, append, otherwise create a new one
// NOT BULLETPROOF
					hdf5listgroup /f/r/type=2 file_id,"/"
					if (whichlistitem("/"+destname,s_hdf5listgroup)>-1)
						k=-1
						do
							hdf5datasetinfo (file_id, destname, 1, di)
							if (col==di.dims[1] && lay==di.dims[2] && chk==di.dims[3])	// Q 4D
								appen_start=di.dims[0]
								break
							endif
							k+=1
							destname=dataname+"_"+num2str(k)
							if (whichlistitem("/"+destname,s_hdf5listgroup)==-1)
								break
							endif
						while (1)
					endif
//& Find the position of the data index of the data. If it doesn't exist, create it.
					n_data=numpnts(data_index)
					data_id=-1
					for (k=0;k<n_data;k+=1)
						if (cmpstr(destname,data_index[k])==0)
							data_id=k
							break
						endif
					endfor
					if (data_id==-1)
						insertpoints n_data,1,data_index
						data_index[n_data]=destname
						data_id=n_data
					endif
//& Perform the save
					sq_ams_stat_upd("Writing as new data")
					if (appen_start>0)
						hdf5savedata/z/apnd=0 save_tmp, file_id, destname
					elseif (chk>0)
						hdf5savedata/GZIP={9,0} /z/layo={2,SQUIRREL_CHUNKSIZE,col,lay,chk}/maxd={-1,col,lay,chk} save_tmp,file_id,destname			// Q 4D			
					elseif (lay>0)	// 1.44B change to add GZIP
						hdf5savedata/GZIP={9,0} /z/layo={2,SQUIRREL_CHUNKSIZE,col,lay}/maxd={-1,col,lay} save_tmp,file_id,destname
					else
						hdf5savedata/GZIP={9,0} /z/layo={2,SQUIRREL_CHUNKSIZE,col}/maxd={-1,col} save_tmp,file_id,destname
					endif
					if (v_flag!=0)
						 squirrel_error=destname+" not written to file "+filename+"  - aborting from squirrel_fetch"
						hdf5closefile /z/a file_id	// 1.47A addition of /a flag
						Abort squirrel_error
					endif
//& Update the index
					for (k=write_start;k<=j;k+=1)
						squirrel_index[index_pos[k]][0][source_id]=2
						squirrel_index[index_pos[k]][1][source_id]=current_file
						squirrel_index[index_pos[k]][2][source_id]=data_id
						squirrel_index[index_pos[k]][3][source_id]=appen_start+k-write_start
						squirrel_index[index_pos[k]][4][source_id]=col
						squirrel_index[index_pos[k]][5][source_id]=lay
						if (journal_pri)
							squirrel_index[index_pos[k]][6][source_id]=journal_row
							squirrel_index[index_pos[k]][7][source_id]=0
						else
							squirrel_index[index_pos[k]][7][source_id]=journal_row
						endif
						if (dimsize(squirrel_index,1) >=9)		//1.58G
							squirrel_index[index_pos[k]][8][source_id]=chk	//Q 4D
						endif
					endfor
					write_start=j+1
//& Loop until all data have been saved
				while (write_start<i)
			endif
		endif
	endfor
	
	if (current_file>-1)
		hdf5closefile /z file_id
		if (V_flag !=0)		// 1.47A, there was an error in closing this hdf
			hdf5closefile /z/a file_id
			if (V_flag !=0)		// 	try again, with the /a flag
				Abort "File "+filename+" not successfully closed - aborting from squirrel_fetch"
			endif
		endif
		current_file=-1
	endif
	killwaves /z save_tmp,cmp_index_w,hdf5slab_w
	killwaves/z temp_file_wave

End


//& Write to memory and update index
Function squirrel_mem_write(index_pos,source,dataname,deststr)
	wave index_pos,source // Index positions (as is passed to calling functions) and data wave
	string dataname,deststr // Name of data type (as used in the index) and a name for the destination wave
	
	wave squirrel_index=root:index:squirrel_index
	wave /t data_index=root:index:data_index

	variable source_id,dest_id=-1,n_data,idex,n_source,col,lay
	variable old_col,old_lay,n_new=0,old_size,index_flag=0,n_index,journal_pri,journal_row	
	string squirrel_error
		
	n_source=numpnts(index_pos)
	col=dimsize(source,1)
	lay=dimsize(source,2)
	
	if (dimsize(squirrel_index,1)==6) // Backwards compatibility
		insertpoints /m=1 6, 2, squirrel_index
	endif
	journal_pri=sq_journal_isprimary(dataname)
	journal_row=sq_journal_current()
	
//& Create a new squirrel entry if it does not already exist	
	source_id=finddimlabel(squirrel_index,2,dataname)
	sq_ams_stat_upd("Preparing for memory write")
	if (source_id==-2)
		source_id=dimsize(squirrel_index,2)
		insertpoints /m=2 source_id,1, squirrel_index
		setdimlabel 2,source_id,$dataname,squirrel_index
	else
		dataname=getdimlabel(squirrel_index,2,source_id)
//& Prevent the indexing of data that already exists in a file
		idex=0
		n_index=dimsize(squirrel_index,0)
//1.47D	normally this is a good idea, but in 1.47 we allow for the ability of the user to move the MSSDiff_p matrix to memory and visa versa
//		do
//			if (squirrel_index[idex][0][source_id]==3)
//				break
//			elseif (squirrel_index[idex][0][source_id]!=0)
//				squirrel_error=(dataname+" already exists in another location. Memory write will take place but will not be indexed.")
//				abort squirrel_error		//1.44B harsher, but prevents the user from pretending nothing is wrong
//				index_flag=1
//				break
//			endif
//			idex+=1
//		while (idex<n_index)
	endif
//& See if the data index entry already exists or not
	n_data=numpnts(data_index)
	for (idex=0;idex<n_data;idex+=1)
		if (cmpstr(data_index[idex],deststr)==0)
			dest_id=idex
			break
		endif
	endfor
	if (dest_id==-1)
		insertpoints n_data,1, data_index
		data_index[n_data]=deststr
		dest_id=n_data
	endif
	wave /z dest=$deststr
	
//1.47D
	make/Free/o/n=(n_source) temp_index = index_pos[p]>=0 ? squirrel_index[index_pos[p]][3][source_id] : -1		//1.58G
	variable NeeedRows = Wavemax(temp_index)
	
	if (!waveexists(dest))
//& Destination doesn't already exist
		sq_ams_stat_upd("Dumping to "+deststr+" to memory as new wave")
		if (!index_flag)
			idex=0
			do
				if (index_pos[idex]>-1)
					squirrel_index[index_pos[idex]][0][source_id]=3
					squirrel_index[index_pos[idex]][2][source_id]=dest_id
					squirrel_index[index_pos[idex]][3][source_id]=idex
					squirrel_index[index_pos[idex]][4][source_id]=col
					squirrel_index[index_pos[idex]][5][source_id]=lay
					if (journal_pri)
						squirrel_index[index_pos[idex]][6][source_id]=journal_row
						squirrel_index[index_pos[idex]][7][source_id]=0
					else
						squirrel_index[index_pos[idex]][7][source_id]=journal_row
					endif
					idex+=1
				else
					deletepoints idex,1,index_pos
					deletepoints /m=0 idex,1,source
				endif
			while (idex<numpnts(index_pos))
		endif
		duplicate source,$deststr
	else
//& Destination already exists
		wave dest=$deststr
		old_size=dimsize(dest,0)
		old_col=dimsize(dest,1)
		old_lay=dimsize(dest,2)
//& Harmonise col and layers wave dimensions
		sq_ams_stat_upd("Checking sizes of waves")
		if (col>old_col)
			insertpoints /m=1 old_col,col-old_col,dest
			if (lay>0)
				dest[][old_col,col-1][]=0//nan
			else
				dest[][old_col,col-1]=0//nan
			endif
			for (idex=0;idex<n_index;idex+=1)
				if (squirrel_index[idex][0][source_id]==3 && squirrel_index[idex][2][source_id]==dest_id)
					squirrel_index[idex][4][source_id]=col
				endif
			endfor
		elseif (old_col>col)
			insertpoints /m=1 col,old_col-col,source
			if (lay>0)
				source[][col,old_col-1][]=0//nan
			else
				source[][col,old_col-1]=0//nan
			endif
		endif
		if (lay>old_lay)
			insertpoints /m=2 old_lay,lay-old_lay,dest
			dest[][][old_lay,lay-1]=0//nan
			for (idex=0;idex<n_index;idex+=1)
				if (squirrel_index[idex][0][source_id]==3 && squirrel_index[idex][2][source_id]==dest_id)
					squirrel_index[idex][5][source_id]=lay
				endif
			endfor
		elseif (old_lay>lay)
			insertpoints /m=2 lay,old_lay-lay,source
			source[][][lay,old_lay-1]=0//nan
		endif
		
		// our destination wave already exists and possible columns and layers have been redimensioned properly
		col=max(old_col,col)
		lay=max(old_lay,lay)
		make/free/o/n=(n_source) append_tmp
		sq_ams_stat_upd("Writing to memory")

//		go through all rows (runs in their acorn)
		for (idex=0;idex<n_source;idex+=1)
			if (index_pos[idex]<0)			//^ Originally index_pos<0
				continue
			endif
			if (squirrel_index[index_pos[idex]][2][source_id]==dest_id && ( dimsize(dest,0) > squirrel_index[index_pos[idex]][3][source_id] ))	//1.47D modification starting at && dimsize...
//& Overwrite existing				
				if (lay>0)
					dest[squirrel_index[index_pos[idex]][3][source_id]][][]=source[idex][q][r]
				else
					dest[squirrel_index[index_pos[idex]][3][source_id]][]=source[idex][q]
				endif
				if (journal_pri)
					squirrel_index[index_pos[idex]][6][source_id]=journal_row
					squirrel_index[index_pos[idex]][7][source_id]=0
				else
					squirrel_index[index_pos[idex]][7][source_id]=journal_row
				endif
			else
//& Append new, via a to-do list
				append_tmp[n_new]=idex
				if (!index_flag)
					squirrel_index[index_pos[idex]][0][source_id]=3
					squirrel_index[index_pos[idex]][2][source_id]=dest_id
					squirrel_index[index_pos[idex]][3][source_id]=old_size+n_new
					squirrel_index[index_pos[idex]][4][source_id]=col
					squirrel_index[index_pos[idex]][5][source_id]=lay
					if (journal_pri)
						squirrel_index[index_pos[idex]][6][source_id]=journal_row
						squirrel_index[index_pos[idex]][7][source_id]=0
					else
						squirrel_index[index_pos[idex]][7][source_id]=journal_row
					endif
				endif
				n_new+=1
			endif
		endfor
//& Perform the append, if required
		if (n_new>0)
			sq_ams_stat_upd("Expanding exisiting "+deststr)
			insertpoints /m=0 old_size,n_new,dest
			if (lay>0)
				dest[old_size,old_size+n_new-1][][]=source[append_tmp[p-old_size]][q][r]
			else
				dest[old_size,old_size+n_new-1][]=source[append_tmp[p-old_size]][q]
			endif
		endif
		killwaves /z append_tmp
	endif
End


//& Delete obsolete HDF read-write files
Function squirrel_tidyHDF()

	wave /t file_index=root:index:file_index
	wave squirrel_index=root:index:squirrel_index

	string squirrel_error
	variable rows=dimsize(squirrel_index,0),num=numpnts(file_index),idex

	make/free/i/o/n=(rows*dimsize(squirrel_index,2)) tidy_tmp=squirrel_index[mod(p,rows)][1][floor(p/rows)]

	string FilePrefix = SQUIRREL_PROC_PREF
	svar/z IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName
	nvar/z IntermFilePrefix_ck = root:panel:IntermFilePrefix_ck
	if (svar_Exists(IntermPrefixExpFileName) && nvar_Exists(IntermFilePrefix_ck) && IntermFilePrefix_ck )
		FilePrefix = IntermPrefixExpFileName
	endif

	for (idex=0;idex<num;idex+=1)
//& Look for the read/write prefix and check for a reference
		if (strsearch(stringfromlist(itemsinlist(file_index[idex],":")-1,file_index[idex],":"),FilePrefix,0,2)==0)		//1.49H
			findvalue /z/i=(idex) tidy_tmp
			if (v_value==-1)
				deletefile /z file_index[idex]
				if (v_flag!=0)
					squirrel_error="File "+file_index[idex]+" not deleted. - aborting from squirrel_tidyHDF"
					abort squirrel_error
				else
					print file_index[idex]+" deleted"
				endif
			endif
		endif
	endfor
	killwaves /z tidy_tmp
end


//& Add a new entry to the journal. To be called once  per button press
Function sq_journal_new(operationstr)
	string operationstr
	
	string newentry
	variable p1
	
	wave /z/t squirrel_journal=root:index:squirrel_journal
	
	if (!waveexists(squirrel_journal))
		make /t/n=1 root:index:squirrel_journal
		wave /t squirrel_journal=root:index:squirrel_journal
	endif
	
	sprintf newentry, "Operation:%s;T_Start:%u;",operationstr,datetime
	
	p1=numpnts(squirrel_journal)
	insertpoints p1,1,squirrel_journal
	squirrel_journal[p1]=newentry

End


//& Put a finish timestamp in the current journal entry. To be called at the end of a button press.
Function sq_journal_end()

	string timestamp
	wave /t squirrel_journal=root:index:squirrel_journal
	variable p1=sq_journal_current()
	
	sprintf timestamp, "%u", datetime
	
	squirrel_journal[p1]=replacestringbykey("T_Finish",squirrel_journal[p1],timestamp)

End
	

//& Add some items to the last entry in the journal, overwriting if needs be
Function sq_journal_add(items)
	string items
	
	variable p1,p2,i,n
	string item,kw,value
	
	wave /t squirrel_journal=root:index:squirrel_journal
	n=itemsinlist(items)
	p1=sq_journal_current()
	
//& Force new entry if the current one has already been declared finished
	if (strlen(stringbykey("T_Finish",squirrel_journal[p1]))>0)
		sq_journal_new("Unknown")
		p1=sq_journal_current()
	endif
	for (i=0;i<n;i+=1)
		item=stringfromlist(i,items)
		p2=strsearch(item,":",1)
		if (p2>0)
			kw=item[0,p2-1]
			value=item[p2+1,strlen(item)-1]
			squirrel_journal[p1]=replacestringbykey(kw,squirrel_journal[p1],value)
		endif
	endfor
End


//& Current journal entry
Function sq_journal_current()

	wave /t squirrel_journal=root:index:squirrel_journal
	return numpnts(squirrel_journal)-1

End


//& Is the current journal entry a primary creation of data, or a secondary modification?
Function sq_journal_isprimary(datatype)
	string datatype
	
	wave /t squirrel_journal=root:index:squirrel_journal
	return numberbykey("Secondary("+datatype+")",squirrel_journal[sq_journal_current()])!=1

End


//& Add the contents of a global variable or string to the journal
Function sq_journal_add_var(varname)
	string varname
	
	string var_id=stringfromlist(itemsinlist(varname,":")-1,varname,":")+":"
	nvar /z var_n=$varname
	svar /z var_s=$varname
	
	if (nvar_exists(var_n))
		sq_journal_add(var_id+num2str(var_n))
	elseif (svar_exists(var_s))
		sq_journal_add(var_id+var_s)
	endif
end


//& Returns num1 if num1 is real or num2 if it isn't.
Function num_or_def(isThisReal,GetThisIfNot)
	variable isThisReal,GetThisIfNot
	return (!numtype(isThisReal))?(isthisreal):(getthisifnot)
end