#pragma TextEncoding = "Windows-1252"
#pragma rtGlobals=3		// Use modern global access method.
//#pragma version=1.17d// decided to not use pragma but a string constant 

//ToF-AMS data processing kit for ToF-AMS analysis Toolkit
//Copyright (C) 2005, 2006, 2007,2008, 2009,2010,2011, 2012, 2013, 2014, 2015, 2016, 2017
//James Allan (SEAES, University of Manchester, UK; DIAC, NCAS, UK)
//Jonathan Crosier (SEAES, University of Manchester, UK)
//Edward Dunlea (CIRES, University of Colorado at Boulder, CO, USA)
//Donna Sueper (CIRES, University of Colorado at Boulder, CO, USA; Aerodyne Research Inc., MA, USA)
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

///////////////////////////////////////////////////////////////////////////////
// CURRENT STATUS
// see Read me file for details.


//STRING CONSTANTS that users may wish to change
STRCONSTANT FD_STANDARD_LIST = "SO4;NO3;ORG;NH4;CHL;Water;NH4_16;NH4_17;SO4_48;SO4_64;SO4_80;SO4_81;SO4_98;NO3_30;NO3_46;Org43;Org44;Org57"
STRCONSTANT FD_DIAGNOSTICS_LIST = "All;NH4;SO4;NO3;Org;Water_vs_Inorg;Org_vs_SO4;NO3_vs_Org;"	//;MassTrend
STRCONSTANT FD_COLORBY_LIST = "Time;Ammonium;Sulfate;Nitrate;Organics;Org/SO4;Water/SO4;NO3/SO4;NH4/SO4;NH4/NO3"
STRCONSTANT FD_COLORWAVES_LIST="root:index:t_series;root:quantifChecks:NH4;root:quantifChecks:SO4;root:quantifChecks:NO3;root:quantifChecks:ORG;root:quantifChecks:ratio_O_S;root:quantifChecks:ratio_W_S;root:quantifChecks:ratio_N_S;root:quantifChecks:ratio_A_S;root:quantifChecks:ratio_A_N"


// The idea is that the nonsmoothed values are found once, and are not calced again.  
// But the smoothed waves, which are the ones plotted, get smoothed every time one generates a plot


// gold button in squirrel panel.  generates many time series waves for future plotting and frag wave checking
Function FD_butt_CalcBatch(ctrlName) : ButtonControl
	string ctrlName
	
	sq_GetIndexNotDoneYet()
	// check added in 1.41A
	nvar ams_time_saved = root:panel:ams_time_saved
	if (ams_time_saved!=1)
		abort "The frag checks should be done using the original time base. aborting from FD_butt_CalcBatch"
	endif
	
	if (FindDimLabel(root:index:squirrel_index, 2, "MSSDiff_p") <0)		// fix in 1.47I
		abort "You must press get index and preprocess MSS data before proceeding. aborting from FD_butt_CalcBatch"
	endif
	
	FD_Check_batch()				// possibly add some 'species' in the batch table
	FD_MakeLines()					// makes 1-to-1 lines and others for graphs 
	FD_GenerateFragTrends()			// generates time series species waves
	FD_MakeRatios()					// makes some useful ratios for plotting, must have calculated the batch list first

	fc_calcPredictNH4()
	fc_FindWaveMedians()		//1.51N

	string df = GetDataFolder(1)		// 1.55D
	SetDataFolder root:ms_mats
	killwaves/a/z
	SetDataFolder $df
End


// right-ish button for plotting individual misc correlation plots
Function FD_butt_CorrelationPlot(ctrlName) : ButtonControl
	string ctrlName

	//y-axis
	controlinfo/w=ams_panel fDiag_popup_yaxis
	if (stringmatch(S_value,"t_series"))
		wave y_axis = root:index:t_series
	else
		wave/z y_axis = $"root:quantifChecks:"+S_value
		if (!waveExists(y_axis))
			abort "There is no wave of the name root:quantifChecks:"+S_Value+" Perhaps you need to press the gold calculate button?  aborting from FD_butt_CorrelationPlot"
		endif
	endif
	//x-axis
	controlinfo/w=ams_panel fDiag_popup_xaxis
	if (stringmatch(S_value,"t_series"))
		wave x_axis = root:index:t_series
	else
		wave/z x_axis = $"root:quantifChecks:"+S_value
		if (!waveExists(x_axis))
			abort "There is no wave of the name root:quantifChecks:"+S_Value+" Perhaps you need to press the gold calculate button?  aborting from FD_butt_CorrelationPlot"
		endif
	endif
	//z-axis
	controlinfo/w=ams_panel fDiag_popup_zaxis
	if (stringmatch(S_value,"t_series"))
		wave z_axis = root:index:t_series
	else
		wave/z z_axis = $"root:quantifChecks:"+S_value
		if (!waveExists(z_axis))
			abort "There is no wave of the name root:quantifChecks:"+S_Value+" Perhaps you need to press the gold calculate button?  aborting from FD_butt_CorrelationPlot"
		endif
	endif
	
	//Make Plot
	display y_axis vs x_axis
	ModifyGraph mode=3,marker=19
	ModifyGraph fSize=14,font="Arial"
	Label bottom NameOfWave(x_axis) +" g/m3"
	Label left NameOfWave(y_axis)+" g/m3"
	ModifyGraph zColor($NameOfWave(y_axis))={$GetWavesDataFolder(z_axis, 2),*,*,Rainbow}
	ColorScale/C/N=text0/A=RC/E trace=$NameOfWave(y_axis)
	ColorScale/C/N=text0/A=RC/E NameOfWave(z_axis)
	
	wavestats/q/m=1 y_axis
	if (V_min < 0)
		SetAxis/A/E=0 left
		ModifyGraph zero(left)=1
	else
		SetAxis/A/E=1 left
	endif
	
	wavestats/q/m=1 x_axis
	if (V_min < 0)
		SetAxis/A/E=0 bottom
		ModifyGraph zero(bottom)=1
	else
		SetAxis/A/E=1 bottom
	endif
	ColorScale/C/N=text0/X=0.00/Y=5.00 width=10,lblMargin=0
	ColorScale/C/N=text0 heightPct=100,tickLen=4.00
	ModifyGraph standoff=0
	
End


// the left-ish button on squirrel panel for plotting one or all of the standard frag diagnostic plots
Function FD_butt_CalcDiags(ctrlName) : ButtonControl
	String ctrlName
		
	sq_GetIndexNotDoneYet()
	nvar fDiag_smth = root:panel:fDiag_smth
	nvar fDiag_ChooseDiagnostics = root:panel:fDiag_ChooseDiagnostics
	nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
	
	// we need to recheck the values of fDiag_ChooseDiagnostics and fDiag_ColorDiags
	ControlInfo/W=ams_panel fDiag_ColorDiags
	fDiag_ColorDiags = V_Value-1
	ControlInfo/W=ams_panel fDiag_ChooseDiagnostics
	fDiag_ChooseDiagnostics = V_Value-1

	string colorWaveStr=stringfromlist(fDiag_ColorDiags, FD_COLORWAVES_LIST)
	string colorByStr=stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)		// obsolete?

	wave/z colorWave = $colorWaveStr
	if (!waveexists(colorWave) )
		abort "You colorByStr first generate the ms time series waves for relevant species via the orange button.  Aborting from FD_butt_CalcDiags"
	endif
		
	//STRCONSTANT FD_DIAGNOSTICS_LIST = "All;NH4;SO4;NO3;Org;Water_vs_Inorg;Org_vs_SO4;NO3_vs_Org;"	
	switch(fDiag_ChooseDiagnostics)
	case 0:
		FD_CalcPlot_Ammonium(fDiag_smth, colorWave)
		FD_CalcPlot_Sulfate(fDiag_smth, colorWave)
		FD_CalcPlot_Nitrate(fDiag_smth, colorWave)	
		FD_CalcPlot_Organics(fDiag_smth, colorWave)
		FD_CalcPlot_OrgVsSO4(fDiag_smth, colorWave)
		FD_CalcPlot_NO3VsOrg(fDiag_smth, colorWave)
		FD_CalcPlot_WaterVsInorganics(fDiag_smth, colorWave)
		break
	case 1:
		FD_CalcPlot_Ammonium(fDiag_smth, colorWave)
		break
	case 2:
		FD_CalcPlot_Sulfate(fDiag_smth, colorWave)
		break
	case 3:
		FD_CalcPlot_Nitrate(fDiag_smth, colorWave)	
		break
	case 4:
		FD_CalcPlot_Organics(fDiag_smth, colorWave)
		break
	case 5:
		FD_CalcPlot_WaterVsInorganics(fDiag_smth, colorWave)
		break
	case 6:
		FD_CalcPlot_OrgVsSO4(fDiag_smth, colorWave)
		break
	case 7:
		FD_CalcPlot_NO3VsOrg(fDiag_smth, colorWave)
		break
	endswitch	
		
End


//Ammonium Diagnostics calculations and plots
Function FD_CalcPlot_Ammonium(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	wave/z NH4 = root:quantifChecks:NH4
	wave/z NH4_17 = root:quantifChecks:NH4_17
	wave/z NH4_16 = root:quantifChecks:NH4_16
	wave/z SO4 = root:quantifChecks:SO4
	wave/z NO3 = root:quantifChecks:NO3
	wave/z Chl = root:quantifChecks:Chl
	
	variable mw_so4 = 96 // email from Tim O  previous value was 98  thinking it was H2SO4 ?? 1.57I
	variable mw_nh4 = 18
	variable mw_no3 = 62  //email from Tim O  previous value was 63 thinking it was HNO3 ?? 1.57I
	variable mw_chl = 35		

	if (!waveexists(NH4) || !waveexists(NH4_17) || !waveexists(NH4_16) || !waveexists(SO4) || !waveexists(NO3) || !waveexists(Chl) )
		abort "You must first generate the ms time series waves for relevant species via the orange button.  Aborting from FD_plot_generator"
	endif

	//calculations
	duplicate/o nh4, root:quantifChecks:NH4_meas, root:quantifChecks:NH4_predict, root:quantifChecks:NH4_ratio
	wave NH4_meas  = root:quantifChecks:NH4_meas
	wave NH4_predict = root:quantifChecks:NH4_predict
	wave NH4_ratio = root:quantifChecks:NH4_ratio

	NH4_predict = (2*mw_nh4/mw_so4)*so4 + (mw_nh4/mw_no3)*no3 + (mw_nh4/mw_chl)*chl
	NH4_ratio = NH4_17 / NH4_16
	
	// deal with smoothing
	duplicate/o  NH4_16, root:quantifChecks:NH4_16_smth
	duplicate/o  NH4_17, root:quantifChecks:NH4_17_smth
	if (fDiag_smth>0)
		wave NH4_17_smth = root:quantifChecks:NH4_17_smth
		wave NH4_16_smth = root:quantifChecks:NH4_16_smth
		sq_smooth_nans(NH4_meas,fDiag_smth)
		sq_smooth_nans(NH4_predict,fDiag_smth)
		sq_smooth_nans(NH4_ratio,fDiag_smth)
		sq_smooth_nans(NH4_16_smth,fDiag_smth)
		sq_smooth_nans(NH4_17_smth,fDiag_smth)
	endif
		
	FD_CreateFzColorBywave(colorWave, "waveforcolor_nh4")
	
	//plot
	DoWindow/F NH4_Fragment		// Kills/makes graph
	if (V_flag==0)
		FD_NH4_Fragment()

		//set axes
		wavestats/q/m=1 root:quantifChecks:NH4_17_smth
		SetAxis y_nh4_17 min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:NH4_16_smth
		SetAxis x_nh4_16 min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:NH4_meas
		SetAxis y_nh4_meas min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:NH4_predict
		SetAxis x_nh4_pred min(0, V_min), V_max
		
		// set color scale		
	 	FD_setColorScale(colorWave, "NH4_CS", "NH4_meas")
		
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=NH4_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	endif
	
End


//Sulfate Diagnostics
Function FD_CalcPlot_Sulfate(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	wave/z SO4 = root:quantifChecks:SO4
	wave/z SO4_48 = root:quantifChecks:SO4_48
	wave/z SO4_64 = root:quantifChecks:SO4_64
	wave/z SO4_80 = root:quantifChecks:SO4_80
	wave/z SO4_81 = root:quantifChecks:SO4_81
	wave/z SO4_98 = root:quantifChecks:SO4_98
	
	if (!waveexists(SO4) || !waveexists(SO4_48) || !waveexists(SO4_64) || !waveexists(SO4_80) || !waveexists(SO4_81) || !waveexists(SO4_98) )
		abort "You must first generate the ms time series waves for relevant species via the orange button.  Aborting from FD_plot_generator"
	endif

	//calculations
	duplicate/o SO4_48, root:quantifChecks:ratio64_48,root:quantifChecks:ratio80_48,root:quantifChecks:ratio81_48,root:quantifChecks:ratio98_48
	wave ratio64_48 = root:quantifChecks:ratio64_48
	wave ratio80_48 = root:quantifChecks:ratio80_48
	wave ratio81_48 = root:quantifChecks:ratio81_48
	wave ratio98_48 = root:quantifChecks:ratio98_48
	ratio64_48 = SO4_64 / SO4_48
	ratio80_48 = SO4_80 / SO4_48
	ratio81_48 = SO4_81 / SO4_48
	ratio98_48 = SO4_98 / SO4_48

	// deal with smoothing
	duplicate/o SO4, root:quantifChecks:SO4_smth
	duplicate/o SO4_48, root:quantifChecks:SO4_48_smth
	duplicate/o SO4_64, root:quantifChecks:SO4_64_smth
	duplicate/o SO4_80, root:quantifChecks:SO4_80_smth
	duplicate/o SO4_81, root:quantifChecks:SO4_81_smth
	duplicate/o SO4_98, root:quantifChecks:SO4_98_smth
	if (fDiag_smth>0)
		wave SO4_smth = root:quantifChecks:SO4_smth
		wave SO4_48_smth = root:quantifChecks:SO4_48_smth
		wave SO4_64_smth = root:quantifChecks:SO4_64_smth
		wave SO4_80_smth = root:quantifChecks:SO4_80_smth
		wave SO4_81_smth = root:quantifChecks:SO4_81_smth
		wave SO4_98_smth = root:quantifChecks:SO4_98_smth
		sq_smooth_nans(ratio64_48,fDiag_smth)
		sq_smooth_nans(ratio80_48,fDiag_smth)
		sq_smooth_nans(ratio81_48,fDiag_smth)
		sq_smooth_nans(ratio98_48,fDiag_smth)
		sq_smooth_nans(SO4_smth,fDiag_smth)
		sq_smooth_nans(SO4_48_smth,fDiag_smth)
		sq_smooth_nans(SO4_64_smth,fDiag_smth)
		sq_smooth_nans(SO4_80_smth,fDiag_smth)
		sq_smooth_nans(SO4_81_smth,fDiag_smth)
		sq_smooth_nans(SO4_98_smth,fDiag_smth)
	endif

	//color by
	FD_CreateFzColorBywave(colorWave, "waveforcolor_so4")
	
	//plot
	DoWindow/F SO4_Fragment		// Kills/makes graph
	if (V_flag==0)
		FD_SO4_Fragment()
		
		//set axes
		wavestats/q/m=1 root:quantifChecks:SO4_64_smth
		SetAxis y_so4_ratio_scatter min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:SO4_48_smth
		SetAxis x_so4_48 min(0, V_min), V_max
		
		// set color scale		
	 	FD_setColorScale(colorWave, "SO4_CS", "SO4_smth")
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=SO4_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	endif
	
End

	
//Nitrate Diagnostics
Function FD_CalcPlot_Nitrate(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	wave/z NO3 = root:quantifChecks:NO3
	wave/z NO3_30 = root:quantifChecks:NO3_30
	wave/z NO3_46 = root:quantifChecks:NO3_46
	wave/z m30 = root:quantifChecks:m30
	wave/z m31 = root:quantifChecks:m31
		
	if (!waveexists(NO3) || !waveexists(NO3_30) || !waveexists(NO3_46) )
		abort "You must first generate the ms time series waves for relevant species via the orange button.  Aborting from FD_plot_generator"
	endif

	//calculations
	duplicate/o NO3_30, root:quantifChecks:ratio30_46,root:quantifChecks:ratio46_30
	wave ratio30_46 = root:quantifChecks:ratio30_46
	wave ratio46_30 = root:quantifChecks:ratio46_30
	ratio46_30 = NO3_46 / NO3_30
	ratio30_46 = NO3_30 / NO3_46 
	
	// deal with smoothing
	duplicate/o NO3 root:quantifChecks:NO3_smth
	duplicate/o NO3_30 root:quantifChecks:NO3_30_smth
	duplicate/o NO3_46 root:quantifChecks:NO3_46_smth
	duplicate/o m30 root:quantifChecks:m30_smth
	duplicate/o m31 root:quantifChecks:m31_smth
	if (fDiag_smth>0)
		wave NO3_smth = root:quantifChecks:NO3_smth
		wave NO3_30_smth = root:quantifChecks:NO3_30_smth
		wave NO3_46_smth = root:quantifChecks:NO3_46_smth
		wave m30_smth = root:quantifChecks:m30_smth
		wave m31_smth = root:quantifChecks:m31_smth
		sq_smooth_nans(ratio46_30,fDiag_smth)
		sq_smooth_nans(ratio30_46,fDiag_smth)
		sq_smooth_nans(NO3_smth,fDiag_smth)
		sq_smooth_nans(NO3_30_smth,fDiag_smth)
		sq_smooth_nans(NO3_46_smth,fDiag_smth)
		sq_smooth_nans(m30_smth,fDiag_smth)
		sq_smooth_nans(m31_smth,fDiag_smth)
	endif
	
	//color by
	FD_CreateFzColorBywave(colorWave, "waveforcolor_no3")
	
	//plot
	DoWindow/F NO3_Fragment		// Kills/makes graph
	if (V_flag==0)
		FD_NO3_Fragment()
		
		//set axes
		wavestats/q/m=1 root:quantifChecks:NO3_46_smth
		SetAxis y_no3_46 min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:NO3_30_smth
		SetAxis x_no3_30 min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:m30_smth
		SetAxis x_m30 min(0, V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:m31_smth
		SetAxis y_m31 min(0, V_min), V_max
		
		// set color scale		
	 	FD_setColorScale(colorWave, "NO3_CS", "NO3_smth")
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=NO3_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	endif
	
End


//Organic Diagnostics
Function FD_CalcPlot_Organics(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	Wave/z Org = root:quantifChecks:Org
	Wave/z Org43 =root:quantifChecks:Org43
	Wave/z Org44 = root:quantifChecks:Org44
	Wave/z Org57 = root:quantifChecks:Org57
		
	if (!waveexists(Org) || !waveexists(Org43) || !waveexists(Org44) || !waveexists(Org57)  )
		abort "You must first generate the ms time series waves for relevant species via the orange button.  Aborting from FD_plot_generator"
	endif

	// deal with smoothing
	duplicate/o Org root:quantifChecks:Org_smth
	duplicate/o Org44 root:quantifChecks:Org44_smth
	duplicate/o Org43 root:quantifChecks:Org43_smth
	duplicate/o Org57 root:quantifChecks:Org57_smth
	if (fDiag_smth>0)
		wave Org_smth = root:quantifChecks:Org_smth
		wave Org44_smth = root:quantifChecks:Org44_smth
		wave Org43_smth = root:quantifChecks:Org43_smth
		wave Org57_smth = root:quantifChecks:Org57_smth
		sq_smooth_nans(Org_smth,fDiag_smth)
		sq_smooth_nans(Org44_smth,fDiag_smth)
		sq_smooth_nans(Org43_smth,fDiag_smth)
		sq_smooth_nans(Org57_smth,fDiag_smth)
	endif
	
	//color by
	FD_CreateFzColorBywave(colorWave, "waveforcolor_org")
	
	//plot
	DoWindow/F Org_Fragment		// Kills/makes graph
	if (V_flag==0)
		FD_Org_Fragment()
		
		//set axes
		wavestats/q/m=1 root:quantifChecks:Org44_smth
		SetAxis y_Org44 min(0,V_min), V_max
		SetAxis x_Org44 min(0,V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:Org_smth
		SetAxis x_org min(0,V_min), V_max
		
		wavestats/q/m=1 root:quantifChecks:Org43_smth
		SetAxis y_Org43 min(0,V_min), V_max			// bug fix in 1.43I
		
		// set color scale		
	 	FD_setColorScale(colorWave, "Org_CS", "Org_smth")
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=Org_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	endif
	
End

	
//Water vs Inorganics
Function FD_CalcPlot_WaterVsInorganics(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	//color by
	FD_CreateFzColorBywave(colorWave, "waveforcolor_water")
		
	//plot
	DoWindow/F Water_vs_Inorganics_plot
	if (V_flag==0)
		FD_Water_vs_Inorganics_plot()
		
		// set color scale		
	 	FD_setColorScale(colorWave, "Water_CS", "Water")
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=Water_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	endif
	
End


//Org vs SO4
Function FD_CalcPlot_OrgVsSO4(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	//color by
	FD_CreateFzColorBywave(colorWave, "waveforcolor_org_vs_so4")
		
	//plot
	DoWindow/F Org_vs_SO4_plot
	if (V_flag==0)
		FD_Org_vs_SO4_plot()
		
		// set color scale		
	 	FD_setColorScale(colorWave, "Org_vs_SO4_CS", "Org")
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=Org_vs_SO4_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	endif
		
End


//NO3 vs Org
Function FD_CalcPlot_NO3vsOrg(fDiag_smth, colorWave)
variable fDiag_smth
wave colorWave

	//color by
	FD_CreateFzColorBywave(colorWave, "waveforcolor_no3_vs_org")
		
	//plot
	DoWindow/F NO3_vs_Org_plot
	if (V_flag==0)
		FD_NO3_vs_Org_plot()
		// set color scale		
		 FD_setColorScale(colorWave, "NO3_vs_Org_CS", "NO3")
	else
		nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
		ColorScale/C/N=NO3_vs_Org_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	 endif

End


// put values in f(x) wave and set scale
Function FD_CreateFzColorBywave(fzWave, waveNameStr)
wave fzWave
string waveNameStr

	duplicate/o fzWave, $("root:quantifChecks:"+waveNameStr)
	wave colorByWave = $("root:quantifChecks:"+waveNameStr)
	if (stringmatch("t_series", NameOfWave(fzWave) ) )
		SetScale d 0,0,"dat", colorByWave
	else
		SetScale d 0,0,"", colorByWave
	endif

End


//set colorscale
Function FD_setColorScale(ColorWave, CSName, TraceName)
wave colorWave
string CSName, traceName

	ColorScale/C/N=$CSName NameOfWave(colorWave)
	if (stringmatch(StringByKey("XUNITS", WaveInfo(colorWave,0)), "dat") )
		ColorScale/C/N=$CSName trace=$traceName,lblMargin=25
	else
		ColorScale/C/N=$CSName trace=$traceName,lblMargin=0
	endif

End


//^ helper function for FD_Check_batch
// usage: FD_modifyBatch("m31", "m31", "frag_nitrate[31]", "31", "1", "1", "" )		// 1.44B fix
Function FD_modifyBatch(spec_listStr, specname_listStr,frag_listStr, iefac_listStr, cefac_listStr, speccorr_listStr )
string spec_listStr, specname_listStr,frag_listStr, iefac_listStr, cefac_listStr, speccorr_listStr

	wave/t spec_list = root:frag:spec_list
	wave/t specname_list = root:frag:specname_list
	wave/t frag_list = root:frag:frag_list
	wave calfac_list = root:frag:calfac_list
	wave iefac_list = root:frag:iefac_list
	wave cefac_list = root:frag:cefac_list
	wave/t speccorr_list = root:frag:speccorr_list
	wave/t/z ceWave_list = root:frag:ceWave_list		// 1.52A
	if (!WaveExists(ceWave_list))  	// 1.52A
		make/o/t/n=(numpnts(spec_list)) root:frag:ceWave_list/wave=ceWave_list	
	elseif(numpnts(ceWave_list) !=numpnts(spec_list))
		Redimension/N=(numpnts(spec_list)) cefac_list
	endif
	variable idex, num, flag=0

	num = numpnts(spec_list)
	for (idex=0;idex<num;idex+=1)
		flag += stringmatch(spec_listStr,spec_list[idex])
	endfor
	if (flag==0)
		Insertpoints num,1, spec_list, specname_list, frag_list, calfac_list, iefac_list, cefac_list, speccorr_list,ceWave_list //, tof_list	 	// 1.52A	
		spec_list[num] = spec_listStr
		specname_list[num] = specname_listStr
		frag_list[num] = frag_listStr
		iefac_list[num] = Str2Num(iefac_listStr)
		cefac_list[num] = Strlen(cefac_listStr)>=0? str2num(cefac_listStr) :cefac_list[num-1]
		speccorr_list[num] = speccorr_listStr		
		ceWave_list[num] = ""		// 1.52A	
	elseif(stringmatch("m31", specname_listStr))		//1.44B fix
		idex = sq_findStr(spec_list,"m31",1)
		frag_list[idex] = "frag_nitrate[31]"
	endif	

End


// possibly add entries to the waves in the batch table in anticipation of generating time series.
Function FD_Check_batch()

	//^ first make frag_m31 wave if it doesn't exist
	wave/t/z frag_m31 = root:frag:frag_air	// we only need this wave for the number of points it has
	if (waveExists(frag_m31)==0)	
		wave/t frag_air = root:frag:frag_air	// we only need this wave for the number of points it has
		make/o/n=(numpnts(frag_air))/t root:frag:frag_m31 = ""
		wave/t frag_m31 = root:frag:frag_m31
		frag_m31[30] = "31,-frag_nitrate[31]"
	endif

	//^ add these entries to the batch waves if they are not already there
	// for FD_modifyBatch params are: spec_listStr, specname_listStr,frag_listStr, iefac_listStr, cefac_listStr, speccorr_listStr

 	FD_modifyBatch("Inorg", "Inorganics", "$NH4,$NO3,$SO4,$Chl","1", "1", "" )		//1.51I fix, removed tof_ListStr
 	FD_modifyBatch("m30", "m30", "frag_nitrate[30]", "1", "1", "" )
 	FD_modifyBatch("m31", "m31", "frag_nitrate[31]", "1", "1", "" )		// 1.44B fix
 	FD_modifyBatch("m39", "m39", "frag_K[39]", "1", "1", "" )
 	FD_modifyBatch("m41", "m41", "frag_K[41],frag_organic[41]","1", "1", "" )
	
 	FD_modifyBatch("Org29", "Org29", "frag_organic[29]","1.4", "1", "" )	//1.56E //1.49E
 	FD_modifyBatch("Org15", "Org15", "frag_organic[15]","1.4", "1", "")
End


// significantly cleaned up in 1.44B
// Subsequent code relies on the generated time-series species wave names to not have a suffix
Function FD_GenerateFragTrends([diffOnlyFlag])	
variable diffOnlyFlag

	svar fDiag_SpeciesException = root:panel:fDiag_SpeciesException
	nvar fDiag_UseAirbeam=root:panel:fDiag_UseAirbeam
	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$"root:"+todoStr			//1.44B
	wave/t spec_list = root:frag:spec_list

	wave/z corr_fact = root:diagnostics:corr_fact  // moved to beginning of function in 1.42E
	if(fDiag_UseAirbeam==1)
		if (waveExists(corr_fact)==0)
			abort "The airbeam correction wave does not exist.  Please generate from the corrections tab. - Aborting from  FD_GenerateFragTrends"
		elseif(numpnts(corr_fact)!=numpnts(root:index:rn_series) )
			DoAlert 1, "The airbeam correction factor wave does not have the same number of points as t_series, which can result in nonsensical results.  Do you want to abort this operation?"
			if (V_flag == 1)		// user pressed yes, so abort
				Abort "The user chose to abort" 
			endif
		endif
	endif
	if(numpnts(todo)==0)
		abort "Choose a todo wave with more than 0 runs -  Aborting from  FD_GenerateFragTrends"
	endif

	variable idex, num
	string paramStr, speclistStr, dummyStr, destList
		
	speclistStr = ""
	destList = ""
	// for now we will calculate all species in the text wave list except 
	
	num =numpnts(spec_list)
	for (idex=0; idex<num; idex+=1)
 		if (FindListItem(spec_list[idex],fDiag_SpeciesException)<0)	  // in wave spec_list but not in string list
			speclistStr += spec_list[idex]+","
			destList += "root:quantifChecks:"+ spec_list[idex]+ "/"
		endif
	endfor

	// 1.49E  add 16, 14 for O16 looks
	speclistStr +="16,"
	destList += "root:quantifChecks:mz16/"
	speclistStr += "14,"
	destList += "root:quantifChecks:mz14/"

	paramstr=""
	speclistStr=replacestring(" ",speclistStr,"")

	SQ_GetParamStr(paramstr,speclistStr,0,dummyStr)
	paramstr+="filter_op:0;"
	paramstr+="corr_op:"+num2str(fDiag_UseAirbeam)+";"
	paramstr+="ug_op:"+num2str(1)+";"		// always do in units of g/m3
	paramstr+="cache_op:"+num2str(0)+";"
	paramstr+="product_type:1;"
	paramstr+="destlist:"+destList+";"
	squirrel_fetch(todo,sq_MS_concentration,paramstr,"MSSDiff_p")	

	// 1.49E  do closed for water traces
	if (! ParamIsDefault(diffOnlyFlag) && diffOnlyFlag==1)			//1.56F
		return 0
	endif
	
	paramstr=""
	speclistStr=replacestring(" ","16,17,18","")
	SQ_GetParamStr(paramstr,speclistStr,0,dummyStr)
	paramstr+="filter_op:0;"
	paramstr+="corr_op:"+num2str(fDiag_UseAirbeam)+";"
	paramstr+="ug_op:"+num2str(1)+";"		// always do in units of g/m3
	paramstr+="cache_op:"+num2str(0)+";"
	paramstr+="product_type:1;"
	paramstr+="destlist:root:quantifChecks:mz16_C/root:quantifChecks:mz17_C/root:quantifChecks:mz18_C"+";"
	squirrel_fetch(todo,sq_MS_concentration,paramstr,"MSSClosed_p")	
	
End


Function FD_MakeRatios()		// Must have calculated batch to run this

	setdatafolder root:
	
	wave t_series = root:index:t_series
	nvar fDiag_smth  = root:panel:fDiag_smth
	
	wave SO4=root:quantifChecks:SO4
	wave Org=root:quantifChecks:Org
	wave NO3=root:quantifChecks:NO3
	wave NH4=root:quantifChecks:NH4
	wave Water = root:quantifChecks:water
	
	make/o/n=(numpnts(t_series)) root:quantifChecks:ratio_O_S,root:quantifChecks:ratio_W_S,root:quantifChecks:ratio_N_S,root:quantifChecks:ratio_A_S,root:quantifChecks:ratio_A_N
	wave ratio_O_S=root:quantifChecks:ratio_O_S
	wave ratio_W_S=root:quantifChecks:ratio_W_S
	wave ratio_N_S=root:quantifChecks:ratio_N_S
	wave ratio_A_S=root:quantifChecks:ratio_A_S
	wave ratio_A_N = root:quantifChecks:ratio_A_N

	ratio_O_S = Org / SO4
	ratio_W_S = Water / SO4
	ratio_N_S = NO3 / SO4
	ratio_A_S = NH4 / SO4
	ratio_A_N = NH4 / NO3

	if (fDiag_smth>1)
		sq_smooth_nans(ratio_O_S,fDiag_smth)
		sq_smooth_nans(ratio_W_S,fDiag_smth)
		sq_smooth_nans(ratio_N_S,fDiag_smth)
		sq_smooth_nans(ratio_A_S,fDiag_smth)
		sq_smooth_nans(ratio_A_N,fDiag_smth)
	endif

End


// make a series of two point waves named root:quantifChecks:line_xxxx that will be used in frag plots
Function FD_MakeLines()		// lines for graphs, need to change for log scale 
// modified in 1.56N

	wave t_series = root:index:t_series
	NewDataFolder/o/s root:quantifChecks
	
//	make/o/n=2 unity= {0,10}		// 1:1 line
//	SetScale/I x 0,10,"", unity
	
//	make/o/n=2 line_1pt1_1={0,11}	//1.1:1 line (for NH4)
//	SetScale/I x 0,10,"", line_1pt1_1
	
//	make/o/n=2 line_at1pt1_time={1.1, 1.1}		// 1.1 line over time (for NH4)
//	SetScale/I x t_series[0],t_series[numpnts(t_series)],"", line_at1pt1_time
	
//	make/o/n=2 line_at1_time = {1,1}
//	SetScale/I x t_series[0],t_series[numpnts(t_series)],"", line_at1_time	// 1 line over time
	
//	make/o/n=2 line_at2_time={2,2}
//	SetScale/I x t_series[0],t_series[numpnts(t_series)],"", line_at2_time	// 2 line over time (NO3)
	
//	make/o/n=2 line_atpt5_time = {0.5,0.5}
//	SetScale/I x t_series[0],t_series[numpnts(t_series)],"", line_atpt5_time	// 0.5 line over time (NO3)
	
//	make/o/n=2 line_1_2 = {0,5}			// 0.5:1 or 1:2 line
//	SetScale/I x 0,10,"",line_1_2	
	
//	make/o/n=2 line_1_4= {0,2.5}		// 0.25:1 or 1:4 line
//	SetScale/I x 0,10,"",line_1_4
	
//	make/o/n=2 line_1_8 = {0,1.25}		// 0.125:1 or 1:8 line
//	SetScale/I x 0,10,"",line_1_8
	
//	make/o/n=2 line_2_1 = {0,10}		// 2:1 line	// 	1.56O
//	SetScale/I x 0,5,"",line_2_1
	
//	make/o/n=2 line_3_1 = {0,10}		// 3:1 line	// 	1.56O
//	SetScale/I x 0,3.3,"",line_3_1
	
//	make/o/n=2 line_4_1= {0,40}		// 4:1 line	// 	1.56O
//	SetScale/I x 0,10,"",line_4_1	
	
//	make/o/n=2 line_5_1 = {0,10}		// 5:1 line	// 	1.56O
//	SetScale/I x 0,2,"",line_5_1
	
//	make/o/n=2 line_0p2 = {0,20}			//0.2 line for Org44 vs org
//	setscale/i x 0,100,"",line_0p2
	
//	make/o/n=2 line_0p08= {0,8}			//0.08 line for Org44 vs org
//	setscale/i x 0,100,"",line_0p08
	
//	make/o/n=2 line_0p03 = {0,3}			//0.03 line for Org44 vs org
//	setscale/i x 0,100,"",line_0p03

	setdatafolder root:

End


Function FD_PopMenuProc(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr

	nvar fd_var  = $("root:panel:"+ctrlName[6,strlen(ctrlName)-1])	// either  fDiag_ColorDiags or fDiag_ChooseDiagnostics controls have a "popup_" prefix
	fd_var = popNum - 1// popups count from 1, everything else in Igor counts from 0

End


//  ------------------------  Frag & Data Diagnostics Graphs ---------------------

Function FD_NH4_Fragment()
	PauseUpdate; Silent 1		// building window...
	Display/N= NH4_Fragment /W=(50, 50, 550, 500) as "NH4_Fragment"
	AppendToGraph/L=y_nh4_time/B=x_time root:quantifChecks:NH4_meas vs root:index:t_series
	AppendToGraph/L=y_nh4_ratio/B=x_time root:quantifChecks:NH4_ratio vs root:index:t_series
	AppendToGraph/L=y_nh4_17/B=x_nh4_16 root:quantifChecks:NH4_17_smth vs root:quantifChecks:NH4_16_smth
//	AppendToGraph/L=y_nh4_17/B=x_nh4_16 root:quantifChecks:line_1pt1_1
//	AppendToGraph/L=y_nh4_ratio/B=x_time root:quantifChecks:line_at1pt1_time
	AppendToGraph/L=y_nh4_meas/B=x_nh4_pred root:quantifChecks:NH4_meas vs root:quantifChecks:NH4_predict
//	AppendToGraph/L=y_nh4_meas/B=x_nh4_pred root:quantifChecks:unity
	ModifyGraph margin(left)=72,margin(bottom)=36
	ModifyGraph mode(NH4_17_smth)=3,mode(NH4_meas#1)=3
	ModifyGraph marker(NH4_17_smth)=19,marker(NH4_meas#1)=19
	ModifyGraph lSize(NH4_meas)=2,lSize(NH4_ratio)=2
//	ModifyGraph lStyle(line_1pt1_1)=3,lStyle(line_at1pt1_time)=2,lStyle(unity)=3
//	ModifyGraph rgb(line_1pt1_1)=(0,0,0),rgb(line_at1pt1_time)=(0,0,0),rgb(unity)=(0,0,0)
	ModifyGraph zColor(NH4_meas)={root:quantifChecks:waveforcolor_nh4,*,*,Rainbow},zColor(NH4_17_smth)={root:quantifChecks:waveforcolor_nh4,*,*,Rainbow}
	ModifyGraph zColor(NH4_meas#1)={root:quantifChecks:waveforcolor_nh4,*,*,Rainbow}
	ModifyGraph tick=2
	ModifyGraph zero(y_nh4_time)=1
	ModifyGraph mirror(y_nh4_time)=1,mirror(x_time)=1,mirror(y_nh4_ratio)=1
	ModifyGraph nticks(y_nh4_time)=3,nticks(x_time)=10
	ModifyGraph font="Arial"
	ModifyGraph minor(x_time)=1
	ModifyGraph sep(x_time)=10
	ModifyGraph fsize=10
	ModifyGraph lblPos(y_nh4_time)=58,lblPos(y_nh4_ratio)=49,lblPos(y_nh4_17)=52,lblPos(x_nh4_16)=75
	ModifyGraph lblPos(y_nh4_meas)=41,lblPos(x_nh4_pred)=36
	ModifyGraph lblLatPos(y_nh4_time)=-3,lblLatPos(y_nh4_ratio)=6,lblLatPos(y_nh4_17)=-2
	ModifyGraph lblLatPos(x_nh4_16)=-16,lblLatPos(y_nh4_meas)=-6
	ModifyGraph freePos(y_nh4_time)=0
	ModifyGraph freePos(x_time)={0,y_nh4_ratio}
	ModifyGraph freePos(y_nh4_ratio)=0
	ModifyGraph freePos(y_nh4_17)=0
	ModifyGraph freePos(x_nh4_16)={0,y_nh4_17}
	ModifyGraph freePos(y_nh4_meas)={0,x_nh4_pred}
	ModifyGraph freePos(x_nh4_pred)={0,y_nh4_meas}
	ModifyGraph axisEnab(y_nh4_time)={0.85,1}
	ModifyGraph axisEnab(y_nh4_ratio)={0.55,0.8}
	ModifyGraph axisEnab(y_nh4_17)={0,0.45}
	ModifyGraph axisEnab(x_nh4_16)={0,0.45}
	ModifyGraph axisEnab(y_nh4_meas)={0,0.45}
	ModifyGraph axisEnab(x_nh4_pred)={0.55,1}
	ModifyGraph dateInfo(x_time)={0,0,0}
	ModifyGraph gaps=0
	Label y_nh4_time "\\f01NH4 g/m3"
	Label x_time " "
	Label y_nh4_ratio "\\f01m/z 17 / 16"
	Label y_nh4_17 "\\f01NH4 at m/z 17"
	Label x_nh4_16 "\\f01NH4 at m/z 16"
	Label y_nh4_meas "\\f01Measured NH4, g/m3"
	Label x_nh4_pred "\\f01Predicted NH4, g/m3"
	SetAxis y_nh4_ratio 0,2
	SetAxis y_nh4_17 -0.01588,0.65971
	SetAxis x_nh4_16 -0.0013087,0.56236
	SetAxis y_nh4_meas 0,1.1289
	SetAxis x_nh4_pred 0,2.3023
	ShowInfo
	TextBox/N=NH4_title/F=0/B=1/A=MC/X=-34.59/Y=60.91 "\\f01\\Z14Ammonium Diagnostics"
	ColorScale/N=NH4_CS/F=0/B=1/A=MT/X=26.38/Y=0.34/E trace=NH4_meas, vert=0
	ColorScale/C/N=NH4_CS heightPct=2, widthPct=50, tickLen=4, nticks=10, fsize=10
	ColorScale/C/N=NH4_CS lblMargin=25, minor=1
	nvar fDiag_ColorDiags = root:panel:fDiag_ColorDiags
	ColorScale/C/N=NH4_CS stringfromlist(fDiag_ColorDiags,FD_COLORBY_LIST)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E

End
	

Function FD_SO4_Fragment()
	PauseUpdate; Silent 1		// building window...
	Display/N=SO4_Fragment /W=(75, 75, 575, 525) as "SO4_Fragment"
	AppendToGraph/L=y_so4_time/B=x_time root:quantifChecks:SO4_smth vs root:index:t_series
	AppendToGraph/L=y_so4_ratio/B=x_time root:quantifChecks:ratio64_48,root:quantifChecks:ratio80_48,root:quantifChecks:ratio81_48,root:quantifChecks:ratio98_48 vs root:index:t_series
	AppendToGraph/L=y_so4_ratio_scatter/B=x_so4_48 root:quantifChecks:SO4_64_smth,root:quantifChecks:SO4_80_smth,root:quantifChecks:SO4_81_smth,root:quantifChecks:SO4_98_smth vs root:quantifChecks:SO4_48_smth
//	AppendToGraph/L=y_so4_ratio_scatter/B=x_so4_48 root:quantifChecks:unity,root:quantifChecks:line_1_2,root:quantifChecks:line_1_4,root:quantifChecks:line_1_8
	ModifyGraph margin(left)=72,margin(bottom)=43
	ModifyGraph mode(SO4_64_smth)=3,mode(SO4_80_smth)=3,mode(SO4_81_smth)=3,mode(SO4_98_smth)=3
	ModifyGraph marker(SO4_64_smth)=19,marker(SO4_80_smth)=19,marker(SO4_81_smth)=19,marker(SO4_98_smth)=19
	ModifyGraph lSize(SO4_smth)=2,lSize(ratio64_48)=2,lSize(ratio80_48)=2,lSize(ratio81_48)=2
	ModifyGraph lSize(ratio98_48)=2
//	modifygraph lSize(unity)=2,lSize(line_1_2)=2,lSize(line_1_4)=2
//	ModifyGraph lSize(line_1_8)=2
//	ModifyGraph lStyle(unity)=2,lStyle(line_1_2)=2,lStyle(line_1_4)=2,lStyle(line_1_8)=2
	ModifyGraph rgb(ratio80_48)=(44032,29440,58880),rgb(ratio81_48)=(0,52224,0),rgb(ratio98_48)=(0,9472,39168)
	ModifyGraph rgb(SO4_80_smth)=(44032,29440,58880),rgb(SO4_81_smth)=(0,52224,0),rgb(SO4_98_smth)=(0,9472,39168)
//	ModifyGraph rgb(unity)=(0,0,0),rgb(line_1_2)=(0,0,0),rgb(line_1_4)=(0,0,0),rgb(line_1_8)=(0,0,0)
	ModifyGraph zColor(SO4_smth)={root:quantifChecks:waveforcolor_so4,*,*,Rainbow}
	ModifyGraph tick=2
	ModifyGraph zero(y_so4_time)=1
	ModifyGraph mirror(y_so4_time)=1,mirror(x_time)=1,mirror(y_so4_ratio)=1
	ModifyGraph nticks(x_time)=10, dateInfo(x_time)={0,1,0}
	ModifyGraph font="Arial"
	ModifyGraph minor(x_time)=1
	ModifyGraph sep(x_time)=10
	ModifyGraph fsize=10
	ModifyGraph lblPos(y_so4_time)=58,lblPos(y_so4_ratio)=51,lblPos(y_so4_ratio_scatter)=53
	ModifyGraph lblPos(x_so4_48)=41
	ModifyGraph lblLatPos(y_so4_ratio_scatter)=8,lblLatPos(x_so4_48)=-14
	ModifyGraph freePos(y_so4_time)=0
	ModifyGraph freePos(x_time)={0,y_so4_ratio}
	ModifyGraph freePos(y_so4_ratio)={0,x_time}
	ModifyGraph freePos(y_so4_ratio_scatter)=0
	ModifyGraph freePos(x_so4_48)={0,y_so4_ratio_scatter}
	ModifyGraph axisEnab(y_so4_time)={0.85,1}
	ModifyGraph axisEnab(y_so4_ratio)={0.55,0.8}
	ModifyGraph axisEnab(y_so4_ratio_scatter)={0,0.45}
	ModifyGraph axisEnab(x_so4_48)={0,0.45}
	ModifyGraph dateInfo(x_time)={0,0,0}
	ModifyGraph gaps=0
	Label y_so4_time "\\f01SO4, g/m3"
	Label x_time " "
	Label y_so4_ratio "\\f01Fragments / 48 (SO)"
	Label y_so4_ratio_scatter "\\f01SO4 Ratios: Fragment / 48 (SO)"
	Label x_so4_48 "\\f01SO4 at m/z 48 (SO)"
	SetAxis/A/E=1 y_so4_time
	SetAxis y_so4_ratio 0,2
	SetAxis y_so4_ratio_scatter 0,2
	SetAxis x_so4_48 0,2
	ShowInfo
	TextBox/N=SO4_title/F=0/A=LT/X=-10/Y=-20 "\\f01\\Z14Sulfate Diagnostics"

	TextBox/N=text1/F=0/A=MC/X=34.62/Y=-25.20 "\\f01Lines\tSulfate Ratios\r\\K(65280,0,0)1:1\tm/z 64 (SO2) / 48 (SO)\r\\K(44032,29440,58880)1:2\tm/z 80 (SO3) / 48 (SO)"
	AppendText "\\K(0,52224,0)1:3\tm/z 81 (HSO4) / 48 (SO)\r\\K(0,9472,39168)1:4\tm/z 98 (H2SO4) / 48 (SO)"

	ColorScale/N=SO4_CS/F=0/B=1/A=MT/X=25/Y=0/E trace=SO4_smth, vert=0
	ColorScale/C/N=SO4_CS heightPct=2, widthPct=50, tickLen=4, nticks=10, fsize=10
	ColorScale/C/N=SO4_CS lblMargin=0, minor=1
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function FD_NO3_Fragment()
	PauseUpdate; Silent 1		// building window...
	Display/N=NO3_Fragment /W=(100, 100, 600, 550) as "NO3_Fragment"
	AppendToGraph/L=t_no3_time/B=x_time root:quantifChecks:NO3_smth vs root:index:t_series
	AppendToGraph/L=y_no3_ratio/B=x_time root:quantifChecks:ratio46_30 vs root:index:t_series
	AppendToGraph/L=y_no3_46/B=x_no3_30 root:quantifChecks:NO3_46_smth vs root:quantifChecks:NO3_30_smth
//	AppendToGraph/L=y_no3_46/B=x_no3_30 root:quantifChecks:line_1_2
//	AppendToGraph/L=y_no3_ratio/B=x_time root:quantifChecks:line_atpt5_time
	AppendToGraph/L=y_m31/B=x_m30 root:quantifChecks:m31_smth vs root:quantifChecks:m30_smth
	ModifyGraph margin(left)=58,margin(bottom)=36
	ModifyGraph mode(NO3_46_smth)=3,mode(m31_smth)=3
	ModifyGraph marker(NO3_46_smth)=19,marker(m31_smth)=19
	ModifyGraph lSize(NO3_smth)=2,lSize(ratio46_30)=2
//	ModifyGraph lStyle(line_1_2)=3,lStyle(line_atpt5_time)=3
//	ModifyGraph rgb(line_1_2)=(0,0,0),rgb(line_atpt5_time)=(0,0,0)
	ModifyGraph zColor(NO3_smth)={root:quantifChecks:waveforcolor_no3,*,*,Rainbow},zColor(NO3_46_smth)={root:quantifChecks:waveforcolor_no3,*,*,Rainbow}
	ModifyGraph zColor(m31_smth)={root:quantifChecks:waveforcolor_no3,*,*,Rainbow}
	ModifyGraph tick(t_no3_time)=2,tick(x_time)=2,tick(y_no3_ratio)=2,tick(y_no3_46)=2
	ModifyGraph tick(x_no3_30)=2
	ModifyGraph zero(t_no3_time)=1
	ModifyGraph mirror(t_no3_time)=1,mirror(x_time)=1,mirror(y_no3_ratio)=1
	ModifyGraph nticks(t_no3_time)=3,nticks(y_no3_ratio)=3,nticks(y_no3_46)=3,nticks(x_no3_30)=3
	ModifyGraph font="Arial"
	ModifyGraph minor(x_time)=1
	ModifyGraph sep(x_time)=10,sep(y_no3_ratio)=10
	ModifyGraph fsize=10
	ModifyGraph lblPos(t_no3_time)=55,lblPos(y_no3_ratio)=50,lblPos(y_no3_46)=55,lblPos(x_no3_30)=40
	ModifyGraph lblPos(y_m31)=52,lblPos(x_m30)=33
	ModifyGraph lblLatPos(t_no3_time)=3,lblLatPos(y_no3_ratio)=3,lblLatPos(y_no3_46)=1
	ModifyGraph lblLatPos(y_m31)=-8,lblLatPos(x_m30)=2
	ModifyGraph freePos(t_no3_time)=0
	ModifyGraph freePos(x_time)={0,y_no3_ratio}
	ModifyGraph freePos(y_no3_ratio)=0
	ModifyGraph freePos(y_no3_46)=0
	ModifyGraph freePos(x_no3_30)=0
	ModifyGraph freePos(y_m31)={0,x_m30}
	ModifyGraph freePos(x_m30)={0,y_m31}
	ModifyGraph axisEnab(t_no3_time)={0.85,1}
	ModifyGraph axisEnab(y_no3_ratio)={0.55,0.8}
	ModifyGraph axisEnab(y_no3_46)={0,0.45}
	ModifyGraph axisEnab(x_no3_30)={0,0.45}
	ModifyGraph axisEnab(y_m31)={0,0.45}
	ModifyGraph axisEnab(x_m30)={0.55,1}
	ModifyGraph dateInfo(x_time)={0,0,0}
	ModifyGraph gaps=0
	Label t_no3_time "\\f01NO3, g/m3"
	Label x_time " "
	Label y_no3_ratio "\\f01m/z 46 / 30"
	Label y_no3_46 "\\f01NO3 at m/z 46 (NO2)"
	Label x_no3_30 "\\f01NO3 at m/z 30 (NO)"
	Label y_m31 "\\f01m/z 31 (HNO)"
	Label x_m30 "\\f01m/z 30 (NO)"
	ShowInfo
	TextBox/N=NO3_title/F=0/A=MC/X=-36.14/Y=61.54 "\\f01\\Z14Nitrate Diagnostics"
	ColorScale/N=NO3_CS/F=0/A=MT/X=27.33/Y=0.00/E trace=NO3_smth, vert=0, heightPct=2
	ColorScale/C/N=NO3_CS widthPct=50, tickLen=4, nticks=10, fsize=10, lblMargin=0
	ColorScale/C/N=NO3_CS minor=1
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function FD_Org_Fragment()
	PauseUpdate; Silent 1		// building window...
	Display/N=Org_Fragment /W=(125, 125, 625, 575) as "Org_Fragment"
	AppendToGraph/L=y_org_time/B=x_time root:quantifChecks:Org_smth vs root:index:t_series
	AppendToGraph/L=y_Org44/B=x_org root:quantifChecks:Org44_smth vs root:quantifChecks:Org_smth
	AppendToGraph/L=y_Org43/B=x_Org44 root:quantifChecks:Org43_smth vs root:quantifChecks:Org44_smth
//	AppendToGraph/L=y_Org44/B=x_org root:quantifChecks:line_0p2,root:quantifChecks:line_0p08,root:quantifChecks:line_0p03
//	AppendToGraph/L=y_Org43/B=x_Org44 root:quantifChecks:line_1_2,root:quantifChecks:unity
	ModifyGraph margin(left)=58,margin(bottom)=43
	ModifyGraph mode(Org44_smth)=3,mode(Org43_smth)=3
	ModifyGraph marker(Org44_smth)=19,marker(Org43_smth)=19
	ModifyGraph lSize(Org_smth)=2
//	ModifyGraph lStyle(line_0p2)=3,lStyle(line_0p08)=3,lStyle(line_0p03)=3,lStyle(line_1_2)=3
//////	ModifyGraph lStyle(unity)=3
//	ModifyGraph rgb(line_0p2)=(0,0,0),rgb(line_0p08)=(0,0,0),rgb(line_0p03)=(0,0,0)
//	ModifyGraph rgb(line_1_2)=(0,0,0),rgb(unity)=(0,0,0)
	ModifyGraph msize(Org44_smth)=4,msize(Org43_smth)=4
	ModifyGraph zColor(Org_smth)={root:quantifChecks:waveforcolor_org,*,*,Rainbow},zColor(Org44_smth)={root:quantifChecks:waveforcolor_org,*,*,Rainbow}
	ModifyGraph zColor(Org43_smth)={root:quantifChecks:waveforcolor_org,*,*,Rainbow}
	ModifyGraph tick=2
	ModifyGraph mirror(y_org_time)=1,mirror(x_time)=1
	ModifyGraph nticks(x_time)=10
	ModifyGraph font="Arial"
	ModifyGraph minor(x_time)=1
	ModifyGraph sep(x_time)=20
	ModifyGraph fsize=10
	ModifyGraph lblPos(y_org_time)=48,lblPos(y_Org44)=52,lblPos(x_org)=41,lblPos(y_Org43)=48
	ModifyGraph lblPos(x_Org44)=41
	ModifyGraph lblLatPos(y_org_time)=3,lblLatPos(y_Org44)=3,lblLatPos(x_org)=-6
	ModifyGraph freePos(y_org_time)=0
	ModifyGraph freePos(x_time)={0,y_org_time}
	ModifyGraph freePos(y_Org44)={0,x_org}
	ModifyGraph freePos(x_org)={0,y_Org44}
	ModifyGraph freePos(y_Org43)={0,x_Org44}
	ModifyGraph freePos(x_Org44)={0,y_Org43}
	ModifyGraph axisEnab(y_org_time)={0.6,1}
	ModifyGraph axisEnab(y_Org44)={0,0.45}
	ModifyGraph axisEnab(x_org)={0,0.45}
	ModifyGraph axisEnab(y_Org43)={0,0.45}
	ModifyGraph axisEnab(x_Org44)={0.55,1}
	ModifyGraph dateInfo(x_time)={0,0,0}
	ModifyGraph gaps=0
	Label y_org_time "\\f01Organics g/m3"
	Label x_time " "
	Label y_Org44 "\\f01Org m/z 44, g/m3"
	Label x_org "\\f01Organics, g/m3"
	Label y_Org43 "\\f01Org m/z 43, g/m3"
	Label x_Org44 "\\f01Org m/z 44, g/m3"
	ShowInfo
	TextBox/N=Org_title/F=0/B=1/A=MC/X=-34.59/Y=60.91 "\\f01\\Z14Organics Diagnostics"
	ColorScale/N=Org_CS/F=0/B=1/A=MT/X=26.38/Y=0.34/E trace=Org_smth, vert=0
	ColorScale/C/N=Org_CS heightPct=2, widthPct=50, tickLen=4, nticks=10, fsize=10
	ColorScale/C/N=Org_CS lblMargin=0, minor=1
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function FD_Org_vs_SO4_plot()
	PauseUpdate; Silent 1		// building window...
	Display/N=Org_vs_SO4_plot  /W=(275,150, 675,350) as "Org_vs_SO4_plot"
	AppendToGraph root:quantifChecks:Org vs root:quantifChecks:SO4
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(Org)={root:quantifChecks:waveforcolor_org_vs_so4,*,*,Rainbow}
	ModifyGraph font="Arial"
	ModifyGraph fSize=14
	ModifyGraph gaps=0
	Label left "Organics, g/m3"
	Label bottom "SO4, g/m3"
	SetAxis/A/E=1 left
	SetAxis/A/E=1 bottom
	ColorScale/N=Org_vs_SO4_CS/A=RC/X=0.00/E trace=Org, width=10, tickLen=4
	ColorScale/C/N=Org_vs_SO4_CS lblMargin=0
	ShowInfo
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function FD_NO3_vs_Org_plot() 
	PauseUpdate; Silent 1		// building window...
	Display/N=NO3_vs_Org_plot /W=(300,175,700,375) as "NO3_vs_Org_plot"
	AppendtoGraph root:quantifChecks:NO3 vs root:quantifChecks:Org 
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(NO3)={root:quantifChecks:waveforcolor_no3_vs_org,*,*,Rainbow}
	ModifyGraph font="Arial"
	ModifyGraph fSize=14
	ModifyGraph gaps=0
	Label left "NO3, g/m3"
	Label bottom "Organics, g/m3"
	ColorScale/N=NO3_vs_Org_CS/A=RC/X=0.00/E trace=NO3, width=10, tickLen=4
	ColorScale/C/N=NO3_vs_Org_CS lblMargin=0
	ShowInfo
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function FD_Water_vs_Inorganics_plot()
	PauseUpdate; Silent 1		// building window...
	Display/N=Water_vs_Inorganics_plot /W=(325,200,725,400) as "Water_vs_Inorganics_plot"
	AppendToGraph root:quantifChecks:Water vs root:quantifChecks:Inorg
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(Water)={root:quantifChecks:waveforcolor_water,*,*,Rainbow}
	ModifyGraph font="Arial"
	ModifyGraph fSize=14
	ModifyGraph gaps=0
	Label left "Water, g/m3"
	Label bottom "Inorganics, g/m3"
	SetAxis/A/E=1 left
	SetAxis/A/E=1 bottom
	ColorScale/N=Water_CS/A=RC/X=0.00/E trace=Water, width=10, tickLen=4, lblMargin=0
	ShowInfo
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End



// ************* NOT IN AMS PANEL YET ***************

// not functional - kept for future reference
Function FD_SO4_frag_scatter()
	PauseUpdate; Silent 1		// building window...
	Display/N=SO4_frag_scatter /W=(65.25,50,744.75,528.5) as "SO4_frag_scatter"
	AppendToGraph/L=y_64_48/B=x_64_48 root:quantifChecks:SO4_64_smth vs root:quantifChecks:SO4_48_smth
	AppendToGraph/L=y_80_48/B=x_80_48 root:quantifChecks:SO4_80_smth vs root:quantifChecks:SO4_48_smth
	AppendToGraph/L=y_81_48/B=x_81_48 root:quantifChecks:SO4_81_smth vs root:quantifChecks:SO4_48_smth
	AppendToGraph/L=y_98_48/B=x_98_48 root:quantifChecks:SO4_98_smth vs root:quantifChecks:SO4_48_smth
	ModifyGraph margin(left)=72,margin(bottom)=54
	ModifyGraph mode=2
	ModifyGraph lSize=2
	ModifyGraph zColor(SO4_64_smth)={root:index:t_series,*,*,Rainbow},zColor(SO4_80_smth)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(SO4_81_smth)={root:index:t_series,*,*,Rainbow},zColor(SO4_98_smth)={root:index:t_series,*,*,Rainbow}
	ModifyGraph nticks=10
	ModifyGraph lblPos(y_64_48)=49,lblPos(x_64_48)=42,lblPos(y_80_48)=49,lblPos(x_80_48)=42
	ModifyGraph lblPos(y_81_48)=48,lblPos(x_81_48)=42,lblPos(y_98_48)=48,lblPos(x_98_48)=42
	ModifyGraph lblLatPos(y_64_48)=1,lblLatPos(x_64_48)=3,lblLatPos(y_80_48)=9,lblLatPos(x_80_48)=-1
	ModifyGraph lblLatPos(x_81_48)=3,lblLatPos(y_98_48)=-1,lblLatPos(x_98_48)=2
	ModifyGraph freePos(y_64_48)={0,x_64_48}
	ModifyGraph freePos(x_64_48)={0,y_64_48}
	ModifyGraph freePos(y_80_48)=-318
	ModifyGraph freePos(x_80_48)={0,y_80_48}
	ModifyGraph freePos(y_81_48)={0,x_81_48}
	ModifyGraph freePos(x_81_48)={0,y_81_48}
	ModifyGraph freePos(y_98_48)=-318
	ModifyGraph freePos(x_98_48)={0,y_98_48}
	ModifyGraph axisEnab(y_64_48)={0.55,1}
	ModifyGraph axisEnab(x_64_48)={0,0.45}
	ModifyGraph axisEnab(y_80_48)={0.55,1}
	ModifyGraph axisEnab(x_80_48)={0.55,1}
	ModifyGraph axisEnab(y_81_48)={0,0.45}
	ModifyGraph axisEnab(x_81_48)={0,0.45}
	ModifyGraph axisEnab(y_98_48)={0,0.45}
	ModifyGraph axisEnab(x_98_48)={0.55,1}
	Label y_64_48 "SO\\B4\\M at m/z 64"
	Label x_64_48 "SO\\B4\\M at m/z 48"
	Label y_80_48 "SO\\B4\\M at m/z 80"
	Label x_80_48 "SO\\B4\\M at m/z 48"
	Label y_81_48 "SO\\B4\\M at m/z 81"
	Label x_81_48 "SO\\B4\\M at m/z 48"
	Label y_98_48 "SO\\B4\\M at m/z 98"
	Label x_98_48 "SO\\B4\\M at m/z 48"
	ShowInfo
	TextBox/N=text0/B=1/A=MC/X=-41.45/Y=41.62 "\\f04m/z 64\r\\f00m/z 48"
	TextBox/N=text0_1/B=1/A=MC/X=10.10/Y=-12.72 "\\f04m/z 98\r\\f00m/z 48"
	TextBox/N=text0_2/B=1/A=MC/X=12.69/Y=41.23 "\\f04m/z 80\r\\f00m/z 48"
	TextBox/N=text0_3/B=1/A=MC/X=-43.13/Y=-13.49 "\\f04m/z 81\r\\f00m/z 48"
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


// not functional - kept for future reference
Function FD_SulfateTypes() 
	PauseUpdate; Silent 1		// building window...
	Display/N=SulfateTypes /W=(42,59.75,699.75,511.25) as "SulfateTypes"
	AppendToGraph/L=y_18_so3/B=x_18_so3 root:quantifChecks:S_18 vs root:quantifChecks:SO4_sum4864
	AppendToGraph/L=y_18_h2so4/B=x_18_h2so4 root:quantifChecks:S_18 vs root:quantifChecks:SO4_sum8198
	AppendToGraph/L=y_32_so3/B=x_32_so3 root:quantifChecks:S_32 vs root:quantifChecks:SO4_sum4864
	AppendToGraph/L=y_32_h2so4/B=x_32_h2so4 root:quantifChecks:S_32 vs root:quantifChecks:SO4_sum8198
	AppendToGraph/L=y_49_so3/B=x_49_so3 root:quantifChecks:S_49 vs root:quantifChecks:SO4_sum4864
	AppendToGraph/L=y_49_h2so4/B=x_49_h2so4 root:quantifChecks:S_49 vs root:quantifChecks:SO4_sum8198
	AppendToGraph/L=y_65_so3/B=x_65_so3 root:quantifChecks:S_65 vs root:quantifChecks:SO4_sum4864
	AppendToGraph/L=y_65_h2so4/B=x_65_h2so4 root:quantifChecks:S_65 vs root:quantifChecks:SO4_sum8198
	AppendToGraph/L=y_66_so3/B=x_66_so3 root:quantifChecks:S_66 vs root:quantifChecks:SO4_sum4864
	AppendToGraph/L=y_66_h2so4/B=x_66_h2so4 root:quantifChecks:S_66 vs root:quantifChecks:SO4_sum8198
	ModifyGraph margin(left)=72,margin(bottom)=72
	ModifyGraph mode=2
	ModifyGraph lSize=2
	ModifyGraph zColor(S_18)={root:index:root:index:t_series,*,*,Rainbow},zColor(S_18#1)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(S_32)={root:index:t_series,*,*,Rainbow},zColor(S_32#1)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(S_49)={root:index:t_series,*,*,Rainbow},zColor(S_49#1)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(S_65)={root:index:t_series,*,*,Rainbow},zColor(S_65#1)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(S_66)={root:index:t_series,*,*,Rainbow},zColor(S_66#1)={root:index:t_series,*,*,Rainbow}
	ModifyGraph noLabel(y_18_h2so4)=2,noLabel(x_32_so3)=2,noLabel(y_32_h2so4)=2,noLabel(x_32_h2so4)=2
	ModifyGraph noLabel(x_49_so3)=2,noLabel(y_49_h2so4)=2,noLabel(x_49_h2so4)=2,noLabel(x_65_so3)=2
	ModifyGraph noLabel(y_65_h2so4)=2,noLabel(x_65_h2so4)=2,noLabel(x_66_so3)=2,noLabel(y_66_h2so4)=2
	ModifyGraph noLabel(x_66_h2so4)=2
	ModifyGraph lblPos(y_18_so3)=62,lblPos(x_18_so3)=45,lblPos(y_18_h2so4)=66,lblPos(x_18_h2so4)=51
	ModifyGraph lblPos(y_32_so3)=63,lblPos(y_32_h2so4)=66,lblPos(y_49_so3)=64,lblPos(y_49_h2so4)=66
	ModifyGraph lblPos(y_65_so3)=63,lblPos(y_65_h2so4)=66,lblPos(y_66_so3)=65,lblPos(y_66_h2so4)=66
	ModifyGraph lblLatPos(y_18_so3)=2,lblLatPos(x_18_so3)=-10,lblLatPos(y_18_h2so4)=2
	ModifyGraph lblLatPos(y_32_so3)=-3,lblLatPos(y_32_h2so4)=-3,lblLatPos(y_49_h2so4)=-1
	ModifyGraph lblLatPos(y_65_so3)=-4,lblLatPos(y_65_h2so4)=-6,lblLatPos(y_66_h2so4)=-2
	ModifyGraph freePos(y_18_so3)=0
	ModifyGraph freePos(x_18_so3)={0,y_18_so3}
	ModifyGraph freePos(y_18_h2so4)={0,x_18_h2so4}
	ModifyGraph freePos(x_18_h2so4)={0,y_18_h2so4}
	ModifyGraph freePos(y_32_so3)=0
	ModifyGraph freePos(x_32_so3)={0,y_32_so3}
	ModifyGraph freePos(y_32_h2so4)={0,x_32_h2so4}
	ModifyGraph freePos(x_32_h2so4)={0,y_32_h2so4}
	ModifyGraph freePos(y_49_so3)=0
	ModifyGraph freePos(x_49_so3)={0,y_49_so3}
	ModifyGraph freePos(y_49_h2so4)={0,x_49_h2so4}
	ModifyGraph freePos(x_49_h2so4)={0,y_49_h2so4}
	ModifyGraph freePos(y_65_so3)=0
	ModifyGraph freePos(x_65_so3)={0,y_65_so3}
	ModifyGraph freePos(y_65_h2so4)={0,x_65_h2so4}
	ModifyGraph freePos(x_65_h2so4)={0,y_65_h2so4}
	ModifyGraph freePos(y_66_so3)=0
	ModifyGraph freePos(x_66_so3)={0,y_66_so3}
	ModifyGraph freePos(y_66_h2so4)={0,x_66_h2so4}
	ModifyGraph freePos(x_66_h2so4)={0,y_66_h2so4}
	ModifyGraph axisEnab(y_18_so3)={0,0.18}, axisEnab(x_18_so3)={0,0.4}
	ModifyGraph axisEnab(y_18_h2so4)={0,0.18}, axisEnab(x_18_h2so4)={0.6,1}
	ModifyGraph axisEnab(y_32_so3)={0.2,0.38}, axisEnab(x_32_so3)={0,0.4}
	ModifyGraph axisEnab(y_32_h2so4)={0.2,0.38}, axisEnab(x_32_h2so4)={0.6,1}
	ModifyGraph axisEnab(y_49_so3)={0.4,0.58}, axisEnab(x_49_so3)={0,0.4}
	ModifyGraph axisEnab(y_49_h2so4)={0.4,0.58}, axisEnab(x_49_h2so4)={0.6,1}
	ModifyGraph axisEnab(y_65_so3)={0.6,0.78}, axisEnab(x_65_so3)={0,0.4}
	ModifyGraph axisEnab(y_65_h2so4)={0.6,0.78}, axisEnab(x_65_h2so4)={0.6,1}
	ModifyGraph axisEnab(y_66_so3)={0.8,1}, axisEnab(x_66_so3)={0,0.4}
	ModifyGraph axisEnab(y_66_h2so4)={0.8,1}, axisEnab(x_66_h2so4)={0.6,1}
	Label y_18_so3 "\\f01m/z 18\\Z09 (no air)"
	Label x_18_so3 "\\f01SO\\B3\\M (48+64)"
	Label y_18_h2so4 " "
	Label x_18_h2so4 "\\f01H\\B2\\MSO\\B4\\M (81+98)"
	Label y_32_so3 "\\f01m/z 32"
	Label y_32_h2so4 " "
	Label y_49_so3 "\\f01m/z 49"
	Label y_49_h2so4 " "
	Label y_65_so3 "\\f01m/z 65"
	Label y_65_h2so4 " "
	Label y_66_so3 "\\f01m/z 66"
	Label y_66_h2so4 " "
	ShowInfo
	ColorScale/N=text0/F=0/B=1/A=MC/X=3.69/Y=-38.34 trace=S_18, heightPct=50
	ColorScale/C/N=text0 width=6, fsize=10, minor=1
	AppendText " "
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


// not functional - kept for future reference
Function FD_Water_Fragments() 
	PauseUpdate; Silent 1		// building window...
	Display/N=Water_Fragments/W=(3.75,38,501,517.25) as "Water_Fragments"
	AppendToGraph/L=y_org_18/B=x_part_org18 root:quantifChecks:org18 vs root:quantifChecks:particle_18
	AppendToGraph/L=y_sulf18/B=x_part_sulf18 root:quantifChecks:sulfate_18 vs root:quantifChecks:particle_18
	AppendToGraph/L=y_gas18/B=x_part_gas18 root:quantifChecks:gas18 vs root:quantifChecks:particle_18
	AppendToGraph/L=y_org18/B=x_sulf_org18 root:quantifChecks:org18 vs root:quantifChecks:sulfate_18
	AppendToGraph/L=water_time/B=x_time root:quantifChecks:Water vs root:index:t_series
	ModifyGraph margin(left)=72,margin(bottom)=72
	ModifyGraph mode(org18)=2,mode(sulfate_18)=2,mode(gas18)=2,mode(org18#1)=2
	ModifyGraph lSize=2
	ModifyGraph zColor(org18)={root:index:t_series,*,*,Rainbow},zColor(sulfate_18)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(gas18)={root:index:t_series,*,*,Rainbow},zColor(org18#1)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zColor(Water)={root:index:t_series,*,*,Rainbow}
	ModifyGraph noLabel(x_part_sulf18)=2,noLabel(x_part_gas18)=2
	ModifyGraph lblPos(y_org_18)=51,lblPos(x_part_org18)=54,lblPos(y_sulf18)=51,lblPos(y_gas18)=54
	ModifyGraph lblPos(x_sulf_org18)=55,lblPos(water_time)=42
	ModifyGraph lblLatPos(y_org_18)=1,lblLatPos(x_part_org18)=-9,lblLatPos(y_sulf18)=3
	ModifyGraph lblLatPos(x_sulf_org18)=-3,lblLatPos(water_time)=-5
	ModifyGraph freePos(y_org_18)=0
	ModifyGraph freePos(x_part_org18)=0
	ModifyGraph freePos(y_sulf18)=0
	ModifyGraph freePos(x_part_sulf18)={0,y_sulf18}
	ModifyGraph freePos(y_gas18)=0
	ModifyGraph freePos(x_part_gas18)={0,y_gas18}
	ModifyGraph freePos(y_org18)={0,x_sulf_org18}
	ModifyGraph freePos(x_sulf_org18)=0
	ModifyGraph freePos(water_time)={0,x_time}
	ModifyGraph freePos(x_time)={0,water_time}
	ModifyGraph axisEnab(y_org_18)={0,0.3}
	ModifyGraph axisEnab(x_part_org18)={0,0.4}
	ModifyGraph axisEnab(y_sulf18)={0.35,0.65}
	ModifyGraph axisEnab(x_part_sulf18)={0,0.4}
	ModifyGraph axisEnab(y_gas18)={0.7,1}
	ModifyGraph axisEnab(x_part_gas18)={0,0.4}
	ModifyGraph axisEnab(y_org18)={0,0.3}
	ModifyGraph axisEnab(x_sulf_org18)={0.6,1}
	ModifyGraph axisEnab(water_time)={0.7,1}
	ModifyGraph axisEnab(x_time)={0.55,1}
	ModifyGraph dateInfo(x_time)={0,0,0}
	Label y_org_18 "\\f01Organic 18"
	Label x_part_org18 "\\f01Particle 18"
	Label y_sulf18 "\\f01Sulfate 18"
	Label y_gas18 "\\f01Air 18"
	Label x_sulf_org18 "\\f01Sulfate 18"
	Label water_time "\\f01Water (ug/m3)"
	Label x_time " "
	ShowInfo
	ColorScale/N=text0/F=0/B=1/A=MC/X=8.13/Y=0.60 trace=org18, heightPct=35, width=6
	ColorScale/C/N=text0 fsize=10, minor=1
	AppendText " "
	TextBox/N=text1/F=0/B=1/A=MC/X=34.78/Y=7.66 "\\f01Data Diagnostics\rWater Calculations"
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


// ************* IE Project Diagnostics ***************

Function FD_IEetalProjectGr()
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:diagnostics:
	Display/N=IEetalProjectGr /W=(9,48.2,616.8,364.4) as "IEetalProjectGr"
	wave corr_fact,corr_fact_flow,airbeam_logged,airbeam_ptof,airbeam
	wave ionEff_logged,ionEff,flowrate,flowrate_logged,ionSingleStr_logged,ionSingleStr
	wave IECalIEVal, IECalTime, IECalABVal,IECalFlowRate,ioneff_to_ab_rel_ratio,IECalIE2ABRatio
		
	AppendToGraph/L=ABCorr corr_fact,corr_fact_flow vs ::index:t_series
	AppendToGraph/L=Airbeam airbeam_logged,airbeam_ptof,airbeam vs ::index:t_series
	AppendToGraph/L=IonEff ionEff_logged,ionEff vs ::index:t_series
	AppendToGraph/L=SI ionSingleStr_logged,ionSingleStr vs ::index:t_series
	AppendToGraph/L=FlowRate flowrate,flowrate_logged vs ::index:t_series
	AppendToGraph/L=IonEff IECalIEVal vs IECalTime
	AppendToGraph/L=Airbeam IECalABVal vs IECalTime
	AppendToGraph/L=FlowRate IECalFlowRate vs IECalTime
	AppendToGraph/L=IE2AB IECalIE2ABRatio vs IECalTime
	AppendToGraph/R=IE2ABCorr ioneff_to_ab_rel_ratio vs ::index:t_series
	SetDataFolder fldrSav0
	ModifyGraph margin(left)=61,margin(bottom)=36,margin(top)=7,margin(right)=36
	ModifyGraph mode(corr_fact)=4,mode(corr_fact_flow)=4,mode(airbeam_logged)=4,mode(airbeam_ptof)=4
	ModifyGraph mode(airbeam)=4,mode(ionEff_logged)=4,mode(ionEff)=4,mode(ionSingleStr_logged)=4
	ModifyGraph mode(ionSingleStr)=4,mode(flowrate)=4,mode(flowrate_logged)=4,mode(IECalIEVal)=3
	ModifyGraph mode(IECalABVal)=3,mode(IECalFlowRate)=3, mode(IECalIE2ABRatio)=3,mode(IECalIEVal)=3
	ModifyGraph mode(ioneff_to_ab_rel_ratio)=4
	ModifyGraph marker(IECalIEVal)=43,marker(IECalABVal)=12,marker(IECalFlowRate)=11, marker(IECalIE2ABRatio)=42
	ModifyGraph marker(corr_fact_flow)=8,marker(airbeam)=8,marker(ionEff)=8,marker(ionSingleStr)=8, marker(flowrate)=8
	ModifyGraph rgb(IECalIEVal)=(44032,29440,58880)
	ModifyGraph rgb(IECalABVal)=(44032,29440,58880)
	ModifyGraph rgb(IECalFlowRate)=(44032,29440,58880)
	ModifyGraph rgb(IECalIE2ABRatio)=(44032,29440,58880)
	ModifyGraph rgb(ioneff_to_ab_rel_ratio)=(0,0,0)
	ModifyGraph msize(corr_fact)=2,msize(corr_fact_flow)=2,msize(airbeam_logged)=2,msize(airbeam_ptof)=2
	ModifyGraph msize(airbeam)=2,msize(ionEff_logged)=2,msize(ionEff)=2,msize(ionSingleStr_logged)=2
	ModifyGraph msize(ionSingleStr)=2,msize(flowrate)=2,msize(flowrate_logged)=2
	ModifyGraph msize(IECalIEVal)=5,msize(IECalABVal)=5,msize(IECalFlowRate)=5,msize(IECalIE2ABRatio)=5
	ModifyGraph msize(ioneff_to_ab_rel_ratio)=2
	ModifyGraph mrkThick(IECalIEVal)=1, mrkThick(IECalABVal)=1,mrkThick(IECalFlowRate)=1, mrkThick(IECalIE2ABRatio)=1
	ModifyGraph gaps(corr_fact)=0,gaps(corr_fact_flow)=0,gaps(airbeam_logged)=0,gaps(airbeam_ptof)=0
	ModifyGraph gaps(airbeam)=0,gaps(ionEff_logged)=0,gaps(ionEff)=0,gaps(ionSingleStr_logged)=0
	ModifyGraph gaps(ionSingleStr)=0,gaps(flowrate)=0,gaps(flowrate_logged)=0
	ModifyGraph zColor(corr_fact)={:diagnostics:FDModeDisplayKey,0,1,Rainbow}		// several fixes in 1.42E  FD_TofTypeDisplayKey ->FDModeDisplayKey
	ModifyGraph zColor(corr_fact_flow)={:diagnostics:FDModeDisplayKey,0,1,Rainbow} //,1}
	ModifyGraph zColor(airbeam_logged)={:diagnostics:FDModeDisplayKey,0,1,Rainbow}
	ModifyGraph zColor(airbeam_ptof)={:diagnostics:FDModeDisplayKey,0,1,Grays} //,1}
	ModifyGraph zColor(airbeam)={:diagnostics:FDModeDisplayKey,0,1,Rainbow},zColor(ionEff_logged)={:diagnostics:FDModeDisplayKey,0,1,Rainbow}
	ModifyGraph zColor(ionEff)={:diagnostics:FDModeDisplayKey,0,1,Rainbow},zColor(ionSingleStr_logged)={:diagnostics:FDModeDisplayKey,0,1,Rainbow}
	ModifyGraph zColor(ionSingleStr)={:diagnostics:FDModeDisplayKey,0,1,Rainbow}
	ModifyGraph zColor(flowrate)={:diagnostics:FDModeDisplayKey,0,1,Rainbow},zColor(flowrate_logged)={:diagnostics:FDModeDisplayKey,0,1,Rainbow}
	ModifyGraph nticks(bottom)=9
	ModifyGraph standoff(ABCorr)=0,standoff(bottom)=0,standoff(Airbeam)=0,standoff(IonEff)=0
	ModifyGraph standoff(SI)=0,standoff(FlowRate)=0
	ModifyGraph lblPos(ABCorr)=90,lblPos(Airbeam)=90,lblPos(IonEff)=89,lblPos(SI)=90
	ModifyGraph lblPos(FlowRate)=90,lblPos(IE2ABCorr)=60,lblPos(IE2AB)=55
	ModifyGraph lblLatPos(IE2ABCorr)=2,lblLatPos(IE2AB)=-3
	ModifyGraph freePos(ABCorr)={0,bottom}
	ModifyGraph freePos(Airbeam)={0,bottom}
	ModifyGraph freePos(IonEff)={0,bottom}
	ModifyGraph freePos(SI)={0,bottom}
	ModifyGraph freePos(FlowRate)=0
	ModifyGraph freePos(IE2ABCorr)=0
	ModifyGraph freePos(IE2AB)=2
	ModifyGraph axisEnab(ABCorr)={0.84,1}
	ModifyGraph axisEnab(Airbeam)={0.67,0.83}
	ModifyGraph axisEnab(IonEff)={0.5,0.66}
	ModifyGraph axisEnab(SI)={0.16,0.32}
	ModifyGraph axisEnab(FlowRate)={0,0.15}
	ModifyGraph axisEnab(IE2ABCorr)={0.33,0.49}
	ModifyGraph axisEnab(IE2AB)={0.33,0.49}
	ModifyGraph dateInfo(bottom)={0,1,0}
	Label ABCorr "AB corr fact"
	Label bottom " "
	Label Airbeam "Airbeam"
	Label IonEff "Ion Eff"
	Label SI "SI"
	Label FlowRate "Flow"
	Label IE2ABCorr "IE/AB Corr fact"
	Label IE2AB "IE/AB"
	ShowInfo
	TextBox/C/N=text0/F=0/A=MC/X=1/Y= 45 "\\Z09\\K(0,15872,65280)corr_fact\r\\K(65280,0,0)corr_fact_flow"
	TextBox/C/N=text1/F=0/A=MC/X=1/Y=27 "\\Z09\\K(65280,0,0airbeam\r\\K(24576,24576,65280)airbeam_logged\r\\K(0,0,0)airbeam_ptof\r\\K(44032,29440,58880)IECalABVal"
	TextBox/C/N=text2/F=0/A=MC/X=1/Y=7 "\\Z09\\K(65280,0,0)ionEff\r\\K(24576,24576,65280)ionEff_logged\r\\K(44032,29440,58880)IECalIEVal"
	TextBox/C/N=text3/F=0/A=MC/X=1/Y=-10 "\\Z09\\K(0,0,0)ioneff_to_ab_rel_ratio\r\\K(44032,29440,58880)IECalIE2ABRatio"
	TextBox/C/N=text4/F=0/A=MC/X=1/Y=-24 "\\Z09\\K(65280,0,0)ionSingleStr\r\\K(24576,24576,65280)ionSingleStr_logged"
	TextBox/C/N=text5/F=0/A=MC/X=1/Y=-44 "\\Z09\\K(65280,0,0)flowrate\r\\K(24576,24576,65280)flowrate_logged\r\\K(44032,29440,58880)IECalFlowRate"
	ControlBar 27
	PopupMenu FD_popup_viewMode,pos={8,2},size={325,24},proc=FD_popMenu_ToFTypeMode,title="Mode"
	PopupMenu FD_popup_viewMode,mode=1,popvalue = "All Modes", value= #"\"All Modes;\"+root:diagnostics:detectorsUsed"
	
	FD_popMenu_ToFTypeMode("All Modes",1,"") 

	string info = IgorInfo(0)
	if (str2num(StringByKey("IGORVERS", info))>=6 )
		ModifyGraph mask={root:diagnostics:FDModeDisplayKey,1,1 }		//1.58G
	else
		ModifyGraph zmrkNum={root:diagnostics:FDModeDisplayKey }
	endif

	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


// essentially the same code as sq_diag_popMenu_ModeType
Function FD_popMenu_ToFTypeMode(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr
	
	wave FDModeDisplayKey = root:diagnostics:FDModeDisplayKey

	if(stringMatch(popStr, "All Modes"))	// all or not found
		FDModeDisplayKey=1
		return 0	
	endif
	
	wave/z ionizationType = root:diagnostics:ionizationType
	if (waveexists(ionizationType))	// we have multiple ionization schemes
		wave detector_num = root:diagnostics:detector_num
		FDModeDisplayKey = (popnum-2 == detector_num[p])		// we have to subtract 2; we count from 1 and the first one is all modes
	else	 // we don't have multiple ionization schemes		
		// first deal with v or w mode	
		wave/z TofTypeVorWKey = $("root:diagnostics:TofType"+popStr[0]+"Key") 
		if (waveexists(TofTypeVorWKey))
			FDModeDisplayKey=TofTypeVorWKey
		else	// we don't have v and w mode switching or cant find toftype
			FDModeDisplayKey=1
		endif
		// now deal with ionization types
		wave/z IonizationKey = $("root:diagnostics:ionization"+popStr[2,strlen(popStr)-1]+"Key")
		if (waveexists(IonizationKey))
			FDModeDisplayKey *= IonizationKey
		endif
	endif

End

// *********************************************************************************************************************************************************************************
// *********************************************************************************************************************************************************************************
// ************* ALL BELOW ARE NEW IN 1.49E ***************

Function sq_FragCheckPanel()
	
	DoWindow/F FragCheckPanel
	if (V_flag==1)
		return 0
	endif
	
	if (!Exists("root:quantifChecks:mz18_C"))		// 1.49E  we need to check that some waves used in the new diagnostic plots exist
		abort "Please press the gold 'Recalculate loadings..' button before using this panel. - aborting from sq_FragCheckPanel"
	endif
	
	PauseUpdate; Silent 1		// building window...	NewPanel/N=FragCheckPanel /W=(290,390,1100,990) as "FragCheckPanel"
	NewPanel/N=FragCheckPanel /W=(93,78,901,657) as "FragCheckPanel"
	ModifyPanel fixedSize=1		//1.57L
	SetDrawLayer UserBack

	SetDrawEnv fsize= 16,fstyle= 1
	DrawText 420,256,"Chemical Fragmentation"
	SetDrawEnv fsize= 16,fstyle= 1
	DrawText 6,22,"Frag Table Modifications & Checks v"+SQVERSION
	SetDrawEnv fsize= 14,fstyle= 1,textrgb= (39168,26112,0),textrot= 90
	DrawText 4,223,"Air interference with Org"
	SetDrawEnv fsize= 14,fstyle= 1,textrgb= (0,34816,52224),textrot= 90
	DrawText 5,393,"O16 coefficient"
	SetDrawEnv fsize= 18,fstyle= 1,textrot= 90
	DrawText 4,549,"Aer. Chemistry"
	SetDrawEnv linefgc= (39168,26112,0),fillpat= 0
	DrawRect 2,30,604,227
	SetDrawEnv linethick= 2,fillpat= 0
	DrawRect 3,406,804,580
	SetDrawEnv linefgc= (0,34816,52224),fillpat= 0
	DrawRect 2,230,410,401
	DrawText 25,50,"Org44 vs Org43"
	DrawText 220,50,"Org29 vs Org43"
	DrawText 420,50,"Org15 vs Org43"
	DrawText 25,245,"NH4_17 vs NH4_16"
	DrawText 320,245,"mz16 vs mz14"
	DrawText 418,281,"Meas. vs Pred. NH4"
	DrawText 545,281,"NO3_46 vs NO3_30"
	DrawText 670,281,"SO4 fragments"
	DrawText 25,420,"particulate water vs total aerosol"
	DrawText 220,420,"Org44 vs Org"
	DrawText 420,420,"NO3 vs Org"
	DrawText 610,420,"SO4 vs Org"
	SetDrawEnv linethick= 2,fillpat= 0
	DrawRect 412,234,801,401
	
	TitleBox title0,pos={608,20},size={203,128},fSize=10,frame=0
	TitleBox title0,variable= root:panel:FragCheckInfo

	Button buttonFragCheck_Kplots,pos={611,184},size={200,20},fsize=10,proc=fc_butt_Kplots,title="Suppl. plots of surface ionization for K"
	Button button_fragCheck_H2Oplots,pos={611,208},size={200,20},fsize=10,proc=fc_butt_H2Oplots,title="Suppl. plots of H2O coefficients at 16,17"
	Button button_wikihelp,pos={328,4},size={60,20},fsize=10,proc=fc_butt_wikiHelp,title="wiki help"
	Button buttonColorLegend,pos={729,36},size={70,20},fsize=10,proc=fc_butt_colorLegend,title="color legend"
	Button button_frag_CO2_44,pos={144,32},size={55,18},fsize=10,proc=sq_butt_fragTableThis,title="frag entry"
	Button button_frag_air_29,pos={340,32},size={55,18},fsize=10,proc=sq_butt_fragTableThis,title="frag entry"		// fixed in 1.51A
	Button button_frag_air_15,pos={534,32},size={55,18},fsize=10,proc=sq_butt_fragTableThis,title="frag entry"  	// fixed in 1.51A
	Button button_frag_O16_16,pos={189,229},size={55,18},fsize=10,proc=sq_butt_fragTableThis,title="frag entry"	   // fixed in 1.51A

	Button button_FC_Org44_v_Org43Graph,pos={201,50},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_NH417_v_NH416Graph,pos={201,244},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_WaterVsTotalGraph,pos={201,421},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_Org44VOrgGraph,pos={396,421},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_NO3VOrgGraph,pos={590,421},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_SO4vOrgGraph,pos={786,420},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_m16_v_m14Graph,pos={396,244},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_Org29_v_Org43Graph,pos={395,50},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_Org15_v_Org43Graph,pos={591,50},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_NH4MeasPredGraph,pos={529,285},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_NO3FragGraph,pos={651,285},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"
	Button button_FC_SO4FragGraph,pos={784,285},size={15,60},fsize=10,proc=sq_butt_popThis,title="p\ro\rp\r<"

	Display/W=(25,50,200,225)/HOST=#
	FC_populate_org44_v_org43Graph()
	RenameWindow #,FC_Org44_v_Org43_GRAPH
	SetActiveSubwindow ##

	Display/W=(220,50,395,225)/HOST=# 
	fc_populate_org29_v_org43Graph()
	RenameWindow #,FC_org29_v_org43GRAPH
	SetActiveSubwindow ##

	Display/W=(415,50,590,225)/HOST=# 
	FC_populate_org15_v_org43Graph()
	RenameWindow #,FC_org15_v_org43GRAPH
	SetActiveSubwindow ##

	Display/W=(25,245,200,400)/HOST=#
	FC_populate_NH417_v_NH416Graph()
	RenameWindow #,FC_NH417_v_NH416GRAPH
	SetActiveSubwindow ##

	Display/W=(220,245,395,400)/HOST=#
	FC_populate_m16_v_m14Graph()
	RenameWindow #,FC_m16_v_m14GRAPH
	SetActiveSubwindow ##

/////////////////////////////////////////////////////// Chemical Fragmentation

	Display/W=(415,285,525,395)/HOST=#
	fc_populate_NH4MeasPredGraph()
	RenameWindow #,FC_H4MeasPredGRAPH 
	SetActiveSubwindow ##

	Display/W=(545,285,650,395)/HOST=#
	fc_populate_NO3FragGraph()
	RenameWindow #,FC_NO3FragGRAPH
	SetActiveSubwindow ##

	Display/W=(670,285,780,395)/HOST=#
	fc_populate_SO4FragGraph()
	RenameWindow #,FC_SO4FragGRAPH 
	SetActiveSubwindow ##

/////////////////////////////////////////////////////// Aerosol Chemistry

	Display/W=(25,420,200,575)/HOST=#
	fc_populate_WaterVstotalGraph()
	RenameWindow #,FC_WaterVstotalGRAPH
	SetActiveSubwindow ##

	Display/W=(220,420,395,575)/HOST=#
	fc_populate_Org44vOrgGraph()
	RenameWindow #,FC_Org44vOrgGRAPH
	SetActiveSubwindow ##

	Display/W=(415,420,590,575)/HOST=#
	fc_populate_NO3VOrgGraph()
	RenameWindow #,FC_NO3VOrgGRAPH 
	SetActiveSubwindow ##

	Display/W=(610,420,785,575)/HOST=#
	fc_populate_SO4vOrgGraph()
	RenameWindow #,FC_SO4vOrgGRAPH
	SetActiveSubwindow ##

End


Function fc_populate_org44_v_org43Graph()
	SetDataFolder root:quantifChecks:
	wave org44,org43

	AppendToGraph org44 vs org43
//	AppendToGraph line_1_2, unity
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(org44)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
//	ModifyGraph mode(unity)=0,lstyle(unity)=2,rgb(unity)=(0,0,0)
//	ModifyGraph mode(line_1_2)=0,lstyle(line_1_2)=4,rgb(line_1_2)=(0,0,0)
	wave org44 = root:quantifChecks:org44
	wave org43 = root:quantifChecks:org43	
	variable graphmax =max(Wavemax(org43), Wavemax(org44))		//1.56N
	variable graphmin =min(WaveMin(org43), WaveMin(org44))
	SetAxis bottom min(0, WaveMin(org43)), Wavemax(org43)
	SetAxis left min(0, WaveMin(org44)), Wavemax(org44)
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A

//	SetDrawEnv xcoord= bottom,ycoord= left
//	DrawLine 0,0,graphmax,graphmax
//	SetDrawEnv dash= 2
//	SetDrawEnv xcoord= bottom,ycoord= left
//	DrawLine 0,0,graphmax,graphmax/2

	if (stringmatch(WinName(0, 1),"fc_org44_v_org43Graph"))
		Label left "Org44 g/m3"
		Label bottom "Org43 g/m3"
		legend
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%Org44] vs root:quantifChecks:FragPanelMedians[][%Org43]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_org29_v_org43Graph()
	SetDataFolder root:quantifChecks:
	wave org29,org43	
	AppendToGraph org29 vs org43
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(org29)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A		//1.56F
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
End

Function fc_populate_org15_v_org43Graph()
	SetDataFolder root:quantifChecks:
	wave org15,org43	
	AppendToGraph org15 vs org43
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(org15)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	if (stringmatch(WinName(0, 1),"fc_org15_v_org43Graph"))
		Label left "Org15 g/m3"
		Label bottom "Org43 g/m3"
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%Org15] vs root:quantifChecks:FragPanelMedians[][%Org43]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_m16_v_m14Graph()
	SetDataFolder root:quantifChecks:
	wave mz16,mz14	
	AppendToGraph mz16 vs mz14	
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(mz16)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	if (stringmatch(WinName(0, 1),"fc_m16_v_m14Graph"))
		Label left "m/z 16 g/m3"
		Label bottom "m/z 14 g/m3"
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%m16] vs root:quantifChecks:FragPanelMedians[][%m14]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E

End

Function fc_populate_NH417_v_NH416Graph()
	SetDataFolder root:quantifChecks:
	wave NH4_17,NH4_16	, org43, org44
	AppendToGraph NH4_17 vs NH4_16
//	AppendToGraph line_1pt1_1
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(NH4_17)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
//	ModifyGraph mode(line_1pt1_1)=0,lstyle(line_1pt1_1)=3,rgb(line_1pt1_1)=(0,0,0)
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	wave NH4_17 = root:quantifChecks:NH4_17
	wave NH4_16 = root:quantifChecks:NH4_16	
	variable graphmax =max(Wavemax(NH4_17), Wavemax(NH4_16))		//1.56N
	variable graphmin =min(WaveMin(NH4_17), WaveMin(NH4_16))
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	SetAxis bottom min(0, WaveMin(org43)), Wavemax(org43)
	SetAxis left min(0, WaveMin(org44)), Wavemax(org44)
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	SetDrawEnv dash= 3
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax*1.1

	if (stringmatch(WinName(0, 1),"fc_NH417_v_NH416Graph"))
		Label left "NH4_17 (NH3) g/m3"
		Label bottom "NH4_16+ (NH2) g/m3"
		legend
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%NH4_17] vs root:quantifChecks:FragPanelMedians[][%NH4_16]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_m16C_v_m18CGraph()
	SetDataFolder root:quantifChecks:
	wave mz16_C,mz18_C
	AppendToGraph mz16_C vs mz18_C
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(mz16_C)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
//	ModifyGraph fSize=8
	ModifyGraph standoff=0
	Label left "m/z 16 Closed g/m3"
	Label bottom "m/z 18 Closed g/m3"
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%mz16_C] vs root:quantifChecks:FragPanelMedians[][%mz18_C]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function fc_populate_m17C_v_m18CGraph()
	SetDataFolder root:quantifChecks:
	wave mz17_C,mz18_C
	AppendToGraph mz17_C vs mz18_C
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(mz17_C)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
//	ModifyGraph fSize=8
	ModifyGraph standoff=0
	Label left "m/z 17 Closed g/m3"
	Label bottom "m/z 18 Closed g/m3"
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%mz17_C] vs root:quantifChecks:FragPanelMedians[][%mz18_C]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
End

Function fc_populate_m39_v_m43Graph()
	SetDataFolder root:quantifChecks:
	wave m39,Org43
	AppendToGraph m39 vs Org43
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(m39)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
//	ModifyGraph fSize=8
	ModifyGraph standoff=0
	Label left "m/z 39(=frag_K[39]) g/m3"
	Label bottom "Org43 g/m3"
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%m39] vs root:quantifChecks:FragPanelMedians[][%Org43]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


Function fc_populate_m41_v_m39Graph()
	SetDataFolder root:quantifChecks:
	wave m41,m39
	AppendToGraph m41 vs m39
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(m41)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
//	ModifyGraph fSize=8
	ModifyGraph standoff=0
	Label left "m/z 41 (K+Org) g/m3"
	Label bottom "m39 (=frag_K[39]) g/m3"
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	//1.51N
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%m41] vs root:quantifChecks:FragPanelMedians[][%m39]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
End

///////////////////////////////////////////////////////////////////////


Function fc_calcPredictNH4()

	wave NH4 = root:quantifChecks:NH4
	wave Chl = root:quantifChecks:Chl
	wave NO3 = root:quantifChecks:NO3
	wave SO4 = root:quantifChecks:SO4
	
	duplicate/o nh4 root:quantifChecks:NH4_predict
	wave NH4_predict = root:quantifChecks:NH4_predict
	
	variable mw_so4 = 98
	variable mw_nh4 = 18
	variable mw_no3 = 63
	variable mw_chl = 35		

	NH4_predict = (2*mw_nh4/mw_so4)*so4 + (mw_nh4/mw_no3)*no3 + (mw_nh4/mw_chl)*chl

End

Function fc_populate_NH4MeasPredGraph()

	 fc_calcPredictNH4()
	 
	SetDataFolder root:quantifChecks:
	wave NH4,NH4_predict
	AppendToGraph NH4 vs NH4_predict
//	AppendToGraph unity
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(NH4)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
//	ModifyGraph mode(unity)=0,lstyle(unity)=2,rgb(unity)=(0,0,0)
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	wave NH4 = root:quantifChecks:NH4
	wave NH4_predict = root:quantifChecks:NH4_predict	
	SetAxis bottom min(0, WaveMin(NH4_predict)), Wavemax(NH4_predict)
	SetAxis left min(0, WaveMin(NH4)), Wavemax(NH4)
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	variable graphmax =max(Wavemax(NH4), Wavemax(NH4_predict))		//1.56N
	variable graphmin =min(WaveMin(NH4), WaveMin(NH4_predict))

	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax
	if (stringmatch(WinName(0, 1),"fc_NH4MeasPredGraph"))
		Label left "NH4 (measured) g/m3"
		Label bottom "NH4_predict g/m3"
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%NH4] vs root:quantifChecks:FragPanelMedians[][%NH4_predict]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_WaterVsTotalGraph()
	SetDataFolder root:quantifChecks:
	wave water, total
	AppendToGraph water vs total
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(water)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	if (stringmatch(WinName(0, 1),"fc_WaterVsTotalGraph"))
		Label left "particulate water g/m3"
		Label bottom "total aerosol g/m3"
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%Water] vs root:quantifChecks:FragPanelMedians[][%Total]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_SO4FragGraph()
	SetDataFolder root:quantifChecks:
	wave SO4_64,SO4_80,SO4_81,SO4_98, SO4_48
	AppendToGraph SO4_64,SO4_80,SO4_81,SO4_98 vs SO4_48
//	AppendToGraph unity,line_1_2,line_1_4,line_1_8
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph  rgb(SO4_64)=(58880,0,0)
	ModifyGraph  rgb(SO4_80)=(44032,29440,58880)
	ModifyGraph  rgb(SO4_81)=(0,52224,0)
	ModifyGraph  rgb(SO4_98)=(0,9472,39168)
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	wave SO4_48 = root:quantifChecks:SO4_48
	wave SO4_64 = root:quantifChecks:SO4_64	
	SetAxis bottom min(0, WaveMin(SO4_48)), Wavemax(SO4_48)
	SetAxis left min(0, WaveMin(SO4_64)), Wavemax(SO4_64)
//	ModifyGraph mode(unity)=0,lstyle(unity)=2,rgb(unity)=(0,0,0)
//	ModifyGraph mode(line_1_2)=0,lstyle(line_1_2)=4,rgb(line_1_2)=(0,0,0)
//	ModifyGraph mode(line_1_4)=0,lstyle(line_1_4)=5,rgb(line_1_4)=(0,0,0)
//	ModifyGraph mode(line_1_8)=0,lstyle(line_1_8)=6,rgb(line_1_8)=(0,0,0)
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	variable graphmax =max(Wavemax(SO4_64), Wavemax(SO4_48))		//1.56N
	variable graphmin =min(WaveMin(SO4_48), WaveMin(SO4_98))
	SetDrawEnv dash= 0
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax
	SetDrawEnv dash= 1
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax/2
	SetDrawEnv dash= 2
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax/4
	SetDrawEnv dash= 3
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax/8

	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax/2
	if (stringmatch(WinName(0, 1),"fc_SO4FragGraph"))
		Label left "SO4_x g/m3"
		Label bottom "SO4_48 (SO) g/m3"
		Legend
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%SO4_64] vs root:quantifChecks:FragPanelMedians[][%SO4_48]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	AppendToGraph root:quantifChecks:FragPanelMedians[][%SO4_80] vs root:quantifChecks:FragPanelMedians[][%SO4_48]
	ModifyGraph mode(FragPanelMedians#1)=3,rgb(FragPanelMedians#1)=(0,0,0)
	AppendToGraph root:quantifChecks:FragPanelMedians[][%SO4_81] vs root:quantifChecks:FragPanelMedians[][%SO4_48]
	ModifyGraph mode(FragPanelMedians#2)=3,rgb(FragPanelMedians#2)=(0,0,0)
	AppendToGraph root:quantifChecks:FragPanelMedians[][%SO4_98] vs root:quantifChecks:FragPanelMedians[][%SO4_48]
	ModifyGraph mode(FragPanelMedians#3)=3,rgb(FragPanelMedians#3)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_NO3FragGraph()
	SetDataFolder root:quantifChecks:
	wave NO3_46, NO3_30
	AppendToGraph NO3_46, vs NO3_30
//	AppendToGraph line_1_2
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(NO3_46)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	wave NO3_30 = root:quantifChecks:NO3_30
	wave NO3_46 = root:quantifChecks:NO3_46
	SetAxis bottom min(0, WaveMin(NO3_30)), Wavemax(NO3_30)
	SetAxis left min(0, WaveMin(NO3_46)), Wavemax(NO3_46)
//	ModifyGraph mode(line_1_2)=0,lstyle(line_1_2)=6,rgb(line_1_2)=(0,0,0)
	variable graphmax =max(Wavemax(NO3_30), Wavemax(NO3_46))		//1.56N
	variable graphmin =min(WaveMin(NO3_30), WaveMin(NO3_46))
	SetDrawEnv dash= 0
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax/2
	if (stringmatch(WinName(0, 1),"fc_NO3FragGraph"))
		Label left "NO3_46 (NO2) g/m3"
		Label bottom "NO3_30 (NO) g/m3"
		legend
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%NO3_46] vs root:quantifChecks:FragPanelMedians[][%NO3_30]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_Org44vOrgGraph()
	SetDataFolder root:quantifChecks:
	wave org44,org
	AppendToGraph org44, vs Org
//	AppendToGraph line_0p2,line_0p08,line_0p03
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(org44)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	wave Org = root:quantifChecks:Org
	wave org44 = root:quantifChecks:org44
	SetAxis bottom min(0, WaveMin(Org)), Wavemax(Org)
	SetAxis left min(0, WaveMin(org44)), Wavemax(org44)
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
//	ModifyGraph mode(line_0p2)=0,lstyle(line_0p2)=2,rgb(line_0p2)=(0,0,44000)
//	ModifyGraph mode(line_0p08)=0,lstyle(line_0p08)=2,rgb(line_0p08)=(44000,0,0)
//	ModifyGraph mode(line_0p03)=0,lstyle(line_0p03)=2,rgb(line_0p03)=(0,44000,0)

	variable graphmax =max(Wavemax(Org), Wavemax(org44))		//1.56N
	variable graphmin =min(WaveMin(org44), WaveMin(Org))
	SetDrawEnv dash= 4
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax*0.02
	SetDrawEnv dash= 8
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax*0.03
	SetDrawEnv dash= 12
	SetDrawEnv xcoord= bottom,ycoord= left 	//1.56N
	DrawLine 0,0,graphmax,graphmax*0.08

	if (stringmatch(WinName(0, 1),"fc_Org44vOrgGraph"))
		Label left "Org44 g/m3"
		Label bottom "Org g/m3"
		Legend
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%Org44] vs root:quantifChecks:FragPanelMedians[][%Org]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E

End

// not used
//Function fc_populate_WaterVsInorgGraph()
//	SetDataFolder root:quantifChecks:
//	AppendToGraph water, vs inorg
//	SetDataFolder root:
//	ModifyGraph mode=3
//	ModifyGraph marker=19
//	ModifyGraph zColor(water)={root:index:t_series,*,*,Rainbow}
//	ModifyGraph zero=1
//	ModifyGraph font="Arial"
//	ModifyGraph standoff=0
//	if (stringmatch(WinName(0, 1),"fc_WaterVsInorgGraph"))
//		Label left "water g/m3"
//		Label bottom "inorganic g/m3"
//	else
//		ModifyGraph fSize=8
//		ModifyGraph margin(left)=28,margin(bottom)=28
//	endif
//End

Function fc_populate_NO3VOrgGraph()
	SetDataFolder root:quantifChecks:
	wave NO3, org
	AppendToGraph NO3, vs Org
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(NO3)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	if (stringmatch(WinName(0, 1),"FC_NO3VOrgGraph"))
		Label left "NO3 g/m3"
		Label bottom "Org g/m3"
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%NO3] vs root:quantifChecks:FragPanelMedians[][%Org]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End

Function fc_populate_SO4vOrgGraph()
	SetDataFolder root:quantifChecks:
	wave SO4, Org
	AppendToGraph SO4, vs Org
	SetDataFolder root:
	ModifyGraph mode=3
	ModifyGraph marker=19
	ModifyGraph zColor(SO4)={root:index:t_series,*,*,Rainbow}
	ModifyGraph zero=1
	ModifyGraph font="Arial"
	ModifyGraph standoff=0
	SetAxis/A/E=3 left		//1.51A
	SetAxis/A/E=3 bottom	//1.51A
	ModifyGraph mode=2,msize=2,lsize=3 	//1.56P
	if (stringmatch(WinName(0, 1),"FC_SO4vOrgGraph"))
		Label left "SO4 g/m3"
		Label bottom "Org g/m3"
	else
		ModifyGraph fSize=8
		ModifyGraph margin(left)=28,margin(bottom)=28
	endif
	//1.51N
	if (!WaveExists(root:quantifChecks:FragPanelMedians))
		fc_FindWaveMedians()
	endif
	AppendToGraph root:quantifChecks:FragPanelMedians[][%SO4] vs root:quantifChecks:FragPanelMedians[][%Org]
	ModifyGraph mode(FragPanelMedians)=3,rgb(FragPanelMedians)=(0,0,0)
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
End


//Function fc_butt_wikiHelp(ctrlName) : ButtonControl
//	String ctrlName
//
//	BrowseUrl "http://cires.colorado.edu/jimenez-group/wiki/index.php/Field_Data_Analysis_Guide#Make_campaign_specific_adjustments_to_fragmentation_table"
//
//End


Function fc_butt_colorLegend(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/F TimeScaleColorLegend
	if (V_flag)
		return 0
	endif
	wave t_series = root:index:t_series
	Make /O /N=(200,1) root:quantifChecks:timeColorLegend		//	vertical legend wave, a 1x200 matrix
	wave timeColorLegend= root:quantifChecks:timeColorLegend
	timeColorLegend=x
	SetScale /I x, WaveMin(t_series),WaveMax(t_series),"dat",root:quantifChecks:timeColorLegend					//	sets Y scale to input range
	display/W=(40,40,430,100)/N=TimeScaleColorLegend as "TimeScaleColorLegend"
	AppendImage root:quantifChecks:timeColorLegend					//	creates image plot; bottom axis enabled
	ModifyImage timeColorLegend ctab= {*,*,Rainbow,0}				//	use chosen color scheme
	ModifyGraph tick(bottom)=0,tick(left)=3,fSize = 10,standoff=0			//	sets up font sizes, etc.
	ModifyGraph noLabel(left)=2							//	lose the bottom axis labels
	ModifyGraph axThick(left)=1							//	lose the bottom axis
	ModifyGraph mirror=2									//	mirror axes, no ticks
	Label bottom " "
	ModifyGraph margin(left)=7,margin(top)=7,margin(right)=7,margin(bottom)=43
	ModifyGraph dateInfo(bottom)={0,1,0}
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E
	ModifyGraph nticks(bottom)=9,minor(bottom)=1
End


Function fc_butt_Kplots(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/F fc_m41_v_m39Graph
	if (!V_flag)
		Display/N=fc_m41_v_m39Graph as "fc_m41_v_m39Graph"
		fc_populate_m41_v_m39Graph()
	endif
	
	DoWindow/F fc_m39_v_m43Graph
	if (!V_flag)
		Display/N=fc_m39_v_m43Graph as "fc_m39_v_m43Graph"
		fc_populate_m39_v_m43Graph()
	endif
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)  //1.56E

End


Function fc_butt_H2Oplots(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/F fc_m16C_v_m18CGraph
	if (!V_flag)
		Display/N=fc_m16C_v_m18CGraph as "fc_m16C_v_m18CGraph"
		fc_populate_m16C_v_m18CGraph()
	endif
	
	DoWindow/F fc_m17C_v_m18CGraph
	if (!V_flag)
		Display/N=fc_m17C_v_m18CGraph as "fc_m17C_v_m18CGraph"
		fc_populate_m17C_v_m18CGraph()
	endif

End


Function sq_butt_FragPanel(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	sq_FragCheckPanel()

End


Function CalcMeanSize(ImageWave, DiameterWave, TimeWave)
wave ImageWave, DiameterWave, TimeWave

	variable idex, numtime
	numtime = dimsize(ImageWave,0)
	
	make/o/n=(numTime) result
	for(idex=0;idex<numTime;idex+=1)
		MatrixOp/o OneSizeDist = row(ImageWave,idex)
		matrixop/o DotProd = OneSizeDist.DiameterWave
// 		result[idex]  = DotProd/sum(OneSizeDist)  //1.57J
	endfor	

End

Function sq_butt_fragTableThis(ctrlName) : ButtonControl
	String ctrlName

//	ctrlName should look like "button_frag_CO2_44"
	string species = stringFromList(2, ctrlName, "_")
	variable mz = str2num(stringFromList(3, ctrlName, "_"))
	string fraglist
	variable pos
	setDataFolder root:frag:
	fraglist = WaveList("frag_*", ";", "" )
	setDataFolder root:
	fraglist = ReplaceString("frag_", fraglist, "")
	pos = WhichListItem(species, fraglist)
	if (numtype(mz)!=0  || pos<0)
		abort "Could not find the frag entry corresponding to "+species+ num2str(mz) 
	endif
	sq_goToFragEntry(species, mz)	// the pop button controls MUST be named correctly, such as button_Mz_PpmGraph

End

Function sq_goToFragEntry(species, mz)
string species
variable mz

	variable column, idex, num
	string str
	DoWindow/F FragPanel
	if (V_flag==0)
		sq_butt_reviewFrags("")
	endif
	
	setDataFolder root:frag:
	string displayedFrags = WaveList("*", ";", "WIN:FragPanel#FragTable" )
	setDataFolder root:
	displayedFrags = ReplaceString("frag_", displayedFrags, "")
	variable pos = WhichListItem(species, displayedFrags)
	
	if (pos<0)		// frag wave not in table
		Checkbox check_frag_O16 ,win=FragPanel ,value=1
		sq_fragPanel_check_Display("check_frag_"+species,1)
		pos = itemsinLIst(displayedFrags)
	else	// 	frag wave in table, now find which column
		num = itemsInList(displayedFrags)
		for (idex=0;idex<num;idex+=1)
			str= StringByKey("COLUMNNAME", TableInfo("FragPanel#FragTable", idex))
			if (stringmatch(species, ReplaceString(".d", ReplaceString("frag_", str, "") ,"")))
 				pos = idex
  				continue
  			endif
  		endfor
  	endif
	
	ModifyTable/W=FragPanel#FragTable selection=(mz-1, pos , mz-1, pos , mz-1, pos ), topLeftCell=(mz-1 , pos)

End


//1.51N addition
Function fc_FindWaveMedians()

	make/o/n=(1,40) root:quantifChecks:FragPanelMedians/Wave=FragPanelMedians		// 40 is arbitrary

	SetDimLabel 1,0,Org, FragPanelMedians
	SetDimLabel 1,1,NO3, FragPanelMedians
	SetDimLabel 1,2,SO4, FragPanelMedians
	SetDimLabel 1,3,NH4, FragPanelMedians
	SetDimLabel 1,4,Chl, FragPanelMedians
	
	SetDimLabel 1,5,Org44, FragPanelMedians
	SetDimLabel 1,6,Org43, FragPanelMedians
	SetDimLabel 1,7,Org29, FragPanelMedians
	SetDimLabel 1,8,Org15, FragPanelMedians
	SetDimLabel 1,9,NH4_17, FragPanelMedians
	SetDimLabel 1,10,NH4_16, FragPanelMedians
	SetDimLabel 1,11,NO3_46, FragPanelMedians
	SetDimLabel 1,12,NO3_30, FragPanelMedians
	SetDimLabel 1,13,SO4_48, FragPanelMedians
	SetDimLabel 1,14,SO4_64, FragPanelMedians
	SetDimLabel 1,15,SO4_80, FragPanelMedians
	SetDimLabel 1,16,SO4_81, FragPanelMedians
	SetDimLabel 1,17,SO4_98, FragPanelMedians

	SetDimLabel 1,18,mz16, FragPanelMedians
	SetDimLabel 1,19,mz14, FragPanelMedians

	SetDimLabel 1,20,Water, FragPanelMedians
	SetDimLabel 1,21,Total, FragPanelMedians

	SetDimLabel 1,22,m30, FragPanelMedians
	SetDimLabel 1,23,m31, FragPanelMedians
	SetDimLabel 1,24,m39, FragPanelMedians
	SetDimLabel 1,25,m41, FragPanelMedians

	SetDimLabel 1,26,NH4_predict, FragPanelMedians

	SetDimLabel 1,27,mz16_C, FragPanelMedians
	SetDimLabel 1,28,mz17_C, FragPanelMedians
	SetDimLabel 1,29,mz18_C, FragPanelMedians

	FragPanelMedians[0][%Org] = gen_findMedian(root:quantifChecks:Org)
	FragPanelMedians[0][%NO3] = gen_findMedian(root:quantifChecks:NO3)
	FragPanelMedians[0][%SO4] = gen_findMedian(root:quantifChecks:SO4)
	FragPanelMedians[0][%NH4] = gen_findMedian(root:quantifChecks:NH4)
	FragPanelMedians[0][%Chl] = gen_findMedian(root:quantifChecks:Chl)
	
	FragPanelMedians[0][%Org44] = gen_findMedian(root:quantifChecks:Org44)
	FragPanelMedians[0][%Org43] = gen_findMedian(root:quantifChecks:Org43)
	FragPanelMedians[0][%Org29] = gen_findMedian(root:quantifChecks:Org29)
	FragPanelMedians[0][%Org15] = gen_findMedian(root:quantifChecks:Org15)
	FragPanelMedians[0][%NH4_17] = gen_findMedian(root:quantifChecks:NH4_17)
	FragPanelMedians[0][%NH4_16] = gen_findMedian(root:quantifChecks:NH4_16)
	FragPanelMedians[0][%NO3_46] = gen_findMedian(root:quantifChecks:NO3_46)
	FragPanelMedians[0][%NO3_30] = gen_findMedian(root:quantifChecks:NO3_30)
	FragPanelMedians[0][%SO4_48] = gen_findMedian(root:quantifChecks:SO4_48)
	FragPanelMedians[0][%SO4_64] = gen_findMedian(root:quantifChecks:SO4_64)
	FragPanelMedians[0][%SO4_80] = gen_findMedian(root:quantifChecks:SO4_80)
	FragPanelMedians[0][%SO4_81] = gen_findMedian(root:quantifChecks:SO4_81)
	FragPanelMedians[0][%SO4_98] = gen_findMedian(root:quantifChecks:SO4_98)

	FragPanelMedians[0][%mz16] = gen_findMedian(root:quantifChecks:mz16)
	FragPanelMedians[0][%mz14] = gen_findMedian(root:quantifChecks:mz14)

	FragPanelMedians[0][%Water] = gen_findMedian(root:quantifChecks:Water)
	FragPanelMedians[0][%Total] = gen_findMedian(root:quantifChecks:Total)

	FragPanelMedians[0][%m30] = gen_findMedian(root:quantifChecks:m30)
	FragPanelMedians[0][%m31] = gen_findMedian(root:quantifChecks:m31)
	FragPanelMedians[0][%m39] = gen_findMedian(root:quantifChecks:m39)
	FragPanelMedians[0][%m41] = gen_findMedian(root:quantifChecks:m41)
	
	FragPanelMedians[0][%NH4_predict] = gen_findMedian(root:quantifChecks:NH4_predict)

	FragPanelMedians[0][%mz16_C] = gen_findMedian(root:quantifChecks:mz16_C)
	FragPanelMedians[0][%mz17_C] = gen_findMedian(root:quantifChecks:mz17_C)
	FragPanelMedians[0][%mz18_C] = gen_findMedian(root:quantifChecks:mz18_C)
End