#pragma TextEncoding = "Windows-1252"
#pragma rtGlobals=3		// Use modern global access method.
#pragma igorVersion=6.3
#include <kbcolorizetraces>
#include <HDF5 Browser>
#include <Percentile and Box Plot>
// #include <FunctionProfiling>

STRCONSTANT SQVERSION="1.62A"

Constant ePToFFractionOpen = 0.503937 // 64/127
Constant ePToFMultipleFactor = 1.98438 // = 1/0.503937
Constant ePToFMaxDVaNm = 5000 // 1.59D  arbitrary max cutoff for ePToF
Constant ePToFSingleNUm = 127 // 1.60D  number of single ePToF positions

//ToF-AMS data processing kit for ToF-AMS analysis Toolkit
//Copyright (C) 2005, 2006, 2007,2008, 2009,2010,2011, 2012, 2013, 2014, 2015, 2016, 2017
//James Allan (SEAES & NCAS, University of Manchester, UK)
//Jonathan Crosier (SEAES & NCAS, University of Manchester, UK)
//Edward Dunlea (CIRES, University of Colorado at Boulder, CO, USA)
//Donna Sueper (CIRES, University of Colorado at Boulder, CO, USA; Aerodyne Research Inc., MA, USA)
//Tim Onasch (Aerodyne Research Inc., MA, USA)
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

///////////////////////////////////////////////////////////////////////////////
// CURRENT STATUS
// see Read me file for details.

// Symbols for Programmers
//& = James (U Manchester)
//* = Jose (CU Boulder)
//$ = Manjula (Aerodyne)
//% = Frank (MPI Mainz)
//@ = Jonny (U Manchester)
//> = Ed (CU Boulder)
//~ = Silke (MPI Mainz)
//^ = Donna (CU Boulder)
//# = Shane (Caltech)

	STRCONSTANT DCMARKER_REG2ONLY_CHANNELS="14,15,16,17,18,20,28,29,32,34,40,44,"
	STRCONSTANT MSAVE_SPECIES_DEFAULT_LIST="Air,Water,NO3,SO4,Org,NH4,Chl"
	STRCONSTANT MSTSERIES_SPECIES_DEFAULT_LIST="Org,NO3,SO4,NH4,Chl" 
	STRCONSTANT PTOFAVE_SPECIES_DEFAULT_LIST="Water,Org,NO3,SO4,NH4,Chl"		// changed in 1.46E so that we don't pretend to do MS of air 
	STRCONSTANT FRAG_CHARS="0123456789*-."		//& Allowed characters in frag lists
	CONSTANT AVOGADRO_NUM=6.0221415e23	// new version in 1.48H// 6.0221367e23	//& Avagadro's number
	CONSTANT MZ_START_VALUE=12    //& start at carbon.  //1.42E change because we use the wave named pt_start all over
//	CONSTANT fit_pr_thresh=0.9998	//& Pearson's R threshold for peak fitting		// not used!!
	CONSTANT EXPECTED_RESOULTION_14_C = 475	//& Expected resolutions
	CONSTANT EXPECTED_RESOULTION_28_C = 650
	CONSTANT EXPECTED_RESOULTION_91_C = 850
	CONSTANT EXPECTED_RESOULTION_184_C = 1000
	CONSTANT EXPECTED_RESOULTION_14_V = 1135
	CONSTANT EXPECTED_RESOULTION_28_V = 1500
	CONSTANT EXPECTED_RESOULTION_91_V = 1950
	CONSTANT EXPECTED_RESOULTION_184_V = 2000
	CONSTANT EXPECTED_RESOULTION_14_W = 2400
	CONSTANT EXPECTED_RESOULTION_28_W = 3100
	CONSTANT EXPECTED_RESOULTION_91_W = 4300
	CONSTANT EXPECTED_RESOULTION_184_W = 4500

	STRCONSTANT FRAG_PANEL_LIST ="air;CO2;O16;water;RH;organic;PAH;Delta02;sulphate;SO3;H2SO4;chloride;HCl;Cl;NH4;NH4_17;nitrate;K"		// modified 1.42A

	STRCONSTANT IONIZATION_TYPE_LIST = "EI;sEI;VUV;Li;Neg;MAB;SP2"	// order important!  it much match values set by daq, added MAB, SP2 in 1.44B


///////////////////////////////////////////////////////////////////////////////
//////////////////// PANEL FUNCTIONS  //////////////////////////
///////////////////////////////////////////////////////////////////////////////

// easy way to start 'er up from pull down menu above
Menu "AMS"		// change in 1.41B, was "Panels" previously

	"AMS Analysis/1",  /q,sq_getAMSwin()

End


// brings panel to front or generates it
Function sq_getAMSWin()
	
	string windows=winlist("ams_panel",";","WIN:64")
	if(strlen(windows)>0)
		dowindow/f ams_panel
	else
		sq_globals()
		sq_ams_panel()		// 1.43I changed from an execute function 
		sq_start_popup()
//		sq_initializeDeconvolveRadio()		//1.60L
	endif
	
End


//> defines all global variables, should be called before anything else is done
Function sq_globals()

	sq_globalsGeneral()
	sq_globalsHDFIndex()
	sq_globalsCorrections()
	sq_globalsMS()
	sq_globalsPToF()
	sq_globalsChecks()
	sq_globalsMisc()

	// moved in 1.49E  This was originally performed in the get index step.  Moved here where it makes more sense.
	newdatafolder/o root:ms_mats
	// moved in 1.49E.  This was originally performed in the Squirrel fetch backbone funciton.
	newdatafolder/o root:hoard
	Setdatafolder root:

	sq_PromptForFragWaves()

End


// create root:panel folder and globals on main ams panel
Function sq_globalsGeneral()

	if ( datafolderexists( "root:panel" ) != 1 )
		newdatafolder root:panel
	endif
	
	// bottom progress region
	sq_initializeGlobalNVar("root:panel:ams_prog", 100)
	sq_initializeGlobalNVar("root:panel:ams_sqprog", 100)
	sq_initializeGlobalSVar("root:panel:sq_str_status", "Ready...")
	
	// time base region
	sq_initializeGlobalNVar("root:panel:ams_time_interval", 0)		// radio button
	sq_initializeGlobalNVar("root:panel:ams_time_custom", 0)		// radio button
	sq_initializeGlobalNVar("root:panel:ams_time_saved", 1)			// radio button
	sq_initializeGlobalNVar("root:panel:ams_timestamp", 2)			// drop down menu
	sq_initializeGlobalNVar("root:panel:ams_time_int_val", nan)		// minute variable
	sq_initializeGlobalSVar("root:panel:ams_time_cus_val", "")			// wave name

	// toDo region
	sq_initializeGlobalSVar("root:panel:toDo_makeFromRuns_sv","")
	sq_initializeGlobalSVar("root:panel:toDo_makeFromName_sv", "")
	sq_initializeGlobalSVar("root:panel:sq_toDoList", "")			// used to fill drop down menu
	sq_initializeGlobalSVar("root:panel:sq_toDoWvNm", "")			// drop down menu current choice
	
	// not in panel, used throughout
	sq_initializeGlobalNVar("root:panel:dutycycle_mz", 28)
	sq_initializeGlobalNVar("root:panel:lastfind", 0)		//1.50C change

	sq_initializeGlobalNVar("root:panel:Update_ams_sqprog", 1)		//1.59C change
	KillStrings/z root:panel:ams_status

End


// create root:panel folder and globals on  HDF Index tab in ams panel
Function sq_globalsHDFIndex()

	sq_initializeGlobalNVar("root:panel:load_plot_diagnostics_ck", 1)	// get index check
	sq_initializeGlobalNVar("root:panel:sq_saveint", 0)				// get index interval
	sq_initializeGlobalNVar("root:panel:load_savint_units", 1)			// get index drop down menu choice
	sq_initializeGlobalNVar("root:panel:load_newonly_ck", 0)			// get index check	

	sq_initializeGlobalNVar("root:panel:load_saveExpAfterPreprocess_ck", 1)		// pre-process check
	sq_initializeGlobalNVar("root:panel:preProc_newonly", 0)						// pre-process check

	sq_initializeGlobalNVar("root:panel:load_preProcessStick_MS_ck", 1)		// pre-process check
	sq_initializeGlobalNVar("root:panel:load_preProcessRaw_MS_ck", 0)		// pre-process check
	sq_initializeGlobalNVar("root:panel:load_preProcessStick_PToF_ck", 1)	// pre-process check
	sq_initializeGlobalNVar("root:panel:load_preProcessRaw_PToF_ck", 0	)	// pre-process check
	
	sq_initializeGlobalNVar("root:panel:load_checkMz_MS_ck", 1)		// pre-process check
	sq_initializeGlobalNVar("root:panel:load_checkMz_PToF_ck", 0)		// pre-process check
	sq_initializeGlobalNVar("root:panel:load_checkBk_MS_ck", 1)		// pre-process check
	sq_initializeGlobalNVar("root:panel:load_checkBk_PToF_ck", 0)		// pre-process check

	sq_initializeGlobalNVar("root:panel:duty_cycle_ck", 1)
//	sq_initializeGlobalNVar("root:panel:duty_cycle_ms_ck", 1)
//	sq_initializeGlobalNVar("root:panel:duty_cycle_ptof_ck", 1)
	sq_initializeGlobalNVar("root:panel:recalcSticks_PToF_ck", 0)
	sq_initializeGlobalNVar("root:panel:recalcSticks_MS_ck",  0)
	sq_initializeGlobalNVar("root:panel:recalcSticks_UseNewMz_ck", 0)
	sq_initializeGlobalNVar("root:panel:recalcSticks_UseBkFit_ck", 0)
//	sq_initializeGlobalNVar("root:panel:recalcSticks_UseBkFit_pTOF_ck", 0)		// JDA change in 1.47G
//	sq_initializeGlobalNVar("root:panel:recalcSticks_OC_MS_ck", 0)
	killvariables/z root:panel:load_applyDC_ck
	sq_initializeGlobalNVar("root:panel:load_applyDC_ck",1)		// default changed in 1.41A		// default changed back in 1.43I

	sq_initializeGlobalNVar("root:panel:load_noBFSP_ck", 1)	// get index check		1.49C
	sq_initializeGlobalNVar("root:panel:IntermFilePrefix_ck", 0)	// intermediate file name	1.49E

	sq_initializeGlobalNVar("root:panel:load_noFastMode",0)	 //1.51K
	
	sq_initializeGlobalNVar("root:panel:load_preProcessRaw_ePToF_ck" ,0)
	sq_initializeGlobalNVar("root:panel:load_preProcessStick_ePToF_ck" ,0)
	sq_initializeGlobalNVar("root:panel:load_preProcessStickSum_ePToF" ,0)
	sq_initializeGlobalNVar("root:panel:load_preProcessStick_ePToFSu_ck" ,0)
	sq_initializeGlobalNVar("root:panel:load_preProcessRaw_ePToFSu_ck" ,0)
//	sq_initializeGlobalNVar("root:panel:duty_cycle_eptof_ck" ,0)
	sq_initializeGlobalNVar("root:panel:recalcSticks_ePToF_ck" ,0)

	sq_initializeGlobalNVar("root:panel:PToF_DCgr_ePToFSumDiffScaling",1)	//1.59
End


// create root:panel folder and globals on Corrections tab in ams panel
Function sq_globalsCorrections()

	sq_initializeGlobalSVar("root:panel:precorr", "")
	sq_initializeGlobalSVar("root:panel:postcorr", "")	
	
	// airbeam subtab
	sq_initializeGlobalNVar("root:panel:airbeam_corr_ck", 1)		// Do Corrections check

	sq_initializeGlobalSVar("root:panel:airbeam_corrFactNote", "AB Correction factor is calculated for\rall runs, not just those in todo wave.")		//^ 1.35

	sq_initializeGlobalNVar("root:panel:airbeam_plot_ck", 1)
	sq_initializeGlobalSVar("root:panel:airbeam_refRuns_sv", "")
	sq_initializeGlobalNVar("root:panel:airbeam_smooth_ms", 0)

	sq_initializeGlobalNVar("root:panel:airbeam_corrFlow_ck", 1)		// correct AB for flow rate check		// changed default in 1.42E
	sq_initializeGlobalNVar("root:panel:airbeam_smooth_flow", 0)	// smooth flowrate
	sq_initializeGlobalNVar("root:panel:airbeam_ref_flowOffset_sv", 0)	// flowrate offset
	
	sq_initializeGlobalNVar("root:panel:airbeam_autoSet_ck", 1)		// auto or manual
//	sq_initializeGlobalNVar("root:panel:airbeam_corrToFTypeVar", 0)	// drop down menu
//	sq_initializeGlobalNVar("root:panel:airbeam_ref_MSab_sv", 0)		//1.52H
//	sq_initializeGlobalNVar("root:panel:airbeam_ref_ionEff_sv", 0)
//	sq_initializeGlobalNVar("root:panel:airbeam_ref_flow_sv", 0)
//	sq_initializeGlobalNVar("root:panel:airbeam_ref_ToFab_sv", 0)
//	sq_initializeGlobalNVar("root:panel:ref_singleion_sv", nan)

	sq_initializeGlobalNVar("root:panel:airbeam_curr_mz", 28)		// drop down menu

	wave/z airbeamCorrToFTypeValue = root:panel:airbeamCorrToFTypeValue
	if (!WaveExists(airbeamCorrToFTypeValue))
		make /o/n=(5,1) root:panel:airbeamCorrToFTypeValue		// not used in panel, used in airbeam corrections function
	endif
	
	KillVariables/z root:panel:airbeam_ref_ionStr_s,  root:panel:AB_corrFactNote		// obsolete by at least 1.39
	KillVariables/z root:panel:airbeam_ref_ionStr_s,  root:panel:airbeam_smooth_tof		// obsolete by at least 1.39
	
	// PToF subtab
	sq_initializeGlobalNVar("root:panel:cor3_recalcD", 0)			// Do Corrections check
	sq_initializeGlobalNVar("root:panel:cor3_overrideDC", 1)		// Do Corrections check
	
	sq_initializeGlobalSVar("root:panel:cor3_vg", "")
	sq_initializeGlobalSVar("root:panel:cor3_vl", "")
	sq_initializeGlobalSVar("root:panel:cor3_dx", "")
	sq_initializeGlobalSVar("root:panel:cor3_b", "")

	sq_initializeGlobalNVar("root:panel:cor3_chamber", 0)		// not in panel, but used in the DVa graph aid
//	sq_initializeGlobalNVar("root:panel:cor3_t_offset", 0)		// not in panel, but used in the DVa graph aid

	sq_initializeGlobalNVar("root:panel:cor3_dcMarker1", 5)		// default changed in 1.41B
	sq_initializeGlobalNVar("root:panel:cor3_dcMarker2", 15)	// default changed in 1.41B
	sq_initializeGlobalNVar("root:panel:cor3_dcMarker3", -15)	// default changed in 1.41B
	sq_initializeGlobalNVar("root:panel:cor3_dcMarker4", -5)		// default changed in 1.41B
	sq_initializeGlobalSVar("root:panel:cor3_region1channels", "")
	sq_initializeGlobalSVar("root:panel:cor3_region2channels", DCMARKER_REG2ONLY_CHANNELS)

	sq_initializeGlobalNVar("root:panel:ptof_dcRegion1Allnot2", 0)			//1.59E
 //	obsolete in 1.42E
//	sq_initializeGlobalNVar("root:panel:ptof_dcRunNumber", 0)		// not in panel, but used in the DC marker graph aid
//	KillVariables/z root:panel:ptof_dcUseBinNumUnits		//1.51P
	sq_initializeGlobalNVar("root:panel:ptof_dcUseBinNumUnits", 1)	// in panel, used in the DC markers // default changed in 1.41B// changed back in 1.42E

//	obsolete in 1.42E		// James readded in 1.46A
	wave/z ptof_dcMarkersPtWave =  root:panel:ptof_dcMarkersPtWave
	if(!WaveExists(ptof_dcMarkersPtWave))
		make/o/n=4 root:panel:ptof_dcMarkersPtWave=0		// not in panel, but used in the DC marker graph aid
	endif
	
	KillVariables/z  root:panel:cor3_errptof_ck			// obsolete by at least 1.39

	// Errors subtab
	sq_initializeGlobalNVar("root:panel:error_ms_ck", 0)		// Do Corrections check
	sq_initializeGlobalNVar("root:panel:error_ptof_ck", 0)		// Do Corrections check
	sq_initializeGlobalNVar("root:panel:error_noise", 0.001)
	sq_initializeGlobalNVar("root:panel:error_sigma", 1.2)
	sq_initializeGlobalSVar(" root:panel:err_note", "")
	
	svar err_note = root:panel:err_note
	err_note = "For MS data, the error matrix will be stored memory in the wave called\r"
	err_note+="MSSDiff_p_err. For PToF and MSSClosed error data, users will need\r"
	err_note+="to dump the dataset (see Misc tab) from intermediate files after it has\r"
	err_note+="been generated. The units of MSSDiff_p_err are in Hz, just like MSSDiff_p."

	KillVariables/z root:panel:cor2_noise, root:panel:cor2_errms_ck, root:panel:cor2_sigma	// obsolete by1.39

	// Flow Rate subtab
	sq_initializeGlobalNVar("root:panel:cor4_flowRateSlope", nan)
	sq_initializeGlobalNVar("root:panel:cor4_flowRateIntercept", nan)
	sq_initializeGlobalNVar("root:panel:cor4_flowRateFind_ck", 0)
	sq_initializeGlobalNVar("root:panel:cor4_flowRatePlot_ck", 1)		// default is to plot
	sq_initializeGlobalSVar("root:panel:cor4_FlowRateNote", "")
	svar cor4_FlowRateNote =root:panel:cor4_FlowRateNote
	cor4_FlowRateNote = "The flow rate is used to convert signal intensity to mass concentration.\r"
	cor4_FlowRateNote += "Flow rate is derived from lens pressure (analog input #3) and converted\r"
	cor4_FlowRateNote +=  "using a linear equation. If the logged flow rate is not accurate a new flow\r" 
	cor4_FlowRateNote +=  "rate can be derived using the parameters below (which are derived\r" 
	cor4_FlowRateNote +=  "from flow rate calibration data).\r" 
	cor4_FlowRateNote +=  "New flow rate = flowrate intercept + flow rate slope * (analog in #03)." 

	// IE Cals subtab
	sq_initializeGlobalNVar("root:panel:cor5_IE2ABFind_ck", 0)
	sq_initializeGlobalNVar("root:panel:cor5_IE2ABPlot_ck", 0); 
	nvar cor5_IE2ABPlot_ck = root:panel:cor5_IE2ABPlot_ck 
	cor5_IE2ABPlot_ck=0
	sq_initializeGlobalSVar("root:panel:cor5_IE2ABNote", "")
	svar cor5_IE2ABNote =root:panel:cor5_IE2ABNote
	cor5_IE2ABNote = "Typically, NH4NO3 calibration data is analyzed separately; the IE cal\r"
	cor5_IE2ABNote += "table button allows for users to enter this calibration data for reference.\r"
	cor5_IE2ABNote += "\r"
	cor5_IE2ABNote += "If the ratios IE/AB at calibrations do not change significantly an IE/AB\r"
	cor5_IE2ABNote += "correction is NOT needed. If the ratios IE/AB at calibrations change\r"
	cor5_IE2ABNote += "significantly then an ion efficiency correction is needed. It applied by\r"		
	cor5_IE2ABNote += "multiplying the ion efficiency wave by a ratio of the calibration IE/AB values.\r"
	cor5_IE2ABNote += "Users are to enter time-interpolated values into the wave \r"
	cor5_IE2ABNote += "root:diagnostics:ioneff_to_ab_rel_ratio. \r"
	cor5_IE2ABNote += "\r"
	cor5_IE2ABNote += "Squirrel will make sure that the IE/AB correction is only applied ONCE."
	
	//Enter the value of 1 in the IE cal table,\r"//1.42F
//	cor5_IE2ABNote += "IECalRefFlag column, to use a particular calbration as a reference.\r"
//	cor5_IE2ABNote += "The IE/AB correction to the ion efficiency wave is only applied ONCE."

	// Threshold
//	sq_initializeGlobalNVar("root:panel:cor6_ThresholdCorrFind_ck",0)
//	sq_initializeGlobalSVar("root:panel:cor6_ThresholdNote", "")
//	sq_initializeGlobalSVar("root:panel:cor6_mzExceptions", "14,16,28,32")
//	svar cor6_ThresholdNote =root:panel:cor6_ThresholdNote
//	cor6_ThresholdNote = "This is a correction which can vary in time and in m/z. \r"
//	cor6_ThresholdNote += "This will be discussed at the \r"
//	cor6_ThresholdNote += "the possible variation in time.\r"
//	cor6_ThresholdNote += "The ratio of (m/z values 40)/(m/z values 28) can be used to determine\r"
//	cor6_ThresholdNote += "the possible variation in time.\r"

End


// create root:panel folder and globals on MS tab in ams panel
Function sq_globalsMS()

	// Time series section
	sq_initializeGlobalSVar("root:panel:ms0_speclist", MSTSERIES_SPECIES_DEFAULT_LIST)	// initialized
//	sq_initializeGlobalNVar("root:panel:ms0_source",1)	//1.46B
//	sq_initializeGlobalNVar("root:panel:ms0_graphop_ug",1)
	sq_initializeGlobalNVar("root:panel:ms0_graphOutputType",1)		//1.46B
	sq_initializeGlobalNVar("root:panel:ms0_whisker", 2)		// 5-95 or 0-100 popmenu choice
	sq_initializeGlobalNVar("root:panel:ms0_ion2mass",1)		// convert to ug/m3 checkbox
//	sq_initializeGlobalNVar("root:panel:ms0_auto",1)			// itialicized (non-working) checkbox in 1.39		// killed in 1.41B
	KillVariables/z root:panel:ms0_auto
	
	// Average spectrum section
//	sq_initializeGlobalSVar("root:panel:ms0_sv_specList", MSAVE_SPECIES_DEFAULT_LIST)		// 1.46B
//	sq_initializeGlobalNVar("root:panel:ms0_ck_plotNew", 1)		1.46B
	sq_initializeGlobalNVar("root:panel:ms0_ck_addControls", 1)
	sq_initializeGlobalNVar("root:panel:ms0_msTseries_suffix_ck", 0)		//1.42B
	sq_initializeGlobalNVar("root:panel:ms0_ck_trunc2zero", 1)
//	sq_initializeGlobalNVar("root:panel:ms0_ck_convert2ug", 1)
	sq_initializeGlobalNVar("root:panel:ms0_AvGraphType",1)			// plot sticks or rawpopmenu choice
//	sq_initializeGlobalNVar("root:panel:ms0_graphtype",1)			// plot sticks or rawpopmenu choice
//	nvar ms0_graphtype = root:panel:ms0_graphtype
//	ms0_graphtype=1									// 1.43I make sure default is changed to plot only sticks
//	sq_initializeGlobalNVar("root:panel:ms0_avdata", 1)				// replaced use in 1.46 with ms0_dataType
	sq_initializeGlobalNVar("root:panel:ms0_dataType", 1)				// Diff/Closed or Open popmenu choice
	sq_initializeGlobalNVar("root:panel:ms0_sv_numStdDev", 0)		// italicized (non-working) in 1.39
	sq_initializeGlobalNVar("root:panel:ms0_ck_findAvgBaseline", 0)		  // whether averaged raw spectra should have baselines removed
//	sq_initializeGlobalNVar("root:panel:ms0_ck_autoUpdate", 1)		// killed in 1.41B
	KillVariables/z root:panel:ms0_ck_autoUpdate

	sq_initializeGlobalNVar("root:panel:ms0_ck_logScale", 1)		// for use in subsequent average spectra graph		
	sq_initializeGlobalNVar("root:panel:ms0_ck_lastOption", 0)		// for use in subsequent average spectra graph

//	sq_initializeGlobalNVar("root:panel:ms0_ck_AvgMSSpeciesErr", 0)		// killed in 1.46 //1.47H

	// m/z base section
	sq_initializeGlobalNVar("root:panel:ms0_mz_saved", 1)		// radio button
	sq_initializeGlobalNVar("root:panel:ms0_mz_saved_regrid", 1)	// as saved option
	sq_initializeGlobalNVar("root:panel:ms0_mz_reg", 0)		// radio button - for defined grid
	sq_initializeGlobalNVar("root:panel:ms0_mz_custom", 0)		// radio button
	sq_initializeGlobalNVar("root:panel:ms0_mz_reg_min", 12)	// regrid min
	sq_initializeGlobalNVar("root:panel:ms0_mz_reg_max", 500)	// regrid max
	sq_initializeGlobalNVar("root:panel:ms0_mz_reg_dm", 1e4)	// regrid mass 28 resolution
	sq_initializeGlobalSVar("root:panel:ms0_mz_custom_str", "")	// name of custom wave
	sq_initializeGlobalNVar("root:panel:ms0_mz_area", 1)		// conserve area checkbox
	sq_initializeGlobalNVar("root:panel:ms0_mz_refit", 1)		// use new m/z fitting parameters checkbox

	sq_initializeGlobalNVar("root:panel:ms0_corr", 1)			// use airbeam correction factor
	sq_initializeGlobalNVar("root:panel:ms0_AppendErrorBars", 0)	// append error bars to graph output

	// added in 1.46E
	sq_initializeGlobalSVar("root:panel:MSAvgGrhelp", " If you rename the waves in this graph, some controls may not work.")	// name of custom wave

	KillStrings/z root:panel:ms0_sv_sumformat					// obsolete by at least 1.39
	KillVariables/z root:panel:ms0_ck_includeRaw				// obsolete by at least 1.39

	sq_initializeGlobalNVar("root:panel:ms0_promptForTSMSmaxmz", 0)		// new in 1.47I

	sq_updateMSLists()		//1.57D

	sq_initializeGlobalNVar("root:panel:deconvolveMike", 0)		// use new m/z fitting parameters checkbox

	sq_initializeGlobalNVar("root:panel:PToF_DCgr_IsEPToF", 0)		// use new m/z fitting parameters checkbox

	sq_initializeGlobalNVar("root:panel:ms0_2dRawMinmz", 28.5)
	sq_initializeGlobalNVar("root:panel:ms0_2dRawMaxmz", 60.5)
End


// create root:panel folder and globals on PToF tab in ams panel
Function sq_globalsPToF()

	sq_initializeGlobalSVar("root:panel:tof1_speclist", PTOFAVE_SPECIES_DEFAULT_LIST)

	sq_initializeGlobalNVar("root:panel:tof1_datatype", 1)		// dxdlogda or X vs ToF popmenu choice
	sq_initializeGlobalNVar("root:panel:tof1_graphOption", 1)	// plote single, multiple popmenu choice

	sq_initializeGlobalNVar("root:panel:tof1_dsmooth", 0)		// italicized (non-working) in 1.39
	sq_initializeGlobalNVar("root:panel:tof1_sdsIgnore", 2)		// italicized (non-working) in 1.39
	
	sq_initializeGlobalNVar("root:panel:tof0_corrop", 1)			// use airbeam correction	// default changed in 1.40D

//	sq_initializeGlobalNVar("root:panel:tof1_autoUpdate", 0)		// checkbox		// killled in 1.41B
	KillVariables/z root:panel:tof1_autoUpdate

	sq_initializeGlobalNVar("root:panel:tof1_showNegs", 1)		// checkbox
	sq_initializeGlobalNVar("root:panel:tof1_ugconv", 1)			// checkbox
 	sq_initializeGlobalNVar("root:panel:tof1_norm", 0)			// checkbox	// default changed in 1.48H

//	KillVariables/z root:panel:tof0_gppp								// no longer needed in 1.41A
	sq_initializeGlobalNVar("root:panel:tof0_gppp", 0)					// 1.41B
	sq_initializeGlobalNVar("root:panel:tof0_normBoundStart", Nan)		// initialize to nan, not 0
	sq_initializeGlobalNVar("root:panel:tof0_normBoundStop", Nan)		// initialize to nan, not 0
	sq_initializeGlobalNVar("root:panel:tof0_normBoundYVal", 1000)		// arbitrary
	sq_initializeGlobalNVar("root:panel:tof0_normBoundDisplay", 1)	// panel checkbox

	KillVariables/z root:panel:tof1_viewNormTable				// in 1.40D
//	sq_initializeGlobalNVar("root:panel:tof1_viewNormTable", 0)	// checkbox added in 1.38A

	// diameter base region
	sq_initializeGlobalNVar("root:panel:tof0_d_saved", 1)		// as saved radio button
	sq_initializeGlobalNVar("root:panel:tof0_d_reg", 0)			// set interval radio button
	sq_initializeGlobalNVar("root:panel:tof0_d_reg_min", 0)
	sq_initializeGlobalNVar("root:panel:tof0_d_reg_max", 0)
	sq_initializeGlobalNVar("root:panel:tof0_d_reg_n", 0)
	sq_initializeGlobalNVar("root:panel:tof0_d_custom", 0)		// set custom radio button
	sq_initializeGlobalSVar("root:panel:tof0_d_cus_val", "")		// name of custom wave

	sq_initializeGlobalNVar("root:panel:tof_stats", 1)		// 1.51H

	sq_initializeGlobalNVar("root:panel:tof0_showDC", 0)	//1.51N

	sq_initializeGlobalNVar("root:panel:PToF_DCMarkerSingleRun",1)		//1.51N

	sq_initializeGlobalNVar("root:panel:DVa_NumPToFBins", nan)  //1.51
	
//	sq_initializeGlobalNVar("root:panelePToF_demux_adaptiveDenoise", nan) //  1.57D

	sq_initializeGlobalNVar("root:panel:ePToF_postmatrixInvDC", 1)  //  1.57D, 1.157I

	sq_initializeGlobalNVar("root:panel:FastMS:doMzcalOnAvgs", 1)		//1.57D
	sq_initializeGlobalNVar("root:panel:FastMS:doCopy", 0)		//1.57B

	sq_initializeGlobalNVar("root:panel:FastMS:Blacklist1Transitions",0)		//1.58c

	NewDataFolder/o root:PToF
	
//	sq_initializeGlobalNVar("root:panel:DCgr_ck_alsoSmooth", 0)		//1.57N
	sq_initializeGlobalNVar("root:panel:DCgr_smoothVar", 1)	//1.57N
 
	sq_initializeGlobalSVar("root:panel:DCgr_ePToF_step1", "Step 1. Select ePToF deconvolution")	//1.57N
	KillVariables/z root:panel:DCgr_PToF_step1				// in 1.40D
	sq_initializeGlobalSVar("root:panel:DCgr_PToF_step1",  "Step 1. Select DC marker parameters")	//1.57N

//	sq_initializeGlobalSVar("root:panel:PToF_DC_gr_info", "PToF DC marker calculations are performed at the\rpre-process step and can be redone at Corrections - \rPToF - Reset DC markers - Do Corrections execution.")
	sq_initializeGlobalSVar("root:panel:PToF_DC_gr_info","")
	svar PToF_DC_gr_info = root:panel:PToF_DC_gr_info
	PToF_DC_gr_info ="PToF DC marker calculations can be redone through the Corrections section."

	sq_initializeGlobalSVar("root:panel:PToFInfo", "")	//1.57N
	svar PToFInfo = root:panel:PToFInfo
	PToFInfo="Important!  Values indicated in this panel will be used for preprocessing PToF & ePToF data. If data is already preprocessed data will be overwritten.\r"
	PToFInfo+="For ePTof data you can choose to deconvolve each run at the preprocess stage by selecting a deconvolution method.  This is necessary if you will\r"
	PToFInfo+="be applying time-dependent correction waves later, e.g., for CE or CO2 frags. Alternatively, you can choose 'Dont deconvolve' at the preprocess stage.\r"
	PToFInfo+="Then, when you generate a PToF product for a todo, the runs will be averaged, then deconvolved in a method you can choose then. This results in better\r"
	PToFInfo+="signal to noise. You can switch between approaches by changing the selection in Step 1 and pre-processing again."
	sq_initializeGlobalSVar("root:panel:tof0_PToFePToFtitle",  "")	//1.57O

	sq_initializeGlobalNVar("root:panel:deconvolveJoel", 0)	//1.60N
	sq_initializeGlobalNVar("root:panel:deconvolveNone", 0)	//1.60N
	sq_initializeGlobalNVar("root:panel:deconvolveMike", 0)	//1.60N
	sq_initializeGlobalNVar("root:panel:deconvolve", 0)	//1.60N
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_IsEPToF", 0)	//1.60N
	sq_initializeGlobalNVar("root:panel:PToF_ePToF_TestRegion", 0)	//1.60N

End


// create root:panel folder and globals on Checks tab in ams panel
Function sq_globalsChecks()

	sq_initializeGlobalNVar("root:panel:fDiag_useAirbeam",1)		// default changed in 1.48H
	sq_initializeGlobalSVar("root:panel:fDiag_speciesException", "Air;water_RH;Oplus16;CO2_air;Del02;Others;Over")
	sq_initializeGlobalNVar("root:panel:fDiag_smth", 0)

 	// drop down menu choices are determined at run time
	sq_initializeGlobalNVar("root:panel:fDiag_ColorDiags", 1)
	sq_initializeGlobalNVar("root:panel:fDiag_ChooseDiagnostics", 1)
 	
 	// not used in panel, used elswhere in frag check code
 	sq_initializeGlobalSVar("root:panel:fDiag_diagnostic_batch",  FD_STANDARD_LIST) // will be overwritten in FD_GenerateFragTrends

	KillStrings/z root:panel:fDiag_zaxis_batch
	sq_initializeGlobalSVar("root:panel:fDiag_zaxis_batch", "t_series;"+FD_STANDARD_LIST)

	KillVariables/z root:panel:fDiag_colorby, root:panel:fDiag_colorname		// obsolete in 1.39

	sq_initializeGlobalSVar("root:panel:FragCheckInfo", "")		//1.49E
	svar FragCheckInfo = root:panel:FragCheckInfo
	FragCheckInfo ="All plots except SO4 Fragments\r"
	FragCheckInfo +="are colored by time.\r\r"
	FragCheckInfo +="Median values are black croses.\r\r"		//1.51N
	FragCheckInfo +="In addition to plots in this panel,\r"
	FragCheckInfo +="users should make average mass\r"
	FragCheckInfo +="spectra and time series plots of\r"
	FragCheckInfo +="filter periods to ensure all m/z\r"
	FragCheckInfo +="aerosol loadings are ~ zero."

End


// create root:panel folder and globals on Misc tab in ams panel
Function sq_globalsMisc()

	// graphing region
	sq_initializeGlobalNVar("root:panel:gdef_line_thick", 2)
	variable/g root:panel:gdef_stick_thick=2		// in 1.41 reset this default for everyone to be 2 as per Doug's request
	sq_initializeGlobalNVar("root:panel:gdef_stick_thick", 2)
	sq_initializeGlobalNVar("root:panel:gdef_zline", 1)
	sq_initializeGlobalNVar("root:panel:gdef_cursors", 0)	// cursors
	sq_initializeGlobalNVar("root:panel:gdef_cbut", 0)		// cursor todo wave creation buttons
	sq_initializeGlobalNVar("root:panel:gdef_leg", 0)
	sq_initializeGlobalNVar("root:panel:gdef_scale", 0)
	sq_initializeGlobalNVar("root:panel:gdef_gaps", 0)		// added in 1.43I
	sq_initializeGlobalNVar("root:panel:dontColorTraces", 0)		// added in 1.58c
	
	// options region
	sq_initializeGlobalSVar("root:panel:sq_dump2memWvNm ", "")
	sq_initializeGlobalSVar("root:panel:sq_dump2memList", "Get List")
	sq_initializeGlobalNVar("root:panel:misc_KillAllInnms_mats", 1)  //1.49E1

	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M

	KillVariables/z root:panel:misc_dattim		// obsolete in 1.39.  The month/day setting is set by the operating system & control panels

End


// For initializing global variables
Function sq_initializeGlobalNVar(NVarName, NVarVal)
string NVarName
variable NVarVal

	nvar/z myVar = $NVarName
	if (!NVar_Exists(myVar))
		variable/g $NVarName
		NVar/z myVar = $NVarName
		myVar = NVarVal
	endif

End


// For initializing global strings
Function sq_initializeGlobalSVar(SVarName, SVarVal)
string SVarName
string SVarVal

	svar/z myVar = $SVarName
	if (!SVar_Exists(myVar))
		string/g $SVarName
		SVar/z myVar = $SVarName
		myVar = SVarVal
	endif

End


// initialises popup menus in main AMS panel
//^ works only when the popmenu control is named exactly the same as the variable it is supposed to initialize to
//^ not sure if this is needed anymore, 1.38E
Function sq_start_popup()

	string controls=Controlnamelist("ams_panel")
	variable idex,num=itemsinlist(controls)
	string control
	for(idex=0;idex<num;idex+=1)
		control=stringfromlist(idex,controls)
		ControlInfo /W=ams_panel $control
		nvar/z var=root:panel:$control
		if(abs(v_flag)==3 && nvar_exists(var))
			PopupMenu $control, win=ams_panel,mode=max(1,var)
		endif
	endfor
	sq_pop_toDoList("",0,"Get List")		// added in 1.47

End


// draws the AMS Analysis Panel
Function sq_ams_panel()
	PauseUpdate; Silent 1		// building window...
	NewPanel/N=ams_panel /W=(4,71,435,659) as "AMS Analysis"
	ModifyPanel fixedSize=1
	SetDrawLayer UserBack
	SetDrawEnv fsize= 28,fstyle= 1,textrgb= (1,1,1)
	DrawText 1,33,"ToF-AMS Analysis Toolkit "+SQVERSION
	DrawPICT 382,528,0.75,0.75,ProcGlobal#redsquirrel
	DrawPICT 20,36,0.75,0.75,ProcGlobal#manchesterlogo
	DrawPICT 127,34,0.85,0.85,ProcGlobal#CUlogoNew
	DrawPICT 249,33,0.6,0.6,ProcGlobal#MPIlogo
	DrawPICT 188,36,0.35,0.35,ProcGlobal#ARIlogoNew
	TabControl ams_tab,pos={5,70},size={420,305},proc=sq_tabcontrol
	TabControl ams_tab,tabLabel(0)="HDF Index",tabLabel(1)="Corrections"
	TabControl ams_tab,tabLabel(2)="MS",tabLabel(3)="PToF",tabLabel(4)="Checks"
	TabControl ams_tab,tabLabel(5)="Misc",value= 0
	Button ams_url,pos={300,51},size={85,20}, fSize=10, proc=SQ_URLButton,title="Version Website"
	Button ams_url,help={"Go to the web site for the latest version of the software."}
	Button ams_url_FAQ,pos={386,32},size={45,41},fSize=10, proc=SQ_URLButton,title="FAQs,\r Support"
	Button ams_url_FAQ,help={"Get information on this program."}
	Button ams_credit_butt,pos={300,32},size={85,20},fSize=10, proc=sq_butt_credits,title="Credits"
	Button ams_credit_butt,help={"View the list of major developers of Squirrel."}
	ValDisplay ams_prog,pos={10,570},size={361,12},limits={0,100,0},barmisc={0,0}
	ValDisplay ams_prog,value= #"root:panel:ams_prog"
	TitleBox ams_status,pos={13,534},size={48,21},labelBack=(65535,65535,65535)
	TitleBox ams_status,frame=2,variable= root:panel:sq_str_status
	ValDisplay ams_sqprog,pos={10,557},size={361,12}
	ValDisplay ams_sqprog,limits={0,100,0},barmisc={0,0},highColor= (0,0,65280)
	ValDisplay ams_sqprog,value= #"root:panel:ams_sqprog"
	GroupBox ams_toDoWaveSelection,pos={10,382},size={175,74},title="ToDo Wave Selection", fcolor=(1,1,1)
	GroupBox ams_toDoWaveCreation,pos={190,382},size={232,83},title="ToDo Wave Creation", fcolor=(1,1,1)
	PopupMenu ams_todolist_pop,pos={20,398},size={145.00,19.00},fSize=10, bodyWidth= 120, proc=sq_pop_toDoList,title="ToDo"
	PopupMenu ams_todolist_pop,mode=1,popvalue="all",value= #"root:panel:sq_toDoList+\"Get List;\"\t"
	SetVariable ams_toDoRunInterval,pos={194,399},size={218,16},fSize=10, title="Run formula"
	SetVariable ams_toDoRunInterval,help={"A comma separated list of run numbers, such as \"xx021-xx034,xx272,xx155\""}
	SetVariable ams_toDoRunInterval,value= root:panel:toDo_makeFromRuns_sv
	SetVariable ams_toDoName,pos={242,417},size={170,16},fSize=10, title="Name"
	SetVariable ams_toDoName,help={"The name of the toDo wave to be created or modified."}
	SetVariable ams_toDoName,value= root:panel:toDo_makeFromName_sv
	Button ams_toDoTable,pos={23,428},size={70,20},fSize=10, proc=sq_butt_toDo_edit,title="ToDo Table"
	Button ams_toDoTable,help={"Make a table of the todo waves."}
	Button ams_toDoGraph,pos={103,428},size={70,20},fSize=10, proc=sq_butt_toDo_graph,title="ToDo Graph"
	Button ams_toDoGraph,help={"Make a time series graph of the todo Waves."}
	Button ams_toDoNewToDo,pos={208,438},size={70,18},fSize=10, proc=sq_butt_ToDoFromRuns,title="New ToDo"
	Button ams_toDoNewToDo,help={"Make a new todo wave from the run intervals indicated in the panel using the Name field above."}
	Button ams_toDoAddToBlackList,pos={292,438},size={70,18},fSize=10, proc=sq_butt_addtoblacklist,title="Blacklist runs"
	Button ams_toDoAddToBlackList,help={"Append the run numbers to the blacklist wave.  The entry in the Name field above will be ignored."}
	Button ams_reviewBatch,pos={340,474},size={89,20},fSize=10, proc=sq_butt_reviewBatch,title="Review Batch"
	Button ams_reviewBatch,help={"Review the batch waves. Asterisked species will be ignored."}
	Button ams_reviewFrags,pos={340,501},size={89,20},fSize=10, proc=sq_butt_reviewFrags,title="Review Frags"
	Button ams_reviewFrags,help={"Review Fragment Waves"}
	GroupBox ams_timegroup,pos={10,461},size={325,67},title="Time Base Selection", fcolor=(1,1,1)
	CheckBox ams_time_saved,pos={15,481},size={62,14},fSize=10, proc=sq_timebase_check,title="As saved"
	CheckBox ams_time_saved,variable= root:panel:ams_time_saved,mode=1
	CheckBox ams_time_interval,pos={129.00,481.00},size={90.00,13.00},proc=sq_timebase_check,title="Set interval (min):"		//1.59E
	CheckBox ams_time_interval,fSize=10,variable= root:panel:ams_time_interval,mode=1
	CheckBox ams_time_custom,pos={129.00,505.00},size={124.00,13.00},proc=sq_timebase_check,title="Custom wave (Igor secs):"
	CheckBox ams_time_custom,fSize=10,variable= root:panel:ams_time_custom,mode=1
	PopupMenu ams_timestamp,pos={15,499},size={130,24},fSize=10, proc=sq_pop_getvariable,title="Time stamp is"
	PopupMenu ams_timestamp,mode=2,popvalue="End",value= #"\"Start;End;Middle\""
	SetVariable ams_time_int_val,pos={225.00,479.00},size={50.00,18.00},title=" "
	SetVariable ams_time_int_val,limits={0.0166667,inf,0},value= root:panel:ams_time_int_val
	SetVariable ams_time_cus_val,pos={258.00,505.00},size={70.00,18.00},bodyWidth=70,title=" "
	SetVariable ams_time_cus_val,value= root:panel:ams_time_cus_val

	GroupBox load_groupBox_GetIndex,pos={21,99},size={397,78},title="HDF File Index", fcolor=(1,1,1)
	Button load_getSquirrelIndex,pos={26,116},size={79,30},proc=sq_butt_GetSquirrelIndex,title="Get Index"
	Button load_getSquirrelIndex,fColor=(65280,43520,0)
	Button load_importIndex,pos={26,152},size={40,20},fSize=10, proc=sq_butt_import_index,title="Import"
	Button load_importIndex,help={"Check file locations (useful if any files have been moved)"}
	Button load_rnIndexButt,pos={145,152},size={60,20},fSize=10,proc=sq_butt_editRunIndex,title="Run Table"
	Button load_diagPlotButt size={85,20}, pos={210,152},fSize=10,proc=sq_butt_DiagPlot, title="Diagnostics Plot"
	Button load_diagupdate,pos={300,152},size={101,20},fSize=10, proc=sq_butt_diagupdate,title="Update Diagnostics"
	Button load_checkfiles,pos={70,152},size={71,20},fSize=10, proc=sq_butt_checkfiles,title="Check index"
	Button load_checkfiles,help={"Check file locations (useful if any files have been moved)"}
	CheckBox load_diagplot,pos={110,135},size={94,14},fSize=10, title="Plot Diagnostics"
	CheckBox load_diagplot,help={"Plot a graph of the diagnostics."}
	CheckBox load_diagplot,variable= root:panel:load_plot_diagnostics_ck
	CheckBox load_newonly,pos={110,117},size={62,14},fSize=10, title="New only"
	CheckBox load_newonly,help={"Skip files that have already been indexed"}
	CheckBox load_newonly,variable= root:panel:load_newonly_ck
	SetVariable load_savint,pos={293,113},size={120,16},fSize=10, title="Interval (0=auto)"
	SetVariable load_savint,help={"Saving interval for the AMS logging computer. Set to 0 for automatic."}
	SetVariable load_savint,limits={0,inf,0},value= root:panel:sq_saveint
	PopupMenu load_savint_units,pos={299,131},size={112,24},fSize=10, proc=sq_pop_getvariable,title="Units"
	PopupMenu load_savint_units,mode=1,popvalue="Minutes",value= #"\"Minutes;Seconds\""
	GroupBox load_groupBox_CheckBeforePp,pos={10,179},size={408,45},title="Checks for UMR Stick Recalculations/Adjustments", fcolor=(1,1,1)
	Button load_checkMz,pos={15,196},size={80,20},proc=sq_butt_CheckMz,title="M/z calibration"
	Button load_checkMz,help={"Check the m/z calibration by doing gaussian fits of peaks."}
	Button load_checkMz,fSize=10
	Button load_checkBk,pos={104,196},size={80,20},proc=sq_butt_CheckBk,title="Baseline, UMR"
	Button load_checkBk,help={"Check the background algorythm for individual runs."}
	Button load_checkBk,fSize=10
	Button load_ion_over,pos={189,196},size={70,20},proc=sq_butt_modifySI,title="Single Ion"
	Button load_ion_over,help={"Modify the single ion strengths used during pre-processing."}
	Button load_ion_over,fSize=10
	Button load_checkDCMarkers,pos={265,192},size={80,30},proc=sq_butt_PToFDCGr_show, title="DC markers\r& ePToF Tool"
	Button load_checkDCMarkers,help={"Set the DC markers for PToF background calculations."}
	Button load_checkDCMarkers,fSize=10
	Button load_preProcFast,pos={350,196},size={65,20},proc=sq_butt_FastMSPanel,title="Fast MS"
	Button load_preProcFast,help={"Pre-processing fast mode data"},fSize=10
	CheckBox load_noBFSP,pos={209,117},size={62,14},fSize=10,title="No BFSP"
	CheckBox load_noBFSP,help={"Index BFSP data (typically from IE calibrations)"}
	CheckBox load_noBFSP,variable= root:panel:load_noBFSP_ck
	CheckBox load_noFast,pos={209,135},size={81,14},fSize=10,title="No fast mode"
	CheckBox load_noFast,help={"Index fast mode data (experiments can get big)"}
	CheckBox load_noFast,variable= root:panel:load_noFastMode

	GroupBox load_groupBoxPreProcess,pos={8,224},size={410,148},title="Pre-Process Data (finalize UMR sticks & raw spectra for HR)"
	GroupBox load_groupBoxPreProcess,fColor=(1,1,1)
	Button load_preProc,pos={20,331},size={90,35},proc=sq_butt_pre_process,title="Pre-Process"
	Button load_preProc,help={"Pre-processing must be done to make data types accessible"}
	Button load_preProc,fColor=(65280,43520,0)
	CheckBox load_check_SaveExp,pos={10,240},size={97,26},title="Save experiment\rafter pre-process"
	CheckBox load_check_SaveExp,fSize=10
	CheckBox load_check_SaveExp,variable= root:panel:load_saveExpAfterPreprocess_ck
//	GroupBox load_groupBox_preprocessData,pos={134,242},size={280,36},fColor=(1,1,1)

	TabControl load_preprocessTab,pos={115,237},size={300,131},proc=sq_PreProcessTab
	TabControl load_preprocessTab,tabLabel(0)="MS",tabLabel(1)="PToF"
	TabControl load_preprocessTab,tabLabel(2)="ePToF",value= 0
	GroupBox load_preprocessGroup pos={118,265},size={170,38}, title=""

	CheckBox loadms_preprocessStick,pos={119,268},size={85,14},disable=1,proc=sq_ck_preprocess,title="Stick MS"  // typo 1.60C
	CheckBox loadms_preprocessStick,help={"Pre-process MS data."},fSize=10
	CheckBox loadms_preprocessStick,variable= root:panel:load_preProcessStick_MS_ck
	CheckBox loadms_preprocessRaw,pos={119,282},size={83,14},disable=1,title="Raw MS"
	CheckBox loadms_preprocessRaw,help={"Preprocess the raw (non-stick) MS data"}, proc=sq_ck_preProcess
	CheckBox loadms_preprocessRaw,fSize=10
	CheckBox loadms_preprocessRaw,variable= root:panel:load_preProcessRaw_MS_ck
	CheckBox loadms_dutyCycle,pos={119,305},size={106,14},disable=1,title="MS m/z duty cycle"
	CheckBox loadms_dutyCycle,fSize=10,variable=root:panel:duty_cycle_ck // root:panel:duty_cycle_ms_ck
	CheckBox loadms_recalcStick,pos={119,340},size={59,26},disable=1,proc=sq_ck_preProcess,title="MS stick\rrecalc"
	CheckBox loadms_recalcStick,help={"Recalculate MS sticks."},fSize=10
	CheckBox loadms_recalcStick,variable= root:panel:recalcSticks_MS_ck
	CheckBox loadms_recalcSticks_UseBkFit,variable= root:panel:recalcSticks_UseBkFit_ck
	CheckBox loadms_recalcSticks_UseNewMz,pos={187,333},size={106,14},disable=1,title="Use m/z fit params"
	CheckBox loadms_recalcSticks_UseNewMz,fSize=10
	CheckBox loadms_recalcSticks_UseNewMz,variable= root:panel:recalcSticks_UseNewMz_ck
	CheckBox loadms_recalcSticks_UseBkFit,pos={187,348},size={127,14},disable=1,title="Subtract baseline"
	CheckBox loadms_recalcSticks_UseBkFit,fSize=10

	CheckBox loadpt_preprocessStick,pos={119,268},size={95,14},disable=1,proc=sq_ck_preprocess,title="Stick PToF"
	CheckBox loadpt_preprocessStick,help={"Pre-process PToF data."},fSize=10
	CheckBox loadpt_preprocessStick,variable= root:panel:load_preProcessStick_PToF_ck		//1.59F
//	CheckBox loadpt_preprocessRaw,pos={119,277},size={93,14},disable=1,proc=sq_ck_preprocess,title="Raw PToF"  //1.59F
//	CheckBox loadpt_preprocessRaw,help={"Pre-process PToF data."},fSize=10
//	CheckBox loadpt_preprocessRaw,variable= root:panel:load_preProcessRaw_PToF_ck
	CheckBox loadpt_dutyCycle,pos={119,305},size={116,14},disable=1,title="PToF m/z duty cycle"
	CheckBox loadpt_dutyCycle,fSize=10,variable= root:panel:duty_cycle_ck	// root:panel:duty_cycle_ptof_ck
	CheckBox loadpt_applyDC,pos={119,320},size={102,14},disable=1,title="Apply DC markers"
	CheckBox loadpt_applyDC,fSize=10,variable= root:panel:load_applyDC_ck
	CheckBox loadpt_recalcStick,pos={119,340},size={69,26},disable=1,proc=sq_ck_preProcess,title="PToF stick\rrecalc"
	CheckBox loadpt_recalcStick,help={"Recalculate PToF sticks."},fSize=10
	CheckBox loadpt_recalcStick,variable= root:panel:recalcSticks_PToF_ck
	CheckBox loadpt_recalcSticks_UseNewMz,pos={187,333},size={106,14},disable=1,title="Use m/z fit params"
	CheckBox loadpt_recalcSticks_UseNewMz,fSize=10,variable= root:panel:recalcSticks_UseNewMz_ck
	CheckBox loadpt_recalcSticks_UseBkFit,pos={187,348},size={100,14},disable=1,title="Subtract baseline"
	CheckBox loadpt_recalcSticks_UseBkFit,fSize=10,variable= root:panel:recalcSticks_UseBkFit_ck

	CheckBox loadep_preprocessStick,pos={119,268},size={77,14},proc=sq_ck_preprocess,title="Stick ePToF"
	CheckBox loadep_preprocessStick,help={"Pre-process ePToF data."},fSize=10
	CheckBox loadep_preprocessStick,variable= root:panel:load_preProcessStick_ePToF_ck
//	CheckBox loadep_preprocessRaw,pos={119,277},size={75,14},proc=sq_ck_preprocess,title="Raw ePToF"    //1.59F
//	CheckBox loadep_preprocessRaw,help={"Pre-process ePToF data."},fSize=10
//	CheckBox loadep_preprocessRaw,variable= root:panel:load_preProcessRaw_ePToF_ck    //1.59F
	CheckBox loadep_preprocessStick_Sum,pos={198,268},size={71,14},proc=sq_ck_preProcess,title="Stick ePToFSum"
	CheckBox loadep_preprocessStick_Sum,help={"Pre-process ePToF stick data summed across PToF dimension."}
	CheckBox loadep_preprocessStick_Sum,fSize=10,variable= root:panel:load_preProcessStick_ePToFSu_ck
	CheckBox loadep_preprocessRaw_Sum,pos={198,282},size={71,14},proc=sq_ck_preProcess,title="Raw ePToFSum"
	CheckBox loadep_preprocessRaw_Sum,help={"Pre-process ePToF raw data summed across PToF dimension"}
	CheckBox loadep_preprocessRaw_Sum,fSize=10,variable= root:panel:load_preProcessRaw_ePToFSu_ck
	CheckBox loadep_dutyCycle,pos={119,305},size={122,14},title="ePToF m/z duty cycle"
	CheckBox loadep_dutyCycle,fSize=10,variable=root:panel:duty_cycle_ck // root:panel:duty_cycle_ePToF_ck

	CheckBox loadep_recalcStick,pos={119,338},size={50,26},proc=sq_ck_preProcess,title="ePToF stick\rrecalc"
	CheckBox loadep_recalcStick,help={"Recalculate ePToF sticks."},fSize=10
	CheckBox loadep_recalcStick,value= 0,variable= root:panel:recalcSticks_ePToF_ck
	CheckBox loadep_recalcSticks_UseNewMz,pos={187,333},size={106,14},title="Use m/z fit params"
	CheckBox loadep_recalcSticks_UseNewMz,fSize=10
	CheckBox loadep_recalcSticks_UseNewMz,variable= root:panel:recalcSticks_UseNewMz_ck
	CheckBox loadep_recalcSticks_UseBkFit,pos={187,348},size={100,14},title="Subtract baseline"
	CheckBox loadep_recalcSticks_UseBkFit,fSize=10
	CheckBox loadep_recalcSticks_UseBkFit,variable= root:panel:recalcSticks_UseBkFit_ck

	CheckBox loadepD_DeconvolveNone,pos={305,259},size={102,14},proc=sq_DeconvolveCheckProc,title="Don't deconvolve"
	CheckBox loadepD_DeconvolveNone,fSize=10,variable= root:panel:deconvolveNone,mode=1
	CheckBox loadepD_DeconvolveJoel,pos={305,275},size={91,14},proc=sq_DeconvolveCheckProc,title="Matrix inversion"
	CheckBox loadepD_DeconvolveJoel,fSize=10,variable= root:panel:deconvolveJoel,mode=1
	CheckBox loadepD_DeconvolveMike,pos={305,321},size={102,14},proc=sq_DeconvolveCheckProc,title="Tofwerk inversion"
	CheckBox loadepD_DeconvolveMike,fSize=10,variable= root:panel:deconvolveMike,mode=1
	SetVariable loadepD_smoothSetVar,pos={318,290},size={70,16},bodyWidth=30,title="Smooth"
	SetVariable loadepD_smoothSetVar,fSize=10,limits={-1,8,1},value= root:panel:DCgr_smoothVar
	CheckBox loadepD_SumDiffScal,pos={318,336},size={88,26},title="Scale to\rEPToFSumDiff"
	CheckBox loadepD_SumDiffScal,fSize=10,variable= root:panel:PToF_DCgr_ePToFSumDiffScaling // ePToFScal
	SetVariable loadepD_TestRegionSetvar,pos={318,305},size={89,16},bodyWidth=40,limits={0,0.9,0.1 }, title="BL region"
	SetVariable loadepD_TestRegionSetvar,fSize=10,value= root:panel:PToF_ePToF_TestRegion

//	CheckBox loadms_preprocessStick_MS,pos={139,246},size={85,14},proc=sq_ck_preprocess,title="Stick MS data"
//	CheckBox loadms_preprocessStick_MS,help={"Pre-process MS data."},fSize=10
//	CheckBox loadms_preprocessStick_MS,variable= root:panel:load_preProcessStick_MS_ck
//	CheckBox loadms_preprocessRaw_MS,pos={139,261},size={83,14},title="Raw MS data"
//	CheckBox loadms_preprocessRaw_MS,help={"Preprocess the raw (non-stick) MS data"}
//	CheckBox loadms_preprocessRaw_MS,fSize=10
//	CheckBox loadms_preprocessRaw_MS,variable= root:panel:load_preProcessRaw_MS_ck
////	CheckBox load_preprocessRaw_PToF,pos={290,260},size={93,14},title="Raw PToF data"		// reinstated 1.57C
////	CheckBox load_preprocessRaw_PToF,help={"Preprocess raw (non-stick) PToF data"}
////	CheckBox load_preprocessRaw_PToF,fSize=10
////	CheckBox load_preprocessRaw_PToF,variable= root:panel:load_preProcessRaw_PToF_ck
////	GroupBox load_groupBox_preprocessActio,pos={134,280},size={280,84}
////	GroupBox load_groupBox_preprocessActio,fColor=(1,1,1)
//	CheckBox loadms_dutyCycle_MS,pos={139,283},size={106,14},title="MS m/z duty cycle"
//	CheckBox loadms_dutyCycle_MS,fSize=10,variable= root:panel:duty_cycle_ms_ck
//	CheckBox loadms_recalcStick_MS,pos={139,300},size={91,14},proc=sq_ck_controlsticks,title="MS stick recalc"
//	CheckBox loadms_recalcStick_MS,help={"Recalculate MS sticks."},fSize=10
//	CheckBox loadms_recalcStick_MS,variable= root:panel:recalcSticks_MS_ck
//	CheckBox loadms_recalcSticks_UseNewMz_MS,pos={150,315},size={106,14},disable=2,title="Use m/z fit params"
//	CheckBox loadms_recalcSticks_UseNewMz_MS,fSize=10
//	CheckBox loadms_recalcSticks_UseNewMz_MS,variable= root:panel:recalcSticks_UseNewMz_ck
//	CheckBox loadms_recalcSticks_UseBkFit,pos={150,329},size={127,14},disable=2,title="Use baseline fit params"
//	CheckBox loadms_recalcSticks_UseBkFit,fSize=10

//	CheckBox loadms_recalcSticks_UseBkFit,variable= root:panel:recalcSticks_UseBkFit_ck
//
//	CheckBox loadpt_preprocessStick_PToF,pos={290,245},size={95,14},proc=sq_ck_preprocess,title="Stick PToF data"
//	CheckBox loadpt_preprocessStick_PToF,help={"Pre-process PToF data."},fSize=10
//	CheckBox loadpt_preprocessStick_PToF,variable= root:panel:load_preProcessStick_PToF_ck
//	CheckBox loadpt_dutyCycle_PToF,pos={290,280},size={116,14},title="PToF m/z duty cycle"
//	CheckBox loadpt_dutyCycle_PToF,fSize=10,variable= root:panel:duty_cycle_ptof_ck


//	CheckBox loadpt_recalcStick_PToF,pos={290,319},size={101,14},proc=sq_ck_controlsticks,title="PToF stick recalc"
//	CheckBox loadpt_recalcStick_PToF,help={"Recalculate PToF sticks."},fSize=10

//	CheckBox loadpt_recalcStick_PToF,variable= root:panel:recalcSticks_PToF_ck
//	CheckBox loadpt_recalcSticks_UseNewMz_PT,pos={301,334},size={106,14},title="Use m/z fit params"
//	CheckBox loadpt_recalcSticks_UseNewMz_PT,fSize=10
//	CheckBox loadpt_recalcSticks_UseNewMz_PT,variable= root:panel:recalcSticks_UseNewMz_ck
//	CheckBox loadpt_recalcSticks_UseBkFit_PT,pos={301,348},size={100,14},title="Subtract baseline"
//	CheckBox loadpt_recalcSticks_UseBkFit_PT,fSize=10
//	CheckBox loadpt_recalcSticks_UseBkFit_PT,variable= root:panel:recalcSticks_UseBkFit_pTOF_ck
////	CheckBox load_OCStick_MS,pos={150,345},size={149,14},disable=2,title="DiffS=OpenS-ClosedS (rare)"
////	CheckBox load_OCStick_MS,help={"Recalculate ms open closed stick data"}
////	CheckBox load_OCStick_MS,variable= root:panel:recalcSticks_OC_MS_ck
//	CheckBox loadpt_applyDC,pos={289,293},size={111,26},title="Apply DC markers &\rDeconvolve ePToF"
//	CheckBox loadpt_applyDC,fSize=10,variable= root:panel:load_applyDC_ck
	
	CheckBox load_preproc_new,pos={10,266},size={124,14},title="Un-pre-proc. only"
	CheckBox load_preproc_new,help={"Only preprocess the runs that have not previously been done."}
	CheckBox load_preproc_new,fSize=10,variable= root:panel:preProc_newonly
	CheckBox load_FilePrefix,pos={10,282},size={112,26},title="User chosen interm.\rfile, experim. prefix"
	CheckBox load_FilePrefix,help={"A prompt for entering the prefix of the intermediate files and experiment name."}
	CheckBox load_FilePrefix,fSize=10,variable= root:panel:IntermFilePrefix_ck
	
	//1.56D
	TitleBox load_ShowPrefix,pos={16,287},size={83,13},fsize=10,frame=0,title="Interm. File Prefix:"
	TitleBox load_FilePrefixTitle,pos={16,300},size={38,13},frame=0
	TitleBox load_FilePrefixTitle,fsize=10,variable= root:panel:IntermPrefixExpFileName

	Button cor0_recalc,pos={166,103},size={100,19},proc=sq_butt_corrections,title="Do Corrections"
	Button cor0_recalc,fColor=(65280,43520,0)
	TabControl cor0_tab,pos={13,125},size={400,243},proc=sq_tabcontrol,fStyle=0
	TabControl cor0_tab,tabLabel(0)="Flow Rate",tabLabel(1)="Airbeam"
	TabControl cor0_tab,tabLabel(2)="PToF",tabLabel(3)="Errors"
	TabControl cor0_tab,tabLabel(4)="IE Cals",value= 1
	SetVariable cor0_user_pre,pos={11,105},size={150,16},title="Pre corr. (opt.)"
	SetVariable cor0_user_pre,help={"A macro or function to run before the automatic corrections. Use for user-defined tweaks and corrections."}
	SetVariable cor0_user_pre,fSize=10,value= root:panel:precorr
	SetVariable cor0_user_post,pos={269,105},size={150,16},title="Post corr. (opt.)"
	SetVariable cor0_user_post,help={"A macro or function to run after the automatic corrections. Use for user-defined tweaks and corrections."}
	SetVariable cor0_user_post,fSize=10,value= root:panel:postcorr

	GroupBox cor1_refvals,pos={25,156},size={382,182},title="Create/Overwrite AB corr. factor"
	GroupBox cor1_refvals,fSize=11,fStyle=1,fColor=(1,1,1)
	CheckBox cor1_ab,pos={24,157},size={16,14},proc=sq_update_corrTabLabels,title=""
	CheckBox cor1_ab,help={"Evaluate airbeam and do corrections."}
	CheckBox cor1_ab,variable= root:panel:airbeam_corr_ck
	TitleBox cor1_Note,pos={29,179},size={172,26},fSize=10,frame=0
	TitleBox cor1_Note,variable= root:panel:airbeam_CorrFactNote
	CheckBox cor1_facplot,pos={31,222},size={148,14},title="Show plot after calculations"
	CheckBox cor1_facplot,help={"Plot graph of airbeam correction factors"},fSize=10
	CheckBox cor1_facplot,variable= root:panel:airbeam_plot_ck
	SetVariable cor1_abref,pos={214.00,187.00},size={186.00,15.00},bodyWidth=90,title="AB ref. run(s) or todo"
	SetVariable cor1_abref,fSize=10,value= root:panel:airbeam_refRuns_sv
	SetVariable cor1_absmooth,pos={31,239},size={150,16},title="MS AB smooth (# runs)"
	SetVariable cor1_absmooth,help={"Number of points of smoothing to apply to the airbeam."}
	SetVariable cor1_absmooth,fSize=10
	SetVariable cor1_absmooth,limits={0,inf,1},value= root:panel:airbeam_smooth_ms
	CheckBox cor1_auto_ab,pos={200,173},size={140,14},proc=sq_ck_abAutoSet,title="Auto-set (Use AB ref runs)"
	CheckBox cor1_auto_ab,help={"Set parameters automatically. (Requires reference run number(s))"}
	CheckBox cor1_auto_ab,fSize=10,variable= root:panel:airbeam_autoSet_ck
	GroupBox cor1_groupCorrFlowRate,pos={31,273},size={165,57},fSize=10
	GroupBox cor1_groupCorrFlowRate,fColor=(1,1,1)
	CheckBox cor1_flow,pos={39,275},size={124,14},title="Correct AB for flowrate"
	CheckBox cor1_flow,help={"Include variations in the flowrate in the airbeam correction calculations"}
	CheckBox cor1_flow,fSize=10,variable= root:panel:airbeam_corrFlow_ck
	SetVariable cor1_frsmooth,pos={39,294},size={150,16},title="Flowrate smooth (# runs)"
	SetVariable cor1_frsmooth,help={"Number of points of smoothing to apply to the flowrate."}
	SetVariable cor1_frsmooth,fSize=10
	SetVariable cor1_frsmooth,limits={0,inf,1},value= root:panel:airbeam_smooth_flow
	SetVariable cor1_flowoff,pos={39,311},size={140,16},title="Flowrate offset (cc/s)"
	SetVariable cor1_flowoff,help={"Offset to flowrate when performing corrections (cc/sec)."}
	SetVariable cor1_flowoff,fSize=10
	SetVariable cor1_flowoff,limits={-inf,inf,0},value= root:panel:airbeam_ref_flowOffset_sv
	Button cor1_resetAB,pos={39,340},size={119,20},proc=sq_butt_reset_AB,title="Reset airbeam to m/z"
	Button cor1_resetAB,fSize=10
	PopupMenu cor1_abmz,pos={163,339},size={98,21},proc=sq_pop_airbeam_mz_set,title="MS AB m/z"
	PopupMenu cor1_abmz,help={"m/z to use for the airbeam calculations. (28=N2 32=O2 40=Ar)"}
	PopupMenu cor1_abmz,fSize=10,mode=1,popvalue="28",value= #"\"28;32;40\""
	Button cor1_plotAB,pos={276,341},size={120,20},proc=sq_butt_plotABcorrFact,title="Show AB corr. fact. plot"
	Button cor1_plotAB,fSize=10
	TitleBox cor1_AutSetHelp,pos={200,207},size={195,13},fSize=10,frame=0
	TitleBox cor1_AutSetHelp,variable= root:panel:ABHelperStr		//1.59D
	Button cor1_A_sq_ABTable,pos={191,226},size={15,45},title="p\ro\rp", proc=sq_butt_popThis, fsize=10			//1.52J
	
	GroupBox cor2_err_box,pos={24,200},size={250,60},disable=1,title="Error Parameters"
	GroupBox cor2_err_box,fColor=(1,1,1)
	CheckBox cor2_err_MS,pos={24,160},size={102,14},disable=1,proc=sq_update_corrTabLabels,title="Calc MS Errors"
	CheckBox cor2_err_MS,help={"Do error analysis calculations."},fSize=11,fStyle=1
	CheckBox cor2_err_MS,variable= root:panel:error_ms_ck
	CheckBox cor2_err_ptof,pos={24,181},size={98,14},disable=1,title="Calc PToF Errors"
	CheckBox cor2_err_ptof,help={"Do error analysis calculations."},fSize=11
	CheckBox cor2_err_ptof,fStyle=2,variable= root:panel:error_ptof_ck
	SetVariable cor2_errSig,pos={29,217},size={150,16},disable=1,title="Sigma (unitless)"
	SetVariable cor2_errSig,help={"Sigma factor for error calculation"},fSize=10
	SetVariable cor2_errSig,limits={-inf,inf,0},value= root:panel:error_sigma
	SetVariable cor2_errElec,pos={29,237},size={183,16},disable=1,title="Electronic Noise (bits root ns)"
	SetVariable cor2_errElec,help={"Electronic noise level, in bits root nanoseconds."}
	SetVariable cor2_errElec,fSize=10
	SetVariable cor2_errElec,limits={0,1,0},value= root:panel:error_noise
	TitleBox cor2_errNote,pos={24,283},size={352,52},disable=1,fSize=10,frame=0
	TitleBox cor2_errNote,variable= root:panel:err_Note

	GroupBox cor3_rec_da_g,pos={22,153},size={384,79},disable=1,title="Change dVa parameters, blank = use logged values"
	GroupBox cor3_rec_da_g,fSize=11,fStyle=1,fColor=(1,1,1)
	GroupBox cor3_dcmark,pos={26.00,248.00},size={239.00,73.00},title="DC marker, 'background 'positions (s), 0=use default"
	GroupBox cor3_dcmark,fSize=10,fColor=(1,1,1)
	GroupBox cor3_groupdcmarker,pos={22.00,234.00},size={385.00,130.00},title="Apply DC Markers to PToF"
	GroupBox cor3_groupdcmarker,fSize=11,fStyle=1,fColor=(1,1,1)

	CheckBox cor3_recalc_da,pos={23,152},size={16,14},disable=1,proc=sq_update_corrTabLabels,title=""
	CheckBox cor3_recalc_da,help={"Recalculate Da (aerodynamic diameter) from ToF data and parameters."}
	CheckBox cor3_recalc_da,fSize=10,variable= root:panel:cor3_recalcD
	SetVariable cor3_vl,pos={30,196},size={100,16},disable=1,title="Vl (m/s)"
	SetVariable cor3_vl,help={"Gas velocity in lens in m/s (set to 0 for old calibration)"}
	SetVariable cor3_vl,fSize=10,limits={0,inf,0},value= root:panel:cor3_vl
	SetVariable cor3_vg,pos={30,212},size={100,16},disable=1,title="Vg (m/s)"
	SetVariable cor3_vg,help={"Gas velocity of particle beam in m/s"},fSize=10
	SetVariable cor3_vg,limits={0,inf,0},value= root:panel:cor3_vg
	SetVariable cor3_g,pos={139,212},size={100,16},disable=1,title="b"
	SetVariable cor3_g,help={"gamma value"},fSize=10
	SetVariable cor3_g,limits={0,inf,0},value= root:panel:cor3_b
	SetVariable cor3_dx,pos={139,196},size={100,16},disable=1,title="Dx (nm)"
	SetVariable cor3_dx,help={"Dx value, in nm"},fSize=10
	SetVariable cor3_dx,limits={0,inf,0},value= root:panel:cor3_dx
	Button cor3_butt_DVaTable,pos={317.00,195.00},size={80.00,30.00},proc=sq_butt_DvaTable,title="PToF Parameter\rTable"
	Button cor3_butt_DVaTable,fSize=10,disable=1
	Button cor3_butt_DVaGraph,pos={254.00,195.00},size={60.00,30.00},proc=sq_butt_DVagraph,title="Simple\rGraph Aid"
	Button cor3_butt_DVaGraph,fSize=10,disable=1
	Button cor3_butt_dcgraph,pos={311,271},size={70,30},disable=1,proc=sq_butt_PToFDCGr_show,title="DC markers\r& ePToF Tool"
	Button cor3_butt_dcgraph,fSize=10,disable=1
	CheckBox cor3_dcover,pos={22.00,234.00},size={13.00,13.00},proc=sq_update_corrTabLabels,title=""
	CheckBox cor3_dcover,help={"Override the selection of the number of DC markers to use in PToF mode."}
	CheckBox cor3_dcover,variable= root:panel:cor3_overrideDC,disable=1
	CheckBox cor3_BinUnits_ck,pos={33.00,261.00},size={154.00,24.00},title="Use PToF bin # as units\r if unchecked, s units are used"
	CheckBox cor3_BinUnits_ck,fSize=10,variable= root:panel:ptof_dcUseBinNumUnits,disable=1
	SetVariable cor3_dc1,pos={35.00,288.00},size={94.00,15.00},bodyWidth=30,title="Region 1 start",disable=1
	SetVariable cor3_dc1,help={"Position of DC marker 1 (begin region 1)"},fSize=10
	SetVariable cor3_dc1,limits={0,inf,0},value= root:panel:cor3_dcMarker1
	SetVariable cor3_dc2,pos={34.00,304.00},size={95.00,15.00},bodyWidth=30,title="Region 1 stop",disable=1
	SetVariable cor3_dc2,help={"Position of DC marker 2 (end region 1)"},fSize=10
	SetVariable cor3_dc2,limits={0,inf,0},value= root:panel:cor3_dcMarker2
	SetVariable cor3_dc3,pos={134.00,288.00},size={94.00,15.00},bodyWidth=30,title="Region 2 start",disable=1
	SetVariable cor3_dc3,help={"Position of DC marker 3 (begin region 2)"},fSize=10
	SetVariable cor3_dc3,limits={-inf,inf,0},value= root:panel:cor3_dcMarker3
	SetVariable cor3_dc4,pos={133.00,305.00},size={95.00,15.00},bodyWidth=30,title="Region 2 stop",disable=1
	SetVariable cor3_dc4,help={"Position of DC marker 4 (end region 2)"},fSize=10
	SetVariable cor3_dc4,limits={-inf,inf,0},value= root:panel:cor3_dcMarker4
	SetVariable cor3_region1OnlyMz,pos={33.00,325.00},size={285.00,15.00},bodyWidth=195,title="Region 1 only m/zs",disable=1
	SetVariable cor3_region1OnlyMz,help={"m/z channels that only use DC region 1 in PToF mode."}, proc=sq_PToFRegion1UserOption		//1.59E
	SetVariable cor3_region1OnlyMz,fSize=10,value= root:panel:cor3_region1channels
	SetVariable cor3_region2OnlyMz,pos={33.00,341.00},size={285.00,15.00},bodyWidth=195,title="Region 2 only m/zs",disable=1
	SetVariable cor3_region2OnlyMz,help={"m/z channels that only use DC region 2 in PToF mode."}
	SetVariable cor3_region2OnlyMz,fSize=10,value= root:panel:cor3_region2channels
	CheckBox cor3_Region1OnlyMzs1,pos={267.00,292.00},size={132.00,24.00},proc=sq_PToF_Region1Check,title="Use Region 1 only for all\rm/zs not in Region 2 only."
	CheckBox cor3_Region1OnlyMzs1,fSize=10,variable= root:panel:ptof_dcRegion1Allnot2

	Button cor3_butt_dcgraph,pos={323.00,248.00},size={70.00,30.00},proc=sq_butt_PToFDCGr_show,title="DC markers\r& ePToF Tool"
	Button cor3_butt_dcgraph,fSize=10
	ValDisplay cor3_chamberLength,pos={27.00,180.00},size={133.00,14.00},bodyWidth=40,title="Chamber length (m)"
	ValDisplay cor3_chamberLength,help={"This is set by Tofwerk and Aerodyne at installation. If you feel this value is incorrect change the global value root:panel:cor3_chamber"}
	ValDisplay cor3_chamberLength,fSize=10,frame=0,limits={0,inf,0},barmisc={0,1000}
	ValDisplay cor3_chamberLength,value= #"root:panel:cor3_chamber"
	ValDisplay cor3_chopperDuty,pos={180.00,180.00},size={171.00,14.00},bodyWidth=40,title="Chopper duty cycle (unitless)"
	ValDisplay cor3_chopperDuty,help={"This is set by Tofwerk and Aerodyne at installation. If you feel this value is incorrect change the global value root:panel:cor3_chamber"}
	ValDisplay cor3_chopperDuty,fSize=10,frame=0,limits={0,inf,0},barmisc={0,1000}
	ValDisplay cor3_chopperDuty,value= #"root:diagnostics:chopper_duty"
	TitleBox cor3_DVaWarning,pos={28,166},size={300,13},title="Dva parameter changes will only apply to runs in selected todo."
	TitleBox cor3_DVaWarning,frame=0				//1.17c

	CheckBox cor4_findNewFlowRate,pos={28,158},size={122,14},disable=1,proc=sq_update_corrTabLabels,title="Find new flow rate"
	CheckBox cor4_findNewFlowRate,fSize=11,fStyle=1
	CheckBox cor4_findNewFlowRate,variable= root:panel:cor4_flowRateFind_ck
	SetVariable cor4_flowrateSlope,pos={28,301},size={130,16},disable=1,title="Flow rate slope"
	SetVariable cor4_flowrateSlope,help={"Reference flowrate slope"},fSize=10
	SetVariable cor4_flowrateSlope,limits={0,inf,0},value= root:panel:cor4_flowrateSlope
	SetVariable cor4_flowRateIntercept,pos={28,321},size={130,16},disable=1,title="Flow rate intercept"
	SetVariable cor4_flowRateIntercept,help={"Reference flowrate"},fSize=10
	SetVariable cor4_flowRateIntercept,limits={-inf,inf,0},value= root:panel:cor4_flowrateIntercept
	TitleBox cor4_Note,pos={23,181},size={341,78},disable=1,fSize=10,frame=0
	TitleBox cor4_Note,variable= root:panel:cor4_FlowRateNote
	CheckBox cor4_plotNewFlowRate,pos={28,281},size={105,14},disable=1,title=" Plot new flow rate"
	CheckBox cor4_plotNewFlowRate,fSize=10,variable= root:panel:cor4_flowRatePlot_ck

	CheckBox cor5_findIE2AB,pos={31,157},size={208,14},disable=1,proc=sq_update_corrTabLabels,title="Find and apply IE / AB correction"
	CheckBox cor5_findIE2AB,fSize=11,fStyle=1,variable= root:panel:cor5_IE2ABFind_ck
	TitleBox cor5_Note,pos={26,179},size={356,143},disable=1,fSize=10,frame=0
	TitleBox cor5_Note,variable= root:panel:cor5_IE2ABNote
	CheckBox cor5_findIE2ABPlot,pos={26,331},size={161,14},disable=1,title="Plot  IE / AB correction values"
	CheckBox cor5_findIE2ABPlot,fSize=10,variable= root:panel:cor5_IE2ABPlot_ck
	Button cor5_IEcaltable,pos={243,156},size={100,20},disable=1,proc=sq_butt_IEcalTable,title="IE cal table"
	Button cor5_IEcaltable,fSize=10

	CheckBox ms0_ion2mass_ck,pos={283,101},size={99,14},fSize=10,disable=1,title="Convert to g/m3"
	CheckBox ms0_ion2mass_ck,help={"Convert to g/m3"},variable= root:panel:ms0_ion2mass		// for time series
	CheckBox ms0_corr,pos={283,117},size={120,14},fSize=10, disable=1,title="Use MS AB correction"
	CheckBox ms0_corr,help={"Correct averages, time series and microgram calculations for changes in reflected in the MS airbeam."}
	CheckBox ms0_corr,variable= root:panel:ms0_corr
	CheckBox ms0_appendErrorBars,pos={283,133},size={101,14},title="Calc, plot 1\F'Symbol's\F'Arial' prec. err."		//1.46B
	CheckBox ms0_appendErrorBars,help={"Append error bars to graph."}
	CheckBox ms0_appendErrorBars,fSize=10,variable= root:panel:ms0_appendErrorBars,disable=1
	CheckBox ms0_msTseries_suffix_ck,pos={283,150},size={136,14},fSize=10,disable=1,title="Ask for wave name suffix"		//1.42B
	CheckBox ms0_msTseries_suffix_ck,help={"A prompt will appear requesting a string to append to the newly created species waves"}	//1.42B
	CheckBox ms0_msTseries_suffix_ck,variable= root:panel:ms0_msTseries_suffix_ck					//1.42B

	Button ms0_button_avcalc,pos={190,265},size={75,20},disable=1,proc=sq_butt_MS_Calc,title="Calculate"
	Button ms0_button_avcalc,help={"Perform averaging."},fColor=(65280,43520,0)
	Button ms0_default,pos={25,242},size={110,20},fSize=10,disable=1,proc=sq_butt_MSAveSpeciesDefault,title="Species list to default"
	Button ms0_default,help={"Use default species."}

	Button ms0_butt_ExportForAMSDB pos={275,278},size={140,20},fsize=10,title="Export for AMS database"		//1.48D
	Button ms0_butt_ExportForAMSDB proc=sq_butt_exportDBPanel,disable=1

//	CheckBox ms0_ugconv,pos={193,223},size={99,14},disable=1,fSize=10,title="Convert to g/m3"
//	CheckBox ms0_ugconv,help={"Convert from Hz (default) to gm-3."}
//	CheckBox ms0_ugconv,variable= root:panel:ms0_ck_convert2ug
//	CheckBox ms0_avgraph,pos={192,238},size={89,14},fSize=10,disable=1,title="Plot new graph"
//	CheckBox ms0_avgraph,help={"Plot new graphs of averaged spectra. (Unchecked will simply update waves in memory.)"}
//	CheckBox ms0_avgraph,variable= root:panel:ms0_ck_plotNew
	CheckBox ms0_AddSpectraControls,pos={149,244},size={78,14},fSize=10,disable=1,title="Graph controls"
	CheckBox ms0_AddSpectraControls,help={"Add control checkboxes and buttons to the graph."}
	CheckBox ms0_AddSpectraControls,variable= root:panel:ms0_ck_addControls
//	CheckBox ms0_AvgMSSpeciesErr,pos={280,278},size={117,15},title="\\Z10Calc species 1 \\F'symbol's\\F'Arial'\\Z10 err."			//1.47H error is duplicated	//1.47H
//	CheckBox ms0_AvgMSSpeciesErr,help={"Also calc the average species error values."},disable=1
//	CheckBox ms0_AvgMSSpeciesErr,fSize=10,variable= root:panel:ms0_ck_AvgMSSpeciesErr
	CheckBox ms0_trunc2zero,pos={244,244},size={112,14},fSize=10,disable=1,title="Truncate sticks to 0 for stacking"
	CheckBox ms0_trunc2zero,help={"Convert from Hz (default) to gm-3."}
	CheckBox ms0_trunc2zero,variable= root:panel:ms0_ck_trunc2zero
	CheckBox ms0_subtractBaselineFromRaw,pos={272,261},size={78,14},fSize=10,disable=1,title="Find raw baseline spectra"
	CheckBox ms0_subtractBaselineFromRaw variable= root:panel:ms0_ck_findAvgBaseline
	CheckBox ms0_subtractBaselineFromRaw,help={"If averageing raw spectra, you can calculate the average baseline."}
	PopupMenu ms0_AvGraphType,pos={25,265},size={102,24},fSize=10,disable=1,proc=sq_pop_getvariable,title="Spectra Type"
	PopupMenu ms0_AvGraphType,help={"Whether to average raw, sticks or both."}
	PopupMenu ms0_AvGraphType,mode=2,popvalue="Sticks",value= #"\"Sticks;Sticks+Raw;Raw vs m/z;Raw vs iToF;Mass Defect;\""		//1.53G
	
//	SetVariable ms0_errFac,pos={257,285},size={115,16},fSize=10,disable=1,title="# SD's for errors"		moved to MSS Avg graph control
//	SetVariable ms0_errFac,limits={1,inf,1},value= root:panel:ms0_sv_numStdDev
	
	PopupMenu ms0_graphOutputType,pos={140, 130},size={160,21},fSize=10,disable=1,proc=sq_pop_getvariable,title="Plot"		//1.57D
	PopupMenu ms0_graphOutputType,help={"How to graph the mass trends or mass spectra."}
	PopupMenu ms0_graphOutputType,mode=1,popvalue="Single",value= #"\"Single;Multiple;Append;Update;Do Nothing\""

	Button ms0_button_diurnalCalc,pos={109,198},size={100,20},proc=sq_butt_MS_Calc,title="Calc diurnal trends"
	Button ms0_button_diurnalCalc,help={"Make diurnal box plots."}
	Button ms0_button_diurnalCalc,fSize=10,disable=1

	GroupBox ms0_AvgGroup,pos={20,226},size={398,145},disable=1,title="Results with a mass spectral dimension", fcolor=(1,1,1)
	GroupBox ms0_TseriesBox,pos={10,157},size={90,65},title="Time Series"
	GroupBox ms0_TseriesBox,fColor=(1,1,1),disable=1
	GroupBox ms0_TseriesDiurnal,pos={107,157},size={125,67},title="Diurnal Time Series"
	GroupBox ms0_TseriesDiurnal,fColor=(1,1,1),disable=1
	GroupBox ms0_TseriesSpectraBox pos={280,168},size={140,66}, fsize = 10, title="2-d Time Series Spectra", fcolor = (1,1,1),disable=1

	Button ms0_button_TseriesMassSpec,pos={285,182},size={120,30},proc=sq_butt_MS_Calc,title="Calc UMR 2d matrix\r(not plotted, no RIE)"
	Button ms0_button_TseriesMassSpec,help={"Creates a time series mass spectra (2-D) matrix."}
	Button ms0_button_TseriesMassSpec,fSize=10,disable=1

	Button ms0_button_f44vf60,pos={238,195},size={35,30},proc=sq_butt_MS_Calc,title=" f44 vs\rf60"
	Button ms0_button_f44vf60,help={"Calculate mass trend(s)."}
	Button ms0_button_f44vf60,fSize=10,disable=1
	Button ms0_button_TseriesCalc,pos={15,199},size={75,20},proc=sq_butt_MS_Calc,title="Calculate"
	Button ms0_button_TseriesCalc,help={"Calculate mass trend(s)."}
	Button ms0_button_TseriesCalc,fColor=(65280,43520,0),disable=1
	Button ms0_button_f43vf44,pos={238,165},size={35,30},proc=sq_butt_MS_Calc,title=" f43 vs\rf44"
	Button ms0_button_f43vf44,help={"Calculate mass trend(s)."}
	Button ms0_button_f43vf44,fSize=10,disable=1

	PopupMenu ms0_whisker,pos={109,174},size={105,21},proc=sq_pop_getvariable,title="Whiskers"
	PopupMenu ms0_whisker,help={"The whiskers to display in the diurnal box plot"}
	PopupMenu ms0_whisker,fSize=10,mode=2,popvalue="5-95%",value= #"\"0-100%;5-95%\""

	PopupMenu ms0_dataType,pos={10,130},size={152,24},fSize=10,disable=1,proc=sq_pop_getvariable,title="Data"
	PopupMenu ms0_dataType,help={"Source data to use."}
	//1.57B
	sq_updateMSLists()
//	svar MSStickList = root:panel:MSStickList
	PopupMenu ms0_dataType,mode=1,popvalue="select",value= #"root:panel:MSStickList"		//1.57K
	//1.57B
	
	SetVariable ms0_speclist,pos={10,105},size={245,16},fSize=10,disable=1,title="Species"
	SetVariable ms0_speclist,help={"List of species to calculate loadings for."}
	SetVariable ms0_speclist,value= root:panel:ms0_speclist

	Button ms0_default_ts,pos={15,176},size={80,20},proc=sq_butt_MSSpeciesDefault,title="Default Species"
	Button ms0_default_ts,help={"Use default species."},fSize=10
	Button ms0_button_TseriesCalc,pos={15,198},size={75,20}, disable=1,proc=sq_butt_MS_Calc,title="Calculate"
	Button ms0_button_TseriesCalc,help={"Calculate mass trend(s)."},fColor=(65280,43520,0)

	CheckBox ms0_mz_saved,pos={30,305},size={62,14},fSize=10,disable=1,proc=sq_ck_mzBase,title="As saved"
	CheckBox ms0_mz_saved,help={"Use the m/z calibration of the first run in the group"}
	CheckBox ms0_mz_saved,variable= root:panel:ms0_mz_saved,mode=1
	CheckBox ms0_mz_reg,pos={30,321},size={78,14},fSize=10,disable=1,proc=sq_ck_mzBase,title="Defined grid:"
	CheckBox ms0_mz_reg,help={"Use a defined grid of a constant m/dm"}
	CheckBox ms0_mz_reg,variable= root:panel:ms0_mz_reg,mode=1
	CheckBox ms0_mz_custom,pos={30,338},size={56,14},fSize=10,disable=1,proc=sq_ck_mzBase,title="Custom:"
	CheckBox ms0_mz_custom,help={"Use a custom m/z wave"}
	CheckBox ms0_mz_custom,variable= root:panel:ms0_mz_custom,mode=1
	SetVariable ms0_mz_custstr,pos={91,338},size={80,16},disable=1,title=" "
	SetVariable ms0_mz_custstr,help={"Custom m/z axis wave"}
	SetVariable ms0_mz_custstr,limits={0,inf,0},value= root:panel:ms0_mz_custom_str
	SetVariable ms0_mz_reg_max,pos={160,320},size={54,16},fSize=10,disable=1,title="Max"
	SetVariable ms0_mz_reg_max,help={"Maximum m/z in defined grid"}
	SetVariable ms0_mz_reg_max,limits={0,inf,0},value= root:panel:ms0_mz_reg_max
	SetVariable ms0_mz_reg_dm,pos={216,320},size={75,16},fSize=10,disable=1,title="Res28"
	SetVariable ms0_mz_reg_dm,help={"Resolution at m/z 28 for the defined grid"}
	SetVariable ms0_mz_reg_dm,limits={0,inf,0},value= root:panel:ms0_mz_reg_dm
	SetVariable ms0_mz_reg_min,pos={110,320},size={49,16},fSize=10,disable=1,title="Min"
	SetVariable ms0_mz_reg_min,help={"Minimum m/z in defined grid"}
	SetVariable ms0_mz_reg_min,limits={0,inf,0},value= root:panel:ms0_mz_reg_min
	GroupBox ms0_mzbox,pos={25,292},size={388,77},fsize=10,disable=1,title="m/z base for raw spectra", fcolor=(1,1,1)	//	1.46B
	CheckBox ms0_mz_area,pos={298,312},size={92,14},fSize=10,disable=1,title="Conserve areas"
	CheckBox ms0_mz_area,help={"Conserve mass spectral peak areas when mapping to m/z space."}
	CheckBox ms0_mz_area,variable= root:panel:ms0_mz_area
	CheckBox ms0_mz_saved_regrid,pos={93,305},size={49,14},fSize=10,disable=1,title="Regrid"
	CheckBox ms0_mz_saved_regrid,help={"Force data onto m/z base of first run. Otherwise, assume consistent ion ToF calibration."}
	CheckBox ms0_mz_saved_regrid,variable= root:panel:ms0_mz_saved_regrid
	CheckBox ms0_mz_refit,pos={298,330},size={87,14},fSize=10,disable=1,title="New m/z fit params"
	CheckBox ms0_mz_refit,help={"Use new m/z calibration parameters, if available."}
	CheckBox ms0_mz_refit,variable= root:panel:ms0_mz_refit	
	CheckBox ms0_ckpromptForTSMSmaxmz,pos={285,211},size={109,14},title="itx for PMF"		//1.47I
	CheckBox ms0_ckpromptForTSMSmaxmz,fSize=10, variable= root:panel:ms0_promptForTSMSmaxmz,disable=1
	Button ms0_butt_ExportRawSpectra,pos={220.00,347.00},size={190.00,17.00},proc=sq_2dMSRawExport,title="Calc, put 2d raw spectra matrix into HDF",disable=1
	Button ms0_butt_ExportRawSpectra,fSize=10

// The entire PToF section was revamped in 1.46E
	SetVariable tof1_masslist_im,pos={10,97},size={225,16},title="Species"
	SetVariable tof1_masslist_im,help={"A comma-separated list of species or m/zs to plot."}
	SetVariable tof1_masslist_im,fSize=10,value= root:panel:tof1_speclist
	PopupMenu tof1_datatype,pos={10,126},size={187,21},proc=sq_pop_tof1_datatype,title="Diameter axis"		//1.60E
	PopupMenu tof1_datatype,help={"Data to plot."},fSize=10
	PopupMenu tof1_datatype,mode=1,popvalue="dXdlogDa vs logDa",value= #"\"dXdlogDa vs logDa;X vs PToF\""
	PopupMenu tof1_graphOption,pos={10,149},size={112,21},proc=sq_pop_getvariable,title="Plot"
	PopupMenu tof1_graphOption,help={"Plot new graphs, a single plot or update only."}
	PopupMenu tof1_graphOption,fSize=10,mode=1,popvalue="Single",value= #"\"Single;Multiple;Append;Update\""
	Button tof1_im_default,pos={10,112},size={120,15},proc=sq_butt_ToFSpeciesDefault,title="Default aerosol species"
	Button tof1_im_default,help={"Use default species."},fSize=10
	Button tof1_ms_default,pos={132,112},size={100,15},proc=sq_butt_ToFSpeciesMSDefault,title="Default MS species"
	Button tof1_ms_default,help={"Use default species."},fSize=10

	CheckBox tof1_ug_conv,pos={255,98},size={101,14},title="Convert to g/m3"
	CheckBox tof1_ug_conv,fSize=10,variable= root:panel:tof1_ugconv
	CheckBox tof0_corr,pos={255,113},size={123,14},title="Use MS AB correction"
	CheckBox tof0_corr,help={"Correct for changes in ionization effeciency."}
	CheckBox tof0_corr,fSize=10,variable= root:panel:tof0_corrop
	CheckBox tof1_norm,pos={255,129},size={156,14},title="Scale (normalize) to MS data"
	CheckBox tof1_norm,help={"Normalise the integrated PToF traces to the corresponding mass calculated in the MS batch."}
	CheckBox tof1_norm,fSize=10,variable= root:panel:tof1_norm

	SetVariable tof0_maxmz,pos={255,144},size={140,16},title="Max m/z (0 = default)"
	SetVariable tof0_maxmz,fSize=10,limits={0,inf,0},value= root:panel:tof0_maxmz
	CheckBox tof0_fragAirIs0,pos={255,160},size={174,14},title="Use nonzero frag_air (adv. users)"
	CheckBox tof0_fragAirIs0,help={"Do calculations as if all frag_air entries were blank.  This is the default method, as calced air values may introduce noise."}
	CheckBox tof0_fragAirIs0,fSize=10,variable= root:panel:tof0_fragAirIs0
	SetVariable tof0_minda,pos={255,176},size={135,16},title="GP/PP boundary (nm)"
	SetVariable tof0_minda,help={"Lower bound of integration for m/z's containing a gas phase component (e.g. 16)."}
	SetVariable tof0_minda,fSize=10,limits={0,inf,0},value= root:panel:tof0_gppp

	CheckBox tof1_WaveSuffix,pos={255,192},size={136,14},title="Ask for wave name suffix"
	CheckBox tof1_WaveSuffix,help={"Ask for wave name suffix."},fSize=10
	CheckBox tof1_WaveSuffix,variable= root:panel:tof0_suffix_ck
	CheckBox tof1_showDCregions,pos={255,208},size={167,14},title="Show DC or ePToF test regions"
	CheckBox tof1_showDCregions,help={"Show the DC regions as grayed areas in the plot."}
	CheckBox tof1_showDCregions,fSize=10,variable= root:panel:tof0_showDC
	CheckBox tof1_ShowStats,pos={255,224},size={170,14},title="Find, display mode, median stats"
	CheckBox tof1_ShowStats,help={"Calculate PToF stats."},fSize=10
	CheckBox tof1_ShowStats,variable= root:panel:tof_stats

	TitleBox tof0_ePToFInfo,pos={13.00,184.00},size={125.00,36.00},fSize=10,frame=0
	TitleBox tof0_ePToFInfo,variable= root:panel:tof0_PToFePToFtitle
	Button tof0_updateEPToFinfo,pos={76.00,208.00},size={50.00,18.00},proc=sq_ePToF_InfoButtonProc,title="Update"
	Button tof0_updateEPToFinfo,help={"If the todo wave has been changed, press this"},fSize=10
	GroupBox tof0_ePToFinfo_group,pos={10,173},size={130,56},title="PToF/EPToF Info"
	GroupBox tof0_ePToFinfo_group,fSize=10,fColor=(1,1,1)

	GroupBox tof0_diambase_group,pos={8,228},size={315,70},title="Diameter Base"
	GroupBox tof0_diambase_group,fColor=(1,1,1)
	CheckBox tof0_diam_saved,pos={11,243},size={62,14},proc=sq_ck_diambase,title="As saved"
	CheckBox tof0_diam_saved,fSize=10,variable= root:panel:tof0_d_saved,mode=1
	CheckBox tof0_diam_interval,pos={11,261},size={93,14},proc=sq_ck_diambase,title="Set nm intervals"
	CheckBox tof0_diam_interval,fSize=10,variable= root:panel:tof0_d_reg,mode=1
	SetVariable tof0_diam_reg_min,pos={188,259},size={63,16},bodyWidth=40,title=" min"
	SetVariable tof0_diam_reg_min,fSize=10
	SetVariable tof0_diam_reg_min,limits={0,inf,0},value= root:panel:tof0_d_reg_min,noedit= 1
	SetVariable tof0_diam_reg_max,pos={254,259},size={66,16},bodyWidth=40,title=" max"
	SetVariable tof0_diam_reg_max,fSize=10
	SetVariable tof0_diam_reg_max,limits={0,inf,0},value= root:panel:tof0_d_reg_max,noedit= 1
	SetVariable tof0_diam_reg_num,pos={115,259},size={68,16},bodyWidth=35,title="# bins"
	SetVariable tof0_diam_reg_num,fSize=10
	SetVariable tof0_diam_reg_num,limits={0,inf,1},value= root:panel:tof0_d_reg_n,noedit= 1
	SetVariable tof0_diam_cus_val,pos={185.00,278.00},size={90.00,15.00},bodyWidth=90,title=" ",fSize=10
	SetVariable tof0_diam_cus_val,value= root:panel:tof0_d_cus_val
	
	CheckBox tof0_diam_custom,pos={11,279},size={230,14},proc=sq_ck_diambase,title="Custom nm wave (wave is in root):"
	CheckBox tof0_diam_custom,fSize=10,variable= root:panel:tof0_d_custom,mode=1
	GroupBox tof1_sizeGroup,pos={12,299},size={132,73},title="DVa Size and Time"
	GroupBox tof1_sizeGroup,fColor=(1,1,1)
	Button tof1_avconc,pos={25,315},size={110,20},proc=sq_butt_TofConc,title="Calc. size distrib."
	Button tof1_avconc,help={"Draw a size distribution plot of the species."}
	Button tof1_avconc,fColor=(52224,34816,0)
	Button tof1_imconc,pos={25,336},size={110,33},proc=sq_butt_TofConc,title="Calc. 2-d time, size\r(image plot)"
	Button tof1_imconc,help={"Draw an image plot representation of the PToF data in memory."}
	Button tof1_imconc,fColor=(52224,34816,0)
	GroupBox tof1_MSgroup,pos={150,298},size={168,74},fsize=10,title="Mass Spectra"
	Button tof1_mscon,pos={154,315},size={160,20},proc=sq_butt_TofConc,title="Calc. size-resolved MS"
	Button tof1_mscon,help={"Draw an image plot representation of the PToF data in memory."}
	Button tof1_mscon,fColor=(52224,34816,0)
	Button tof1_exco,pos={154,336},size={160,33},proc=sq_butt_TofConc,title="Calc time, size-resolved mass\rspectra (3-d matrix, not plotted)"
	Button tof1_exco,help={"Export PToF data matricies."},fSize=10

	GroupBox tof1_MSvsPToFgroup,pos={325,247},size={95,125},title="MS vs PToF\r(not for ePToF)"
	GroupBox tof1_MSvsPToFgroup,fColor=(1,1,1), fsize=10
	Button tof1_ms_MSvsPToFCalcs,pos={327,275},size={80,30},proc=sq_butt_ToFvsPtoFCalcs,title="Do calcs for\rpanels below"
	Button tof1_ms_MSvsPToFCalcs,help={"Use default species."},fSize=10
	Button tof1_MSvsPToF,pos={327,306},size={90,30},proc=sq_button_MSvsPToF,title="MSSDiff vs PToF\rspecies panel"
	Button tof1_MSvsPToF,help={"Use default species."},fSize=10
	Button tof1_MSSCvsDCregions,pos={327,338},size={90,30},proc=sq_button_MSSCvsDC,title="MSSC Hz vs\rDC regions"
	Button tof1_MSSCvsDCregions,help={"Use default species."},fSize=10
	
	//1.59D
	GroupBox tof0ePToF_DeconGroup,pos={142.00,145.00},size={105.00,96.00},fSize=10
	GroupBox tof0ePToF_DeconGroup,fColor=(1,1,1)
	CheckBox tof0ePToF_DeconvolveNone,pos={144.00,148.00},size={93.00,13.00},proc=sq_DeconvolveCheckProc,title="Don't deconvolve"
	CheckBox tof0ePToF_DeconvolveNone,fSize=10
	CheckBox tof0ePToF_DeconvolveNone,variable= root:panel:deconvolveNone,mode=1
	CheckBox tof0ePToF_DeconvolveJoel,pos={144.00,162.00},size={84.00,13.00},proc=sq_DeconvolveCheckProc,title="Matrix inversion"
	CheckBox tof0ePToF_DeconvolveJoel,fSize=10
	CheckBox tof0ePToF_DeconvolveJoel,variable= root:panel:deconvolveJoel,mode=1
	CheckBox tof0ePToF_DeconvolveMike,pos={144.00,204.00},size={90.00,13.00},proc=sq_DeconvolveCheckProc,title="Tofwerk inversion"
	CheckBox tof0ePToF_DeconvolveMike,fSize=10
	CheckBox tof0ePToF_DeconvolveMike,variable= root:panel:deconvolveMike,mode=1
	SetVariable tof0ePToF_smoothSetVar,pos={158.00,173.00},size={69.00,15.00},bodyWidth=30,title="Smooth"
	SetVariable tof0ePToF_smoothSetVar,fSize=10
	SetVariable tof0ePToF_smoothSetVar,limits={-1,8,1},value= root:panel:DCgr_smoothVar
	CheckBox tof0ePToF_SumDiffScal,pos={157.00,216.00},size={76.00,24.00},disable=2,title="Scale to\rEPToFSumDiff"
	CheckBox tof0ePToF_SumDiffScal,fSize=10,variable=:panel:PToF_DCgr_ePToFSumDiffScaling
	SetVariable tof0ePToF_TestRegionSetVar,pos={160.00,188.00},size={86.00,15.00},bodyWidth=40,disable=2,title="BL region"
	SetVariable tof0ePToF_TestRegionSetVar,fSize=10
	SetVariable tof0ePToF_TestRegionSetVar,limits={0,0.9,0.1},value= root:panel:PToF_ePToF_TestRegion

	GroupBox fDiag_group_Frag,pos={15,102},size={405,152},title="Fragmentation & NH4 RIE Checks"
	GroupBox fDiag_group_Frag,fSize=10,fColor=(1,1,1),disable=1

	CheckBox fDiag_ck_useAirbeam,pos={19,119},size={146,14},title="Use MS airbeam correction"
	CheckBox fDiag_ck_useAirbeam,fSize=10,variable= root:panel:fDiag_UseAirbeam,disable=1
	Button fDiag_button_calcbatch,pos={20,154},size={280,20},proc=FD_butt_CalcBatch,title="Calc. loadings for all species *except* those above"
	Button fDiag_button_calcbatch,fColor=(65280,43520,0),disable=1
	SetVariable fDiag_speclist_Excecptions,pos={19,135},size={365,16},title="Species not calculated for Frag Checks"
	SetVariable fDiag_speclist_Excecptions,help={"List of species to calculate loadings for."},disable=1
	SetVariable fDiag_speclist_Excecptions,fSize=10,disable=1
	SetVariable fDiag_speclist_Excecptions,value= root:panel:FDiag_SpeciesException

	GroupBox fDiag_group_StdDataDiag,pos={21,181},size={384,68},title="Additional Fragmenation Diagnostic Graphs",disable=1
	GroupBox fDiag_group_StdDataDiag,fSize=10,fColor=(1,1,1)

	Button fDiag_button_CalcFDiags,pos={256,204},size={133,19},proc=FD_Butt_CalcDiags,title="Plot Data Diagnostics"
	Button fDiag_button_CalcFDiags,fSize=10,disable=1
	Button fDiag_butt_FragPlotsPanel,pos={305,154},size={110,20},proc=sq_butt_FragPanel,title="Frag plots panel"
	Button fDiag_butt_FragPlotsPanel,fColor=(65280,43520,0),disable=1
	PopupMenu fDiag_ChooseDiagnostics,pos={31,224},size={188,21},bodyWidth=130,title="Diagnostics"
	PopupMenu fDiag_ChooseDiagnostics,fSize=10,disable=1
	PopupMenu fDiag_ChooseDiagnostics,mode=1,popvalue="All",value= #"FD_DIAGNOSTICS_LIST"
	PopupMenu fDiag_ColorDiags,pos={31,198},size={161,21},bodyWidth=120,title="Color by"
	PopupMenu fDiag_ColorDiags,fSize=10,disable=1
	PopupMenu fDiag_ColorDiags,mode=1,popvalue="Time",value= #"FD_COLORBY_LIST"

	GroupBox fDiag_group_CDCECheck,pos={15,262},size={193,47},title="Composition Dependent CE (CDCE)"
	GroupBox fDiag_group_CDCECheck,fSize=10,fColor=(1,1,1),disable=1
	Button fDiag_butt_cePanel,pos={20,283},size={110,19},proc=sq_CE_ButtonProc,title="CDCE panel"
	Button fDiag_butt_cePanel,fColor=(65280,43520,0),disable=1			// 1.157Z2
	Button fDiag_butt_ceWebLink,pos={140,283},size={60,19},proc=SQ_URLButton,title="paper link"
	Button fDiag_butt_ceWebLink,fSize=10

	GroupBox fDiag_group_Pieber,pos={211,262},size={201,47},title="Pieber et al correction"	// 1.157Z2
	GroupBox fDiag_group_Pieber,fSize=10,fColor=(1,1,1)
	Button fDiag_butt_Pieber,pos={214,283},size={130,19},proc=sq_Pieber_ButtonProc,title="Pieber et al panel"	// 1.157Z2
	Button fDiag_butt_Pieber,fColor=(65280,43520,0), fstyle=2  //1.59D
	Button fDiag_butt_PieberWebLink,pos={347,283},size={60,19},proc=SQ_URLButton,title="paper link"	// 1.157Z2
	Button fDiag_butt_PieberWebLink,fSize=10

	GroupBox fDiag_group_IEChecks,pos={15,316},size={405,45},title="Project Diagnostics, IE Calibrations"
	GroupBox fDiag_group_IEChecks,fSize=10,fColor=(1,1,1),disable=1
	Button fDiag_butt_ProjectDiagGr,pos={20,337},size={140,19},proc=sq_butt_IEetalProjectGr,title="Project Diagnostics Graph"
	Button fDiag_butt_ProjectDiagGr,fSize=10,disable=1
	Button fDiag_butt_IECalTable,pos={169,338},size={110,19},proc=sq_butt_IECalTable,title="IE calibration table"
	Button fDiag_butt_IECalTable,fSize=10,disable=1
	
	GroupBox misc_graph,pos={20,100},size={250,122},title="Graphing",fSize=10
	GroupBox misc_graph,fColor=(1,1,1)
	SetVariable misc_graphline,pos={30,120},size={100,16},title="Trace Thickness"
	SetVariable misc_graphline,help={"The default line thickness to use on line graphs."}
	SetVariable misc_graphline,fSize=10
	SetVariable misc_graphline,limits={0,inf,0},value= root:panel:gdef_line_thick
	SetVariable misc_stick,pos={30,138},size={100,16},title="Stick Thickness"
	SetVariable misc_stick,help={"The default stick thickness to use on graphs."}
	SetVariable misc_stick,fSize=10
	SetVariable misc_stick,limits={0,inf,0},value= root:panel:gdef_stick_thick
	CheckBox misc_zero,pos={145,121},size={63,14},title="Zero Line"
	CheckBox misc_zero,help={"Add a zero line to new graphs."},fSize=10
	CheckBox misc_zero,variable= root:panel:gdef_zline
	CheckBox misc_csr,pos={145,136},size={53,14},title="Cursors"
	CheckBox misc_csr,help={"Add cursors."},fSize=10
	CheckBox misc_csr,variable= root:panel:gdef_cursors
//	CheckBox misc_csrctrl,pos={145,151},size={86,14},title="Cursor buttons"
//	CheckBox misc_csrctrl,help={"Add buttons to generate todo waves from cursors."}
//	CheckBox misc_csrctrl,fSize=10,variable= root:panel:gdef_cbut
	CheckBox misc_legend,pos={145,166},size={76,14},title="Add Legend"
	CheckBox misc_legend,help={"Add a legend to new graphs."},fSize=10
	CheckBox misc_legend,variable= root:panel:gdef_leg
	CheckBox misc_scale,pos={145,181},size={96,14},title="Scale From Zero"
	CheckBox misc_scale,help={"Use zero as one of the graph's limits."},fSize=10
	CheckBox misc_scale,variable= root:panel:gdef_scale
	CheckBox misc_gaps,pos={215,121},size={43,14},title="Gaps"
	CheckBox misc_NoColoring,pos={145.00,196.00},size={120.00,13.00},title="Do not modify\rexisting traces"
	CheckBox misc_NoColoring,help={"Do not attempt to set colors or trace thickness for new traces added to graph."}
	CheckBox misc_NoColoring,fSize=10,variable= root:panel:dontColorTraces
	CheckBox misc_gaps,help={"Set the Gaps setting (for connecting values between nans"}
	CheckBox misc_gaps,fSize=10,variable= root:panel:gdef_gaps

	Button misc_apply,pos={30,162},size={84,19},proc=SQ_Butt_appgraphdefs,title="Apply to Current"		
	Button misc_apply,help={"Apply the defaults to the current top graph."},fSize=10
	Button misc_reviewSpeciesColors,pos={30,189},size={110,20},proc=sq_butt_SpeciesColorTable,title="AMS Color Table"
	Button misc_reviewSpeciesColors,help={"Review Species Colors"},fSize=10

	GroupBox misc_FileExtension,pos={275.00,100.00},size={125.00,70.00},title="File Extension"
	GroupBox misc_FileExtension,fSize=10,fColor=(1,1,1)
	CheckBox misc_hdf,pos={284.00,114.00},size={94.00,24.00},proc=sq_fileExtensionCheckProc,title=".hdf (default,\ruse for DAQ v.4.x)"
	CheckBox misc_hdf,help={"For DAQ data files saved with .hdf file extension."}
	CheckBox misc_hdf,fSize=10,value= 0,mode=1
	CheckBox misc_h5,pos={284.00,143.00},size={86.00,24.00},proc=sq_fileExtensionCheckProc,title=".h5 (standard\rfor DAQ v. 5.x+)"
	CheckBox misc_h5,help={"For DAQ data files saved with .h5 file extension."}
	CheckBox misc_h5,fSize=10,value= 1,mode=1

	Button misc_reviewDAQparams,pos={276.00,175.00},size={110.00,35.00},proc=sq_butt_allSavedParams,title="All DAQ Saved\rParameters Table"
	Button misc_reviewDAQparams,help={"Review all the non-spectra values saved by the DAQ"},fSize=10		//1.59E

	GroupBox misc_opt,pos={26,221},size={386,95},title="Odds & Ends",fSize=10
	GroupBox misc_opt,fColor=(1,1,1),disable=1
	PopupMenu misc_smooth,pos={32,238},size={162,21},title="Data Smoothing",disable=1
	PopupMenu misc_smooth,help={"Which smoothing algorithm to use."},fSize=10
	PopupMenu misc_smooth,mode=1,popvalue="Gaussian",value= #"\"Gaussian;Boxcar\""
	Button misc_exportBatch,pos={30,265},size={80,20},proc=sq_butt_ExportAsItx,title="Export Batch",disable=1
	Button misc_exportBatch,help={"Export batch waves to an itx file."},fSize=10
	Button misc_exportFrags,pos={30,288},size={80,20},proc=sq_butt_ExportAsItx,title="Export Frags",disable=1
	Button misc_exportFrags,help={"Export frag waves to an itx file."},fSize=10
//	Button misc_journalTable,pos={119,264},size={120,20},proc=sq_butt_reviewJournal,title="Review Journal Table",disable=1
//	Button misc_journalTable,help={"Displays a simple table of squirrel journal entries."}
//	Button misc_journalTable,fSize=10
	Button misc_FileTable,pos={117.00,265.00},size={140.00,20.00},proc=sq_FileIndexTable,title="HDF file Table (do not edit)"
	Button misc_FileTable,fSize=10
	Button misc_changeDir,pos={116.00,288.00},size={140.00,20.00},proc=sq_butt_changeHDFPath,title="Change paths for HDF files"
	Button misc_changeDir,help={"If you move the location of the raw and intermediate files you may want to do this."}
	Button misc_changeDir,fSize=10

	Button misc_moveMSSDiffpToInterm,pos={210.00,234.00},size={200.00,20.00},proc=sq_butt_transferMSSDiffpToHDF,title="Transfer MSSDiff_p, Err Matrix to HDF"
	Button misc_moveMSSDiffpToInterm,fSize=10,disable=1 

	CheckBox misc_ShowSquirrelMessages,pos={270.00,260.00},size={115.00,24.00},title="Update Squirrel progress\rmessages"
	CheckBox misc_ShowSquirrelMessages,help={"For faster processing do not show squirrel progress messages."}
	CheckBox misc_ShowSquirrelMessages,fSize=10,variable= root:panel:Update_ams_sqprog

	CheckBox misc_killWavesMS_mats,pos={271,292},size={138,14},title="Kill temp. ms_mats waves"
	CheckBox misc_killWavesMS_mats,help={"Kill temporary waves in the ms_mats data folder."}
	CheckBox misc_killWavesMS_mats,fSize=10,variable= root:panel:misc_KillAllInnms_mats, disable=1

	GroupBox misc_groupBox_MemTransfer,pos={24,319},size={390,49},fSize=10,disable=1,title="HDF to Memory Transfers - Typically Unnecessary"
	GroupBox misc_groupBox_MemTransfer, fcolor=(1,1,1)
	PopupMenu misc_dump2mem_pop,pos={35,336},size={188.00,19.00},bodyWidth=150,fSize=10,disable=1,proc=sq_pop_dump2memList,title="Wave"
	PopupMenu misc_dump2mem_pop,mode=1,popvalue="InfoVal",value= #"root:panel:sq_dump2memList+\"Get List;\"\t"
	Button misc_dump2mem_but,pos={260,336},size={90,20},fSize=10,disable=1,proc=sq_butt_dump2mem,title="Dump to Memory"		//1.44B typos
	Button misc_dump2mem_but,help={"Dump contents into memory."}
//	Button misc_list,pos={310,340},size={100,20},fSize=10,disable=1,proc=sq_butt_deletefrommem,title="Delete from Memory"
//	Button misc_list,help={"Delete from memory."}

	Edit/W=(208,227,403,330)/HOST=#  as "AMS Analysis"
	sq_populate_ABTable() 
	RenameWindow #,ABtable
	SetActiveSubwindow ##

	sq_tabControl("", 1)

	sq_update_corrTabLabels("",nan)

	sq_SetDimLabelsABCorrToFType()	// 1.52J
	
	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M
	sq_fileExtensionCheckProc(HdfFileExtension, nan)

	sq_PreProcessTab("load_preprocessTab", 0)
	sq_ck_preProcess("",Nan)
End


Function sq_Butt_Pieber(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			abort "This isn't ready yet.  Please go to the Peiber paper for details about how to correct"
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


//> draws the AMS Analysis Panel credits
Function sq_panel_credits()

	PauseUpdate; Silent 1		// building window...
	NewPanel /K=1 /W=(265,102,733,502) as "AMS Analysis Software"
	ShowTools/A
	SetDrawLayer UserBack
	SetDrawEnv fsize= 14
	DrawText 17,85,"James Allan - james.allan@manchester.ac.uk"
	SetDrawEnv fsize= 14
	DrawText 17,102,"Jonny Crosier - j.crosier@postgrad.manchester.ac.uk"
	SetDrawEnv fsize= 14
	DrawText 18,156,"Edward Dunlea - No longer at Colorado"
	SetDrawEnv fsize= 14
	DrawText 18,176,"Mike Cubison - Now at Tofwerk"
	SetDrawEnv fsize= 14
	DrawText 17,321,"Donna Sueper* - donna@aerodyne.com"
	SetDrawEnv fsize= 14
	DrawText 15,227,"Silke Hings - No longer at Mainz"
	SetDrawEnv fsize= 14
	DrawText 15,246,"Frank Drewnick - drewnick@mpch-mainz.mpg.de"
	SetDrawEnv fsize= 14
	DrawText 17,302,"Tim Onasch - onasch@aerodyne.com"
	DrawPICT 357,61,0.75,0.75,ProcGlobal#manchesterlogo
	DrawPICT 406,134,0.85,0.85,ProcGlobal#CUlogoNew
	DrawPICT 410,204,0.6,0.6,ProcGlobal#MPIlogo
	DrawPICT 402,279,0.35,0.35,ProcGlobal#ARIlogoNew
	DrawText 12,347,"* Individual to whom questions about the software should be addressed."
	TitleBox cred_title,pos={8.00,8.00},size={436.00,31.00},title="AMS Analysis Software Developed by:"
	TitleBox cred_title,font="Arial",fSize=26,frame=0
	GroupBox group0,pos={10.00,45.00},size={450.00,65.00},title="University of Manchester"
	GroupBox group0,font="Arial",fSize=16,fColor=(1,1,1)
	GroupBox group1,pos={10.00,117.00},size={450.00,65.00},title="  University of Colorado, Boulder"
	GroupBox group1,font="Arial",fSize=16,fColor=(1,1,1)
	GroupBox group2,pos={10.00,188.00},size={450.00,65.00},title="Max-Planck Institute for Chemistry, Mainz"
	GroupBox group2,font="Arial",fSize=16,fColor=(1,1,1)
	GroupBox group3,pos={10.00,262.00},size={450.00,65.00},title="Aerodyne Research, Inc."
	GroupBox group3,font="Arial",fSize=16,fColor=(1,1,1)
	Button ButtonPaperListingWebSite,pos={15.00,361.00},size={400.00,25.00},proc=sq_URLButton,title="Go to web site listing major papers of High Resolution AMS"
	Button ButtonPaperListingWebSite,fSize=14
End


///////////////////////////////////////////////////////////////////////////////
///////////////////  PANEL CONTROLS ////////////////////////////
///////////////////////////////////////////////////////////////////////////////

//& The function controlling the tabs in main ams panel
Function sq_tabControl(ctrlName, tab) : TabControl
	string ctrlName
	variable tab
	
	variable cont_disp,tab_1,idex,num
	string cont_list, cont_item
	
//& The object is to store the number of the selected tab on the main tabcontrol in 'tab'
//& and the number of the selected tab on the current sub-tabcontrol in 'tab_1'
	if (stringmatch(ctrlname[0,2],"ams"))
		if (tab==1)
			controlinfo /w=ams_panel cor0_tab
			tab_1=v_value
		else	
			tab_1=-1
		endif
	else
		tab_1=tab
		controlinfo /w=ams_panel ams_tab
		tab=v_value
	endif
	cont_list=controlnamelist("")
	num=itemsinlist(cont_list)
	for (idex=0;idex<num;idex+=1)
		cont_item=stringfromlist(idex,cont_list)
		strswitch (cont_item[0,3])
			case "ams_":	
				cont_disp=0
				break
			case "load":	// same as hdf index
				cont_disp=tab!=0
				break
			case "cor0": 	// Corrections tab, no subtab
				cont_disp=tab!=1
				break
			case "cor1":	// Corrections tab, airbeam
				cont_disp=(tab!=1) || (tab_1!=1)//(tab_1!=0)		//1.43I
				break
			case "cor2":	// Corrections tab, errors
				cont_disp=(tab!=1) || (tab_1!=3)//(tab_1!=2)		//1.43I
				break
			case "cor3":	// Corrections tab, ptof
				cont_disp=(tab!=1) || (tab_1!=2)//(tab_1!=1)		//1.43I
				break
			case "cor4":	// Corrections tab, flow rate
				cont_disp=(tab!=1) || (tab_1!=0) //(tab_1!=3)		//1.43I
				break
			case "cor5":	// Corrections tab, IE cals
				cont_disp=(tab!=1) || (tab_1!=4)
				break
//			case "cor6":	// Corrections tab, Threshold		// 1.41B
//				cont_disp=(tab!=1) || (tab_1!=5)
//				break
			case "ms0_":
				cont_disp=tab!=2
				break
			case "ms1_":
				cont_disp=(tab!=2)
				break
			case "ms2_":
				cont_disp=(tab!=2)
				break
			case "tof0":
				cont_disp=tab!=3
				break
			case "tof1":
				cont_disp=(tab!=3)		
				break
			case "tof2":
				cont_disp=(tab!=3) 		
				break
			case "fDia":
				cont_disp= tab!=4
				break
			case "misc":
				cont_disp=tab!=5
				break
			default:
				cont_disp=1
		endswitch
		controlinfo /w=ams_panel $cont_item
		switch (abs(v_flag))
			case 1:
				button $cont_item disable=cont_disp
				break
			case 2:
				checkbox  $cont_item disable=cont_disp
				break
			case 3:
				popupmenu $cont_item disable=cont_disp
				break
			case 4:
				valdisplay $cont_item disable=cont_disp
				break
			case 5:
				setvariable $cont_item disable=cont_disp
				break
			case 6:
				chart $cont_item disable=cont_disp
				break
			case 7:
				slider $cont_item disable=cont_disp
				break
			case 8:
				tabcontrol $cont_item disable=cont_disp
				break
			case 9:
				groupbox $cont_item disable=cont_disp
				break
			case 10:
				titlebox $cont_item disable=cont_disp
				break
			case 11:
				listbox $cont_item disable=cont_disp
				break
		endswitch
	endfor

	if(tab==0)
//		nvar load_preProcessStick_MS_ck = root:panel:load_preProcessStick_MS_ck
//		nvar load_preProcessStick_PToF_ck = root:panel:load_preProcessStick_PToF_ck
//		sq_ck_preProcess("load_preprocessStick_MS",load_preProcessStick_MS_ck) 
//		sq_ck_preProcess("load_preprocessStick_PToF",load_preProcessStick_PToF_ck) 
		sq_updatePrefix() // 1.57D
		ControlInfo/w=ams_panel load_preprocessTab
		sq_PreProcessTab("load_preprocessTab", V_Value)
	elseif(tab==2)
		sq_ck_mzBase("",0)
	elseif(tab==1)
		nvar airbeam_autoset_ck = root:panel:airbeam_autoset_ck
		sq_ck_abAutoSet("cor1_auto_ab",airbeam_autoset_ck)
// 1.52H
		sq_update_corrTabLabels("", 0)
	elseif(tab==3)	
//		CheckBox tof1_ePToFAvgFirst disable=1
	endif

	SetWindow ams_panel#abtable, Hide=(tab!=1 || tab_1!=1 )
End

Function sq_update_corrTabLabels(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked

	nvar airbeam_corr_ck = root:panel:airbeam_corr_ck
	nvar cor3_recalcD = root:panel:cor3_recalcD
	nvar error_ms_ck = root:panel:error_ms_ck
	nvar cor4_flowRateFind_ck = root:panel:cor4_flowRateFind_ck
	nvar cor3_overrideDC = root:panel:cor3_overrideDC
	nvar cor5_IE2ABFind_ck = root:panel:cor5_IE2ABFind_ck

	TabControl cor0_tab, tabLabel(0)="Flow Rate"+selectstring(cor4_flowRateFind_ck, "", "*")
	TabControl cor0_tab, tabLabel(1)="Airbeam"+selectstring(airbeam_corr_ck, "", "*")
	TabControl cor0_tab, tabLabel(2)="PToF"+selectstring(cor3_recalcD,"", "*")+ selectstring(cor3_overrideDC, "", "*")
	TabControl cor0_tab, tabLabel(3)="Errors"+selectstring(error_ms_ck, "", "*")
	TabControl cor0_tab, tabLabel(4)="IE Cals"+selectstring(cor5_IE2ABFind_ck, "", "*")	

End

//& Update progress bar ams_prog
Function sq_ams_prog_upd(perc, [acorns])		// 1.49E in anticipation of merging with Tofwerk, MikeQ
	variable perc
	variable acorns			// 1.49E in anticipation of merging with Tofwerk, MikeQ
	
	nvar ams_prog=root:panel:ams_prog
	nvar/z Update_ams_sqprog=root:panel:Update_ams_sqprog		//1.60M
	if (!NVar_exists(Update_ams_sqprog) || Update_ams_sqprog)	
		ams_prog=perc
		controlupdate /w=ams_panel ams_prog
	endif
End



//& Update progress bar ams_sqprog
Function sq_sqprog_upd(perc)
	variable perc
	
	nvar ams_sqprog=root:panel:ams_sqprog
	nvar/z Update_ams_sqprog=root:panel:Update_ams_sqprog		//1.60M
	if (!NVar_exists(Update_ams_sqprog) || Update_ams_sqprog)	
		ams_sqprog=perc
		controlupdate /w=ams_panel ams_sqprog
	endif

End


//& Update status window
Function sq_ams_stat_upd(mes, [acorns])  // 1.49E in anticipation of merging with Tofwerk, MikeQ
	string mes
	variable acorns  // 1.49E in anticipation of merging with Tofwerk, MikeQ
	
	nvar/z Update_ams_sqprog=root:panel:Update_ams_sqprog
	if (NVar_exists(Update_ams_sqprog) && Update_ams_sqprog)
		svar sq_str_status=root:panel:sq_str_status
		if (!stringmatch(sq_str_status,mes))
			sq_str_status=mes
	//		controlupdate /w=ams_panel ams_status
		endif
	endif
End


// 1.04J, an HR version of the squirrel function
Function sq_pop_tof1_datatype(controlName,popNum,popStr) : PopUpMenuControl
	string controlName
	variable popNum
	string popStr

	nvar var=root:panel:tof1_datatype
	var=popnum
	popupmenu tof1_datatype win = ams_panel, mode = popNum		//1.14J  is this necessary?  Pedro was having problems.
	if (WinType("HR_Analysis_Panel")==7 )
		ControlInfo/W=HR_Analysis_Panel HRResultsP_datatype 
		if (abs(V_flag) == 3)
			popupmenu HRResultsP_datatype win = HR_Analysis_Panel, mode = popNum
		endif
	endif
			
End


//@ PopUpMenu to set globals associated with popups
Function sq_pop_getVariable(controlName,popNum,popStr) : PopUpMenuControl
	string controlName
	variable popNum
	string popStr
		
	nvar var=root:panel:$controlname
	var=popnum
	
	if (stringmatch(controlname,"ms0_AvGraphType"))		// if raw spectra
		sq_ck_mzBase("",0)
		Checkbox ms0_subtractBaselineFromRaw disable=2*(var==1 || var == 4 ),  Win=ams_panel		// edited in 1.46E
		Checkbox ms0_trunc2zero disable=2*(var==3 || var == 4 ),  Win=ams_panel		// edited in 1.46E
//		Checkbox ms0_AvgMSSpeciesErr disable=2*(var==3 || var == 4 ),  Win=ams_panel		// edited in 1.46E  1.47H
	endif
		
End


// Button function added in 1.43I - Doug wanted a separate button to display diagnostic graph.
Function sq_butt_diagPlot(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	sq_plot_diag()

End


//> PopUpMenu for choosing m/z for airbeam calc
Function sq_pop_airbeam_mz_set(controlName,popNum,popStr) : PopUpMenuControl
	string controlName
	variable popNum
	string popStr
	
	nvar airbeam_curr_mz=root:panel:airbeam_curr_mz
	airbeam_curr_mz=str2num( popStr )
	DoAlert 0, "If you intend to use "+popStr+" for the AB correction, don't forget to presss the adjacent Reset airbeam to m/z button"	// 1.59F

End


//& Function controlling the time base radio buttons
Function sq_timebase_check(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked
	
	nvar ams_time_interval=root:panel:ams_time_interval
	nvar ams_time_custom=root:panel:ams_time_custom
	nvar ams_time_saved=root:panel:ams_time_saved
	ams_time_interval=(strsearch(ctrlname,"time_interval",0)>=0)			//1.59E
	ams_time_custom=(strsearch(ctrlname,"time_custom",0)>=0)
	ams_time_saved=(strsearch(ctrlname,"time_saved",0)>=0)

End


//^ In the airbeam corrections tab, makes the set variables ioneff, ab, tofab editable or not, 
//^depending on whether the auto set checkbox is checked.
Function sq_ck_abAutoSet(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked
	
//	nvar airbeam_ref_ionEff_sv = root:panel:airbeam_ref_ionEff_sv
//	nvar airbeam_ref_MSab_sv = root:panel:airbeam_ref_MSab_sv
//	
//	if (checked)
//		SetVariable cor1_manie noedit=1
//		SetVariable cor1_manab noedit=1
//	else
//		SetVariable cor1_manie noedit=0
//		SetVariable cor1_manab noedit=0
//	endif

	//1.52H
	nvar airbeam_autoset_ck = root:panel:airbeam_autoset_ck
	svar/z ABHelperStr = root:panel:ABHelperStr
	if (!svar_exists(ABHelperStr))
		string/g root:panel:ABHelperStr=""
		svar ABHelperStr = root:panel:ABHelperStr
	endif
	
	airbeam_autoset_ck = checked	// in case we call this from a function
	ABHelperStr = SelectString(airbeam_autoset_ck,"Enter #s in rows IONEFF, AIRBEAM_HZ.", "AB Ref runs need to include all detector types.")

End


//^ In the airbeam corrections tab, when autoset is not checked, this inserts values in the 
//^ set variables to the appropriate place in global wave airbeamCorrToFTypeValue.
//Function sq_setVar_ABAutoSet(ctrlName,varNum,varStr,varName) : SetVariableControl
//	String ctrlName
//	Variable varNum
//	String varStr
//	String varName
//	
//	wave airbeamCorrToFTypeValue = root:panel:airbeamCorrToFTypeValue
//	nvar airbeam_corrToFTypeVar = root:panel:airbeam_corrToFTypeVar
//
//	strswitch(ctrlName)
//		case "cor1_manie":
//			airbeamCorrToFTypeValue[0][airbeam_corrToFTypeVar]= varNum
//			break
//		case "cor1_manab":
//			airbeamCorrToFTypeValue[1][airbeam_corrToFTypeVar]= varNum
//			break
//		case  "cor1_manflow":
//			airbeamCorrToFTypeValue[4][airbeam_corrToFTypeVar] = varNum
//			break
//	endswitch
//End

////////////////////////////////////////////////////////////////////////////////
//////////////// SQUIRREL INDEXING //////////////////////////////
////////////////////////////////////////////////////////////////////////////////

//& Recursively scan folders for files
Function sq_harvest_files(pathstr,filelist,ext)
	string pathstr,&filelist,ext
	
	string dumplist
	variable idex,jdex,dirflag
	
	newpath /o/q harvest,pathstr
	
	dirflag=stringmatch(ext,"dir")
	if (!dirflag)
		dumplist=indexedfile(harvest,-1,ext)
		jdex=itemsinlist(dumplist)
		for (idex=0;idex<jdex;idex+=1)
			filelist+=pathstr+stringfromlist(idex,dumplist)+";"
		endfor
	endif
	
	dumplist=indexeddir(harvest,-1,1)
	if (dirflag)
		filelist+=dumplist
	endif
	
	jdex=itemsinlist(dumplist)
	for (idex=0;idex<jdex;idex+=1)
		sq_harvest_files(stringfromlist(idex,dumplist)+":",filelist,ext)
	endfor

End


// Main function for creating an index
// in 1.49 E the diagnostics and misc other checking was moved to its own function sq_initializeAfterGetIndex()
Function sq_butt_getSquirrelIndex(ControlName) : ButtonControl
	string Controlname
		
	nvar load_newonly_ck=root:panel:load_newonly_ck
	nvar load_noFastMode=root:panel:load_noFastMode		//1.51K

	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M
		
	variable attLoad, num, idex, fileFlag, pos, numHdfFiles, tempVar, currentNumFiles, numOldTseries
	string hdfPathStr, hdfFiles, currentFile,currentFullPath, str1, str2		

	//This has been moved to a globals function.  It really has nothing to do with anything index-related.
//	Setdatafolder root:
//	newdatafolder/o root:ms_mats
			
//^	This section was moved to the beginning.  This is the first button press and we should make sure we have frag waves before we do anything else
// sq_PromptForFragWaves()	// change in 1.49E, moved to sq_globals
	
	SetDataFolder root:		// 1.50L just in case
	
	//@ make the index waves and/or reference them
	if(datafolderexists("root:index") && waveexists(root:index:squirrel_index))
		wave/u/i squirrel_index=root:index:squirrel_index
		wave/t file_index=root:index:file_index
		wave/u/i run_index=root:index:run_index
		wave/t data_index=root:index:data_index
		wave/d time_index=root:index:time_index
	else
		newdatafolder root:index
		make/u/i/n=(0,9,0) root:index:squirrel_index	// 1.58G  Cubison uses the 9th dimension
		wave/u/i squirrel_index=root:index:squirrel_index
		make/t/n=0 root:index:file_index
		wave/t file_index=root:index:file_index
		make/u/i/n=(0) root:index:run_index
		wave/u/i run_index=root:index:run_index
		make/t/n=0 root:index:data_index
		wave/t data_index=root:index:data_index
		make/d/n=(0) root:index:time_index
		wave/d time_index=root:index:time_index
		SetScale d 0,0, "dat", time_index
		attLoad=1
	endif
	sq_journal_new("GetSquirrelIndex")

	// save some information about any existing time series waves before we load new stuff
	wave/z t_series = root:index:t_series
	if (waveExists(t_series))
		variable/g root:index:numOldTseries = numpnts(t_series)
	else
		variable/g root:index:numOldTseries=nan
	endif
	
	// get a list of files for inserting/updating the index	
	hdfPathStr = sq_SetDAQHDFpath()		// prompts for hdf path.
	hdfFiles=""
//	sq_harvest_files(hdfPathStr,hdfFiles,".hdf") //& Recursive - may make an option
	sq_harvest_files(hdfPathStr,hdfFiles,"."+HdfFileExtension) //& Recursive - may make an option
	killpath /z harvest		// created in sq_harvest_files
	
	numHdfFiles=itemsinlist(hdfFiles) 
	if (numHdfFiles==0)			//1.55G  
//		DoAlert 1, "There seem to be no files at this location with the extension "+HdfFileExtension+"  DAQ version 5+ uses the h5 extension, DAQ4.x versions use hdf. Do you want to try again with the other extension?"
//		if (V_flag)		// 1.57D
			string TryOther =selectString (stringmatch(HdfFileExtension, "h5") , "h5", "hdf")
			sq_fileExtensionCheckProc("misc_"+TryOther,1) 
			sq_harvest_files(hdfPathStr,hdfFiles,"."+HdfFileExtension) //& Recursive - may make an option
			numHdfFiles=itemsinlist(hdfFiles) 
		if (numHdfFiles ==0)

			Abort "No files were indexed.  Aborting from sq_butt_getSquirrelIndex"
		endif		
	endif

	// Send each file in turn to the index filler
	sq_ams_stat_upd("Indexing files...")

	make /i/o/n=0 new
	note new,"TYPE:todo;"

	nvar/z MajorDaqVersion = root:diagnostics:MajorDaqVersion 		//1.53N
	if (!NVar_exists(MajorDaqVersion) )
		NewDataFolder/o root:diagnostics
		variable/g root:diagnostics:MajorDaqVersion 
		nvar MajorDaqVersion = root:diagnostics:MajorDaqVersion 
	endif

	for(idex=0;idex<numHdfFiles;idex+=1)

		sq_ams_prog_upd(100*idex/numHdfFiles)
		currentFullPath=stringFromList(idex, hdfFiles) 
		currentFile=ParseFilePath(3, currentFullPath, ":", 0, 0)	// stringfromlist(itemsinlist(currentFullPath,":")-1,currentFullPath,":") //&
		
		// slightly rearranged for the occurrance of run numbers greater than 1 million (Tags dudes!)
		// Good AMS files look like 070901_005448921_fF.hdf or 090522_107882_m.hdf
		if( !stringmatch(currentFile[6],"_") || ItemsInList(currentFile, "_")!=3 )	// we should always have a yymmdd_XXX_y.hdf file format
			continue
		endif
		
		// if the run has already been indexed and the user only wants new, move along
		// will not work if user adds _p raw ptof files later and only wants to index them
		tempVar = str2num(stringFromList(1, currentfile, "_"))	
		if (load_newonly_ck && sq_findRun(run_index, tempVar)>=0 )			
			continue
		endif
		
		// find the position of this file in the file_index
		pos=sq_findstr(file_index,currentFullPath,1)		
		fileFlag=pos==-1?(0):(1)
		if(fileFlag==0)	// this is a new file
			pos=numpnts(file_index)
			file_index[pos]={currentFullPath}
		endif
		if ( MajorDaqVersion == 0 )
			MajorDaqVersion = sq_GetMajorFileVersion(currentFullPath)		// I need a DAQ versions before we do diagnostics 
		endif

		if (load_newonly_ck==0 || fileflag==0)	// either we don't care to load only new or this is a new file
			sq_File2SquirrelIndex(currentFullPath,pos,0 )	//1.52B	// fills in data_index, time_index, run_index and, most importantly, squirrel index
		endif
	endfor

	wave run_index = root:index:run_index
	if (numpnts(run_index)==0)		//1.49E
		abort "No runs were indexed - please check your folder or Misc tab - FileExtension settings. - aborting from sq_butt_getSquirrelIndex"
	endif

	// we have the *_index waves, now we want the *_series waves
	sq_gen_t_series() // makes t_series, rn_series, l_series, t_series_old, imt_series
	
	// make the blacklist and all todo waves
	if(!waveexists(root:blacklist))
		make/i/u/n=0 blacklist
	endif
	duplicate/o root:index:run_index,all
	note all,"TYPE:todo;"
	sq_create_todo("all and not blacklist","all")

	//1.51G  if we have tons of runs we should set the flag to put MSSDiff_p into intermediate files
	if (FindDimLabel(root:index:squirrel_index, 2, "MSSDiff_p")<0 && numpnts(root:index:rn_series)> 50000)	// 50,000 is arbitrary
		variable/g root:panel:PutInMemory=0
	endif
	
	// check to see that the all todo wave is monotonic increasing and that there are no duplicates  //1.40D
	duplicate/o/FREE all alltemp		//1.49E
	alltemp[1,] = all[p] - all[p-1]		//1.58G
	alltemp[0] = 1	
	wavestats/q/m=1 alltemp
	if (V_min <=0)		
		edit all
		abort "There is a problem with duplication or decreasing values in the run numbers!  Investigate the all todo wave at point "+num2str(V_minloc)+".  Aborting from  sq_butt_getSquirrelIndex." 
	endif	
	killwaves/z alltemp		//1.60M
	if (Wavemin(all)==0)	
		abort "It is not recommended to use a run with its run number equal to zero. It is recommended that you remove or alter the DAQ hdf with this run.  Blacklisting is not enough."
	endif
	
//	print info to history
	wave new = root:new			//1.48F
	if (numpnts(new)>0)		//1.59D
		sprintf str1, "%d", new[0]
		sprintf str2, "%d", new[numpnts(new)-1]
	else		//1.59F
		sprintf str1, "%d", all[0]
		sprintf str2, "%d", all[numpnts(all)-1]
	endif
	print "//**  The Get Index button was executed at ", time() ," and resulted in",num2str(numpnts(new))," new runs indexed.  (min:",str1, "max:", str2, ")" 
	print "// The location of the raw the hdf files is " +hdfPathStr

	sq_journal_end()

	string returnStr = sq_initializeAfterGetIndex()

	nvar PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF//1.61F
	sq_HideEPToFControls(!PToF_DCgr_IsEPToF) //1.61F

	if (!DataFolderExists("root:TagPanel"))		// we do NOT have a tag panel.  An unhappy compromise
		if (str2num(StringByKey("putMSSDiffpIntermHdf", returnStr))==1)  // putMSSDiffpIntermHdf:1"
			// we have > 1e5 runs in this experiment.  Check to see if the MSSDiff_p and MSSDiff_p_err exist.
			// If they do, we should warn users about out of memory errors  If they do not exist, set a flag for them to automatically be put into interm files instead of memory.
			wave squirrel_index = root:index:squirrel_index 		//1.50K out of memory issue
			variable mssDiff_p_pos = FindDimLabel(squirrel_index, 2, "MSSDiff_p")
			wave/z MSSDiff_p = root:MSSDiff_p
			if (mssDiff_p_pos>=0)
				if (WaveExists(MSSDiff_p))		// these matricies already exist
					print "// The number of runs in this experiment > 1e5. It is recommended that you put MSSDiff_p and the possible error matrix MSSDiff_p_err into intermediate files via the button in the Misc tab."
				else	// perhaps they already put the matricies into intermediate files.  In this case don't bug the user.
				endif
			else		// the user hasn't preprocessed the sticks yet.  Force them to put the matrix in intermediate files.
				variable/g root:panel:PutInMemory = 0
			endif
		endif
	else
//		tag_initializeAfterGetIndex()	// a function within a tag ipf	
	endif

End


// created in 1.49E
// Creates many AMS-specific globals, calls the squirrel diagnostics fetch function, etc.
// should be run right after a get index function
Function/s sq_initializeAfterGetIndex()

	wave squirrel_index = root:index:squirrel_index
	nvar load_plot_diagnostics_ck=root:panel:load_plot_diagnostics_ck
	nvar load_newonly_ck=root:panel:load_newonly_ck
	nvar numOldTseries=root:index:numOldTseries

	variable ComParValExists, tempVar, numCurrentTseries, correctionsWarningFlag
	string returnStr=""

	nvar/z MajorDaqVersion = root:diagnostics:MajorDaqVersion
	if ( !NVar_Exists(MajorDaqVersion) )
		wave/t file_index = root:index:file_index
		variable/g root:diagnostics:MajorDaqVersion = sq_GetMajorFileVersion(file_index[0])		// I need a DAQ versions before we do diagnostics 
		nvar/z MajorDaqVersion = root:diagnostics:MajorDaqVersion
	endif

// AMS diagnostics stuff
	ComParValExists = FindDimlabel(squirrel_index,2,"ComParVal")>=0
	sq_ams_stat_upd("Making Diagnostics")
	wave all = root:all
	if (load_newonly_ck)
	       wave new = root:new
	       if (numpnts(new)==0)        // 1.49B fix
	            DoAlert 0, "There are no new runs to index.  To retrieve DAQ diagnostic values, choose the Update Diagnostics button. - aborting from sq_butt_getSquirrelIndex"   // 1.49B fix
	            return ""  // 1.49B fix
	       endif  // 1.49B fix
		if (ComParValExists) //1.48C
			squirrel_fetch(new,sq_Diagnostics,"newonly:1;","InfoVal;ParVal;ComParVal")		//1.48A
		else
			squirrel_fetch(new,sq_Diagnostics,"newonly:1;","InfoVal;ParVal;")		//1.48C
		endif
	else
		if (ComParValExists) //1.48C
			squirrel_fetch(all,sq_Diagnostics,"newonly:0;","InfoVal;ParVal;ComParVal")	//1.48A
		else
			squirrel_fetch(all,sq_Diagnostics,"newonly:0;","InfoVal;ParVal;")	//1.48C
		endif
	endif

	// 1.48F deal with the user setting the save interval to be non-zero after a get index press, and/r the addition of later or previous runs.
	wave t_series=root:index:t_series
	numCurrentTseries = numpnts(t_series)
	if (numCurrentTseries!=numOldTseries && numtype(numOldTseries)==0)
		correctionsWarningFlag=sq_remapWavesAfterMoreRuns(numOldTseries, numCurrentTseries)
	endif
	if(numCurrentTseries> 1e5)		//1.50K  large file issue with TimO
		returnStr="putMSSDiffpIntermHdf:1"
	endif

//	deal with todo waves
	sq_FixFastModeTimesDAQ34()	//1.55L
	sq_makeToDoAllVW() 		//^ make v and w todo and key waves 
	sq_makeToDoIonizationType()
	sq_makeTodoallMS()			// added in 1.44B
	sq_makeToDoFastOC()   		//^ added in 1.42D
	sq_fixTotalTimeElapsedInRun()	  //^ added in 1.57Z1
	
//	sq_FixPToFDiagWaves()		//^  1.35  //1.60B  This is already called in sq_makeToDoAllPToF
	sq_makeToDoAllPToF()		 // Moved this to happen later
	sq_SetePToFExists()		// added in 1.57Z1
	
	sq_makeRawPToFtodo()  //1.22A
		
	//1.47B for SP2 data
	tempVar = sq_findMaxMinMz(all, 1, 1)
	if (numtype(tempVar) !=0 || tempVar<0 || tempVar>1e8)		// 1e8 is arbitrary
		abort "The maximum Mz of "+num2str(tempVar)+" seems incorrect.  Aborting from sq_initializeAfterGetIndex" 
	endif		//1.60L
//	if (tempVar>1000)		//1.49E  1.52H
		wave amus = root:diagnostics:amus
		redimension/n=(tempVar) amus
		amus=p+1
//	endif

	// added in 1.44C 
//	tempVar = sq_makeTodosFromChangingVals("ChopperFreq;mStart;mFinish;ptofNumSpectraPerChop;ptof_b_logged;ptof_dx_logged;ptof_vg_logged;ptof_vl_logged;ptof_step;ptof_t0;eptof_enabled;eptof_oversampling" , "diagnostics", "allPToF", "allPToF")// 1.49E added mFinish
	tempVar = sq_makeTodosFromChangingVals("ChopperFreq;numPtsRawSpectra;ptofNumSpectraPerChop;ptof_b_logged;ptof_dx_logged;ptof_vg_logged;ptof_vl_logged;ptof_step;ptof_t0;eptof_enabled;eptof_oversampling" , "diagnostics", "allPToF", "allPToF")// 1.49E added mFinish
		
// reset some menus on sq panel
	sq_pop_dump2memList("",0,"Get List")
	sq_pop_toDoList("",0,"Get List")
	
	sq_SetDimLabelsABCorrToFType()		//1.52J	

// section below is handled differently in 1.48F	See the section in this function before the section dealing with refinding todo waves.
	// 1.44D
//	wave/z corr_fact = root:diagnostics:corr_fact
	if (correctionsWarningFlag )
		sq_addedNewRuns()
		DoAlert 0, "With the addition of new runs or blank runs due to non-zero interval values in the get index step, you need to redo your airbeam correction factor and other correction factors; your m/z calibration panel may need to be updated."
	endif 
		//@ only plots if data present and checkbox ticked
	if(load_plot_diagnostics_ck) 		//^ not necessary && v_npnts>0)
		SQ_plot_diag()
	endif
	return returnStr  // 1.50K

	if(MajorDaqVersion<4)
		DoWindow/F TimeTable
		if (!V_flag)
			sq_createTableTimeWaves()
			DoAlert 0, "The DAQ version for this data is older than version 4.  Please make sure that you have sensible values for the timewaves, specifically for waves TimeAcquiring*, by copying values from other waves if necessary."
		endif
	endif
	
End	
	

// 1.22A
Function/wave sq_makeRawPToFtodo()

	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index
	variable RawPToFPos=FindDimlabel(squirrel_index, 2, "PToF")  //1.22A
	if (RawPToFPos< 0)  // no raw PToF data.		//1.22A
		STRUCT WMButtonAction ba
 		sq_FileIndexTable(ba)
		return $""
		// Abort "Raw PToF spectra has not yet been indexed. Look for *_p files in the list of indexed DAQ and intermediate files."
	endif
	make/o/n=(dimsize(squirrel_index,0))  root:RawPToFFlag/wave=	RawPToFFlag
	make/free/o/n=(dimsize(squirrel_index,0))  RawPToFfree	
	RawPToFfree = squirrel_index[p][5][RawPToFPos]  // will have number of points in raw spectra, i.e. 25,000
	RawPToFFlag = RawPToFfree[series_index[p]]>0
	sq_create_todo("RawPToFFlag","allRawPToF")
	Killwaves/z RawPToFFlag
	wave allRawPToF =root:allRawPToF
	return allRawPToF
End


// when new runs have been added and corrections have been done to create some new waves (original waves retain *_logged suffix)
// we overwrite the entire wave
Function sq_addedNewRuns()

 	string param, paramstr
 	variable idex, num
 	
 	param="ptof_vl;ptof_vg;ptof_dx;ptof_b;flow;mzpower"
	num = itemsInList(param)
	
 	for (idex=0;idex<num;idex+=1)
 		paramStr = stringfromlist(idex,param)
		wave/z wav=$("root:diagnostics:"+paramStr)
		wave/z wav_logged=$("root:diagnostics:"+paramStr+"_logged")
		if (WaveExists(wav) && WaveExists(wav_logged))
			redimension/n=(numpnts(wav_logged)) wav
			wav = wav_logged		
		endif
		if (stringMatch(paramStr, "mzpower") )
			wave rn_series = root:index:rn_series
			redimension/n=(numpnts(rn_series)) wav
			wav=.5
		endif
	endfor

End		

// added in 1.48F to deal with non-zero interval values after an initial get index, and/or more runs before or after current runs
Function sq_t_series_map(t_old, t_new, t_series_map)
wave t_old, t_new, t_series_map

	variable idex, numOld, numNew, counter
	
	numOld = numpnts(t_old)
	numNew = numpnts(t_NEW)

	make /o/n=(numOld) tdiff
	t_series_map[0,numOld-1]=round(binarysearchinterp(t_new,t_old[p]))
	t_series_map[numOld,]=numOld
	duplicate/o t_series_map t_series_mapDup 
	tdiff[0,numOld-2]  = t_series_map[p+1] - t_series_map[p] -1
	t_series_map=p
	counter=numOld-1
	for (idex=numOld-1;idex>=0;idex-=1)
		if ( tdiff[idex]>0)
			insertpoints counter+1, tdiff[idex], t_series_map
			t_series_map[counter+1, counter+tdiff[idex]]=numOld
		endif
		counter-=1
	endfor
	killwaves/z tdiff
End


// new in 1.48F
Function sq_remapWavesAfterMoreRuns(numOldTseries, numCurrentTseries)
variable numOldTseries, numCurrentTseries

	string resetList, resetTextList
	variable correctionsWarningFlag, idex
		
 	resetList="root:diagnostics:ionSingleStr;root:diagnostics:corr_fact;root:diagnostics:ioneff;root:diagnostics:ptof_vl;root:diagnostics:ptof_vg;root:diagnostics:ptof_dx;root:diagnostics:ptof_b;"
	resetList +="root:mzFitting:mz_FitPower;root:mzFitting:mz_FitSlope;root:mzFitting:mz_FitIntercept;"
	resetList +="root:mzFitting:mz_FitPowerClosed;root:mzFitting:mz_FitSlopeClosed;root:mzFitting:mz_FitInterceptClosed;"
	resetList +="root:mzFitting:mz_FitPowerOpen;root:mzFitting:mz_FitSlopeOpen;root:mzFitting:mz_FitInterceptOpen;"
	resetList +="root:mzFitting:mz_RatioIntercept;root:mzFitting:mz_RatioSlope;root:mzFitting:mz_RatioPower;"	
	resetList +="root:mzFitting:mz_FitChiSq;root:mzFitting:FitFilterKey;root:mzFitting:mz_ToFTypeDisplayKey;"	
	resetList +="root:mzFitting:t_ion;root:mzFitting:Resolution;root:mzFitting:ppmStd;root:mzFitting:deltaTSquared_Chisq;"
	resetList +="root:mzFitting:mzPower;"

	resetList +="root:mzFitting:deltaTSquared_coefs;root:mzFitting:AllRunsMassSigma;root:mzFitting:AllRunsAccuracyTime;root:mzFitting:AllRunsAccuracyMass;"

// 1.53O
	resetList +="root:HR_PeakShape:HR_FinalPWInterceptWave;"
	resetList +="root:HR_PeakShape:HR_FinalPWPowerWave;"
	resetList +="root:HR_PeakShape:HR_FinalPWSlopeWave;"
	resetList +="root:HR_PeakShape:PW_RunMask;"
	resetList +="root:index:HRstick_series;"

	// added in 1.56E
//	resetList +="root:diagnostics:EPToF_denoise;"
//	resetList +="root:diagnostics:EPToF_sharpening;"
	resetList +="root:diagnostics:EPToF_testregion;"
	resetList +="root:diagnostics:deconvolveType;"
	resetList +="root:diagnostics:DCregion1Start;"
	resetList +="root:diagnostics:DCregion1Stop;"
	resetList +="root:diagnostics:DCregion2Start;"
	resetList +="root:diagnostics:DCregion2Stop;"

	resetTextList="root:index:HRstick_seriesKey;"
	resetTextList +="root:HR_PeakShape:HR_FinalPSNameWave;"

	// first do the diagnostic waves
	SetDataFolder root:diagnostics
	wave t_series = root:index:t_series
	wave t_series_old = root:diagnostics:t_series_old
//	make/o/n=(numCurrentTseries) t_series_map
//	sq_t_series_map(t_series_old, t_series, t_series_map)
//  redone in 1.61A
	variable numOld = numpnts(t_series_old)
	for (idex=0;idex<itemsInList(resetList);idex+=1)
		wave/z dest=$stringfromList(idex,resetList )
		if (WaveExists(dest))
//			duplicate /o dest,diag_tmp
//			insertpoints/M=0 numOldTseries, 1, diag_tmp
			if (dimsize(dest,1)==0)
//				diag_tmp[numOldTseries]=nan
				redimension/n=(numCurrentTseries) dest
//				dest=diag_tmp[t_series_map[p]]
				dest[numOld,]=nan
			else
//				diag_tmp[numOldTseries][]=nan
				redimension/n=(numCurrentTseries, dimsize(dest,1)) dest
//				dest=diag_tmp[t_series_map[p]][q]			
				dest[numOld,][]=nan			
			endif
		endif
	endfor
	
	//1.53O
	for (idex=0;idex<itemsInList(resetTextList);idex+=1)
		wave/t/z destText=$stringfromList(idex,resetTextList )
		if (WaveExists(destText))
//			duplicate/t /o destText,diagText_tmp
//			insertpoints/M=0 numOldTseries, 1, diagText_tmp
			if (dimsize(destText,1)==0)
//				diagText_tmp[numOldTseries]=""
				redimension/n=(numCurrentTseries) destText
//				destText=diagText_tmp[t_series_map[p]]
				destText[numOld,]=""
			else
//				diagText_tmp[numOldTseries][]=""
				redimension/n=(numCurrentTseries, dimsize(dest,1)) destText
//				destText=diagText_tmp[t_series_map[p]][q]			
				destText[numOld,][]=""
			endif
		endif
	endfor

	wave/z mz_Mass = root:mzFitting:mz_Mass
	if (WaveExists(mz_Mass))		//1.53L
		variable numMasses=numpnts(mz_Mass)
		string MassStr
		for (idex=0;idex<numMasses;idex+=1)
			sprintf MassStr "%1.2f", mz_Mass[idex]
			MassStr = ReplaceString(".",MassStr,"_")			
			wave/z dest= $"root:mzFitting:Accuracy_"+MassStr
			if (WaveExists(dest))
//				duplicate /o dest,diag_tmp
//				insertpoints/M=0 numOldTseries, 1, diag_tmp
//				diag_tmp[numOldTseries]=nan
				redimension/n=(numCurrentTseries) dest
//				dest=diag_tmp[t_series_map[p]]
				dest[numOld,]=nan
				correctionsWarningFlag=1
			endif
		endfor
	endif
	
	if (DataFolderExists("root:gaussFits:"))		// user has started the HR analysis  //1.53O
		SetDataFolder root:gaussFits		
		string GaussCoeffList = WaveList("GaussCoeff_Closed_*", ";","DIMS:2")
		for (idex=0;idex<itemsInList(GaussCoeffList);idex+=1)
			wave/z dest= $stringFromList(idex, GaussCoeffList)
//			duplicate /o dest,dest_tmp
//			insertpoints/M=0 numOldTseries, 1, dest_tmp
//			dest_tmp[numOldTseries][]=nan
			redimension/n=(numCurrentTseries, dimsize(dest,1)) dest
//			dest=dest_tmp[t_series_map[p]][q]
			dest[numOld,][]=nan
			correctionsWarningFlag=1			
		endfor
	endif

	killwaves/z diag_tmp, dest_tmp, diagText_tmp
	SetDataFolder root:

	return correctionsWarningFlag

End


//^creates handy key waves ToFTypeVKey and ToFTypeWKey which have only 1s and nans, and allV and allW todo waves
//^  v = 1, w = 2
Function sq_makeToDoAllVW()

	wave rn_series = root:index:rn_series
	if ( !waveexists(rn_series) ||  (numpnts(rn_series)==0))
		abort " There were no runs identified in the hdf files. - Aborting from sq_makeToDoAllVW"
	endif
	wave toftype = root:diagnostics:toftype
	if  (!waveexists(toftype))
		abort "Could not find waves toftype - Aborting from sq_makeToDoAllVW"
	endif
	
	nvar cor3_chamber = root:panel:cor3_chamber

	variable/g root:diagnostics:VWSwitching
	variable/g root:diagnostics:isV
	variable/g root:diagnostics:isW
	variable/g root:diagnostics:isC
	variable/g root:diagnostics:isL
	nvar VWSwitching = root:diagnostics:VWSwitching
	nvar isV = root:diagnostics:isV
	nvar isW = root:diagnostics:isW
	nvar isC = root:diagnostics:isC
	nvar isL = root:diagnostics:isL

//	0.295 = length of Long tof
	
	variable myW, myV, n = numpnts(rn_series)

	duplicate/o rn_series allV, allW	
	note allV,"TYPE:todo;"
	note allW,"TYPE:todo;"
	
	make/o/n=(n) root:diagnostics:ToFTypeVKey
	make/o/n=(n) root:diagnostics:ToFTypeWKey
	wave ToFTypeVKey = root:diagnostics:ToFTypeVKey
	wave ToFTypeWKey = root:diagnostics:ToFTypeWKey
	
	TofTypeVKey = toftype[p] ==1		//^ tof type 1 = v
	TofTypeWKey = toftype[p] ==2		//^ tof type 2 = w
	
	sq_create_todo("root:diagnostics:ToFTypeWKey and all","allW")
	sq_create_todo("root:diagnostics:ToFTypeVKey and all","allV")
	isV=0; isW=0;isC=0; isL=0			//1.60Y
	
	if ( numpnts(allV)>0 && numpnts(allW)>0 )
		VWSwitching = 1
		print "// V and W tof types were detected."
		isV=1
		isW=1
	else
		VWSwitching = 0
		if (numpnts(allV)>0)
			isV=1		
		elseif (numpnts(allW)>0)
			isW=1
		elseif(cor3_chamber< 0.2)
			isC=1
		else
			isL=1
		endif
		Killwaves allV, allW	//^ they are redundant
	endif
	
End


//^ make allPToF todo wave
Function sq_makeToDoAllPToF()
	
	sq_FixPToFDiagWaves()	// fixes ptofNumTimesThrough
	sq_create_todo("root:diagnostics:ptofNumTimesThrough and all","allPToF")
	wave all = root:all
	wave allPToF = root:allPToF
			//1.53C
	if (numpnts(allPToF)==0)
		killwaves allPToF
		return 0
	endif

	nvar MajorDaqVersion = root:diagnostics:MajorDaqVersion
	if (MajorDaqVersion<=3)		//1.60B
		wave timePToF = root:diagnostics:TimePToFSec
	else
		wave timePToF = root:diagnostics:TimeAcquiringPToFInRun	
	endif

	make/FREE/o/n=(numpnts(timePToF)) todoMask
	sq_makeMaskFromTodofindRun(todoMask,allPToF)
	wave/z allPToF = root:allPToF
	todoMask=timePToF/todoMask
	todoMask = todomask[p] < 0.3 ? 1 : 0
	wavestats/q/m=1 todoMask
	// DTS changed in 1.20S for better interface & prevent users from NOT removing these troublesome runs.
	wave/z allShortTimePToF = root:allShortTimePToF		
	if (WaveExists(allShortTimePToF))  // prevent all kinds of warnings popping up
		duplicate/o allShortTimePToF OLDallShortTimePToF
		wave/z OLDallShortTimePToF = root:OLDallShortTimePToF
	endif	
	if (sum(todoMask)>0)
		duplicate/o todoMask allShortTimePToFKeyWave
		sq_create_todo("allShortTimePToFKeyWave","allShortTimePToF")
		wave/z allShortTimePToF = root:allShortTimePToF
		if (WaveExists(allShortTimePToF) && WaveExists(OLDallShortTimePToF) && numpnts(allShortTimePToF) == numpnts(OLDallShortTimePToF))
			killwaves/z OLDallShortTimePToF
			return 0
		endif
		
		Print "// "+num2str(sum(todoMask))+" runs in the todo wave allShortTimePToF have PToF data that was collected for a short time, <0.3s. These runs have been removed from default PToF todo waves such as allPToF allPToFGrpx, etc."
//		if (V_flag && numpnts(allShortTimePToF) != numpnts(allPToF))  // only a few of the PToF runs were problematic
		string PToFGrpList, PToFGrpStr
		variable idex, numPToFGrp		
		PToFGrpList = WaveList("allPToFGrp*",";","") + WaveList("allePToFGrp*",";","")
		PToFGrpList = SortList(PToFGrpList) 
		numPToFGrp = itemsInList(PToFGrpList)
		for(idex=0;idex<numPToFGrp;idex+=1)
			PToFGrpStr = stringFromList(idex, PToFGrpList)
			sq_create_todo(PToFGrpStr+" and not allShortTimePToF",PToFGrpStr)
		endfor
		sq_create_todo("allPToF and not allShortTimePToF","allPToF")
		wave/z allPToF = root:allPToF
		if (numpnts(allPToF) == 0)
			DoAlert 1, "It appears that every PToF run has be aquired for a short time.  This is not normal.  Continue?"
			if (!V_flag)
				sq_ShortPToFTimesTable()
				Abort "User has aborted due to short PToF times."
			endif
		endif
//			print "//  From this set of todo waves: allPToF;"+PToFGrpList+" the runs listed in allShortTimePToF were removed."
//		else
//				sq_ShortPToFTimesTable()
//		endif
	endif
	
End


//1.59D Added to help users diagnose possible problem runs.
Function sq_ShortPToFTimesTable()
	DoWindow/F ShortPToFTimeTable
	if (V_flag)
	endif
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:diagnostics:
	Edit/N=ShortPToFTimeTable/W=(234,168.5,645.75,629.75) as "ShortPToFTimeTable"
	wave TimeAcquiringPToFInRun,ptofNumTimesThrough
	AppendToTable root:allShortTimePToF, ::index:rn_series,::allShortTimePToFKeyWave,TimeAcquiringPToFInRun
	AppendToTable root:diagnostics:ptofNumTimesThrough
	ModifyTable format(Point)=1,size(::allShortTimePToFKeyWave)=14,width(::allShortTimePToFKeyWave)=27
	ModifyTable rgb(::allShortTimePToFKeyWave)=(65535,0,0),width(TimeAcquiringPToFInRun)=96
	ModifyTable width(ptofNumTimesThrough)=96
	SetDataFolder fldrSav0
End


// added in 1.44B
//sq_makeTodosFromChangingVals("ChopperFreq;mStart;ptofNumSpectraPerChop;ptof_b_logged;ptof_dx_logged;ptof_vg_logged;ptof_vl_logged;ptof_step;ptof_t0" , "diagnostics", "allPToF", "allPToF")
// a very versatile function that allows for the creation of todo waves based on when other waves change their values.
// Initially this was intended for when PToF settings changed, but could be used for other setting changes
//  changed in 1.47B for John J, NYC crazy exp
Function sq_makeTodosFromChangingVals(wlist, dirStr, allWaveSubset, TodoPrefix)
string wlist, dirStr, allWaveSubset, TodoPrefix

    wave rn_series = root:index:rn_series
    wave/z allWave = $"root:"+allWaveSubset
    if (!WaveExists(allWave))    // every run has ptof data	
	 	if (stringmatch(TodoPrefix, "allPToF") && FindDimLabel(root:index:squirrel_index, 2, "ptof_stick" )<0)	// or there is no PToF data
			return 0 		//1.53C
	 	else			// every run has PToF data
	       wave allWave = $"root:all"
	 	endif
    endif

    string wstr, NoteStr
    variable idex, numwlist, counter, num, numsteps, pVal

    num = numpnts(rn_series)
    numwlist = itemsInList(wlist)

    // check to see that all waves we intend to use exist
    for (idex=0;idex<numwlist;idex+=1)
        wstr = stringFromList(idex, wlist)
        wave/z w_wave = $"root:"+dirStr+":"+wstr
        if (!WaveExists(w_wave) )
            abort "//  The wave root:"+dirStr+":"+wstr +" intended for use in sq_makeTodosFromChangingVals was not found, aborting from sq_makeTodosFromChangingVals"
        endif
    endfor

    make/o/n=(num) wave_key, TodoMask, tempMask, doneMask
    //    make key wave of 0s and 1s to keep track of runs we have dealt with
    sq_makeMaskFromTodofindRun(TodoMask,allWave)

    doneMask=0

    pVal=0
    counter=0

    // start at the first run and get values for each wave.
    do
        NoteStr=""
        tempMask=1
        // go through all waves in list
        for (idex=0;idex<numwlist;idex+=1)
            wstr = stringFromList(idex, wlist)
            wave w_wave = $"root:"+dirStr+":"+wstr
            tempMask*= (w_wave[pVal] == w_wave[p])
            NoteStr+= wstr+":"+ num2str(w_wave[pVal])+";"
        endfor

		 	if (str2num(StringByKey("eptof_enabled",NoteStr)) )
				TodoPrefix = "allePToF" 	
		 	else
				TodoPrefix = "allPToF" 	
		 	endif
		 	
		        wave_key=(tempMask)*TodoMask
		        sq_create_todo(Nameofwave(allWave) +" and wave_key",TodoPrefix+"Grp"+gen_num2str2char(counter))
		        wave GrpTodo = $"root:"+TodoPrefix+"Grp"+gen_num2str2char(counter)
		        if (numpnts(GrpTodo)==0)         // added in 1.50I
		            Killwaves/z GrpTodo
		            counter-=1
		        elseif(StringMatch(StringByKey("ptofNumSpectraPerChop", NoteStr), "0"))  // added in 1.50I
		            Killwaves/z GrpTodo
		            counter-=1
		        endif
		        if (WaveExists(GrpTodo))		//1.50K
		        	Note/NOCR GrpTodo NoteStr        // added in 1.50I
			endif
      
        counter+=1

        doneMask = doneMask || wave_key

        wave_key =!doneMask/!doneMask
        pVal = sq_findFirst(wave_key, pVal+1)

    while(pVal < num && counter < 20)        //1.48A  presume that we have at most 20 different PToF settings        // 1.49E changed max from 100 to 200

    killwaves/z wave_key, TodoMask, tempMask, doneMask
    return counter

End 


//1.49E
// Generates a non empty string when a todo wave overlaps more than one PToF groups
//Function/s sq_checkPToFGroupings(todo)
//wave todo
//
//	svar sq_toDoList = root:panel:sq_toDoList
//	string returnStr, PToFGrpList
//	variable tempVar, idex, num, numtodo, successFlag, numTemp
//	
//	returnStr=""
//	wave/z NumPtsRawSpectra =  root:diagnostics:NumPtsRawSpectra
//	if (!WaveExists(NumPtsRawSpectra) || numpnts(NumPtsRawSpectra) !=  numpnts(root:index:rn_series))
//		squirrel_fetch(root:index:rn_series,sq_getNewDiagValuesList,"dataFolderStr:diagnostics;colList:11;destList:NumPtsRawSpectra","ParVal;")	
//	endif
//	
//	if ( ! (!Exists("allPToFGrp00") && (!Exists("allePToFGrp00") ))
//		tempVar = sq_makeTodosFromChangingVals("ChopperFreq;mStart;mFinish;ptofNumSpectraPerChop;ptof_b_logged;ptof_dx_logged;ptof_vg_logged;ptof_vl_logged;ptof_step;ptof_t0;eptof_enabled;eptof_oversampling" , "diagnostics", "allPToF", "allPToF")
//	endif
//	
//	successFlag=0
//	numtodo = numpnts(todo)
//	PToFGrpList = WaveList("allPToFGrp*",";","") +  WaveList("allePToFGrp*",";","")
//	PToFGrpList = SortList(PToFGrpList) 
//	num = itemsInList(PToFGrpList)
//	for (idex=0;idex<num;idex+=1)
//		sq_create_todo(NameOfWave(todo)+" and "+stringfromList(idex, PToFGrpList),"tempTodo")
//		wave tempTodo
//		numTemp=numpnts(tempTodo) 
//		if (numTemp == numtodo)			// success, the todo wave is a subset of one of the PToF group todo waves
//			successFlag=1 
//		elseif (numTemp < numtodo && numTemp>0)
//			returnStr+=stringfromList(idex, PToFGrpList)+";"
//		endif
//	endfor
//
//	if (successFlag==1)
//		returnStr=""
//	else
//		returnStr="// Alert!  you are generating PToF results when the DAQ PToF settings have changed for different runs in the todo wave "+NameOfWave(todo) +"PToF groups: "+returnStr
//	endif
//	
//	killwaves/z tempTodo	//1.51C
//	return returnStr
//	
//End
//
//
// *************************************************
//  Returns a 2 char or more length string of the number x
Function/s gen_Num2Str2Char(i)
	Variable i

	string returnStr = num2str(i)
	
	if ( (i>=0) && (i<=9) )
		returnStr = "0"+returnStr
	endif
	
	return returnStr

End


Function gen_RepeatLastNonNan(wav)
	Wave wav

	variable idex=sq_FindFirst(wav, 0), num=numpnts(wav)
	variable temp = wav[idex]
	
	if (idex == num)
		return 0		// the entire wave is nans
	endif
	
	do
		if(numtype(wav[idex])==2)
			wav[idex]=temp
		else
			temp = wav[idex]
		endif 	
		idex+=1
	while(idex<num)

	return 1
	
End


//^ For Ron Brown daq version 
// ionization types:   0=EI; 1=sEI; 2=VUV; 3=Li; 4=Neg
Function sq_makeToDoIonizationType()
	
	setdatafolder root:
	
	wave/z rn_series = root:index:rn_series
	if ( !waveexists(rn_series) ||  (numpnts(rn_series)==0))
		abort " There were no runs identified in the hdf files. - Aborting from sq_makeToDoIonizationType"
	endif
	
	variable IonizationTypeVar, IonizationTypeNum, numRuns, det_n
	string  IonizationTypeStr, setpop
	
	IonizationTypeNum = ItemsInList(IONIZATION_TYPE_LIST)
	string /g root:diagnostics:detectorsused=""
	svar detectorsused=root:diagnostics:detectorsused
	
	numRuns = numpnts(rn_series)
	make /o/n=(numRuns) root:diagnostics:detector_num
	wave detector_num=root:diagnostics:detector_num
	detector_num=numtype(rn_series)?(nan):(0)		//^ I don't know when rn_series would be nan or inf.... but this sets the detector type to nan if rn_series is not a real number
	
	wave/z allV = root:allV
	wave/z allW = root:allW
	wave/z toftypeWkey=root:diagnostics:toftypewkey
	wave/z toftypeVkey=root:diagnostics:toftypevkey

	nvar/z isW = root:diagnostics:isW				// 1.43B change to not generate errors if not existing
	nvar/z isV = root:diagnostics:isV
	nvar/z isC = root:diagnostics:isC
	nvar/z VWSwitching = root:diagnostics:VWSwitching

	wave/z ionizationType = root:diagnostics:ionizationType

	 det_n=0
	 if  (waveexists(ionizationType)==1)		//^ 2006 Ron Brown data
		for (IonizationTypeVar=0; IonizationTypeVar< IonizationTypeNum;IonizationTypeVar+=1)
			IonizationTypeStr = StringFromList(IonizationTypeVar, IONIZATION_TYPE_LIST)
			sq_ams_stat_upd("Making ionization type "+IonizationTypeStr+" todo wave")
			
			variable/g $"root:diagnostics:is"+IonizationTypeStr		// a true/false flag for the presence of runs using this ion type
			nvar isVar = $"root:diagnostics:is"+IonizationTypeStr
			isVar=0 // initialize
			
			make/o/n=(numRuns) $"root:diagnostics:ionizationType"+IonizationTypeStr+"Key"	// a key wave of 0s and 1s to indicate ion type usage
			wave ionizationTypeKey = $"root:diagnostics:ionizationType"+IonizationTypeStr+"Key"
			ionizationTypeKey = ionizationType[p] == IonizationTypeVar 		// important that IonizationTypeVar matches daq
			wavestats /q/m=1 ionizationTypeKey
			if (v_max>0)
				sq_create_todo("root:diagnostics:ionizationType"+IonizationTypeStr+"Key and all","all"+IonizationTypeStr)
				wave allwave=$("all"+IonizationTypeStr)
				if ( numpnts(allWave)>0 )
					isVar=1
					if (isV)	// we have v mode data
						if (waveExists(allV))	// we have v and w mode
							sq_create_todo("all"+IonizationTypeStr+" and allV","all"+IonizationTypeStr+"andV")
							wave combo = $"root:all"+IonizationTypeStr+"andV"
							if (numpnts(combo)==0)
								killwaves combo
							else
								detectorsused+="V_"+IonizationTypeStr+";"
								detector_num+=det_n*toftypeVkey*ionizationTypeKey
								det_n+=1
							endif
						else
							detectorsused+="V_"+IonizationTypeStr+";"
							detector_num+=det_n*toftypevkey*ionizationTypeKey
							det_n+=1
						endif
					endif		// endif isV
					if (isW)
						if (waveExists(allW))	// we have v and w mode
							sq_create_todo("all"+IonizationTypeStr+" and allW","all"+IonizationTypeStr+"andW")
							wave combo = $"root:all"+IonizationTypeStr+"andW"
							if (numpnts(combo)==0)
								killwaves combo
							else
								detectorsused+="W_"+IonizationTypeStr+";"
								detector_num+=det_n*toftypewkey*ionizationTypeKey		// 1.41 error, typo v mode to w mode
								det_n+=1
							endif
						else
							detectorsused+="W_"+IonizationTypeStr+";"
							detector_num+=det_n*toftypewkey*ionizationTypeKey		// 1.41 error, typo v mode to w mode
							det_n+=1
						endif
					endif		// endif isW
					if (isC)	
						detectorsused+="C_"+IonizationTypeStr+";"
						detector_num+=det_n*ionizationTypeKey
						det_n+=1
					endif		// endif is C

				else
					killwaves allWave, ionizationTypeKey		// this ion type not used, get rid of unneeded waves
				endif		// end if numpnts(all wave )>0
			else
				killwaves ionizationTypeKey
			endif
			sq_ams_prog_upd(100*(IonizationTypeVar+1)/IonizationTypeNum)
		endfor
	else //^ pre - 2006 Ron Brown data type
		if (VWSwitching)
			detectorsused="V_EI;W_EI"
			wave toftypeWkey = root:diagnostics:toftypeWkey			// 1.43B fix
			detector_num=toftypeWkey								// 1.43B fix
			det_n=2
		elseif(isC)
			detectorsused="C_EI;"
			detector_num=0
			det_n=1
		elseif(isV)
			detectorsused="V_EI;"
			detector_num=0
			det_n=1
		else		// isW
			detectorsused="W_EI;"
			detector_num=0
			det_n=1
		endif
	endif
	
	wave airbeamCorrToFTypeValue = root:panel:airbeamCorrToFTypeValue
//	if (dimsize(airbeamCorrToFTypeValue,1)<itemsinlist(detectorsused))
		redimension /n=(dimsize(airbeamCorrToFTypeValue,0),itemsinlist(detectorsused)) airbeamCorrToFTypeValue
//	endif
	
//	setpop=replacestring("_",detectorsused,"-ToF (")
//	setpop="popupmenu cor1_ToFType win=ams_panel,value=\""+replacestring(";",setpop,");")+"\""
//	execute setpop

	sq_ams_stat_upd("Done")

End


//  Function created by Donna, will be inserted in new version of Squirrel.		//1.44B
// Makes a todo wave named allMS that has ms data (and not runs where there is only PToF data)
Function sq_makeTodoallMS([displayFlag])
variable displayFlag

	setDataFolder root:
	
	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index
	wave all = root:all
	
	variable num, MSSDiff_pos, MSSDiff_v_pos, MSSDiff_w_pos
	
	num = dimsize (squirrel_index,0)
	
	MSSDiff_pos = FindDimLabel(squirrel_index, 2, "MSSDIff")
	MSSDiff_v_pos = FindDimLabel(squirrel_index, 2, "MSSDiff_v")
	MSSDiff_w_pos = FindDimLabel(squirrel_index, 2, "MSSDiff_w")

	if (MSSDiff_pos < 0 && MSSDiff_v_pos < 0 && MSSDiff_w_pos <0 )
		print  "// There is no MSSDiff data - hopefully there is PToF data - printing from CreateAllMS"		// 1.46E changed from an abort statement for folks doing their velocity calibrations in squirrel.
		return 0
	endif
	
	make/o/n=(num) root:MSSDiff_num=0, root:MSSDiff_v_num=0, root:MSSDiff_w_num=0, root:MSKeywave 
	
	wave MSSDiff_num = root:MSSDiff_num
	wave MSSDiff_v_num = root:MSSDiff_v_num
	wave MSSDiff_w_num = root:MSSDiff_w_num
	wave MSKeywave = root:MSKeywave

	if (MSSDiff_pos>=0)
		MSSDiff_num = squirrel_index[p][4][MSSDiff_pos]>0 ? 1 : 0
	endif
	if (MSSDiff_v_pos>=0)
		MSSDiff_v_num = squirrel_index[p][4][MSSDiff_v_pos]>0 ? 1 : 0
	endif
	if (MSSDiff_w_pos>=0)
		MSSDiff_w_num = squirrel_index[p][4][MSSDiff_w_pos]>0 ? 1 : 0
	endif

 	variable idex
 	for(idex=0;idex<num;idex+=1)
 		MSKeywave[series_index[idex]]= MSSDiff_num[idex] || MSSDiff_v_num[idex] || MSSDiff_w_num[idex]
	endfor

	sq_create_todo("all and MSKeywave", "allMS")		
	wave allMS = root:allMS
	
	wave FastKey = root:diagnostics:FastKey		//1.53 I 
	wave TimeAcquiringMSOpenInRun = root:diagnostics:TimeAcquiringMSOpenInRun		//1.53 I 
	wave TimeAcquiringMSClosedInRun = root:diagnostics:TimeAcquiringMSClosedInRun 	//1.53 I 
	make/o/n=(num) ZeroTimeMSKey = (FastKey[p]!=2 && (TimeAcquiringMSOpenInRun[p]==0) ||  (FastKey[p]!=0 && TimeAcquiringMSClosedInRun[p]==0 ) )

	if ( sum(ZeroTimeMSKey)>0)
		 print "// There are "+ num2istr(sum(ZeroTimeMSKey)) +" runs which have no MS data, perhaps only PToF data.  To see a table of such runs, from the command line run sq_makeTodoallMS(displayFlag=1) "		//1.57D

		if ( !ParamisDefault(displayFlag) && displayFlag)   //1.57D
			make/o/n=(num) ZeroTimeMSOpenKey = FastKey[p]!=2 && TimeAcquiringMSOpenInRun[p]==0
			make/o/n=(num) ZeroTimeMSClosedKey = FastKey[p]!=0 && TimeAcquiringMSClosedInRun[p]==0

			sq_create_todo("all and ZeroTimeMSOpenKey", "noMSOpen")		
			sq_create_todo("all and ZeroTimeMSClosedKey", "noMSClosed")		
//			wave allZeroTimeMS = root:allZeroTimeMS
			wave noMSClosed = root:noMSClosed
			wave noMSOpen = root:noMSOpen

			if (numpnts(noMSClosed)==0 )// perhaps they were blacklisted
				killwaves/z noMSClosed
			endif
			if (numpnts(noMSOpen)==0 )// perhaps they were blacklisted
				killwaves/z noMSOpen
			endif
			DoWindow/F zeroTimeMS_table
			if (!V_flag)
				wave rn_series = root:index:rn_series		//1.53 I 
				edit/N= zeroTimeMS_table as "zeroTimeMS_table"
				appendtotable rn_series, FastKey,TimeAcquiringMSOpenInRun, TimeAcquiringMSClosedInRun
				if (numpnts(noMSClosed)!=0 )// perhaps they were blacklisted
					appendtotable noMSClosed, ZeroTimeMSClosedKey
				endif
				if (numpnts(noMSOpen)!=0 )// perhaps they were blacklisted
					appendtotable noMSOpen, ZeroTimeMSOpenKey
				endif
			endif
		else
			killwaves/z ZeroTimeMSKey		
		endif
	endif
		
	killwaves/z MSKeywave, MSSDiff_num, MSSDiff_v_num, MSSDiff_w_num, ZeroTimeMSKey

End

 
//^ 1.42D
 // creates todo waves allFastOpen, allFastClosed, allFast, allSlow
 // allSlowMS
Function sq_makeToDoFastOC() 

	wave/z fastKey = root:diagnostics:fastKey
	if (waveExists(fastKey))
		wavestats/q/m=1 fastKey
		if (V_npnts>0)
			duplicate/o fastKey root:diagnostics:fastKey_temp
			wave fastkey_temp = root:diagnostics:fastKey_temp
			fastKey_Temp = fastKey[p]==0
			sq_create_todo("root:diagnostics:fastKey_temp and all","allFastOpen")
			fastKey_Temp = fastKey[p]==2
			sq_create_todo("root:diagnostics:fastKey_temp and all","allFastClosed")
			sq_create_todo("allFastOpen or allFastClosed","allFast")	
			killwaves/z fastKey_temp
			sq_create_todo("all and not allFast","allSlow")			//1.50E
			sq_create_todo("allSlow and allMS","allSlowMS")			//1.50E
//			sq_makeToDoallSlowMS()   	// 1.53C
		endif
	endif
	
End


//1.57ZI
Function sq_fixTotalTimeElapsedInRun()			// due to conversations with Joel and Leah Aug 8, 2015

	wave/z TotalTimeElapsedInRun = root:diagnostics:TotalTimeElapsedInRun
	wave/z fastKey = root:diagnostics:fastKey
	if (waveExists(fastKey) && WaveExists(TotalTimeElapsedInRun))
		wavestats/q/m=1 fastKey
		if (V_npnts>0)
			wave TimeAcquiringMSClosedInRun = root:diagnostics:TimeAcquiringMSClosedInRun
			wave TimeAcquiringMSOpenInRun = root:diagnostics:TimeAcquiringMSOpenInRun
			TotalTimeElapsedInRun = numtype(fastKey)== 0 ? TimeAcquiringMSOpenInRun[p]+TimeAcquiringMSClosedInRun[p] : TotalTimeElapsedInRun[p]
		endif
	endif
End
//1.52O
//Function sq_makeToDoallSlowMS() 
//	// get all MS
//	wave squirrel_index = root:index:squirrel_index 
//	wave series_index = root:index:series_index
//	variable MSSClosedLay, num, idex, MSSOpenLay
//	MSSClosedLay=FindDimLabel(squirrel_index, 2, "MSClosed") 	// bug in 1.56F.  There is no MSSOpen
//	MSSOpenLay=FindDimLabel(squirrel_index, 2, "MSOpen")		// bug in 1.56F.  There is no MSSOpen
//	num = dimsize(squirrel_index,0)
//	make/i/o/n=(num) MSClosedKey = squirrel_index[p][0][MSSClosedLay]>0		// bug April 2014 
//	make/i/o/n=(num) MSClosedKeyseries
//	make/i/o/n=(num) MSOpenKey = squirrel_index[p][0][MSSOpenLay]>0		// bug April 2014 
//	make/i/o/n=(num) MSOpenKeyseries
//	sq_create_todo("all and not allFast and MSClosedKey and MSOpenKey","allSlowMS")   //1.50E
////	killwaves/z MSClosedKey, MSClosedKeyseries,  MSOpenKey, MSOpenKeyseries
//End


//^ For a given hdf file, inserts rows and values into data_index, time_index, run_index and, most importantly, squirrel index.  Also sets new todo wave.
//^ step 1: load runInfo data set from hdf file
//^ step 2: puts new values in run_index, time_index, todo wave new ; updates number of rows (runs)  in squirrel_index 
//^ step 3: updates the data_index wave, sets the dim labels for squirrel_index
//^ step 4: inputs values into squirrel_index
//^ step 5:  loads the attribute info for any dataset if attLoad flag set
// revamped a bit in 1.49D
Function sq_file2SquirrelIndex(hdfFile,fileRowID,attLoad)
	string hdfFile //@ file name
	variable fileRowID,attLoad	//@ file positon in list, and info on whether a new exp is being started
		
	nvar load_noBFSP_ck=root:panel:load_noBFSP_ck		// new in 1.49E
	nvar load_noFastMode=root:panel:load_noFastMode		// new in 1.51K

	//@ reference all the indexes
	wave squirrel_index=root:index:squirrel_index
	wave/i run_index=root:index:run_index
	wave/t data_index=root:index:data_index
	wave/d time_index=root:index:time_index
	wave new = root:new		// new todo wave
	
	//@ delare all locals parameters
	variable idex,jdex,run,insert,pos,fileID,lay,loc,newpos,filepos,icol,mHdfFlag,toftype,valflag, runPos, npts, lastRunPos
	variable numRunsInHdf, numOfDataSets, numLayers, numInDataIndex, numOfAttributes, allNewRunsFlag, badRunsFlag, dupTime
	string dataSetList,dataSet,sub, att, runStr
	STRUCT HDF5DataInfo di	// Defined in HDF5 Browser.ipf.
	
	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M

	//^ step 1: load runInfo data set from hdf file

	mHdfFlag=cmpstr(stringfromlist(2,ParseFilePath(0, hdfFile, ":", 1, 0),"_"),"m."+HdfFileExtension)==0		// an m hdf could have only ptof sticks in it, no ms		//1.51L fix for file path name
	
	HDF5OpenFile/z/r/p=HdfDirPath fileID as hdfFile
	if (V_Flag)
		Abort "There is something wrong with the file "+	hdfFile+" Try to open it in the HDF5 browser or delete??"
	endif
	
	//@ look for the run index wave in the HDF
	hdf5LoadData/n=DataSetRunInfo/o/q/z fileID,"RunInfo"
	wave/z DataSetRunInfo=root:DataSetRunInfo
	if(!waveexists(DataSetRunInfo))
		HDF5CloseFile fileID
		Abort "// File "+hdfFile+" does not contain a 'RunInfo' data set & thus can't be indexed - Aborting from sq_File2SquirrelIndex"
	endif
			
	//  1.60H sanity check for Pedro's ATOM3 test flight data set.
	wave DataSetRunInfo
	if (sq_checkRunInfoMonotonicity(DataSetRunInfo))	//1.20I
		HDF5CloseFile fileID
		edit DataSetRunInfo
		Abort "// File "+hdfFile+" contains monotonicity in columns 5 or 7.  Did the DAQ crash?  You need to fix in a smart way! - Aborting from sq_File2SquirrelIndex"
	endif
	
	variable/g root:AMSType
	nvar AMSType = root:AMSType
	AMSType=DataSetRunInfo[0][4]			//^ added in 1.33.. kinda klunky.. we do it here before the diagnostics folder is created.
	AMSType= numtype(AMSType)==0? AMSType : 0	//^ added in 1.37B to address older (2005) data sets where this value was nan because there were no v or w tofs.
	AMSType=(AMSType==2)? 1 : AMSType		//^ gets reset every time, oh well.  0 = ctof, 1 = v/w tof.  Not sure why this ==2 logic is here, was inherited.
	
	numRunsInHdf=dimsize(DataSetRunInfo,0)
	
	if (load_noFastMode)		//1.51K  
		MatrixOP/o activeModes=col(DataSetRunInfo,6)
		activeModes = strSearch(num2str(activeModes[p]), "4", 0) >=0  || strSearch(num2str(activeModes[p]), "5", 0) >=0
		if (sum(activeModes)>0)
			print "// Fast mode runs were encountered in file " +hdfFile+ " - not indexing this file. Continuing indexing...."
			killwaves/z activeModes
			return 0
		endif
		killwaves/z activeModes
	endif

	//^ step 1Z: we need to eliminate any runs that have neither MS or PToF data, specifically if they have only BFSP (type=3) data
	//^  Joel tells me on 1/3/2008 that we never write BFSP data to HDF.  So this section must deal with Heidi-converted data.
	// combed wtih step 2
	if (load_noBFSP_ck)		// // 1.55I moved to right before for loop.  We want to keep activeModes around to search for BFSP
		MatrixOP/o activeModes=col(DataSetRunInfo,6)
		activeModes = mod(activeModes[p],10)==3 || mod(activeModes[p],100)==3  || mod(activeModes[p],1000)==3		//1.55I
//		activeModes = strSearch(num2str(activeModes[p]), "3", 0) >=0
		if (sum(activeModes)==numRunsInHdf )		//1.55I
			print "//Only  BFSP runs were encountered in file " +hdfFile+ " - not indexing this file. Continuing indexing...."
			killwaves/z activeModes, DataSetRunInfo
			return 0
		endif
//		killwaves/z activeModes
	endif
	
	MatrixOP/o RunWave=col(DataSetRunInfo,0)
	badRunsFlag=sq_indexCheckForRunMonotonicity(RunWave)
	if (badRunsFlag>=0)
		HDF5CloseFile fileID
		//  Better to indicate row number than run number... duplicate run can appear in different spots.
		print hdfFile+" appears to have duplicate or non-monotonically increasing run numbers near row "+num2str(badRunsFlag) +" and cannot proceed. "
		Edit  root:RunWave, root:Rundiff, root:DataSetRunInfo
		ModifyTable selection=(badRunsFlag , 0 , badRunsFlag , 3 , badRunsFlag , 0 ), topLeftCell=(max(badRunsFlag-2,0) ,0 )
		abort hdfFile+" appears to have duplicate or non-monotonically increasing run numbers near row "+num2str(badRunsFlag) +" and cannot proceed. See the history window."
	endif

	allNewRunsFlag=0
	for(idex=0;idex<numRunsInHdf;idex+=1)		// go through each run
		runPos=sq_findRun(run_index,DataSetRunInfo[idex][0])		//^ faster than findvalue
		if (load_noBFSP_ck && activeModes[idex])	// 	  don't want BFSP 
			continue		//1.55I
		endif
		if(runPos==-1)
			insert+=1
//		else		// we have seen this run before.  Are we dealing with _m and _p files?  // 1.51L change for duplicate runs
//			if( !sq_RunDataSetsInFile(hdfFile, DataSetRunInfo[idex][0], runPos, squirrel_index) )	// run has been indexed before.  This shouldn't happen unless the DAQ used an old menu file.
//				sprintf sub, "%d", DataSetRunInfo[idex][0]
//				print  "There is a duplicate run number of "+sub +" in file "  + hdfFile
//				abort "There is a duplicate run number of "+sub +" in file "  + hdfFile
//			endif
		else
			dupTime = date2secs(DataSetRunInfo[idex][1],1,1)+(86400*DataSetRunInfo[idex][2])+DataSetRunInfo[idex][3] // time of possibly duplicated run  1.20S
			if (abs(time_index[runPos]-dupTime)>=0.05 )  // these two time stamps should be the same
				Edit/W=(5,40,510,250) run_index, time_index
				ModifyTable width(time_index)=100, format(Point)=1,format(time_index)=8,digits(time_index)=1,showFracSeconds(time_index)=1
				ModifyTable selection=(runPos,0,runPos,0,runPos,0), topLeftCell=(runPos,0)				
				Edit/W=(5,260,510,470) DataSetRunInfo
				ModifyTable selection=(idex,0,idex,0,idex,0), topLeftCell=(idex,0)				
				sprintf runStr, "%u",  DataSetRunInfo[idex][0]
				Abort "There is a duplicated run number of "+runStr+ " in file "+hdfFile+". There may be others. An hdf file needs to be eliminated or altered before starting over."
			endif
		endif
		if((runPos>-1 || idex==numRunsInHdf-1) && insert>0) // if we are at the end OR we found a run that has already been indexed, add chunks of new runs now
			pos=numpnts(run_index)
			insertpoints pos,insert,run_index,time_index		//1.50 change
			insertpoints/m=0 pos,insert,squirrel_index
			newpos=numpnts(new)
			insertpoints newpos,insert,new
			if (idex==numRunsInHdf-1 && runPos==-1)			//^ we are at the last run and it wasn't in run_index
				insert-=1									//^ kinda tricky, we count rows beginning with 1, but index from 0
				allNewRunsFlag =1		// 1.49E
			endif
			run_index[pos,*]=DataSetRunInfo[p-pos+idex-insert][0]
			time_index[pos,*]=date2secs(DataSetRunInfo[p-pos+idex-insert][1],1,1)+(86400*DataSetRunInfo[p-pos+idex-insert][2])+DataSetRunInfo[p-pos+idex-insert][3]
			new[newpos,*]=DataSetRunInfo[p-newpos+idex-insert][0]
			insert=0
		endif

	endfor
	killwaves/z activeModes  // 1.55I
			
	//1.57D		for cases where no MS data  for a run is deliberate, and not a mistake of the DAQ 
//	MatrixOP/o noMSMode=col(DataSetRunInfo,5)	// colum 5 is "MS ToF type counter"
//	noMSMode = numtype(noMSMode[p])!=0
//	if (WaveMax(noMSMode)>=0)		// we have some runs that were not set up for MS
//		MatrixOP/o runs=col(DataSetRunInfo,0)
//		runs = noMSMode[p]>0 ? runs[p] : nan
//		gen_RemoveNaNs(runs)
//		Concatenate {runs}, allNoMSMode
//	endif
//	killwaves/z noMSMode, runs  // 1.55I
	
	//^ step 3: updates the data_index wave, redimensions and sets the dim labels for squirrel_index

	HDF5ListGroup/TYPE=2 fileID, "/"	//^ reads in only data set names in root of hdf file
	dataSetList=S_HDF5ListGroup
	dataSetList=RemoveFromList("RunInfo",dataSetList)
	dataSetList=RemoveFromList("Notes",dataSetList)		//^ 1.36C	
	numOfDataSets=itemsinlist(dataSetList)
	
	if (numOfDataSets==0)		//1.55K
		HDF5CloseFile fileID
		abort "This hdf file "+hdfFile+" does not seem to have any other groups beyond RunInfo.  Aborting from sq_changeRunNumbers"
	endif

	// update data_index wave
	// note that in the case of raw ptof files, we can have all the runs already indexed, but we may see the existence of new data sets
	for(idex=0;idex<numOfDataSets;idex+=1)	// loops through data set items 

		dataSet=Stringfromlist(idex,dataSetList)
		sub=dataSet[strlen(dataSet)-2,strlen(dataSet)-1]
		if(stringmatch(sub, "01") ) 		//^ 136C
			sub = "_01"
		endif
		
		// The entries in the data_index wave *include* the suffix such as _v in MSClosed_v
		pos=sq_findstr(data_index,dataSet,1)		//^ look in data_index  The entries in the data_index wave *include* the suffix such as _v in MSClosed_v
		if(pos<0)		// new data set 
			npts = numpnts(data_index)
			insertpoints npts,1,data_index
			data_index[npts]=dataSet
		endif
		
		// The dimension labels in squirrel_index *do no include* the suffix such as _v in MSClosed_v
		if(cmpstr(sub,"_v")==0 || cmpstr(sub,"_w")==0)
			dataSet=dataSet[0,strlen(dataSet)-3]
		elseif (cmpstr(sub,"_01")==0)
			dataSet=dataSet[0,strlen(dataSet)-4]
		endif		
		
		pos=FindDimlabel(squirrel_index,2,dataSet)	//^ look for truncated name in dim labels of layers of squirrel_index
		if(pos<0)		// new data set
			numLayers = dimsize(squirrel_index,2)
			if(numLayers!=0)	//^ if we have >0 layers
				insertpoints/m=2 numLayers,1,squirrel_index		
			else
				redimension/n=(dimsize(squirrel_index,0),dimsize(squirrel_index,1),1) squirrel_index		// keep same number or rows and columns, just make it layer 1
			endif
			SetDimLabel 2,numLayers,$dataSet,squirrel_index
		endif
	
	endfor
	
	//^ step 4: inputs values into squirrel_index	
	// recall info from RunInfo data set:
	// DataSetRunInfo 0 = run number ,1=year, 2=day in year, 3=secs after midnight, 4 = MS tofType (c=0,1=v,2=w), 5 = type counter, 6 = active modes (1=MS,2=PToF,3=BFSP,4=FMO,5=FMC)
	// 7=PTofTypecounter, 8 = ch 2 mode, 9 = ch2 MSType counter 10=PToF type counter, 11 = ion type (0=EI,1=sEI,2=VUV,3=Li,4=Neg), 12 = sampling type
	// all data in file are fast mode - do it all in one go because we likely have a ton of runs.

	InitHDF5DataInfo(di)
	
	for(jdex=0;jdex<numOfDataSets;jdex+=1)  // loop through data sets
	
		dataSet=stringfromlist(jdex,DataSetList)
		sub=dataSet[strlen(dataSet)-2,strlen(dataSet)-1]
		if(stringmatch(sub, "01") ) 		//^ 136C  not sure why we check "01" (intermeditate version of the daq?) but this is 1 and c = 0
			sub = "_01"
		endif
		
		valflag= (cmpstr(dataSet,"InfoVal")==0 || cmpstr(dataSet,"ParVal")==0 || cmpstr(dataSet,"ComParVal")==0  )//& REALLY nasty, but can't think of a better way of doing it
		loc=sq_findstr(data_index,dataSet,1)
		
		// set tofType; to be used later when dealing with runs v = 1, w = 2, 
		if(cmpstr(sub,"_v")==0)
			lay=FindDimLabel(squirrel_index,2,dataSet[0,strlen(dataSet)-3])
			toftype=1
		elseif (cmpstr(sub,"_w")==0)
			lay=FindDimLabel(squirrel_index,2,dataSet[0,strlen(dataSet)-3])
			toftype=2
		elseif (cmpstr(sub,"_01")==0)
			lay=FindDimLabel(squirrel_index,2,dataSet[0,strlen(dataSet)-4])		//^136C
			toftype=1														// may not be correct!!!
		else
			lay=FindDimLabel(squirrel_index,2,dataSet)
			toftype=0
		endif

		// icol indicates MS tofType Counter.   Earlier versions of DataSetRun info had only 6? columns
		// icol = 7 for most non PToF data sets, _m file data sets
		// icol = 5 for any PToF data sets, _p files or really really old Daq files (Heidi converted files?)
		icol=(mHdfFlag && dimsize(DataSetRunInfo,1)>7 && cmpstr(dataSet[0,3],"ptof")==0)?7:5 // MS tofType Counter  // Will need expanding once Channel2 is implemented
		HDF5DatasetInfo(fileID, dataSet, 0, di)		// sets the dimensions of this data set, puts results in di= data set info

		// added in 1.49E, a way to quickly add a bunch of runs in one swoop.  Useful for example if large file has many runs of all one mode.
		pos=sq_findRun(run_index,DataSetRunInfo[0][0])		//^ faster than findvalue
		 // every run is new in this file, and the row dimensions of this data set match the number of runs
// 1.50 and 1.50A ERROR.  Code was inserted to streamline tag data.  Makes regular AMS switching go bad
//		 if( allNewRunsFlag && di.dims[0] == numRunsInHdf) //  we can do this quickly
//			squirrel_index[pos,pos+numRunsInHdf-1][0][lay]=1
//			squirrel_index[pos,pos+numRunsInHdf-1][1][lay]=fileRowID	// hdf file row in file_index, function parameter
//			squirrel_index[pos,pos+numRunsInHdf-1][2][lay]=loc		// data set location in  data_index
//			squirrel_index[pos,pos+numRunsInHdf-1][3][lay]=p-pos	// hdf file row number
//			if (di.ndims==1)	// we have only one run in this hdf		//1.35 fix
//				squirrel_index[pos,pos+numRunsInHdf-1][4][lay]=di.dims[0]
//				squirrel_index[pos,pos+numRunsInHdf-1][5][lay]=di.dims[1]					
//			else	// more than one run in this hdf
//				squirrel_index[pos,pos+numRunsInHdf-1][4][lay]=di.dims[1]
//				squirrel_index[pos,pos+numRunsInHdf-1][5][lay]=di.dims[2]
//			endif
//			continue // go to the next data set
//		else		// every run is NOT new and/or the number of runs in this data set != the number of runs

			// we go through this data set one run at a time
			for(idex=0;idex<numRunsInHdf;idex+=1)		// loop through runs in this hdf  for this data set 
				// (DataSetRunInfo[idex][6]!=3 && load_noBFSP_ck) 
				// if cmode or we have a correct tof type for this data set
				if ( toftype==0 || toftype==DataSetRunInfo[idex][4]  )			//1.38A// if c or if run matches v/w mode

					// column 5 or 7 (MS or PToF count) is a real number
					if (numtype(DataSetRunInfo[idex][icol])!=0 && !valflag)		// 1.46B, we don't have a real number for this value.  Issue found with Ed, 4/22/09.  This means we have ptof only
						continue		  //1.52A
						// column 6 indicates the active modes of acquisition in this run.
						// DataSetRunInfo[idex][icol] = selectnumber(strsearch(num2str(DataSetRunInfo[idex][6]),"2",0)>=0, 0, 1)  //1.47I fix, change from > to >=//go the Runinfo, col 6, to see if there is a 2, indicating PToF data
					endif

					filepos=valflag?(idex):(DataSetRunInfo[idex][icol]-1)		// check to see that it is an info or parval data set - if InfoVal just use row, else, use row for this data set
					pos=sq_findRun(run_index,DataSetRunInfo[idex][0])		//^ faster than findvalue
					
					if (filepos>=di.dims[0])
						sprintf runStr, "%u",  DataSetRunInfo[idex][0]
						print "// Non-existent row "+num2str(filepos)+" in dataset "+dataSet+" indexed in "+hdffile+" for run "+runStr  // 1.57N
						squirrel_index[pos][0][lay]=0				
					elseif (filepos>-1)
						if (!mHdfFlag && valflag && squirrel_index[pos][0][lay]==1) //& JDA optimisation mod to 1.51Q
							continue //&
						endif //&
						squirrel_index[pos][0][lay]=1
						squirrel_index[pos][1][lay]=fileRowID	// parameter sent to this function (same value for every run, data set)
						squirrel_index[pos][2][lay]=loc
						squirrel_index[pos][3][lay]=filepos		// the row of this run in this data set in this file
						if (di.ndims==1)	// we have only one run in this hdf		//1.35 fix
							squirrel_index[pos][4][lay]=di.dims[0]
							squirrel_index[pos][5][lay]=di.dims[1]					
						else	// more than one run in this hdf
							squirrel_index[pos][4][lay]=di.dims[1]
							squirrel_index[pos][5][lay]=di.dims[2]
						endif
					else
						squirrel_index[pos][0][lay]=0
					endif
				endif
			endfor	// all runs in this data set	
//		endif	// end if of easy case where all runs in this file are new and the number of rows in this data set = the number of rows  that were newly added
	endfor		// add data sets in this hdf
	
	// extra sanity check 
	if (numpnts(run_index) != dimsize(squirrel_index,0) )
		abort "Something is wrong with the indexing at file "+hdfFile+". Aborting from sq_file2squirrelIndex"
	endif
	
	//^ step 5:  loads the attribute info for any dataset if attLoad flag set
	// revamped a bit in 1.49D
	if(attLoad)	// this is not longer used by default (attLoad==0) but someday someone may want it
//		InitHDF5DataInfo(di)		// di is not used below
//		att=""
		numInDataIndex=Dimsize(data_index,0)		// total number of data sets, not just the ones in the _m.hdfs
		for(idex=0;idex<numInDataIndex;idex+=1)		// 
			dataSet=data_index[idex]
			HDF5ListAttributes/z fileID , dataSet			// not all data sets in data_index will be in an hdf file, added /z
			if (V_Flag!=0)
				continue
			endif
			numOfAttributes=itemsinlist(S_HDF5ListAttributes)
			att=stringfromlist(0,S_HDF5ListAttributes)
			jdex=0
			if(numOfAttributes>0)		//^ if numOfAttributes==0 don't make.  the wave reference below is null, but no harm done
				jdex = strsearch(att, "_", 0)		//1.42E fix.  The ParStr attribute came out as ParStr_
				make/o/t/n=(numOfAttributes) $("root:index:"+att[0,jdex > 0? jdex-1 : strlen(att)-1] )      //+att[0,strlen(att)-3])
//				make/o/t/n=(numOfAttributes) $("root:index:"+att[0,strlen(att)-3])
				wave/t/z dest=$("root:index:"+att[0, jdex > 0? jdex-1 : strlen(att)-1] )  
				for(jdex=0;jdex<numOfAttributes;jdex+=1)
					att=stringfromlist(jdex,S_HDF5ListAttributes)
					HDF5LoadData/A=att/Q/Z/N=attTmp/O fileID, dataSet
					wave/t source=$("root:attTmp")
					dest[jdex]=source
				endfor
			endif							
			killwaves/z source
		endfor
	endif

	//@ Close HDF file and kill temporary DataSetRunInfo
	HDF5CloseFile fileID
	killwaves/z DataSetRunInfo, Rundiff, RunWave
	
End


//1.60H
Function sq_checkRunInfoMonotonicity(RunInfo)
wave RunInfo

	variable n, returnVar=0
	Matrixop/o/free MSRowCounter = col(RunInfo,5)		// for _p.h5 files this is the PToF counter
	
	Matrixop/o/free PToFRowCounter = col(RunInfo,7) 		// for _p.h5 files this is unused

	extract/free MSRowCounter, NoNansMSRowCounter, numtype(MSRowCounter[p])==0
	extract/free PToFRowCounter, NoNansPToFRowCounter, numtype(PToFRowCounter[p])==0

	sort NoNansMSRowCounter, NoNansMSRowCounter
	sort NoNansPToFRowCounter, NoNansPToFRowCounter

	n = numpnts(NoNansMSRowCounter)
	if (n>1)
		make/free/o/n=(n) Diff
		Diff[0,n-2]=NoNansMSRowCounter[p+1] - NoNansMSRowCounter[p]
		Diff[n-1]=inf
		returnVar=WaveMin(Diff)<0
	endif
			
	n = numpnts(NoNansPToFRowCounter)
	if (n>1)
		make/free/o/n=(n) Diff
		Diff[0,n-2]=NoNansPToFRowCounter[p+1] - NoNansPToFRowCounter[p]
		Diff[n-1]=inf
		returnVar=returnVar || WaveMin(Diff)<0
	endif	
	
	return returnVar
End


// Initial check to see if runs were non monotonic -1 means all is ok
Function sq_indexCheckForRunMonotonicity(RunWave)
wave RunWave

	variable returnVal=-1, num=numpnts(Runwave)
	
	if (numpnts(RunWave)==1)
		return -1	
	endif
	
	make/o/i/n=(num-1) Rundiff
	Rundiff[0,num-2] = Runwave[p+1] - Runwave[p]
	
	if (Wavemin(Rundiff)<=0 )
		WaveStats/q/m=1 Rundiff
		returnVal=	V_minloc// because there might be duplicates we return row instead of run	//  Runwave[V_minloc]
	endif
	
	return returnVal

End


//1.51L fix for duplicate run numbers
// if we have indexed a run and this run appears again we need to check
// that the data for this hdf is different (check that the file associated with it
// was an _m or a _p but not both)
Function sq_RunDataSetsInFile(hdfFile, run, runPos, squirrel_index)
string hdfFile
variable run, runPos
wave squirrel_index

	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M

	string existingIndexedFile = ""
	variable is_mhdfFileOld, is_mhdfFileNew, existingIndexedPos = nan
	
//	wave squirrel_index = root:index:squirrel_index
	wave/t file_index = root:index:file_index

	existingIndexedPos = squirrel_index[runPos][1][0]
	existingIndexedFile = file_index[existingIndexedPos]
	
	is_mhdfFileOld = strsearch(existingIndexedFile, "_m."+HdfFileExtension, 0)>0
	is_mhdfFileNew = strsearch(hdfFile, "_m."+HdfFileExtension, 0)>0
	
	if ( (!is_mhdfFileOld && is_mhdfFileNew) || (is_mhdfFileOld && !is_mhdfFileNew)  ) 
		return 1		// one is an _m hdf file and the other is a _p hdf file
	else
		return 0	// both are either _m or _p
	endif
			
End


//> Buttons on Load Data tab
Function sq_butt_editRunIndex(controlName) : ButtonControl
	string controlName
	
	sq_GetIndexNotDoneYet()
	DoWindow/F RunIndexTable
	if (!V_flag)
		edit/n=RunIndexTable/k=1/w=(50,50,350,550)/N=RunIndexTable root:index:t_series, root:index:rn_series as "RunIndexTable"
		modifytable format(root:index:t_series)=8
	endif

End


//@ function to check a file hasnt moved
Function sq_fileCheck(filename,ref)
	string &filename
	variable ref
	
	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M

	variable fileID
	string file
	wave/t file_index=root:index:file_index
	open/r/z fileID as filename
	if(!v_flag)
		close fileID
		return 1
	else
//		file=stringfromlist(itemsinlist(filename,":")-1,filename,":")		//1.57N
		file=parseFilePath(0, filename, ":", 1, 0)			// stringfromlist(itemsinlist(filename,":")-1,filename,":")  1.57N
		open/r/d/m=("Find missing file "+file+" that had been located in "+parseFilePath(1, filename, ":", 1, 0)) fileID			// /t=("."+HdfFileExtension)  returns an error when using .h5   //1.57M
		if( cmpstr(file,parseFilePath(0, S_filename, ":", 1, 0))==0)

//		if(cmpstr(stringfromlist(itemsinlist(filename,":")-1,filename,":"),stringfromlist(itemsinlist(S_filename,":")-1,S_filename,":"))==0)  //1.57N
			file_index[ref]=S_filename
			filename=S_filename
			return 1
		else
			return 0
		endif
	endif

End


//& Function to import the index from another experiment (file index only)
Function sq_butt_import_index(ControlName) : Buttoncontrol
	string controlname
	
	nvar load_plot_diagnostics_ck=root:panel:load_plot_diagnostics_ck
	
	wave /z squirrel_index=root:index:squirrel_index
	if (waveexists(squirrel_index))
		abort "The current experiment already contains an index. Please start a new experiment before importing."
	endif

	variable filenum,idex,jdex,num,layflag
	string filename	//,wavlist

	open /d/r/m="Select experiment containing index to import."/t=".pxp" filenum
	filename=s_filename
	if (strlen(filename)>0)
		sq_ams_stat_upd("Importing data...")
		setdatafolder root:
		loaddata /q/j="all;blacklist;AMSType;"/l=3/o filename
		loaddata /q/l=5/o/s="index"/t filename
		loaddata /q/l=7/o/s="diagnostics"/t filename
		wave /z squirrel_index=root:index:squirrel_index
		if (waveexists(squirrel_index) && dimsize(squirrel_index,0)>0)
			num=dimsize(squirrel_index,0)
			jdex=0
			do
				layflag=0
				for (idex=0;idex<num;idex+=1)
					if (squirrel_index[idex][0][jdex]==1)
						layflag=1
						break
					elseif (squirrel_index[idex][0][jdex]!=0)
						break
					endif
				endfor
				if (layflag==1)
					jdex+=1
				else
					deletepoints /m=2 jdex,1,squirrel_index
				endif
			while (jdex<dimsize(squirrel_index,2))

			sq_makeToDoAllVW() //^ make v and w todo and key waves 
			sq_makeToDoIonizationType()		// for RonBrown daq

//			wavlist="airbeam_ptof;airbeam_logged;ionEff_logged;HeaterBias;MCP_Gain;MCP_V;ch1ThresholdVolts;ch2ThresholdVolts;"
//			wavlist+="ch1FullScaleVolts;ch2FullScaleVolts;ionSingleStr_logged;Res14;Res28;Res91;Res184;PeakPosCal1;PeakPosCal2;"
//			wavlist+="DutyCycleMS;DutyCyclePToF;DutyCycleBFSP;DutyCycleGenAlt;"	
//			sq_splitdiags(wavlist)		// 1.41C change
	
			//@ only plots if data present and checkbox ticked
			if(load_plot_diagnostics_ck)
				SQ_plot_diag()
			endif
			
			sq_pop_dump2memList("",0,"Get List")
			sq_pop_toDoList("",0,"Get List")
//			sq_journal_end()
			
		else
			print "Data not loaded from "+filename
		endif
	endif

End


////////////////////////////////////////////////////////////////////////////////
///////// PRE-PROCESS  ///////////////////
////////////////////////////////////////////////////////////////////////////////

Function sq_butt_pre_process(ControlName): ButtonControl
	string controlName
	
	string savedDataFolder = GetDataFolder(1)	//^ 1.35
	SetDataFolder root:						//^ 1.35

	wave/z rn_series=root:index:rn_series
	
	sq_GetIndexNotDoneYet()	
	wave run_index=root:index:run_index
	nvar mss=root:panel:load_preProcessStick_MS_ck
	nvar ms=root:panel:load_preProcessRaw_MS_ck
	nvar ptofs=root:panel:load_preProcessStick_PToF_ck
	nvar ptof=root:panel:load_preProcessRaw_PToF_ck
	nvar eptofs=root:panel:load_preProcessStick_ePToF_ck
	nvar eptof=root:panel:load_preProcessRaw_ePToF_ck
	nvar ePToFSumS=root:panel:load_preProcessStick_ePToFSu_ck
	nvar ePToFSumR=root:panel:load_preProcessRaw_ePToFSu_ck

	nvar duty_op = root:panel:duty_cycle_ck
//	nvar duty_op_tof = root:panel:duty_cycle_ptof_ck
//	nvar duty_op_etof = root:panel:duty_cycle_eptof_ck

	nvar recalcSticks_MS_ck = root:panel:recalcSticks_MS_ck
	nvar recalcSticks_PToF_ck = root:panel:recalcSticks_PToF_ck
	nvar recalcSticks_ePToF_ck = root:panel:recalcSticks_ePToF_ck
	nvar recalcSticks_UseBkFit_ck=root:panel:recalcSticks_UseBkFit_ck
	nvar recalcSticks_UseNewMz_ck = root:panel:recalcSticks_UseNewMz_ck		//^		// one checkbox for all types, MS, PToF, ePToF.
	nvar save_op = root:panel:load_saveexpafterpreprocess_ck
	nvar airbeam_curr_mz = root:panel:airbeam_curr_mz
	nvar preProc_newonly = root:panel:preProc_newonly
	nvar load_applyDC_ck=root:panel:load_applyDC_ck
	nvar cor3_dcmarker1=root:panel:cor3_dcmarker1
	nvar cor3_dcMarker2=root:panel:cor3_dcMarker2
	nvar cor3_dcmarker3=root:panel:cor3_dcmarker3
	nvar cor3_dcmarker4=root:panel:cor3_dcmarker4
	svar cor3_region1channels=root:panel:cor3_region1channels
	svar cor3_region2channels=root:panel:cor3_region2channels
	nvar ptof_dcUseBinNumUnits = root:panel:ptof_dcUseBinNumUnits
	nvar chopper_duty = root:diagnostics:chopper_duty
	nvar IntermFilePrefix_ck = root:panel:IntermFilePrefix_ck
	nvar ams_sqprog = root:panel:ams_sqprog		// blue progress bar, not the one for squirrel fetches		//1.52O5
	
	wave airbeam_logged = root:diagnostics:airbeam_logged		// change in 1.50C
	wave/z squirrel_index = root:index:squirrel_index

	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$"root:"+todoStr
	wave/z run_index = root:index:run_index
	wave/z allMS = root:allMS		// there are some runs whereby we have no MS data, only PToF data.  Deal only with runs where we have MS data.
	wave all = root:all		//1.59F

	wave/z ePToF_oversampling = root:diagnostics:ePToF_oversampling		//1.52D
	wave/z ePToF_enabled = root:diagnostics:ePToF_enabled		//1.52D
	variable ePToF_exists = (WaveExists(ePToF_oversampling) && (WaveExists(ePToF_enabled)	) && Wavemin(ePToF_oversampling)!=0	&& ! (Wavemax(ePToF_enabled)==0 && Wavemin(ePToF_enabled)==0)  )  //1.52D		//1.55B  klunky fix for DAQ versions ePToF enabled should be 1 but is -1 
	if (ePToF_exists)
		wave/z ePToF_invSeq127 =  root:PToF:ePToF_invSeq127	// 1D inverse sequence (created in sq_EPToFMakeSequenceInv
		if (!WaveExists(ePToF_invSeq127))
			 sq_EPToFMakeSequenceInv()
		endif
	endif

	variable hz_op = 1 // Always convert to Hz
	
	nvar/z PutInMemory = root:panel:PutInMemory  //1.47E
	variable PutInMemory_temp = ( NVar_exists(PutInMemory) && PutInMemory==0 ) ? 0 : 1		// 1.47E  If the variable exists, it should always be 0, unless we implement an easy way for users to go back and forth
//	Default behavior is to put MSSDiff_p in memory.
	string hdf_opStr ="hdf_op:"+num2str(!PutInMemory_temp)		//1.50

	nvar/z resolution_dm = root:diagnostics:resolution_dm
	nvar/z resolution_m0 = root:diagnostics:resolution_m0
	nvar/z resolution_R0 = root:diagnostics:resolution_R0
 	nvar/z bk_StickRegionMaxAmu = root:baselineFitting:bk_StickRegionMaxAmu
 	nvar/z bk_UseLinear = root:baselineFitting:bk_UseLinear
	nvar/z bk_UseMassDefect = root:baselineFitting:bk_UseMassDefect
	nvar/z bk_smoothBackground = root:baselineFitting:bk_smoothBackground
	nvar/z bk_ck_AdditionalStickComp = root:baselineFitting:bk_ck_AdditionalStickComp
	nvar/z bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline		// JDA change, 1.47G, donna fix so that folks don't have to do baseline stuff

	nvar/z UseFastModeSettings = root:panel:fastMS:UseFastModeSettings

//	nvar/z DoNans = root:panel:fastMS:DoNans
	nvar/z DoAv = root:panel:fastMS:DoAv
	nvar/z DoExtrap = root:panel:fastMS:DoExtrap
	nvar/z DoCopy = root:panel:fastMS:DoCopy
	nvar/z DoReplaceAllAvg = root:panel:fastMS:doReplaceAllAvg

	sq_initializeGlobalNVar("root:panel:PToF_DCgr_ePToFSumDiffScaling",0)
	nvar PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling
	nvar deconvolveMike = root:panel:deconvolveMike

	sq_initializeGlobalNVar("root:panel:FastMS:doMzcalOnAvgs", 1)		//1.57D
	nvar/z doMzcalOnAvgs = root:panel:FastMS:doMzcalOnAvgs		// created when panel initialized
//	if (!NVAR_Exists(doMzcalOnAvgs))
//		variable/g root:panel:FastMS:doMzcalOnAvgs=0
//		nvar/z doMzcalOnAvgs = root:panel:FastMS:doMzcalOnAvgs
//	endif

	string hz_op_str="hz_op:1;"			/// +num2str(hz_op)+";"	// we always convert to Hz, user can choose to apply duty cycle
	string duty_op_str="duty_op:"+num2str(duty_op)+";"
//	string duty_op_tof_str="duty_op:"+num2str(duty_op_tof)+";"
	string param,paramDC, tempStr, PToFGrpList		//1.49E
	variable PToFRunFlag, tempVar, idex, numPToFGrp	
	string paramStr=""  //1.52O
	
	string multipleOpStr, doCopyStr="", paramSumStr, RawSpectraTodoList = ""
	variable numRawList = nan
	string collapsePToFStr="", PToFtodoStr   //1.57D

	variable ePToF_flag, ePToF_OS, numPToFBins, firstRunPos		//1.53M
	variable rawDex	//1.57J
	variable numruns = dimsize(squirrel_index,0)
	variable ePToFNoMSClosedFlag=0   //1.59R
	wave/z allFast = root:allFast		//1.53C
	variable DoAvBlankFlag=0				//1.56K
	variable numDataPreProc, tstart		//1.20N
	sq_initializeGlobalNVar("root:panel:Update_ams_sqprog",1);nvar Update_ams_sqprog = root:panel:Update_ams_sqprog

	bk_TofwerkBLGlobals() // 1.60Y
	
	sq_SetProcessedPaths()
	svar processed_path = root:processed_path
	
	// check to see that the Get Index button was pressed 		//1.42E
	sq_GetIndexNotDoneYet()

	if ( !waveexists(todo)  || numpnts(todo)==0)	//^
		Abort " Either the todo wave was not found or was of zero length - Aborting from sq_butt_pre_process"
	endif
	
	//1.43B
	if (!ms && !mss && !ptofs && !eptofs && !ptof && !eptof && !ePToFSumS && !ePToFSumR ) // && ePToFSumS && ePToFSumR)		// !ptof  && !eptof
		Abort "No data was selected to pre-process - Aborting from sq_butt_pre_process"
	endif

	// 1.49E addition
	if (nvar_Exists(IntermFilePrefix_ck) && IntermFilePrefix_ck==1)
		svar/z IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName
		if  (!Svar_exists(IntermPrefixExpFileName) || strlen(IntermPrefixExpFileName)==0)
			sq_GetIntermedFileName()
		else
			CheckBox load_FilePrefix disable = 1
			TitleBox load_FilePrefixTitle variable=root:panel:IntermPrefixExpFileName,frame=0
		endif
	endif

	if ( mss && recalcSticks_MS_ck && recalcSticks_UseNewMz_ck)
		if (!doMzcalOnAvgs && strlen(sq_CheckMzFittingWaves(todo,recalcSticks_UseNewMz_ck))==0 )		//^		
			Abort "The user chose to abort pre prcoess function because there are nans in the new mz fitting parameter waves - Aborting from sq_butt_pre_process"
		endif
	endif	

	//1.46D
	if ( mss && recalcSticks_MS_ck  && recalcSticks_UseBkFit_ck && !NVAR_Exists(resolution_dm) )		//^1.51L
		//1.59D
		DoAlert, 1, "The user chose to recalculate the MS sticks but the baselines have not yet been investigated - To continue with defaults press yes; no will abort."
		if (V_flag==2)		// no
			return 0
		else
			bk_CreateGlobalsBaseline()
		endif
	endif	

//	1.44D addition	
	if ( ptofs && recalcSticks_PToF_ck && recalcSticks_UseNewMz_ck && strlen(sq_CheckMzFittingWaves(todo,recalcSticks_UseNewMz_ck))==0)  		//^
		sq_butt_checkMz("")  //1.59D
		Abort "The user chose to abort pre process function but there are nans in the new mz fitting parameter waves - Aborting from sq_butt_pre_process"
	endif	

	wave/z PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix
	if ( ptofs && !WaveExists(PToF_DCgr_onePToFMatrix) )  		//^
		//1.59D
		DoAlert, 1, "The 'Stick PToF data' checkbox has been checked but the DC markers haven't been investigated - To continue with defaults press yes; no will abort."
		if (V_flag==2)		// no
			return 0
		else
			DoWindow/F DCMarker_gr 
			if (V_flag==0)
				sq_globalsDCMarkerGr()
				sq_DCMarkerGr()
			endif
		endif
	endif	

	if ( mss && recalcSticks_MS_ck && recalcSticks_UseBkFit_ck && !DataFolderExists("baselineFitting"))	
		//1.59D
		DoAlert, 1, "The user chose to recalculate the MS sticks but the baselines have not yet been investigated - To continue with defaults press yes; no will abort."
		if (V_flag==2)		// no
			return 0
		else
			bk_CreateGlobalsBaseline()
		endif
	endif	

	if (ePToF_exists && eptofs && deconvolveMike && PToF_DCgr_ePToFSumDiffScaling && !ePToFSumS)
		ePToFSumS = 1
		print "// In order to execute Tofwerk deconvolution with scale to ePToFSumDiff, the checkbox Stick ePToFSum must be checked. SQ is doing this for you and proceeding." 
	endif
	
 	if (ePToF_exists && eptofs && recalcSticks_ePToF_ck && !ePToFSumS) 
		ePToFSumS = 1
		print "// If you recalculate your ePToF sticks you must also check ePToF Sum sticks - this has been checked for you... proceeding."		
	endif	

 	if (ePToF_exists && ePToFSumR && FindDimLabel(root:index:squirrel_index, 2, "PToF")<0)		// check to see that we have raw spectra 		
		DoAlert 1, "No raw ePToF spectra has been indexed yet. So you cannot create the raw ePToFSum data set.  Press yes to unselect this option and continue.  No to quit."		
		if (V_flag)
			sq_ck_preProcess("loadep_preprocessRaw_Sum",1)
			ePToFSumR=0		// should be unneccessary
		else
			return 0
		endif
	endif	
 
	if ( (ptofs && recalcSticks_PToF_ck)  || (ePToF_exists && eptofs && recalcSticks_ePToF_ck) )		//^
		DoAlert 1, "Recalculating PToF sticks takes a very long time. Press Yes to continue, no to quit."
//		if (V_flag==2)
//			Abort "The user chose to quit."
//		endif
		//1.46D
		if ( !NVAR_Exists(resolution_dm) )		//^
			Abort "The user chose to recalculate the PToF sticks but the baselines have not yet beem investigated - Aborting from sq_butt_pre_process"
		endif	
	endif	
 
	if (NVAR_Exists(UseFastModeSettings) && UseFastModeSettings == 1) 	// Preprocess using fast mode!
		wave/z FMS_ClosedCycles =  root:index:FMS_ClosedCycles
		if (!WaveExists(FMS_ClosedCycles))
			abort " To Use fast mode settings do steps 1 - 2  in fast mode panel- Aborting from sq_butt_pre_process"
		endif
	endif

// 1.43I this is handled differently now
	if ( ptofs || eptofs || ePToFSumS || ePToFSumR)		// ||  ptof
		PToFRunFlag = sq_verifyTodoForPToF(todo)
		if (PToFRunFlag==0)
			Abort "PToF or ePToF stick data has been checked but there are no PToF or ePToF runs in current todo wave.  Mistake?  - Aborting from sq_butt_pre_process"
		endif
	endif	

	//1.47
	if (mss && NVAR_Exists(UseFastModeSettings) && UseFastModeSettings == 1) 	// Preprocess using fast mode!
		if (!ms)
			// Abort "You need to have the Raw MS checkbox also checked if you are using fast mode settings - Aborting from sq_butt_pre_process"
			ms=1
			print "// You need to have the Raw MS checkbox also checked if you are using fast mode setting - this has been checked for you... proceeding."		
		endif
	endif
	
	if (ePToF_exists && (ePToFSumR || ePToFSumS))		
		// first determine if we have MS closed during the ePToF runs
		sq_create_todo(NameofWave(todo)+" and allMS", "todoMS_tmp")  
		wave todoMS_tmp
		sq_create_todo(NameofWave(todo)+" and allPToF and eptof_enabled", "todo_ePToF_tmp")  
		wave todo_ePToF_tmp
		sq_create_todo("todoMS_tmp and todo_ePToF_tmp", "todo_MSePToF_tmp") 
		wave todo_MSePToF_tmp 
		ePToFNoMSClosedFlag = ! ((numpnts(todo_MSePToF_tmp) == numpnts(todo_ePToF_tmp)) &&  (numpnts(todo_MSePToF_tmp) == numpnts(todoMS_tmp)) )
		// when ePToFNoMSClosedFlag is 1,  we have ePToF runs without MSClosed being in the same run
		if (ePToFNoMSClosedFlag && ePToFSumR  && !ms && FindDimLabel(squirrel_index, 2, "MSClosed_p") <0)
			abort "You cannot generate ePToFSumR without first having processed the raw MS signal (for MSClosed). Aborting from sq_butt_pre_process"
		elseif(ePToFNoMSClosedFlag && ePToFSumS && !mss && FindDimLabel(squirrel_index, 2, "MSSClosed_p") <0)
			abort "You cannot generate ePToFSumS without first having processed the raw MSS signal (for MSSClosed). Aborting from sq_butt_pre_process"
		endif
		killwaves/z todoMS_tmp, todo_ePToF_tmp, todo_MSePToF_tmp
	endif		

	sq_SetProcessedPaths()
	
	sq_journal_new("Pre_Process")
	sq_journal_add("ToDo:"+todostr+";MSS:"+num2str(mss)+";MS:"+num2str(ms)+";PToFS:"+num2str(ptofs)+";")
	sq_journal_add(";Hz:"+num2str(hz_op)+";Duty_MS:"+num2str(duty_op)+";")		// "PToF:"+num2str(ptof)+
	sq_journal_add("Duty_ToF:"+num2str(duty_op)+";Sticks_MS:"+num2str(recalcSticks_MS_ck)+";")
		
	SetDataFolder root:			//1.59C
	
	print "//** The Pre-Process button was executed on the todo wave "+todoStr+" beginning at", time() ," using Squirrel version "+SQVERSION+" with the following parameters: "		//  "; PToF Raw = ",ptof,  eptof, "; ePToF Stick Sum = ", 
	print "//** The list of data sets to preprocess are: MS Stick = ", mss, "; MS Raw = ", ms, "; PToF Stick = ", ptofs,"; ePToF Stick = ", eptofs, "; ePToF Raw = ",eptof
	if (  mss || ptofs || eptofs )	//  added in 1.20N
		print "//     Stick correction for m/z duty cycle:"+num2str(duty_op)
	endif
	
	// add journal info
	if (  (recalcSticks_MS_ck && mss) || (recalcSticks_PToF_ck && ptofs) || (recalcSticks_ePToF_ck && eptofs) )	//  added in 1.44B		// modified in 1.51N  modified in 1.20N
		tempStr = SelectString(recalcSticks_MS_ck && mss , "", "MS ")+SelectString(recalcSticks_PToF_ck && ptofs , "", "PToF ")+SelectString(recalcSticks_ePToF_ck && eptofs , "", "ePToF ")
		print "// 	For recalcing "+tempStr+"stick data:    Use New Mz params =", recalcSticks_UseNewMz_ck, "; Use Baseline params =", recalcSticks_UseBkFit_ck
		if (recalcSticks_UseBkFit_ck)
//			sq_journal_add("ResolutionDm:"+num2str(resolution_dm)+";ResolutionM0:"+num2str(resolution_m0)+";ResolutionR0:"+num2str(resolution_R0)+";")
//			sq_journal_add("MaxAmu:"+num2str(bk_StickRegionMaxAmu)+";SmoothBackground:"+num2str(bk_smoothBackground)+";")
//			sq_journal_add("UseLinear:"+num2str(bk_UseLinear)+";AdditionalStickComp:"+num2str(bk_ck_AdditionalStickComp)+";UseMassDefect:"+num2str(bk_UseMassDefect)+";")
			nvar BKIsZer = root:baselineFitting:bk_BKIsZeroBeyondThisMass
			string beyondStr = ""
			if (BKIsZer>=0)
				nvar bk_BKIsX_Open = root:baselineFitting:bk_BKIsX_Open
				nvar bk_BKIsX_Closed = root:baselineFitting:bk_BKIsX_Closed
				sprintf beyondStr, "//     Baseline option: Beyond m/z "+num2str(BKIsZer)+" OpenBL=%1.4f ClosedBL=%1.4f" , bk_BKIsX_Open, bk_BKIsX_Closed
			endif
			print "//     UMR stick regions: dm = "+num2str(resolution_dm)+"; M0 = "+num2str(resolution_m0)+"; R0 = "+num2str(resolution_R0)
			print "//     MaxAmu:"+num2str(bk_StickRegionMaxAmu)+"; AdditionalStickComp:"+num2str(bk_ck_AdditionalStickComp)+"; UseMassDefect:"+num2str(bk_UseMassDefect)
			if (bk_UseLinear)
				print "//     Baseline option: Linear; SmoothBackground="+num2str(bk_smoothBackground)
				if (strlen(beyondStr)>0)
					print beyondStr+"\r"
				endif				
			elseif(bk_UseCubicSpline)
				nvar VOpen =root:baselineFitting:bk_StdDevNoise_VOpen
				nvar VClosed =root:baselineFitting:bk_StdDevNoise_VClosed
				nvar WOpen =root:baselineFitting:bk_StdDevNoise_WOpen
				nvar WClosed =root:baselineFitting:bk_StdDevNoise_WClosed				
				printf "//     Baseline option: Cubic Spline; C/V Open=%1.2e C/V Closed=%1.2e W Open=%1.2e W Closed=%1.2e\r", VOpen, VClosed, WOpen, WClosed
				if (strlen(beyondStr)>0)
					print beyondStr+"\r"
				endif				
			else			// tofwerk
				nvar bk_twWidth = root:baselineFitting:bk_twWidth
				nvar bk_twNoiseScaling = root:baselineFitting:bk_twNoiseScaling
				nvar bk_twckLoPass = root:baselineFitting:bk_twckLoPass
				nvar bk_twf2 = root:baselineFitting:bk_twf2
				nvar bk_twN = root:baselineFitting:bk_twN
				printf "//     Baseline option: Tofwerk; Width=%d Noise scaling=%1.1f Low pass filter=%d f2=%1.2f N=%d\r", bk_twWidth, bk_twNoiseScaling, bk_twckLoPass, bk_twf2, bk_twN
			endif	
		endif
	endif
		
	if (eptofs || eptof || ptofs || ptof || ePToFSumS || ePToFSumR) 
		PToFGrpList = WaveList("allPToFGrp*",";","") + WaveList("allePToFGrp*",";","")
		PToFGrpList = SortList(PToFGrpList) 
		numPToFGrp = itemsInList(PToFGrpList)
	endif

	sq_makeRawSpectraGroups()		//1.51F creates todo waves raw spectraXX where XX is the number of points in the raw spectra
	// We will want to do our squirrel fetches with todo waves that have the same number of points in the raw spectra to avoid
	// having to redimension things within a fetch (i.e. raw spectra points of 80,000 and 40,000)  
	RawSpectraTodoList = waveList("RawSpectra*", ";", "")
	numRawList = itemsInList(RawSpectraTodoList)  

	numDataPreProc = (ms+mss+ePToFs+ePToFSumR+ePToFSumS+pToFs)
	
	tstart=datetime
	ams_sqprog=100*(0/numDataPreProc)		//1.59F
	if(mss || ms)		//1.43B

		// limit todo to be runs that have MS data.
		wave/z allMS = root:allMS
		if (WaveExists(allMS))
			sq_create_todo(NameofWave(todo)+" and allMS", "todoMS_tmp")
			wave todoMS_tmp= $"todoMS_tmp"	
		else			// we assume that every run has ms
			wave todoMS_tmp= todo
		endif
		if (ms)
			
			// Need to force MS preprocess if MSClosed runs are missing - or maybe move the fill blanks to the stick data...
			if (preProc_newonly)
				sq_preproc_check("MSOpen_p","preproc_tmp1",todoMS_tmp)		// change in 1.46E
				wave preproc1=preproc_tmp1
				sq_preproc_check("MSClosed_p","preproc_tmp2",todoMS_tmp)
				wave preproc2=preproc_tmp2
				sq_create_todo("preproc_tmp1 or preproc_tmp2", "preproc_tmp")				

				wave preproc_tmp = root:preproc_tmp			// should we add a zero length sanity check?
			else
				wave preproc_tmp = todoMS_tmp
			endif
						
			if (!Update_ams_sqprog)		//1.20N  In case in the future the preprocessing goes into an inf loop.
				print "//		Preprocessing MS data, "+num2istr(numpnts(preproc_tmp))+" runs."
			endif
			// first deal with any slow closed and open
			//				sq_makeToDoallSlowMS() 
			wave/z allSlowMS = root:allSlowMS

			if (WaveExists(allSlowMS))
				sq_create_todo(NameOfWave(preproc_tmp)+" and allSlowMS", "preproc_tmpSlow")
				wave preproc_tmpSlow = root:preproc_tmpSlow	
			else
				wave preproc_tmpSlow = preproc_tmp	
			endif

			funcref squirrel_proto sq_f=sq_MS_preprocess
			// deal with slow
			if (numpnts(preproc_tmpSlow)>0)
				sq_iterateOverList(preproc_tmpSlow, RawSpectraTodoList, numRawList, hz_op_str+"SaveMS_op:1;dest:MSOpen_p;", "MSOpen", sq_f)
				sq_iterateOverList(preproc_tmpSlow, RawSpectraTodoList, numRawList, hz_op_str+"SaveMS_op:1;dest:MSClosed_p;", "MSClosed", sq_f)
			endif

			if (WaveExists(allFast) & numpnts(allFast)>0 )
				// Next deal with fast Open
				sq_create_todo(NameOfWave(preproc_tmp)+" and allFastOpen", "preprocFastOpen_tmp")
				wave preprocFastOpen_tmp=root:preprocFastOpen_tmp
				sq_iterateOverList(preprocFastOpen_tmp, RawSpectraTodoList, numRawList, hz_op_str+"SaveMS_op:1;dest:MSOpen_p;", "MSOpen", sq_f)
				killwaves/z preprocFastOpen_tmp
				
				for(RawDex=0;rawdex<numRawList; rawDex+=1)  // 1.57J  we have to deal with instances of different raw spectra lengths of fast mode cycles (different fast mode menus)
					sq_create_todo(NameOfWave(preproc_tmp)+" and "+ stringFromList(RawDex,RawSpectraTodoList),"RawSpecTodo_tmp")
					wave RawSpecTodo_tmp=root:RawSpecTodo_tmp

					if (numpnts(RawSpecTodo_tmp)>0)
						if (NVAR_Exists(UseFastModeSettings) && UseFastModeSettings == 1) 	// Preprocess using fast mode!
											
							// first figure out how to handle fast closed
							//  Lines below overwrite the raw average closed within a fast closed section.  The word 'extrapolate' in Mike Cubison's function
							// below has to do with extrapolating acorss an individual fast closed section; it does not do the work of the fill blanks!
							if (DoAv)		// average the fast closed to get one average value duplicated across each fast mode section within a fast cycle
								fm_DoAvClosed(RawSpecTodo_tmp, "MSClosed")
								DoAvBlankFlag = 1
							endif
							// note that the DAQ has nans in the raw closed during the open part of a fast cycle
							if (DoExtrap)	// Does not do any fill blanks stuff.  Only takes care of situations where fast cycle did not finish with a fast closed.
								fm_DoExtrapolateClosed(RawSpecTodo_tmp, "MSClosed_p")
							endif
							if (DoCopy)		// set a flag that will be sent to sq_FillBlankSpectraTypes	//1.57D	
								doCopyStr="doCopy:1;"
							endif  
							if (!DoAv && !DoCopy)    //1.55J
								squirrel_fetch(RawSpecTodo_tmp,sq_MS_preprocess,doCopyStr+hz_op_str+"SaveMS_op:1;dest:MSClosed_p", "MSClosed")
							endif								
							if (RawDex==0)
								print  "// Fast mode preprocessing detected: DoAv="+num2istr(DoAv)+", doReplaceAllAvg="+num2istr(doReplaceAllAvg)+", doMzCalOnAvgs="+num2istr(doMzCalOnAvgs)+", DoExtrap="+num2iStr(DoExtrap)+", doCopy="+num2iStr(doCopy)+ ".  See wave root:diagnostics:FastModePreProcessWave"
							endif
						else // we have fast mode data but we do not want to do any fast closed modification.
							// 
							//paramStr =""	
							sq_create_todo("RawSpecTodo_tmp and allFastClosed", "preprocFastClosed_tmp")   //1.56K
							wave preprocFastClosed_tmp=root:preprocFastClosed_tmp	
							if (numpnts(preprocFastClosed_tmp)>0)
								squirrel_fetch(preprocFastClosed_tmp,sq_MS_preprocess,hz_op_str+"SaveMS_op:1;dest:MSClosed_p;","MSClosed")	
								print  "// Fast mode preprocessing detected, but not opted."
							endif
						endif
					
						// keep trace of how runs were preprocessed.. not a squirrel fetch function
						fm_setFmPreProcessWave(RawSpecTodo_tmp, UseFastModeSettings, DoAv, doReplaceAllAvg, doMzCalOnAvgs, DoExtrap, doCopy)		
					endif		// numpnts(RawSpecTodo_tmp)>0 		
 					sq_completePartialFastCycles(RawSpecTodo_tmp, "MSClosed_p")  //1.60Z
				endfor

				killwaves/z root:RawSpecTodo_tmp, root:preprocFastClosed_tmp, root:preproc_tmpSlow	

			endif		// !allFast

			// regardless of fast or slow,  do the fillblanks.  Note that preproc is already restricted to runs with MS data.
//			sq_FillBlankSpectraTypes(preproc_tmp, RawSpectraTodoList, numRawList ,"MSClosed_p", 0, "", "", AvgFlag = DoAvBlankFlag)
			sq_FillBlankSpectraTypes(todo, RawSpectraTodoList, numRawList ,"MSClosed_p", 0, "", "", AvgFlag = DoAvBlankFlag)

		endif		// ms
		ams_sqprog=100*(ms/numDataPreProc)		//1.59F  ms+mss+ePToFs+ePToFSumR+ePToFSumS+pToFs

		if (mss)	// 1.43B

			if (preProc_newonly)
				sq_preproc_check("MSSDiff_p","preproc_tmp",todoMS_tmp)		// MSSOpen is not saved in DAQ hdfs
				wave preproc_tmp=preproc_tmp
			else
				wave preproc_tmp=todoMS_tmp
			endif
			if (!Update_ams_sqprog)		//1.20N  In case in the future the preprocessing goes into an inf loop.
				print "//		Preprocessing MSS data, "+num2istr(numpnts(preproc_tmp))+" runs. The time is "+time()+"  "+Secs2Time(datetime - tstart, 3)+ " elapsed thus far"
			endif
			//  first take care of slow MSS (all non fast)		//1.53
			if (!recalcSticks_MS_ck)		// don't recalc sticks from raw spectra

				// if we have fast mode and we don't recalculate sticks we won't be able to average MSSClosed and get new MSSOpen, so none of the fast mode settings apply
				funcref squirrel_proto sq_f=sq_insert_Matrix
				sq_iterateOverList(preproc_tmp, RawSpectraTodoList, numRawList, "text:MS;hdf_op:"+num2str(!PutInMemory_temp)+";dest:MSSDiff_p;"+duty_op_str+hz_op_str, "MSSDiff", sq_f)					
				// squirrel_fetch(preproc_tmp,sq_insert_Matrix,"text:MS;hdf_op:"+num2str(!PutInMemory_temp)+";dest:MSSDiff_p;"+duty_op_str+hz_op_str,"MSSDiff")		//1.47E
			
				sq_iterateOverList(preproc_tmp, RawSpectraTodoList, numRawList, "text:MS;hdf_op:1;dest:MSSClosed_p;"+duty_op_str+hz_op_str, "MSSClosed", sq_f)					
				// squirrel_fetch(preproc_tmp,sq_insert_Matrix,"text:MS;hdf_op:1;dest:MSSClosed_p;"+duty_op_str+hz_op_str,"MSSClosed")
				
				funcref squirrel_proto sq_f=sq_sumCalc
				sq_iterateOverList(preproc_tmp, RawSpectraTodoList, numRawList, "dest:MSSOpen_p", "MSSDiff_p;MSSClosed_p", sq_f)					
//				squirrel_fetch(preproc_tmp,sq_sumCalc,"dest:MSSOpen_p","MSSDiff_p;MSSClosed_p")		//1.50D MSSOpen not saved by DAQ

			else		// recalc sticks from raw		//1.49E

				param="kill:1;"+sq_CheckMzFittingWaves(preproc_tmp, recalcSticks_UseNewMz_ck)
				param+="stickBL_op:"+num2str(recalcSticks_UseBkFit_ck)+";smoothpnts:"+num2str(bk_smoothBackground)+";spline_op:"+num2str(bk_UseCubicSpline)+";" //&  1.51M			

				param+=duty_op_str	
				
				funcref squirrel_proto sq_f=sq_MSstick
				if (ms)		// we are also preprocessing raw spectra
					sq_iterateOverList(preproc_tmp, RawSpectraTodoList, numRawList, param+"hz_op:0;MSSStickflag:1;", "MSOpen_p;MSClosed_p", sq_f)					
//					sq_MSStickSpectraTypes(preproc_tmp, RawSpectraTodoList, numRawList, param+"hz_op:0;","MSOpen_p;MSClosed_p")  sq_MSstick
				else	
					sq_iterateOverList(preproc_tmp, RawSpectraTodoList, numRawList, param+hz_op_str+"raw_flag:1;MSSStickflag:1;", "MSOpen;MSClosed", sq_f)					
//					sq_MSStickSpectraTypes(preproc_tmp, RawSpectraTodoList, numRawList, param+hz_op_str+"raw_flag:1;","MSOpen;MSClosed")
				endif
			endif		// recaclcing sticks or not
			
//			if (WaveExists(allFast) & numpnts(allFast)>0 )
// 				sq_PartialFastCycles(todo, "MSSClosed_p")  //1.60Z
//			endif
			
			sq_FillBlankSpectraTypes(todo, RawSpectraTodoList, numRawList ,"MSSClosed_p", 0, "", "", AvgFlag = DoAvBlankFlag)		// note use of todo rather than preproc_tmp todo

			//update airbeam for this todo			// Needs to be modified for ePToFDiff

			wave/z airbeam = root:diagnostics:airbeam
 			if (!WaveExists(airbeam) || numpnts(airbeam)!=numruns )// first time		//1.58G 
 				make/o/n=(numpnts(airbeam_logged)) root:diagnostics:airbeam/Wave=airbeam
				airbeam=nan
				wave all=root:all
				squirrel_fetch(all, sq_setAB,"mz:"+num2str(airbeam_curr_mz),"MSSDiff_p")
			else
				wave/z todo=$"root:"+todoStr
				squirrel_fetch(todoMS_tmp, sq_setAB,"mz:"+num2str(airbeam_curr_mz),"MSSDiff_p")		// only changes AB values in todo
			endif
			
		endif  //mss,  1.43B

		killwaves/z root:todoMS_tmp
		ams_sqprog=100*(ms+mss)/numDataPreProc		//1.59F  ms+mss+ePToFs+ePToFSumR+ePToFSumS+pToFs
	endif		// MS sticks or raw

	if(eptofs || eptof || ptofs || ptof || ePToFSumS || ePToFSumR) 
		
		// limit todo to be runs that have PToF data.
		wave/z allPToF = allPToF
		if (WaveExists(allPToF))
			sq_create_todo(NameofWave(todo)+" and allPToF", "todoPToF_tmp")
			wave todoPToF_tmp= root:todoPToF_tmp
		else			// we assume that every run has ms
			wave todoPToF_tmp= todo
		endif

	endif
	
	// we deal with ePToF first, but we could deal with PToF first.
	if (eptof || eptofs || ePToFSumR || ePToFSumS)
		
		if (eptof || ePToFSumR)		// raw ePToF
			if (preProc_newonly)
				sq_preproc_check("MSePToFSumDiff_p","preproc_tmp",todoPToF_tmp)
				wave preproc_tmp=todoPToF_tmp
			else			// we assume that every run has ms
				wave preproc_tmp= todoPToF_tmp
			endif
			
			if (!Update_ams_sqprog)		//1.20N  In case in the future the preprocessing goes into an inf loop.
				print "//		Preprocessing raw ePToF data, "+num2istr(numpnts(preproc_tmp))+" runs. The time is "+time()+"  "+Secs2Time(datetime - tstart, 3)+ " elapsed thus far"
			endif

			funcref squirrel_proto sq_f = sq_MS_preprocess		// may or may not save eptof raw to HDF
			paramSumStr = "collapsePToF_op:1;collapsePToF_dest:MSePToFSum_p;collapsePToF_Avg:1;"		// 1.60M  1.60N
			sq_iterateOverList(preproc_tmp, PToFGrpList, numPToFGrp, "checkeEPToFflag:1;"+hz_op_str+"SaveMS_op:"+num2str(eptof)+";dest:PToF_p;"+paramSumStr, "PToF", sq_f)			

			if (ePToFSumR)				
				if (ePToFNoMSClosedFlag)  // we have ePToF runs without MSClosed_p		//1.59F
					sq_FillInMSClosedPToFOnly(preproc_tmp, 1)
				endif
				
				multipleOpStr = "multiplyFactor:"+num2str(1/127)+ ";"
				funcref squirrel_proto sq_f=sq_diffcalc
				sq_iterateOverList(preproc_tmp, PToFGrpList, numPToFGrp, multipleOpStr+"checkeEPToFflag:1;hdf_op:0;raw:1;dest:MSePToFSumDiff_p", "MSePToFSum_p;MSClosed_p", sq_f)//1.20N  added checkeEPToFflag:1 1.60R
			endif

		endif		// raw ePToF (eptof || ePToFSumR)

		ams_sqprog=100*(ms+mss+ePToFSumR)/numDataPreProc		//1.59F  ms+mss+ePToFs+ePToFSumR+ePToFSumS+pToFs

		if (eptofs  || ePToFSumS)  //Stick ePToF
			if (preProc_newonly)
				if (eptofs && !ePToFSumS) 
					sq_preproc_check("ptof_stick_p","preproc_tmp",todoPToF_tmp) //1.60C
					wave preproc=preproc_tmp
				elseif(!eptofs && ePToFSumS)
					sq_preproc_check("MSSePToFSum_p","preproc_tmp",todoPToF_tmp)	 //1.60C	
					wave preproc=preproc_tmp
				else
					sq_preproc_check("ptof_stick_p","preproc_tmp1",todoPToF_tmp) //1.60C
					sq_preproc_check("MSSePToFSum_p","preproc_tmp2",todoPToF_tmp) //1.60C
					sq_create_todo("preproc_tmp1 or preproc_tmp2", "preproc_tmp")				
					wave preproc=preproc_tmp
					Killwaves/z root:preproc_tmp1, root:preproc_tmp2
				endif
			else
				wave preproc=todoPToF_tmp		//1.60C
			endif

			if (!Update_ams_sqprog)		//1.20N  In case in the future the preprocessing goes into an inf loop.
				print "//		Preprocessing ePToF stick data, "+num2istr(numpnts(preproc))+" runs. The time is "+time()+"  "+Secs2Time(datetime - tstart, 3)+ " elapsed thus far"
			endif

			if (ePToFSumS && ePToFNoMSClosedFlag)  // we have ePToF runs without MSClosed_p		//1.59F
				sq_FillInMSClosedPToFOnly(preproc, 0)
			endif

			paramDC="applyDC:1;"		// we always pretend we do DC marker... actually this is the deconvolution option
			//1.49E
			for (idex=0;idex<numPToFGrp;idex+=1)		//for each PToF group
				ams_sqprog=100*( idex/numPToFGrp)		//1.52O5
				PToFtodoStr=stringfromList(idex, PToFGrpList)
				wave PToFGroup = $"root:"+PToFtodoStr
				sq_create_todo(NameOfWave(preproc)+" and "+PToFtodoStr,"tempPToFTodo")	//1.50H fix  //1.51N fix  needed " and " instead of "and "
				wave tempPToFTodo = root:tempPToFTodo

				if (numpnts(tempPToFTodo)==0)		//1.59
					continue
				endif
				
				sq_ReturnePToFFlags(ePToF_flag, ePToF_OS, numPToFBins, firstRunPos, tempPToFTodo)		//1.57D

				if (!ePToF_flag)
					continue
				endif
				
				if (numpnts(tempPToFTodo) >0)			// success, the todo wave is a subset of one of the PToF group todo waves							

 					// first deal with MSSePToFSumDiff_p
					if ( ePToFSumS)		// in case we have MS closed   could give problems when only part of MSClosed was preprocessed
 //						sq_FillInMSClosedPToFOnly(tempPToFTodo, 0)
						collapsePToFStr+="SaveMS_op:1;collapsePToF_op:1;collapsePToF_Avg:"+Num2istr(numPToFBins)+";collapsePToF_dest:MSSePToFSum_p;"
					endif
										
					param="dest:PToF_stick_p;"+duty_op_str+"hdf_op:1;"		// standard
					param+="ePToF_flag:"+num2str(ePToF_flag)+";ePToF_OS:" + num2str(ePToF_OS)+";"	// consider ePToF
					param+="text:PToF;"+hz_op_str+paramDC+collapsePToFStr

					// prepare for finalizing UMR sticks
					// First deal with ePToFSum and ePToFSumDiff  
					if (!recalcSticks_ePToF_ck)	//1.20G	// don't recalc sticks, use DAQ... majority of cases
						squirrel_fetch(tempPToFTodo, sq_insert_Matrix,param,"PToF_stick;MSSClosed_p")	// we need closed to make MSSePToFSumDiff
					else		// recalc PToF sticks from DAQ
				 		variable maxMz = sq_FindMaxMinMz(preproc,1,0)	//1.52E1  find the smallest of the max mzs.  Make sure we don't request to fit a mass > smallest mz
						if (numtype(maxMz) !=0 || maxMz<0 || maxMz>1e8)		// 1e8 is arbitrary
							abort "The maximum Mz of "+num2str(maxMz)+" seems incorrect.  Aborting from sq_butt_pre_process" 
						endif		//1.60L
						param+="kill:1;MaxMz:"+num2str(maxMz)+";"+sq_CheckMzFittingWaves(todo, recalcSticks_UseNewMz_ck)
				 		variable minMz = sq_FindMaxMinMz(preproc,0,1)//1.52E1  find the smallest of the max mzs.  Make sure we don't request to fit a mass > smallest mz
						if (numtype(minMz) !=0 || minMz<0 || minMz>1e8)		// 1e8 is arbitrary
							abort "The minimum Mz of "+num2str(minMz)+" seems incorrect.  Aborting from sq_butt_pre_process" 
						endif		//1.60L
						param+="MinMz:"+num2str(minMz)+";" 		//1.49E
						param+="stickBL_op:"+num2str(recalcSticks_UseBkFit_ck)+";smoothpnts:"+num2str(bk_smoothBackground)+";spline_op:"+num2str(bk_UseCubicSpline)+";" //&

						squirrel_fetch(tempPToFTodo,sq_PToFstick,param+"raw_flag:1;","PToF")
					endif

				endif	//ptofs we have PToF to preprocess
			endfor
			ams_sqprog=100*(1)
			
			killwaves/z root:todo_temp,  fillblank_todo,fillblank_blanks, root:tempPToFTodo		//1.43I
			
		endif 	// eptof sticks		//1.43B		
	endif		// ePToF or ePToF sticks
	
	ams_sqprog=100*(ms+mss+ePToFs+ePToFSumR+ePToFSumS)/numDataPreProc		//1.59F  ms+mss+ePToFs+ePToFSumR+ePToFSumS+pToFs

	// we deal with PToF after ePToF but we don't have to.
	if(ptofs || ptof )  //1.43B		// ptof should not be 1 any more... unless ePToF

		if (PToFRunFlag<0)	//1.43I	 we have a todo wave that has runs with no PToF data, change the todo wave so that we don't
			wave allPToF = root:allPToF
			sq_create_todo(NameofWave(todo)+" and allPToF","todo_temp")
			wave todo_temp=root:todo_temp			//1.50G  there was a mistake in 1.50F whereby this wave was called tempPToFTodo instead, resulting in non-preprocessing of many or all PToF runs.
			PToFtodoStr = "todo_temp"		//1.50H fix
		else		// all runs in todo have PToF
			PToFtodoStr = todoStr
		endif
		
		// preprocess raw spectra
		if (ptof)		// this really isn't used anymore		// used again in 1.57C
			if (!Update_ams_sqprog)		//1.20N  In case in the future the preprocessing goes into an inf loop.
				print "//		Preprocessing raw PToF data, "+num2istr(numpnts(todo_temp))+" runs. The time is "+time()+"  "+Secs2Time(datetime - tstart, 3)+ " elapsed thus far"
			endif

			for (idex=0;idex<numPToFGrp;idex+=1)		//for each PToF group
				wave PToFGroup = $"root:"+stringfromList(idex, PToFGrpList)
				sq_create_todo(PToFtodoStr+" and "+stringfromList(idex, PToFGrpList),"tempPToFTodo")	//1.50H fix  //1.51N fix  needed " and " instead of "and "
				wave tempPToFTodo = root:tempPToFTodo

				if (numpnts(tempPToFTodo)==0)		//1.59
					continue
				endif

				sq_ReturnePToFFlags(ePToF_flag, ePToF_OS, numPToFBins, firstRunPos, tempPToFTodo)		//1.57D

				if (ePToF_flag)
					continue
				endif

				if (preProc_newonly)		// the preprocess new only may be different between raw and sticks
					sq_preproc_check("PToF_p","preproc_tmp",tempPToFTodo)
					wave preproc=preproc_tmp
				else
					wave preproc=tempPToFTodo  // todo
				endif

				if (numpnts(preproc) >0)			// success, the todo wave is a subset of one of the PToF group todo waves							
					squirrel_fetch(preproc, sq_MS_preprocess,hz_op_str+"SaveMS_op:1;collapsePToF_op:0","PToF")			
				endif				
			endfor   
		endif		//ptof raw
		
		if (ptofs)		//1.43B

			paramDC="applyDC:"+num2str(load_applyDC_ck) + ";"		// 1.53J  we can choose to deconvolve or not
			//1.49E

			if (!Update_ams_sqprog)		//1.20N  In case in the future the preprocessing goes into an inf loop.
				print "//		Preprocessing PToF stick data, "+num2istr(numpnts(todo))+" runs. The time is "+time()+"  "+Secs2Time(datetime - tstart, 3)+ " elapsed thus far"
			endif

			for (idex=0;idex<numPToFGrp;idex+=1)		//for each PToF group
//				ams_sqprog=100*( idex/numPToFGrp)		//1.52O5

				wave PToFGroup = $"root:"+stringfromList(idex, PToFGrpList)
				sq_create_todo(PToFtodoStr+" and "+stringfromList(idex, PToFGrpList),"tempPToFTodo")	//1.50H fix  //1.51N fix  needed " and " instead of "and "
				wave tempPToFTodo = root:tempPToFTodo
				
				if (numpnts(tempPToFTodo)==0)		//1.59
					continue
				endif

				sq_ReturnePToFFlags(ePToF_flag, ePToF_OS, numPToFBins, firstRunPos, tempPToFTodo)		//1.57D

				if (ePToF_flag)
					continue
				endif

				// 'new' only?
				if (preProc_newonly)	
					sq_preproc_check("PToF_stick_p","preproc_tmp",tempPToFTodo)
					wave preproc=preproc_tmp
				else
					wave preproc=tempPToFTodo
				endif
				param=""

				if (numpnts(preproc) >0)			// success, the todo wave is a subset of one of the PToF group todo waves							

					// set up DC marker values for non ePToF
					if ( load_applyDC_ck)  	// not eptof flag,we are doing the usual apply DC to regular PToF
						if (cor3_dcmarker1==0 && cor3_dcmarker2==0 && cor3_dcmarker3==0 && cor3_dcmarker4==0 && ptof_dcUseBinNumUnits==1)  //
							cor3_dcmarker1 = 5
							cor3_dcmarker2 = 15
							cor3_dcmarker3 = -15
							cor3_dcmarker4 = -5		/// defaults				
						endif
						sq_dcMarkersExamine(firstRunPos)	//1.52O5
						paramDC="dc1:"+num2str(cor3_dcmarker1)+";dc2:"+num2str(cor3_dcmarker2)+";dc3:"+num2str(cor3_dcmarker3)+";dc4:"+num2str(cor3_dcmarker4)+";"
						paramDC+="region1only:"+cor3_region1channels+";region2only:"+cor3_region2channels+";applyDC:1;"
						sq_journal_add("OverrideDC:1;Secondary(ptof_stick_p):1;"+paramDC)	
					endif	// not eptof and not dc marker
					
					param="dest:PToF_stick_p;"+duty_op_str+"hdf_op:1;"		// standard
					param+="ePToF_flag:"+num2str(ePToF_flag)+";ePToF_OS:" + num2str(ePToF_OS)+";"	// consider ePToF
					param+="text:PToF;"+hz_op_str+paramDC+collapsePToFStr

					// prepare for finalizing UMR sticks

					if (!recalcSticks_PToF_ck)		// don't recalc sticks, use DAQ... majority of cases
						squirrel_fetch(preproc, sq_insert_Matrix,param,"PToF_stick")		//1.59D
					else		// recalc PToF sticks from DAQ
						param+="kill:1;MaxMz:"+num2str(sq_FindMaxMinMz(preproc,1,0))+";"+sq_CheckMzFittingWaves(preproc, recalcSticks_UseNewMz_ck)
						param+="stickBL_op:"+num2str(recalcSticks_UseBkFit_ck)+";smoothpnts:"+num2str(bk_smoothBackground)+";spline_op:"+num2str(bk_UseCubicSpline)+";"
						param+="MinMz:"+num2str(sq_FindMaxMinMz(preproc,0,1))+";" 		//1.49E
						squirrel_fetch(preproc,sq_PToFstick,param+"raw_flag:1;","PToF")

					endif
				endif	//ptofs we have PToF to preprocess

			endfor
			
			killwaves/z todo_temp,  fillblank_todo,fillblank_blanks, tempPToFTodo		//1.43I
			
		endif // ptof sticks		//1.43B		
	endif		// PToF or PToF sticks
	
	ams_sqprog=100	//1.59F  ms+mss+ePToFs+ePToFSumR+ePToFSumS+pToFs

	killwaves/z root:todo_temp,  root:fillblank_todo,root:fillblank_blanks		//1.43I
	killwaves/z root:Grouptodo_tmp,  root:todoPToF_tmp		//1.43I

	sq_updatePrefix()
	sq_updateMSLists()
	
	svar/z IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName		//1.49E
	tempStr = StrVarOrDefault("root:panel:IntermPrefixExpFileName", SQUIRREL_PROC_PREF)	
 
	PathInfo proc_path
	print "// The location of the intermediate hdf files is " , S_path, "with intermediate file name prefix as ",tempStr
	if (save_op)
		sq_ams_stat_upd("Saving the experiment....")	

		if (!stringmatch(IgorInfo(1), "Untitled") )		// 1.49E exp saved already			//1.56B
			PathInfo home
			NewPath/q/o ExperimentSavePath, S_path		// set ExperimentSavePath to the current location
			SaveExperiment
		else		// experiment not saved yet
			if (svar_Exists(IntermPrefixExpFileName) && !stringmatch(SQUIRREL_PROC_PREF,IntermPrefixExpFileName ) && strlen(IntermPrefixExpFileName)!=0  )
				PathInfo ExperimentSavePath //& JDA moved around  1.51Q
				if (V_flag==0)
					NewPath/o/q/M="Select the location to save the experiment file"  ExperimentSavePath
					if (V_flag!=0)
						abort "User chose to abort the saving of the experiment  Aborting from sq_butt_pre_process"
					endif
				endif
				SaveExperiment/P=ExperimentSavePath as IntermPrefixExpFileName[0, strlen(IntermPrefixExpFileName)-2] +".pxp"  //1.52D	// delete last "_" character
			else
				SaveExperiment
			endif
		endif
		sq_ams_stat_upd("Done.")		//1.44B
		PathInfo home
		print "// The location and name of this Igor experiment is " , S_path, IgorInfo(1)	
	else
		print "// This Igor experiment was not saved after the pre-process step. "
	endif

	killwaves/z root:RawSpecTempTodo
	killwaves/z root:preproc_tmp1, root:preproc_tmp2	
	Killwaves/z root:preproc_tmp, root:tempPToFTodo
	KillWaves/z  root:tempTodoFastOpen,root:tempTodoFastClosed,root:preproc_tmp
	KillWaves/z  root:FMS_Extrapolate_ToDo,root:myIndex_pos
	KillWaves/z  root:preproc_tmpFastOpen, root:tw_ePTOF_applyPreSm1D_temp
	
	print "//** The Pre-Process button finished at", time()
	sq_journal_end()
	
	sq_KillWavesInList(RawSpectraTodoList)	

End


//		if (ePToFNoMSClosedFlag==0 )
//		// then for every ePToF we have MS		
//			if ( ePToFSumR & !ms )		//   make sure the user has preprocessed MSClosed  1.57N
//				sq_preproc_check("MSClosed_p","preproc_tmp",todo_MSePToF_tmp)		// generates runs that need to be preprocessed
//				wave preproc_tmp=preproc_tmp
//				if (numpnts(preproc_tmp)>0 )//1.59D		// there are some runs that have not been preprocessed yet.  Perhaps they don't have MSclosed data at all.
//					killwaves/z todoMS_tmp,todo_ePToF_tmp, todo_MSePToF_tmp, preproc_tmp 
//					Doalert 2, "If you wish to generate an ePToFSum data set you need to preprocess the MS data first (to get MS Closed for ePToFSumDiff). Press yes to select MS Stick dat, no to see a todo wave of run needing preprocessing before exiting"
//					if (V_flag)
//						ms=1
//					elseif(V_flag==2)
//						edit preproc_tmp 
//						return 0
//					elseif(V_flag==0)
//						return 0
//					endif
//				endif	// all runs have been preprocessed
//			endif // ePToFSumS & mss  
//
//			if (ePToFSumS & !mss )		//  make sure the user has preprocessed MSSClosed  1.57N
//				sq_preproc_check("MSSClosed_p","preproc_tmp",todo_MSePToF_tmp)		// generates runs that need to be preprocessed
//				wave preproc_tmp
//				if (numpnts(preproc_tmp)>0)		// there are some runs that have not been preprocessed yet.  Perhaps they don't have MSclosed data at all.
//					killwaves/z todoMS_tmp,todo_ePToF_tmp, todo_MSePToF_tmp
//					Doalert 2, "If you wish to generate an ePToFSum data set you need to preprocess the MSS data first (to get MSS Closed for ePToFSumDiff). Press yes to select MS Stick dat, no to see a todo wave of run needing preprocessing before exiting"
//					if (V_flag)
//						mss=1
//					elseif(V_flag==2)
//						edit preproc_tmp 
//						return 0
//					elseif(V_flag==0)
//						return 0
//					endif
//				endif	// all runs have been preprocessed
//			endif // ePToFSumS & mss  
//			
//		else	// we have some ePToF runs that don't have a matching MS Closed
//			if ( ePToFSumR & !ms )		//  if we have ePToF and and no MS for the same runs we will later create MSClosed data.... make sure the user has preprocessed MSClosed  1.57N
//				sq_preproc_check("MSClosed_p","preproc_MSp_tmp",all)		// generates runs that need to be preprocessed
//				sq_preproc_check("MSClosed","preproc_MS_tmp",all)		// generates runs that need to be preprocessed
//				sq_create_todo("preproc_MS_tmp and not preproc_MSp_tmp", "todo_nonp_MSclosed_tmp")  
//				wave todo_nonp_MSclosed_tmp, preproc_MSp_tmp, preproc_MS_tmp
//				if (numpnts(todo_nonp_MSclosed_tmp)>0)		// there are some runs that have not been preprocessed yet.  Perhaps they don't have MSclosed data at all.
//					killwaves/z todoMS_tmp,todo_ePToF_tmp, todo_MSePToF_tmp, preproc_MSp_tmp, preproc_MS_tmp
//					Doalert 1, "If you wish to generate an ePToFSum data set you need to preprocess all the MSS data first (to get MSS Closed for ePToFSumDiff). Press yes to see a todo wave of run needing preprocessing before exiting"
//					if (V_flag)
//						edit todo_nonp_MSclosed_tmp 
//					endif
//					killwaves/z todo_nonp_MSclosed_tmp
//					return 0
//				endif
//				killwaves/z preproc_MSp_tmp, preproc_MS_tmp, todo_nonp_MSclosed_tmp
//			endif
//
//			if (ePToFSumS & !mss )		//  if we have PToF and and no MS for the same runs we will later create MSClosed data.... make sure the user has preprocessed MSClosed  1.57N
//				sq_preproc_check("MSSClosed_p","preproc_MSSp_tmp",all)		// generates runs that need to be preprocessed
//				sq_preproc_check("MSSClosed","preproc_MSS_tmp",all)		// generates runs that need to be preprocessed
//				sq_create_todo("preproc_MSS_tmp and not preproc_MSSp_tmp", "todo_nonp_MSSclosed_tmp")  
//				wave todo_nonp_MSSclosed_tmp, preproc_MSSp_tmp, preproc_MSS_tmp
//				if (numpnts(todo_nonp_MSSclosed_tmp)>0)		// there are some runs that have not been preprocessed yet.  Perhaps they don't have MSclosed data at all.
//					killwaves/z todoMS_tmp,todo_ePToF_tmp, todo_MSePToF_tmp, preproc_MSSp_tmp, preproc_MSS_tmp
//					Doalert 1, "If you wish to generate an ePToFSum data set you need to preprocess all the MSS data first (to get MSS Closed for ePToFSumDiff). Press yes to see a todo wave of run needing preprocessing before exiting"
//					if (V_flag)
//						edit todo_nonp_MSSclosed_tmp 
//					endif
//					killwaves/z todo_nonp_MSSclosed_tmp
//					return 0
//				endif
//				killwaves/z preproc_MSSp_tmp, preproc_MSS_tmp, todo_nonp_MSSclosed_tmp
//			endif
//			
//		endif
//		
//	endif


// new in 1.52
//Tool to allow grouping of runs based on the number of points in the raw spectra... 
// Good for when one wants to recalc sticks and needs to know the max mz value.
Function sq_makeRawSpectraGroups()

	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index
	variable numrows, rawOpenpos, rawClosedPos, num
	string str
	
	rawOpenPos = FindDimLabel(squirrel_index, 2, "MSopen" )
	rawclosedPos = FindDimLabel(squirrel_index, 2, "MSclosed" )	
	
	numrows = dimsize(squirrel_index,0)
	make/i/o/n=(numRows) maxpts, tempMask		// tempMask cant be free

	maxpts = max(squirrel_index[p][4][rawOpenPos], squirrel_index[p][4][rawclosedPos])   // faster with imagetransform?
	duplicate/o/free series_index series_temp			//1.56B
	sort series_temp , maxpts
	
	do
		num =WaveMax(maxpts)
		if (num>0)
			sprintf str, "%d",num	
			tempMask = (maxpts == num)
			sq_create_todo("tempMask","RawSpectra"+str)
			maxpts = maxpts[p] == num ?  -1 : maxpts[p]
		endif 	
	while(num>0)
	
	killwaves/z maxpts, tempMask // $"RawSpectra"+str
end


Function sq_makeRawSpectraGroupsePToFSum()   //1.58c

	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index
	variable numrows, rawOpenpos, rawClosedPos, rawPToF, num
	string str
	
	rawPToF = FindDimLabel(squirrel_index, 2, "MSePToFSum_p" )	
	
	if (rawPToF<0)
		return 0
	endif
	numrows = dimsize(squirrel_index,0)
	make/i/o/n=(numRows) maxpts, tempMask		// tempMask cant be free
	
	maxpts = squirrel_index[p][4][rawPToF]

	duplicate/o/free series_index series_temp			//1.56B
	sort series_temp , maxpts
	
	do
		num =WaveMax(maxpts)
		if (num>0)
			sprintf str, "%d",num	
			tempMask = (maxpts == num)
			sq_create_todo("tempMask","RawSpectra"+str)
			maxpts = maxpts[p] == num ?  -1 : maxpts[p]
		endif 	
	while(num>0)
	
	killwaves/z maxpts, tempMask // $"RawSpectra"+str
end


//1.52
//Tool to allow grouping of runs based on the number of points in the raw spectra... 
// Good for when one wants to recalc sticks and needs to know the max mz value.
Function sq_PreprocessRaw(todo, RawTodoList, num)
wave todo
string RawTodoList
variable num

	wave/z allFast = root:allFast
	string todoList
	variable idex, numFastOpen, numFastClosed
				
	for(idex=0;idex<num;idex+=1)
		sq_create_todo(nameOfWave(todo)+ " and "+ stringFromList(idex,RawTodoList),"tempTodo")
		wave/z tempTodo = root:tempTodo
		if (numpnts(TempTodo)==0)
			continue
		endif
		
		if (WaveExists(allFast))
			sq_create_todo("tempTodo and allFastClosed", "tempTodoFastClosed")
			wave tempTodoFastClosed = root:tempTodoFastClosed	
			if (numpnts(tempTodoFastClosed)>0)		
				squirrel_fetch(tempTodoFastClosed,sq_MS_preprocess,"dest:MSClosed_p;hz_op:1;SaveMS_op:1;","MSClosed")		// converts to Hz
			endif		

			sq_create_todo("tempTodo and allFastOpen", "tempTodoFastOpen")
			wave tempTodoFastOpen = root:tempTodoFastOpen	
			// if data set has fast mode but this todo wave doesn't have any fast mode
			if (numpnts(tempTodoFastOpen)==0 && numpnts(tempTodoFastClosed)==0)		
				squirrel_fetch(tempTodo,sq_MS_preprocess,"dest:MSClosed_p;hz_op:1;SaveMS_op:1;","MSClosed")  // converts to Hz
			endif
		else
			if (numpnts(tempTodo)>0)		
				squirrel_fetch(tempTodo,sq_MS_preprocess,"dest:MSClosed_p;hz_op:1;SaveMS_op:1;","MSClosed")  // converts to Hz
			endif
		endif
	endfor

	killwaves/z tempTodo

End


// returns a todo wave of the name  dimLabelStr+"_Todo_temp" consisting of runs where data type exists 
Function sq_todoWaveFromDimLabel(dimLabelStr)
string dimLabelStr

	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index

	variable numrows, dimIndex, idex
	
	dimIndex = FindDimLabel(squirrel_index,2, dimLabelStr)
	if (dimIndex==-2)		// label not found
		return 0
	endif
	
	numrows = dimsize(squirrel_index,0)

	make/o/n=(numrows) DimSize_index_temp, DimSize_series_temp
	DimSize_index_temp = squirrel_index[p][4][dimIndex]	
	for (idex=0;idex<numRows;idex+=1)
		DimSize_series_temp[series_index[idex]] = DimSize_index_temp[idex]
	endfor			
	sq_create_todo("all and DimSize_series_temp", dimLabelStr+"_Todo_temp")
	
	killwaves/z DimSize_index_temp, DimSize_series_temp
	
End


//^ Very Simple squirrel fetch function for getting two waves: fillblank_todo and fillblank_blanks
Function sq_findBlanksFetch(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns
	
	wave source=$stringbykey("acorn_0",paramstr)

	sq_findblanks(index_pos,source,acorn==0,acorn==n_acorns-1)
	
	if (acorn==n_acorns-1)		//1.59F
		wave/z fillblank_blanks = root:fillblank_blanks
		if (WaveExists(fillblank_blanks) && numpnts(fillblank_blanks)>0) 
			Sort fillblank_blanks,fillblank_blanks  // later we do a binary search on this
		endif
	endif
	
End


Function sq_preProc_check(typestr,deststr,basewav)
//& Generate a todo wave based on the preprocessing requirements of a data type
	string typestr,deststr
	wave basewav
	
	wave run_index=root:index:run_index
	wave squirrel_index=root:index:squirrel_index
	
	variable lay=finddimlabel(squirrel_index,2,typestr)		// does this data type exist?
	
	if (lay>=0)	// yes, so find the rows that have data for it.
		make /o/i/n=(numpnts(run_index)) preproc_chk_tmp=squirrel_index[p][0][lay]==0?(run_index[p]):(-1)
		note preproc_chk_tmp,"TYPE:TODO;"
		sq_create_todo("preproc_chk_tmp and "+nameofwave(basewav),deststr)
		killwaves /z preproc_chk_tmp
	else
		duplicate/o basewav $deststr  // overwrites!  just
	endif
	
End


//^ initializes globals and creates SQ_MzCalibration_Panel
Function sq_butt_checkMz(ctrlName) : ButtonControl
	string ctrlName
	
	if (!DataFolderExists("root:index:"))
		Abort "You must first press 'Get Index' before you can check the m/z calibration - aborting from  sq_butt_CheckMz"
	endif
	
	DoWindow/F SQ_MzCalibration_Panel
	if(!V_Flag)
		mz_CreateGlobalsMzCalibration()
		mz_CalibrationPanel()		//1.58G
	endif

End


//^ initializes globals and creates SQ_Baseline_Panel
Function sq_butt_checkBk(ctrlName) : ButtonControl
	String ctrlName

	if (!DataFolderExists("root:index:"))
		Abort "You must first press 'Get Index' before you can check the background - aborting from  sq_butt_CheckBk"
	endif

//	if (!DataFolderExists("root:baselineFitting:"))		// this folder and encompassing waves are needed
		bk_CreateGlobalsBaseline()
//	endif
	
	DoWindow/F SQ_Baseline_Panel
	if(V_Flag!=1)
		bk_BaselinePanel()	//1.58G
	endif

End


//@ Function controlling the stick re-calc selectors
// edited in 1.43I to allow for pre-processing of raw without sticks
Function sq_ck_preProcess(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked
	
	nvar load_preProcessStick_MS_ck=root:panel:load_preProcessStick_MS_ck
	nvar load_preProcessStick_PToF_ck=root:panel:load_preProcessStick_PToF_ck
	nvar load_preProcessStick_ePToF_ck=root:panel:load_preProcessStick_ePToF_ck
	nvar load_preProcessStick_ePToFSu_ck=root:panel:load_preProcessStick_ePToFSu_ck
	nvar recalcSticks_MS_ck=root:panel:recalcSticks_MS_ck
	nvar recalcSticks_PToF_ck=root:panel:recalcSticks_PToF_ck
	nvar recalcSticks_EPToF_ck=root:panel:recalcSticks_EPToF_ck

	nvar deconvolveMike=root:panel:deconvolveMike	//^1.34
	nvar deconvolveJoel=root:panel:deconvolveJoel	//^1.34
	nvar deconvolveNone=root:panel:deconvolveNone	//^1.34

	ControlInfo/w=ams_panel load_preprocessTab
	
	sq_initializeDeconvolveRadio()		//1.20L

	nvar/z PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling
	if (load_preProcessStick_ePToF_ck && stringmatch("loadep_preprocessStick",ctrlName) && PToF_DCgr_ePToFSumDiffScaling )
		load_preProcessStick_ePToFSu_ck=1
	endif

//	CheckBox load_preprocessRaw_MS,win=ams_panel,disable=2*(load_preProcessStick_MS_ck==0) // disable = 2 means gray out, 1 means hide
	CheckBox loadms_dutyCycle,win=ams_panel,disable=selectNumber(V_Value==0, 0, 1, 2*(load_preProcessStick_MS_ck==0) ) 
	CheckBox loadms_recalcStick,win=ams_panel,disable=selectNumber(V_Value==0, 0, 1, 2*(load_preProcessStick_MS_ck==0) ) 
	CheckBox loadms_recalcSticks_UseNewMz,win=ams_panel,disable=selectNumber(V_Value==0, 0, 1, selectNumber(load_preProcessStick_MS_ck*recalcSticks_MS_ck, 0, 2, 0) ) //1.60L 		// 0 is normal, 1 is hide, 2 is disable
	CheckBox loadms_recalcSticks_UseBkFit,win=ams_panel,disable=selectNumber(V_Value==0, 0, 1, selectNumber(load_preProcessStick_MS_ck*recalcSticks_MS_ck, 0, 2, 0) )  //1.60L
//	CheckBox loadms_OCStick_MS,win=ams_panel,disable=2*(load_preProcessStick_MS_ck==0)

//	CheckBox load_preprocessRaw_PToF,win=ams_panel,disable=2*(load_preProcessStick_PToF_ck==0)
	CheckBox loadpt_dutyCycle,win=ams_panel,disable=selectNumber(V_Value==1, 0, 1, 2*(load_preProcessStick_PToF_ck==0) ) 
	CheckBox loadpt_recalcStick,win=ams_panel,disable=selectNumber(V_Value==1, 0,1, 2*(load_preProcessStick_PToF_ck==0) ) 
	CheckBox loadpt_recalcSticks_UseNewMz,win=ams_panel,disable=selectNumber(V_Value==1, 0, 1, selectNumber(load_preProcessStick_PToF_ck*recalcSticks_PToF_ck, 0, 2, 0)  ) //1.60L 
	CheckBox loadpt_applyDC,win=ams_panel,disable=selectNumber(V_Value==1, 0, 1, 2*(load_preProcessStick_PToF_ck==0) ) 
	CheckBox loadpt_recalcSticks_UseBkFit,win=ams_panel,disable=selectNumber(V_Value==1, 0, 1, selectNumber(load_preProcessStick_PToF_ck*recalcSticks_PToF_ck, 0, 2, 0) ) //1.60L 

//	CheckBox load_preprocessRaw_PToF,win=ams_panel,disable=2*(load_preProcessStick_ePToF_ck==0)
	CheckBox loadep_dutyCycle,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, 2*(load_preProcessStick_ePToF_ck==0) ) 
	CheckBox loadep_recalcStick,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, 2*(load_preProcessStick_ePToF_ck==0) ) 
	CheckBox loadep_recalcSticks_UseNewMz,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, selectNumber(load_preProcessStick_ePToF_ck*recalcSticks_EPToF_ck, 0, 2, 0) )  //1.60L
	CheckBox loadep_recalcSticks_UseBkFit,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, selectNumber(load_preProcessStick_ePToF_ck*recalcSticks_EPToF_ck, 0, 2, 0) )  //1.60L

	CheckBox loadepD_DeconvolveNone,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, 2*(load_preProcessStick_ePToF_ck==0) ) 
	CheckBox loadepD_DeconvolveJoel,win=ams_panel,disable=selectNumber(V_Value==2, 0,1, 2*(load_preProcessStick_ePToF_ck==0) )
	SetVariable loadepD_smoothSetVar,win=ams_panel,disable=selectNumber(V_Value==2, 0,1, 2*(load_preProcessStick_ePToF_ck==0) )
	CheckBox loadepD_DeconvolveMike,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, 2*(load_preProcessStick_ePToF_ck==0) )
	CheckBox loadepD_SumDiffScal,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, 2*(load_preProcessStick_ePToF_ck==0) )
	SetVariable loadepD_TestRegionSetvar,win=ams_panel,disable=selectNumber(V_Value==2, 0, 1, 2*(load_preProcessStick_ePToF_ck==0) )

	if (recalcSticks_ePToF_ck)
		load_preProcessStick_ePToFSu_ck=1			
	endif
	
	sq_preprocessTabString()

End


Function sq_preprocessTabString()

	nvar load_preProcessStick_MS_ck=root:panel:load_preProcessStick_MS_ck
	nvar load_preProcessStick_PToF_ck=root:panel:load_preProcessStick_PToF_ck
	nvar load_preProcessStick_ePToF_ck=root:panel:load_preProcessStick_ePToF_ck

	nvar load_preProcessRaw_MS_ck=root:panel:load_preProcessRaw_MS_ck
	nvar load_preProcessRaw_PToF_ck=root:panel:load_preProcessRaw_PToF_ck
	nvar load_preProcessRaw_ePToF_ck=root:panel:load_preProcessRaw_ePToF_ck

	nvar load_preProcessStick_ePToFSu_ck=root:panel:load_preProcessStick_ePToFSu_ck
	nvar load_preProcessRaw_ePToFSu_ck=root:panel:load_preProcessRaw_ePToFSu_ck

	string strM = SelectString(load_preProcessStick_MS_ck, "","s")+SelectString(load_preProcessRaw_MS_ck, "","r")
	string strP = SelectString(load_preProcessStick_PToF_ck, "","s")+SelectString(load_preProcessRaw_PToF_ck, "","r")
	string strE = SelectString(load_preProcessStick_ePToF_ck, "","s")+SelectString(load_preProcessRaw_ePToF_ck, "","r")

	strE += SelectString(load_preProcessStick_ePToFSu_ck, "","S")+SelectString(load_preProcessRaw_ePToFSu_ck, "","R")
	TabControl load_preprocessTab ,win=ams_panel, tabLabel(0)="MS "+SelectString(strlen(strM)>0, "","("+strM+")")
	TabControl load_preprocessTab ,win=ams_panel, tabLabel(1)="PToF "+SelectString(strlen(strP)>0, "","("+strP+")")
	TabControl load_preprocessTab ,win=ams_panel, tabLabel(2)="ePToF "+SelectString(strlen(strE)>0, "","("+strE+")")

End


//& Convert to Hz, is used for MS or PToF data
Function sq_Hz(index_pos,datawav)
	wave index_pos,datawav
	
	wave ToFPulserInHz=root:diagnostics:ToFPulserInHz
	wave /z ion_wave=root:diagnostics:ionSingleStr
	if (!waveexists(ion_wave) || numpnts(ion_wave)==0)
		wave ion_wave=root:diagnostics:ionSingleStr_logged
	elseif (numpnts(ToFPulserInHz)!=numpnts(ion_wave)  )
		wave ion_wave_logged=root:diagnostics:ionSingleStr_logged
		ion_wave=ion_wave_logged
	endif
	wave series_index=root:index:series_index
// & Ion strength is evaluated as a function of time
	
	variable IonMin, PulserMin, Val			//1.57K
	IonMin = Wavemin(ion_wave)
	PulserMin = Wavemin(ToFPulserInHz)
	if ( abs(IonMin -WaveMax(ion_wave) )<1e-3 && ( Abs(PulserMin - WaveMax(ToFPulserInHz)) <1  )  )
		datawav*=PulserMin/IonMin		// much faster
//		Val= PulserMin/IonMin
//		MatrixOp/o datawav = datawav*(Val)
	else
		datawav*= (index_pos[p] <0 ? 1 : (1/ion_wave[series_index[index_pos[p]]]) * ToFPulserInHz[series_index[index_pos[p]]])
	endif

End		


//& Changed to only handle one data type at a time
//& Also finds gaps in the data ready for filling
Function sq_MS_preprocess(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns

	string dest=stringbykey("dest",paramstr)
	variable hz_op=numberbykey("hz_op",paramstr)
	variable SaveMS_op=numberbykey("SaveMS_op",paramstr)
	variable fillblank_op=numberbykey("fillblank_op",paramstr)==1
	
	variable collapsePToF_op=numberbykey("collapsePToF_op",paramstr)
	variable collapsePToF_Avg=numberbykey("collapsePToF_Avg",paramstr)
	string collapsePToF_dest=stringbykey("collapsePToF_dest",paramstr)
//	variable collapsePToF_ChopDuty=numberbykey("collapsePToF_ChopDuty",paramstr)
//	variable dutyCycle_op=numberbykey("dutyCycle_op",paramstr)		//1.54D
	variable dutycycle_op = 0
	
	wave source=$stringbykey("acorn_0",paramstr)
	variable ptof_flag=dimsize(source,2)>0?(1):(0)		// this distinction between MS and PToF was eliminated in 1.38 added in 1.57C
		
	sq_ams_stat_upd("Processing Raw MS Spectra")
	if (ptof_flag && collapsePToF_op)
		variable numPToFbins = dimsize(source, 1)
		sq_create_MS_PToF(index_pos, source, numPToFbins, 1, dutycycle_op, collapsePToF_dest, acorn==n_acorns-1)			//1.60M	
		sq_ams_stat_upd("Processing Raw PToF Spectra")
	endif

	if (hz_op)
		sq_Hz(index_pos,source)
	endif
	if (SaveMS_op)
		squirrel_hdf_write(index_pos,source,dest)
	endif
				
End


//1.57C
//@ compresses all ms in a single ptof run into a single ms
//& Optimised for speed
Function sq_create_MS_PToF_fetch(index_pos,paramstr,acorn,n_acorns)		// renamed in 1.49A
	wave index_pos
	string paramstr
	variable acorn,n_acorns

	wave source=$stringbykey("acorn_0",paramstr)
	variable AvgFlag = numberbykey("AvgFlag",paramstr)
	variable hz_op = numberbykey("hz_op",paramstr)	
	string dest=stringbykey("dest",paramstr)
//	variable collapsePToF_ChopDuty = numberbykey("collapsePToF_ChopDuty",paramstr)	
	variable dutycycle_op	=0
	variable killFlag=(acorn==n_acorns-1)? 1 : 0

 	AvgFlag =numtype(AvgFlag)== 0 ? AvgFlag : 0
 	hz_op =numtype(hz_op)== 0 ? hz_op : 0
 
	sq_create_MS_PToF(index_pos, source, 0, 0, dutycycle_op, dest, killFlag)

End


//1.57C
Function/wave sq_create_MS_PToF(index_pos, source, collapsePToF_Avg, hz_op, dutycycle_op, collapsePToF_dest, KillFlag)	
wave index_pos, source
variable collapsePToF_Avg, hz_op, dutycycle_op, KillFlag
string collapsePToF_dest

	string df = GetDataFolder(1)
	SetDataFolder root:hoard: 
	
	imagetransform /g=1 transposevol source	// M_VolumeTranspose=source[p][r][q], swap columns and layers.  Resulting wave has column corresponding to amu
	wave m_volumetranspose
	imagetransform sumplanes m_volumetranspose //creates a 2D wave M_SumPlanes, same number of rows and columns, Each entry in M_SumPlanes is the sum of the layers in all the planes of the source wave
	wave m_sumplanes
		
	if (collapsePToF_Avg>0)
		M_SumPlanes/=dimsize(source,1)  // 1.60M  collapsePToF_Avg		// we divide because we want the average in Hz	
	endif
	
	if (hz_op)
		sq_Hz(index_pos,M_SumPlanes)	
	endif
	
	if (dutycycle_op)
		sq_dutyCycleCorr(M_SumPlanes, KillFlag)	
	endif

	squirrel_hdf_write(index_pos,m_sumplanes,collapsePToF_dest)
	
	SetDataFolder $df
	
//	if(killFlag)
//		killwaves/z m_volumetranspose,m_sumplanes
//	endif
	return m_sumplanes

End


//& Quick and dirty difference calculator - can be used for sticks or raw
Function sq_diffCalc(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns

	string dest=stringbykey("dest",paramstr)
	wave/z MSSOpen=$stringbykey("acorn_0",paramstr)		// it really doesn't matter what is passed - it will subtract the data set in acorn 1 from acorn 0
	wave MSSClosed=$"root:hoard:acorn_1"		// stringbykey("acorn_1",paramstr)
	wave/z M_SumPlanes = root:hoard:M_SumPlanes		// this is for the tricky case of doing the MSSePToFSumDIff data set.

	variable hdf_op=numberbykey("hdf_op",paramstr)		//1.50K		if 1 we write to intermediate file
	variable rawFlag = str2num(stringbykey("raw",paramstr))		// 1.46C
	variable HR_op=numberbykey("HR_op",paramstr)		//1.14M
	variable Multiplefactor=numberbykey("Multiplefactor",paramstr)		//1.14M
	variable acorn2Flag=numberbykey("acorn2Flag",paramstr)
	
	variable ColOpen, ColClosed, maxCol, diffCol

	if (acorn2flag)
		if (!WaveExists(M_SumPlanes))
			abort "Something is wrong.  acorn 2 is not as expected.  Aborting from sq_diffCalc"
		endif
		wave MSSOpen = M_SumPlanes
	endif
	
	ColOpen = dimsize(MSSOpen,1)
	ColClosed = dimsize(MSSClosed,1)
	
	if(ColClosed==0 || ColOpen==0) 
		abort "something is wrong.... we do not have closed or open spectra.  Aborting from sq_diffCalc"
	elseif (ColOpen!=ColClosed)		// 1.42E		// this can happen especially for MSSePToFSum and MSSClosed
		maxCol = max(ColOpen, ColClosed)
		diffCol = abs(ColOpen - ColClosed)		
		redimension/n=(dimsize(MSSOpen,0), maxCol) MSSOpen, MSSClosed
		MSSOpen[][maxCol - diffCol-1, maxCol-1] = 0
		MSSClosed[][maxCol - diffCol-1, maxCol-1] = 0
		print "// In finding the difference spectra, there was a mismatch in the number of columns.  Open had "+num2str(ColOpen)+" and Closed had "+num2str(ColClosed)+". This can happen with ePToFSumDiff data.  Continuing..."
	endif
	
//	matrixop /o diffcalc_tmp=MSSOpen - MSSClosed		// could also be MSOpen - MSClosed
	if (Multiplefactor > 0)
		MatrixOP/o diffcalc_tmp = Multiplefactor*(MSSOpen -MSSClosed)
	else
		MatrixOP/o diffcalc_tmp = MSSOpen - MSSClosed
	endif		

	if (rawFlag)		// raw spectra	
		//1.14M  Raw spectra
		squirrel_hdf_write(index_pos,diffcalc_tmp,dest)
	else 	// sticks
		if (hdf_op)			//1.50K		
			if (HR_op)
				//1.14M 'expanded' columns to the next 200 HR spectra
				variable sq_RoundNumHRionCols = 200
				variable numHRCols = dimsize(diffcalc_tmp,1)
				variable numMoreCols = mod(dimsize(diffcalc_tmp,1), sq_RoundNumHRionCols)	//1.57J
				InsertPoints/M=1 numHRCols, (sq_RoundNumHRionCols-numMoreCols), diffcalc_tmp
				diffcalc_tmp[][numHRCols,]=nan
				squirrel_hdf_write(index_pos,diffcalc_tmp,dest)
			else
				//1.14M  UMR
				squirrel_hdf_write(index_pos,diffcalc_tmp,dest)
			endif
		else
			squirrel_mem_write(index_pos,diffcalc_tmp,dest,dest)
		endif
	endif
	
	if (acorn==n_acorns-1 && !Multiplefactor)
		killwaves/z diffcalc_tmp 
	endif
	
End


//& Quick and dirty sum calculator
Function sq_sumCalc(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns

	string dest=stringbykey("dest",paramstr)
	wave MSSDiff=$stringbykey("acorn_0",paramstr)		// it really doesn't matter what is passed - it will subtract the data set in acorn 1 from acorn 0
	wave MSSClosed=$stringbykey("acorn_1",paramstr)
	
	variable ColDiff, ColClosed, maxCol, diffCol
	ColDiff = dimsize(MSSDiff,1)
	ColClosed = dimsize(MSSClosed,1)
	
	if (ColDiff!=ColClosed)
		maxCol = max(ColDiff, ColClosed)
		diffCol = abs(ColDiff - ColClosed)		
		redimension/n=(dimsize(MSSDiff,0), maxCol) MSSDiff, MSSClosed
		MSSDiff[][maxCol - diffCol-1, maxCol-1] = nan
		MSSClosed[][maxCol - diffCol-1, maxCol-1] = nan
		print "// In find finding the difference spectra, there was a mismatch in the number of columns.  Diff had "+num2str(ColDiff)+" and Closed had "+num2str(ColClosed)
	endif
	
	matrixop /o diffcalc_tmp=MSSDiff + MSSClosed		// could also be MSDiff + MSClosed
	
	//1.14M  UMR
	squirrel_hdf_write(index_pos,diffcalc_tmp,dest)
	
	if (acorn==n_acorns-1)
		killwaves /z diffcalc_tmp
	endif

End

//& Only fill the blanks where they're needed, that is only in the current todo wave
//^ Trims rows from fillblank_pos,fillblank_tmp
// The rows are trimmed if fillblank_pos[i]<0 or fillblank_pos[i] is found in fill_id (=fillBlanks_blanks a wave that has position numbers of places we need to fill in )
Function sq_vet_blanks(fillblank_pos,fillblank_tmp,fill_id)
	wave /i fillblank_pos,fill_id
	wave fillblank_tmp
	
	variable idex=0
	
	do
		if (fillblank_pos[idex]<0  ||  sq_findrun(fill_id, fillblank_pos[idex])<0)
			deletepoints /m=0 idex,1,fillblank_pos,fillblank_tmp
		else
			idex+=1
		endif
	while (idex<numpnts(fillblank_pos))

End


//& Find blanks and make waves in preparation to fill
// At the end of processing all acorns
//^ fillblank_blanks contains the positions of runs with blanks that we want to fill in
//^ fillblank_todo contains the run numbers of runs that are NOT blank nor blacklisted
Function sq_findBlanks(index_pos,source,first_flag,last_flag)
	wave index_pos,source
	variable first_flag,last_flag
	
	variable idex,n_nan,n,ptof_flag=dimsize(source,2)>0

	idex=0
	n_nan=0
	
	if (first_flag)
		make /i/o/n=0 fillblank_blanks
	else
		wave /i fillblank_blanks
	endif
	
	duplicate /o index_pos, index_pos_blank
	
	//^ step through a copy of the index_pos wave to get  n_nan +numpnts(index_pos_blank) = numpnts(index_pos) and n_nan = numpnts(fillblank_blanks)
	// At the end of the do-while loop index_pos_blank has all the position values of GOOD (non-nan) runs
	// and                                              fillblank_blanks has all the position values of BAD (nan etc) runs
	do
		if (!(index_pos_blank[idex]>-1))		// first check if index_pos is -1
			deletepoints idex,1,index_pos_blank
			n_nan+=1
		elseif (ptof_flag?(numtype(source[idex+n_nan][0][0])):(numtype(source[idex+n_nan][0]))) // next check the numtype of the source
			insertpoints n_nan,1,fillblank_blanks
			fillblank_blanks[n_nan]=numtype(index_pos_blank[idex])?(-1):(index_pos_blank[idex])
			deletepoints idex,1,index_pos_blank
			n_nan+=1
		else				// we have good data for this run
			idex+=1
		endif
	while (idex<numpnts(index_pos_blank))
	
	// Now put our position numbers in our todo wave
	if (first_flag)
		make /o/i/n=(numpnts(index_pos_blank)) fillblank_todo
		if (numpnts(index_pos_blank)>0)		//1.58G
			 fillblank_todo=index_pos_blank		// kinda confusing here because at this point it the todo wave doesn't have run numbers, but instead position values
		endif
		note fillblank_todo,"TYPE:todo;"
	else
		wave /i fillblank_todo
		idex=numpnts(fillblank_todo)
		if (numpnts(index_pos_blank)>0)		//1.40D fix
			insertpoints idex,numpnts(index_pos_blank),fillblank_todo
			fillblank_todo[idex,idex+(numpnts(index_pos_blank)-1)]=index_pos_blank[p-idex]		//1.58G
		endif
	endif
	
	// Now change our fillblank_todo from position numbers to run numbers then sort the run numbers.  
	// Why don't we assume that run numbers are chronological? and eliminate the fillblank_t?
	if (last_flag)
		if (numpnts(fillblank_blanks)==0)
			killwaves /z fillblank_todo,fillblank_blanks
		else
			wave run_index=root:index:run_index
			wave time_index=root:index:time_index
			make /o/d/n=(numpnts(fillblank_todo)) fillblank_t
			if (numpnts(fillblank_todo)>0)
				fillblank_t=time_index[fillblank_todo[p]]
				fillblank_todo=run_index[fillblank_todo[p]]
				sort fillblank_t,fillblank_todo
			endif
			killwaves /z fillblank_t
		endif
		killwaves /z index_pos_blank
	endif

End


//& Take the todo wave and any gaps in the data, fill with interpolated values
//& Will only work on 2D data (can't see why we'd need 3D data but it'd be easy to upgrade)
//& Assumes the todo wave used is in chronological order
//^ The original fetch todo wave should contain only those runs that have real (non-nan) data!
//
//  option added in 1.52O to copy the last good value instead of interpolate between good values.
Function sq_fillBlanks(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns
	
	variable idex,numInAcorn,numCol,numRow,p1,p2, p3, p4, counter, jdex
	
	wave source=$stringbykey("acorn_0",paramstr)
	wave /i fill_id=$stringbykey("fill_id",paramstr)			// real wave is named filblank_blanks, has series run numbers of rows that need filling in
	string deststr=stringbykey("dest",paramstr)
	
	wave series_index=root:index:series_index
	wave t_series=root:index:t_series
	wave l_series=root:index:l_series

	sq_initializeGlobalNVar("root:panel:FastMS:doCopy", 0)		//1.57B
	
	nvar/z doCopy = root:panel:FastMS:doCopy  		//1.52N
//	if (!NVAR_Exists(doCopy) )
//		variable/g root:panel:FastMS:doCopy=0  		//1.52N
//		nvar/z doCopy = root:panel:FastMS:doCopy  		//1.52N
//	endif

	variable mynumSets, myCount, myindex, pstart
	variable maxFill = 500		// 1.51F an arbitrary number of the maximum number of runs we will fill in in one hdf write
							// users can modify as they like... make smaller if you are getting out of memory errors
				// in theory one  would determine this number by the length of the raw spectra (for SP ams the raw spectra can be 4 x bigger than old school AMS)
				// in practice just make sure that the user can load in maxFill x length of raw spectra size of data set (+ overhead) in a go.
	numCol=dimsize(source,1)
	numInAcorn=numpnts(index_pos)

	p2=series_index[index_pos[0]]		// p2 is always the last or right-most point the the region we need to fill in.

	if (acorn ==0 && p2>0)
// we need to see what row positions if any,  are blank before the "real" data starts
		p3 = floor(binarysearch(fill_id, p2)) //p2 should *not* be in fill_id		// p3 is a substitute for p1 for this case
		if (p3>=0)		// p3 is the right most point 
			//1.52O new
			myNumSets = ceil(numRow/maxFill)
			myCount=numRow
			pstart=p3
			for(myindex=0;myindex<myNumSets;myindex+=1)
			
				make/o/n=(min(maxFill, myCount))  fillblank_pos=numtype(l_series[p3+1+p])?(-1):(l_series[p3+1+p])				
				make/o/n=(min(maxFill, myCount),numCol) fillblank_tmp =source[0][q]
				sq_vet_blanks(fillblank_pos, fillblank_tmp, fill_id)
				if (numpnts(fillblank_pos)>0)
					//1.14M  Raw spectra or UMR
					squirrel_hdf_write(fillblank_pos, fillblank_tmp, deststr)
				endif
				myCount-=maxFill
				p3+=maxFill			// could this get messed up if series_index is not monotonic??
									
			endfor
			// idex+=numRow  // numRow-1 ??		// 1.52O  this is badddddd!!  Let idex take care of itself through the for loop		
			
			//1.52O old
//			if (p3+1<maxFill)		// 1.51F change to avoid creating huge raw spectra matricies
//				make /i/o/n=(p3+1) fillblank_pos=numtype(l_series[fill_id[p]])?(-1):(l_series[fill_id[p]])
//				make /o/n=(p3+1,numCol) fillblank_tmp=source[0][q]
//				squirrel_hdf_write(fillblank_pos,fillblank_tmp,deststr)
//			endif
		endif 
//& Fill in any values between this acorn and previous		//1.44B
	elseif (acorn>0)
		wave/z fillblank_last 	// the spectra of the last 'good' run
		nvar/z fillblank_last_pos	// the series number of the last 'good' run
		if (waveexists(fillblank_last) || NVar_exists(fillblank_last_pos))
			p1=fillblank_last_pos
			numRow=p2-p1-1
			if (numRow>0)		//1.51F		last two values were non consequtive... we have something to fill in
				//1.52O new
				myNumSets = ceil(numRow/maxFill)
				myCount=numRow
				for(myindex=0;myindex<myNumSets;myindex+=1)		// do this in maxFill size groupings
				
					make/o/n=(min(maxFill, myCount)) fillblank_pos=numtype(l_series[p1+1+p])?(-1):(l_series[p1+1+p])	

					make /o/n=(0) fillblank_w
					make /o/n=(0,min(numCol,numpnts(fillblank_last))) fillblank_tmp
					counter=0
					for (jdex=0; jdex<numRow; jdex+=1)		// a surrogate for the sq_vet_blanks
						if (! (fillblank_pos[jdex]<0  || sq_findrun(fill_id, fillblank_pos[jdex])<0) )
							insertpoints /m=0 counter,1,fillblank_w, fillblank_tmp
					
							if (doCopy) 
								fillblank_tmp[counter][]=source[0][q]
							else
								fillblank_w[counter]=(t_series[p1+1+jdex]-t_series[p1])/(t_series[p2]-t_series[p1])
								fillblank_tmp[counter][]=(fillblank_last[q]*(1-fillblank_w[counter]))+(source[0][q]*fillblank_w[counter])
							endif
							counter+=1
						else
							deletepoints /m=0 jdex,1,fillblank_pos
						endif
					endfor 

					if (numpnts(fillblank_pos)>0)
						//1.14M  Raw spectra or UMR
						squirrel_hdf_write(fillblank_pos, fillblank_tmp, deststr)
					endif
					myCount-=maxFill
					p1+=maxFill			// could this get messed up if series_index is not monotonic??
										
				endfor
				//1.52O old
//				make /i/o/n=(numRow) fillblank_pos=numtype(l_series[p1+1+p])?(-1):(l_series[p1+1+p])		 // has -1s or l_series position numbers
//				make /o/n=(0) fillblank_w
//				make /o/n=(0,min(numCol,numpnts(fillblank_last))) fillblank_tmp
//				counter=0
//				for (jdex=0; jdex<numRow; jdex+=1)
//					if (! (fillblank_pos[jdex]<0  || sq_findrun(fill_id, fillblank_pos[jdex])<0) )
//						insertpoints /m=0 counter,1,fillblank_w, fillblank_tmp
//						fillblank_w[counter]=(t_series[p1+1+jdex]-t_series[p1])/(t_series[p2]-t_series[p1])
//						fillblank_tmp[counter][]=(fillblank_last[q]*(1-fillblank_w[counter]))+(source[0][q]*fillblank_w[counter])
//						counter+=1
//					else
//						deletepoints /m=0 jdex,1,fillblank_pos
//					endif
//				endfor 
//				if (numpnts(fillblank_pos)>0)
//					squirrel_hdf_write(fillblank_pos,fillblank_tmp,deststr)
//				endif

			endif
		endif
	endif

//& Find gaps and fill	
// within any original todo wave (and the associated index_pos values) there may be rows between elements in the todo wave that need filling 
	for (idex=1;idex<numInAcorn;idex+=1)		// we step through all 'good' runs
		if (index_pos[idex]>=0)
			p1=p2
			p2=series_index[index_pos[idex]]
			numRow=p2-p1-1
			if (numRow>0) 		// always do in chunks to prevent out of memory issues
//				1.52O new
				myNumSets = ceil(numRow/maxFill)
				myCount=numRow
				pstart = p1
				for(myindex=0;myindex<myNumSets;myindex+=1)		// we increment p1 by maxFill
				
					make/o/n=(min(maxFill, myCount)) fillblank_pos = numtype(l_series[p1+1+p]) ? (-1) : l_series[p1+1+p]
					if (doCopy)
						make/o/n=(min(maxFill, myCount),numCol) fillblank_tmp =source[idex-1][q]
					else
						make /o/n=(min(maxFill, myCount)) fillblank_w=(t_series[p1+1+p]-t_series[pstart])/(t_series[p2]-t_series[pstart])
						make/o/n=(min(maxFill, myCount),numCol) fillblank_tmp =source[idex-1][q]*(1-fillblank_w[p])+(source[idex][q]*fillblank_w[p])
					endif

					sq_vet_blanks(fillblank_pos, fillblank_tmp, fill_id)
					if (numpnts(fillblank_pos)>0)
						//1.14M  Raw spectra or UMR
						squirrel_hdf_write(fillblank_pos, fillblank_tmp, deststr)
					endif
					myCount-=maxFill
					p1+=maxFill			// could this get messed up if series_index is not monotonic??
										
				endfor
				// idex+=numRow  // numRow-1 ??		// 1.52O  this is badddddd!!  Let idex take care of itself through the for loop		
//			1.52Old
//			if (numRow>0 && numRow < maxFill)		// 1.50J Tim O issue.   We don't want to run out of memory for raw spectra
//
//				make /i/o/n=(numRow) fillblank_pos=numtype(l_series[p1+1+p])?(-1):(l_series[p1+1+p])
//				make /o/n=(numRow) fillblank_w=(t_series[p1+1+p]-t_series[p1])/(t_series[p2]-t_series[p1])
//				make /o/n=(numRow,numCOl) fillblank_tmp=(source[idex-1][q]*(1-fillblank_w[p])+(source[idex][q]*fillblank_w[p])
//				sq_vet_blanks(fillblank_pos,fillblank_tmp,fill_id)
//				if (numpnts(fillblank_pos)>0)
//					squirrel_hdf_write(fillblank_pos,fillblank_tmp,deststr)
//				endif
//
//			elseif (numRow>0 && numRow>=maxFill)		// Tim O's ugly case
														// we are trying todo a fill and we don't have enough memory for all the run we want to fill in.
			endif
		endif
	endfor

//& Save data for next acorn	
	if (acorn<n_acorns-1)
		make /o/n=(numCol) fillblank_last=source[numInAcorn-1][p]
		variable /g fillblank_last_pos=p2
	else

		variable last  = numInAcorn		//1.59F
		do
			last-=1
		while(index_pos[last]<0)

//& Fill values after last run
		// usually p1 is left edge,  p2 is right edge
		p4=series_index[index_pos[last]]    //1.60H
//		p4=series_index[index_pos[numInAcorn-1]]
		p3 = floor(binarysearch(fill_id, p4)) //p4 should *not* be in fill_id
		if (p3>=0)  // here p3 is p1 and p4 is p2
//1.52O new
			myNumSets = ceil(numRow/maxFill)
			myCount=numRow
			pstart = p3
			variable thisNum, numFill_id=numpnts(fill_id)
			for(myindex=0;myindex<myNumSets;myindex+=1)
				thisNum = min(maxFill, myCount)
				if(p3+1+thisNum >= numFill_id)	//1.59C
					thisNum = numFill_id - (p3+1)
				endif
				make/o/n=(thisNum) fillblank_pos = numtype(l_series[fill_id[p3+1+p]])?(-1):(l_series[fill_id[p3+1+p]])
				make/o/n=(thisNum,numCol) fillblank_tmp =source[numInAcorn-1][q]
				sq_vet_blanks(fillblank_pos, fillblank_tmp, fill_id)
				if (numpnts(fillblank_pos)>0)
					//1.14M  UMR or Raw spectra
					squirrel_hdf_write(fillblank_pos, fillblank_tmp, deststr)
				endif
				myCount-=maxFill
				p3+=maxFill			// could this get messed up if series_index is not monotonic??
									
			endfor

// 1.52O old		
//			make /i/o/n=(p3+1) fillblank_pos=numtype(l_series[fill_id[p3+1+p]])?(-1):(l_series[fill_id[p3+1+p]])
//			make /o/n=(p3+1,numCol) fillblank_tmp=source[numInAcorn-1][q]
//			squirrel_hdf_write(fillblank_pos,fillblank_tmp,deststr)
		endif 

		Killwaves /z fillblank_last, fillblank_pos, fillblank_tmp, fillblank_w
		killvariables /z fillblank_last_pos
		killwaves/z myIndexData, myIndexPos, myfillblank_w
	endif

End


//@ function to resize ms and ptof stick matrices so that m/z =1 is col 0
//& Includes modular conversion to Hz and the duty cycle correction
Function sq_insert_Matrix(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns

	wave series_index=root:index:series_index
	wave mStart = root:diagnostics:mStart
	
	variable kill=(acorn==n_acorns-1)? 1 : 0
	variable insert=0,insertflag=0
	
	wave source=$"root:hoard:acorn_0"
	wave/z MSSClosed_p=$"root:hoard:acorn_1"  // "ePToFSumDIffMS
	string text=stringbykey("text",paramstr)
	string dest=stringbykey("dest",paramstr)
	variable ptof_flag=dimsize(source,2)>0?(1):(0)
	variable num=dimsize(source,0)
	variable hz_op=numberbykey("hz_op",paramstr)
	variable hdf_op=numberbykey("hdf_op",paramstr)
	variable hdfwrite=strlen(dest)>0 && hdf_op
	variable duty_op=numberbykey("duty_op",paramstr)
	variable applyDC=numberbykey("applyDC",paramstr)==1
	variable ePToF_flag=numberbykey("ePToF_flag",paramstr)==1
	variable ePToF_OS=numberbykey("ePToF_OS",paramstr)
	variable idex,insertdiff

	//1.57D
	variable collapsePToF_op=numberbykey("collapsePToF_op",paramstr)
	variable collapsePToF_Avg=numberbykey("collapsePToF_Avg",paramstr)
	string collapsePToF_dest=stringbykey("collapsePToF_dest",paramstr)
//	variable collapsePToF_ChopDuty=numberbykey("collapsePToF_ChopDuty",paramstr)

	nvar deconvolveMike = root:panel:deconvolveMike
	nvar PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling

	variable SamplingInterval = sq_nSecMSsamplingIntervalConst()

	sq_ams_stat_upd("Resizing "+text+" Stick Matrices")
	sq_insertstick_check(index_pos,insert,mStart,series_index,insertflag)		// sets the values of insert and insertFlag
		
// make sure mz1 is column 0
	if(ptof_flag)
		insertPoints/m=2 0, (insert-1), source
		source[][0][0, insert-1]*=abs(source[p][insert][0]) //& Propagate dead data to the first point		// change in 1.42E
	else
		insertPoints/m=1 0, (insert-1), source
		source[][0, insert-1]*=abs(source[p][insert])		// change in 1.42E
	endif
	
	if(insertflag)
		if(ptof_flag)
			make/o/n=(dimsize(source,1),dimsize(source,2)) transfer	//1.59D
		else
			make/o/n=(dimsize(source,1)) transfer
		endif

		for(idex=0;idex<num;idex+=1)
			sq_ams_prog_upd(100*(acorn+(idex/num))/n_acorns)
			if(index_pos[idex]==-1)
				continue
			endif
			if(ptof_flag)
				transfer=source[idex][p][q]			
			else
				transfer=source[idex][p]
			endif	
			insertdiff=insert-mStart[series_index[index_pos[idex]]]
			if (insertdiff>0)
				if(ptof_flag)
					source[idex][][]=r<dimsize(source,2)-insertdiff?(transfer[q][r+insertdiff]):(0)
				else
					source[idex][]=q<dimsize(source,1)-insertdiff?(transfer[q+insertdiff]):(0)
				endif
			endif
		endfor
	endif	// endif insertflag
	
// convert to Hz
	if(hz_op) // Convert to Hz - same function for MS and PToF
		sq_Hz(index_pos,source)
	endif
	
	sq_correctSamplingTimeUnit(index_pos,source, nSecMSsamplingIntervalVal=SamplingInterval) 		// convert to units correctly  1.54D

	if (duty_op) // mz Duty cycle correction ( not chopper wheel duty cycle)
		sq_dutyCycleCorr(source, acorn==n_acorns-1)
	endif

	// deal with MSSePToFSum  // 1.57D
	if (ePToF_flag && collapsePToF_op)
		sq_ams_stat_upd("Generating ePToFSumDiff matrices")
		wave MSSePToFSum = sq_create_MS_PToF(index_pos, source, collapsePToF_Avg, 0, 0, collapsePToF_dest, acorn==n_acorns-1)	
		sq_diffCalc(index_pos,"acorn_1:acorn_1;acorn2Flag:1;"+"multipleFactor:" + num2str(ePToFMultipleFactor)+ ";" +"hdf_op:1;raw:0;dest:MSSePToFSumDiff_p",acorn,n_acorns)
		if (applyDC && deconvolveMike && deconvolveMike)		// if we are preprocessing ePToF and we need MSSePToFSumDiff 
			wave MSSePToFSumDiff = $"diffcalc_tmp"
		endif
	endif

	sq_initializeGlobalNVar("root:panel:PToF_DCgr_ePToFSumDiffScaling",0)
	nvar PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling

	// this is done before any deconvolution
	if (ePToF_flag && ePToF_OS>0)		// should always both be true
		if (applyDC)		// this checkbox now does apply DC marker and deconvolving of ePTOF
			if (applyDC && deconvolveMike && PToF_DCgr_ePToFSumDiffScaling)
				sq_preProcessEPToF(index_pos,source, ePToF_OS,1,acorn==n_acorns-1, ePToFSumDiff =MSSePToFSumDIff)  // sq_SumAcrossPToFStick is done inside  sq_preProcessEPToF			
			else
				sq_preProcessEPToF(index_pos,source, ePToF_OS,1,acorn==n_acorns-1)  // sq_SumAcrossPToFStick is done inside  sq_preProcessEPToF
			endif
			sq_ams_stat_upd("Deconvolving ePToF matrices")
			sq_ams_prog_upd(100*(acorn+(idex/num))/n_acorns)
		endif
	elseif (applyDC && ptof_flag) //& Apply DC markers  regular PToF, do DC markers
		variable dc1=numberbykey("dc1",paramstr)
		variable dc2=numberbykey("dc2",paramstr)
		variable dc3=numberbykey("dc3",paramstr)
		variable dc4=numberbykey("dc4",paramstr)
		string region1only=stringbykey("region1only",paramstr)
		string region2only=stringbykey("region2only",paramstr)
	
		sq_ams_stat_upd("Applying DC markers")
		sq_ams_prog_upd(100*(acorn+(idex/num))/n_acorns)
		sq_ApplyDCmarkers(source,index_pos,acorn==n_acorns-1,dc1,dc2,dc3,dc4,region1only,region2only, ePToF_flag, ePToF_OS,1)		
	endif
	
	sq_ams_stat_upd("Dumping "+text+" data")

	if(hdfwrite)
		//1.14M  UMR
		sq_ams_stat_upd("Writing PToF or ePToF data")
		squirrel_hdf_write(index_pos,source,dest)
	elseif(!hdf_op && !ptof_flag )
		squirrel_mem_write(index_pos,source,dest,dest)
	endif
	
	if (kill)
		killwaves/z ConfLImitMx, deconvolved, transfer, m_volumetranspose,m_sumplanes, diffcalc_tmp
		sq_ams_stat_upd("Done")
		sq_ams_prog_upd(100)
	endif
	
End


// does any deconvolution on data Data is assumed to be in units of Hz// 
//   makes waves 
//	root:diagnostics:EPToF_testregion
//	root:diagnostics:deconvolveType	
//	root:diagnostics:EPToF_noise
//	root:diagnostics:EPToF_scalar
//	root:diagnostics:EPToF_bsl
//	root:diagnostics:EPToF_boxW
// then calls sq_EPToFDeconvolve3D
//  if deconvolveJoel, do 'DC marker subtraction
//
Function sq_preProcessEPToF(index_pos,source,ePToF_OS,WriteFlag, KillFlag, [ePToFSumDiff])
	wave index_pos
	wave source, ePToFSumDiff
	variable ePToF_OS,WriteFlag,KillFlag

	nvar/z PToF_ePToF_TestRegion =  root:panel:PToF_ePToF_TestRegion		//1.12N
	if (!NVar_Exists(PToF_ePToF_TestRegion))
		sq_globalsDCMarkerGr()
	endif
	
	wave ChopperFreq = root:diagnostics:ChopperFreq
	// take care of deconvolving  we have to do this BEFORE the DC marker stuff
	nvar PToF_ePToF_TestRegion =  root:panel:PToF_ePToF_TestRegion
//	nvar PToF_ePToF_Denoise =  root:panel:PToF_ePToF_Denoise
//	nvar PToF_ePToF_Sharpening =  root:panel:PToF_ePToF_Sharpening
	nvar deconvolveJoel =  root:panel:deconvolveJoel
	nvar deconvolve=  root:panel:deconvolve  // Rich
	sq_initializeGlobalNVar("root:panel:deconvolveMike", 0)		
	nvar/z deconvolveMike = root:panel:deconvolveMike
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_ePToFSumDiffScaling", 0)		
	nvar PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling

	wave series_index = root:index:series_index
	variable idex, num, numbins, numRuns, numMz, JoelSmoothFlag=nan
	
	numRuns=numpnts(series_index)

	num = dimsize(source,0)
	numMz = dimsize(source,2)
	numbins = dimsize(source,1)
	
//	wave/z EPToF_denoise =  root:diagnostics:EPToF_denoise
//	wave/z EPToF_sharpening = root:diagnostics:EPToF_sharpening
	wave/z EPToF_testregion = root:diagnostics:EPToF_testregion
	wave/z deconvolveType = root:diagnostics:deconvolveType
//	if (!waveExists(EPToF_denoise) || !waveExists(EPToF_sharpening) || !waveExists(EPToF_testregion) || !waveExists(deconvolveType))
	if ( !waveExists(EPToF_testregion) || !waveExists(deconvolveType))
//		make/o/n=(numRuns)  root:diagnostics:EPToF_denoise=nan		
//		make/o/n=(numRuns)  root:diagnostics:EPToF_sharpening=nan		
		make/o/n=(numRuns)  root:diagnostics:EPToF_testregion=nan		
		make/o/n=(numRuns)  root:diagnostics:deconvolveType=nan		
//		wave EPToF_denoise = root:diagnostics:EPToF_denoise
//		wave EPToF_sharpening = root:diagnostics:EPToF_sharpening
		wave EPToF_testregion = root:diagnostics:EPToF_testregion
		wave deconvolveType = root:diagnostics:deconvolveType
	endif

	wave/z EPToF_noise=  root:diagnostics:EPToF_noise
	wave/z EPToF_scalar = root:diagnostics:EPToF_scalar
	wave/z EPToF_bsl = root:diagnostics:EPToF_bsl
	wave/z EPToF_boxW = root:diagnostics:EPToF_boxW
//	if (!waveExists(EPToF_noise) || !waveExists(EPToF_scalar) || !waveExists(EPToF_bsl) || !waveExists(EPToF_boxW))
		make/o/n=(numRuns, numMz)  root:diagnostics:EPToF_noise=nan		
		make/o/n=(numRuns, numMz)  root:diagnostics:EPToF_scalar=nan		
		make/o/n=(numRuns, numMz)  root:diagnostics:EPToF_bsl=nan		
		make/o/n=(numRuns, numMz)  root:diagnostics:EPToF_boxW=nan		
		wave EPToF_noise = root:diagnostics:EPToF_noise
		wave EPToF_scalar = root:diagnostics:EPToF_scalar
		wave EPToF_bsl = root:diagnostics:EPToF_bsl
		wave EPToF_boxW = root:diagnostics:EPToF_boxW
//	endif

	note/K deconvolveType "0:not deconvolved;1:matrixInversion;2:matrixInversion and DC subtracted;3:Tofwerk;" //4:demux;5:demux and adaptive denoise"
//	note/K EPToF_denoise "-1:not used"
//	note/K EPToF_sharpening "-1:not used"
	note/K EPToF_testregion ""

	sq_SeqExpand(ePToF_OS)
	Wave SeqOutExp = root:PToF:SeqOutExp

	//1.57B  do othis before any deconvolution!
//	sq_AvgAcrossPToF(index_pos, source, KillFlag)
//	sq_create_MS_PToF(index_pos, source, ePToF_OS*127, 0, "MSSePToFSum_p", KillFlag)
//	nvar DCgr_ck_alsoSmooth = root:panel:DCgr_ck_alsoSmooth
	nvar DCgr_smoothVar = root:panel:DCgr_smoothVar	
//	nvar PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling

	if (deconvolveJoel || deconvolve || deconvolveMike)		//1.57N
		make/o/n=(dimsize(source,0),dimsize(source,1),dimsize(source,2)) deconvolved
		
		if (!deconvolveMike)
			make/o/n=(num,numMz) AcornMx=0
			make/o/n=(numMz) oneRunMx=0
		else
			make/o/n=(num,numMz,4) AcornMx=0
			make/o/n=(numMz,4) oneRunMx=0
			TWEPToF_SetDimLabels(AcornMx, 2)
//			SetDimLabel 2,0, noise, AcornMx
//			SetDimLabel 2,1, bsl, AcornMx
//			SetDimLabel 2,2, boxW, AcornMx
//			SetDimLabel 2,3, scalar, AcornMx
		endif
		
		if (WaveMin(source)	<0)		//1.59D
			wave rn_series = root:index:rn_series
			wave mStart = root:diagnostics:mStart
			duplicate/o/Free source sourceFree		//1.60D  1.60H
			sourceFree = source[p][q][r]<0		//1.20N
			wavestats/q/m=1 source
			variable pos = series_index[index_pos[idex]]
			string runStr
			sprintf runStr, "%u" ,rn_series[pos]			
			print "// Alert! Detected undeconvolved PTOF value<0 of "+num2str(V_min)+" at PToF bin "+ num2str(V_minColLoc)+" at mz "+ num2str(V_minlayerLoc+1)+ " for run "+runStr //1.20N
			print "// Within a grouping of "+num2str(numpnts(index_pos))+" ePToF runs, "+num2istr(Sum(sourceFree))+" were <0."
		endif
		
		if (deconvolveJoel)
			if ( DCgr_smoothVar>0)	// DCgr_ck_alsoSmooth &&
				JoelSmoothFlag=DCgr_smoothVar>0 //  DCgr_ck_alsoSmooth*DCgr_smoothVar
				sq_EPToFDeconvolve3D(source, ePToF_OS, deconvolved, AcornMx, oneRunMx, SeqOutExp,  KillFlag, 0, smoothVal=DCgr_smoothVar )	
			else
				sq_EPToFDeconvolve3D(source, ePToF_OS, deconvolved, AcornMx, oneRunMx, SeqOutExp, KillFlag, 0 )	
			endif
			fastop source=deconvolved
			sq_ApplyDCmarkers(source,index_pos,KillFlag,nan,nan,nan,nan,"","", 1, ePToF_OS,1)		// moved to this location 1.59D		
		elseif (deconvolveMike)
			sq_EPToFDeconvolve3D(source, ePToF_OS, deconvolved, AcornMx, oneRunMx, SeqOutExp, KillFlag, PToF_DCgr_ePToFSumDiffScaling )	
			fastop source=deconvolved
			if (PToF_DCgr_ePToFSumDiffScaling)
				duplicate/free deconvolved deconvolvedDup
				deconvolvedDup*= (1/ePToFFractionOpen)*ChopperFreq[series_index[index_pos[idex]]] 
				sq_EPToFScaling(deconvolvedDup, ePToFSumDiff, AcornMx, index_pos, KillFlag )	
				fastop source=deconvolvedDup
				source/= (1/ePToFFractionOpen)*ChopperFreq[series_index[index_pos[idex]]] 
			endif				
		endif
						
	endif		// (!deconvolveJoel && !deconvolve )
	
//	nvar ePToF_demux_adaptiveDenoise = root:panel:ePToF_demux_adaptiveDenoise	
//	variable deconvolveVar, EPToF_denoiseVar, EPToF_sharpeningVar, EPToF_testregionVar
	variable deconvolveVar, EPToF_testregionVar	
	string type=""
	if (deconvolveJoel)
		deconvolveVar = 1 // + ePToF_postmatrixInvDC
//		EPToF_denoiseVar = -1
//		EPToF_sharpeningVar =-1 
		EPToF_testregionVar = PToF_ePToF_TestRegion
		type = "matrix inversion"
	elseif (deconvolveMike)
		deconvolveVar = 3
//		EPToF_denoiseVar = 0
//		EPToF_sharpeningVar =0
		EPToF_testregionVar = 0.25		// currently hard coded!  want to change this to PToF_ePToF_TestRegion
		type = "Tofwerk"

//	elseif(deconvolve)		// i.e. rich
//		deconvolveVar = 4 + ePToF_demux_adaptiveDenoise
//		EPToF_denoiseVar = PToF_ePToF_Denoise
//		EPToF_sharpeningVar = PToF_ePToF_Sharpening
//		EPToF_testregionVar = PToF_ePToF_TestRegion
//		if (!ePToF_demux_adaptiveDenoise)
//			type += "demux, params:"
//		else
//			type += "adaptive noise demux, initial params: "
//		endif
//		type += "EPToF_denoiseVar="+num2str(EPToF_denoiseVar)+" EPToF_sharpeningVar="+num2str(EPToF_sharpeningVar) +" EPToF_testregionVar="+num2str(EPToF_testregionVar)
//		type += " EPToF_testregionVar="+num2str(EPToF_testregionVar)
	else		// do not deconvolve
		deconvolveVar = 0
//		EPToF_denoiseVar =  -1
//		EPToF_sharpeningVar =  -1
		EPToF_testregionVar = 0
		type = "no deconvolution"
	endif	
	
	if (deconvolveJoel)
		for(idex=0;idex<num;idex+=1)
//			EPToF_denoise[series_index[index_pos[idex]]] = EPToF_denoiseVar // -1
//			EPToF_sharpening[series_index[index_pos[idex]]] = EPToF_sharpeningVar // -1
			if (index_pos[idex]<0)
				continue
			endif
			EPToF_testregion[series_index[index_pos[idex]]] = EPToF_testregionVar // PToF_ePToF_TestRegion  //1.54A
			deconvolveType[series_index[index_pos[idex]]] = deconvolveVar
			EPToF_noise[series_index[index_pos[idex]]][] = nan
			EPToF_scalar[series_index[index_pos[idex]]][] = nan 
			EPToF_bsl[series_index[index_pos[idex]]][] = nan 
			EPToF_boxW[series_index[index_pos[idex]]][] = JoelSmoothFlag
		endfor
	elseif(deconvolveMike)
		for(idex=0;idex<num;idex+=1)
			if (index_pos[idex]<0)
				continue
			endif
			EPToF_testregion[series_index[index_pos[idex]]] = EPToF_testregionVar // PToF_ePToF_TestRegion  //1.54A
			deconvolveType[series_index[index_pos[idex]]] = deconvolveVar
			EPToF_noise[series_index[index_pos[idex]]][] = AcornMx[idex][%noise][q] 
			EPToF_scalar[series_index[index_pos[idex]]][] = AcornMx[idex][%scalar][q] 
			EPToF_bsl[series_index[index_pos[idex]]][] = AcornMx[idex][%bsl][q] 
			EPToF_boxW[series_index[index_pos[idex]]][] = AcornMx[idex][%boxW][q] 
		endfor
	elseif(!deconvolveJoel && !deconvolveMike)
		for(idex=0;idex<num;idex+=1)
			if (index_pos[idex]<0)
				continue
			endif
			EPToF_testregion[series_index[index_pos[idex]]] = EPToF_testregionVar // PToF_ePToF_TestRegion  //1.54A
			deconvolveType[series_index[index_pos[idex]]] = deconvolveVar
		endfor
	endif

	if (KillFlag)
		killwaves/z deconvolved, ConfLimitMx, twoDdata, deconvolved2Ddata, oneDdata, deconvolved1DData, confidLim1D
		killwaves/z  AcornMx, oneRunMx
		print "// ePToF data was preprocessed using the method: "+type
	endif
End


//////////////////////////////////////////////////////////////////////////////////////
///////////////////////// DIAGNOSTICS //////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

Function sq_butt_diagUpdate(ControlName): ButtonControl
	string ControlName

	nvar load_plot_diagnostics_ck=root:panel:load_plot_diagnostics_ck
	wave/z all=root:all		// we need to do this only and always for the the all wave
	wave/z squirrel_index = root:index:squirrel_index
	variable ComParValExists
	
	sq_GetIndexNotDoneYet()
	
	if( !waveexists(all) || !waveExists(squirrel_index))
		Abort "Cound not find the all todo wave  - Aborting from sq_butt_diagUpdate"	//^  1.35
	endif

	ComParValExists = FindDimlabel(squirrel_index,2,"ComParVal")>=0			// 1,48C
	sq_journal_new("DiagUpdate")

	if (ComParValExists) //1.48C
		sq_CreateAttTextWaves(all)		//1.55K
		squirrel_fetch(all,sq_Diagnostics,"","InfoVal;ParVal;ComParVal")		//1.48A
	else
		squirrel_fetch(all,sq_Diagnostics,"","InfoVal;ParVal;")		//1.48C
	endif

	if(load_plot_diagnostics_ck)
		SQ_plot_diag()
	endif	

	sq_FixPToFDiagWaves()		//^  1.35
	sq_journal_end()
	
	print "// The update diagnostics button was pressed on "+date() +" "+time()+"  Be aware that waves in the diagnostics folder will have been overwritten for all runs."

End


//@ makes the time series of t_series etc
// makes t_series, rn_series, l_series, t_series_old, imt_series
Function sq_gen_t_series() 

	setdatafolder root:index:
	
	wave run_index, time_index
	nvar sq_saveint=root:panel:sq_saveint
	nvar load_savint_units=root:panel:load_savint_units
	variable num, int, pos, sav_int
	
	wave run_index, time_index

	//1.48F
	wave/z t_series = root:index:t_series
	if (waveexists(t_series))
		duplicate/o t_series root:diagnostics:t_series_old	//  for historical reasons this wave is not in the index folder
	endif

	num=numpnts(run_index)
	duplicate /o time_index,t_series
	duplicate /o run_index,series_index
	make/o/d/n=(num) l_series
	make/o/n=(num) rn_series=run_index[p]
	l_series=p
	
	sav_int=(load_savint_units==1)? sq_saveint*60 : sq_saveint
	sort {t_series,rn_series},t_series,rn_series,l_series		// 1.44B change for possible later situations of identical times 
	
	if(sav_int>0)
		num=0
		do
			int=t_series[num+1]-t_series[num]
			if(int>1.75*sav_int)
				insertpoints num+1,1,t_series,rn_series,l_series
				t_series[num+1]=t_series[num]+sav_int
				rn_series[num+1]=nan
				l_series[num+1]=nan
			endif
			num+=1
		while(num<numpnts(t_series))
	endif
	
	duplicate/o t_series,imt_series
	insertpoints 0,1, imt_series
	imt_series[0]=(2*t_series[0])-t_series[1]		//^ same as t_series[0] - (t_series[1] - t_series[0])
	
	num=0
	do
		if(numtype(l_series[num])==0)
			series_index[l_series[num]]=num
		endif
		num+=1
	while(num<numpnts(l_series))
	
	setdatafolder root:

End



//1.55K addition
Function sq_CreateAttTextWaves(todo)
wave todo

	wave/t file_index = root:index:file_index
	wave run_index = root:index:run_index
	wave squirrel_index = root:index:squirrel_index
	variable pos = sq_findRun(run_index,todo[0]) 
	variable lay = FindDimLabel (squirrel_index, 2, "InfoVal") 
	variable fileNum = squirrel_index[pos][1][lay]		//1.57K   bug column 1 indicates the file number
	make/o/n=0/t root:diagnostics:InfoValText/wave =  InfoValText
	make/o/n=0/t root:diagnostics:ParValText/wave =  ParValText
	make/o/n=0/t root:diagnostics:ComParValText/wave =  ComParValText
	sq_LoadAttributesFromHDF(file_index[fileNum], "InfoVal",  root:diagnostics:InfoValText)
	sq_LoadAttributesFromHDF(file_index[fileNum], "ParVal",  root:diagnostics:parValText)
	sq_LoadAttributesFromHDF(file_index[fileNum], "ComParVal",  root:diagnostics:ComParValText)

End


//@ load in basic diagnostics into memory
Function sq_diagnostics(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn
	variable n_acorns
	
	wave source0=$stringbykey("acorn_0",paramstr)		//^ InfoVal
	wave source1=$stringbykey("acorn_1",paramstr)		//^ ParVal
	wave/z source2=$stringbykey("acorn_2",paramstr)		//^ CommonParVal
	
	wave t_series=root:index:t_series
	wave series_index=root:index:series_index

	nvar/z MajorDaqVersion = root:diagnostics:MajorDaqVersion		//1.56C

	variable newonly=numberbykey("newonly",paramstr)
	variable numTime,idex,jdex,p1,numDiag,numOldTime, numAcorn, ComParValExists, tempVar

   ComParValExists = WaveExists(source2)		//1.48C for earlier data sets, this does not exist
      
	if(numtype(newonly)!=0)		//1.38B
		newonly = 0
	endif
	
	if(!datafolderexists("root:diagnostics"))
		newdatafolder/s root:diagnostics	// 1.55K addition of attribute waves.  We simply check the firsthdf
	else
		setdatafolder root:diagnostics
	endif
		
	sq_diag_list_init() //1.38B we need to update diag list because we added to it.
	wave/t diag_list
	wave diag_loc

	sq_initializeGlobalNVar("root:diagnostics:chopper_duty",nan)
	nvar chopper_duty=root:diagnostics:chopper_duty		//^ assumed to be constant for one experiment, instrument
	nvar cor3_chamber=root:panel:cor3_chamber
//	nvar cor3_t_offset=root:panel:cor3_t_offset			//1.59E
	nvar airbeam_curr_mz=root:panel:airbeam_curr_mz
	
	numdiag=numpnts(diag_list)
	if(acorn==0)
		numtime=numpnts(t_series)
		wave /z t_series_old
		if (!newonly || !waveexists(t_series_old)) //& Create entirely new waves  ) //  1.38B// 1.49E			
			for (idex=0;idex<numdiag;idex+=1)
				make /o/n=(numtime) $diag_list[idex]=nan
				wave dest = $diag_list[idex]		// change in 1.47I
				Note dest, selectString(diag_loc[idex][0]-1, "InfoVal Column " + num2str(diag_loc[idex][1]),"ParVal Column " + num2str(diag_loc[idex][1]), "Custom formula")		//change in 1.47I
			endfor
			make/o/n=(1000) amus=p+1			//^fixed value, always going up to 1000 amu.. should this be changed in a later version?
  			if( ComParValExists)
				cor3_chamber=source2[0][8]		//^ is not a wave, is constant  CommonPar9
				chopper_duty=source2[0][7]		//^ is not a wave, is constant CommonPar8
			else
				cor3_chamber=source1[0][15]		//^ is not a wave, is constant  ParVal15
				chopper_duty=source1[0][14]		//^ is not a wave, is constant  ParVal4
			endif
			
			//1.55K		// for now we do this for
			wave/t file_index = root:index:file_index
			make/o/n=0/t root:diagnostics:InfoValText/wave =  InfoValText
			make/o/n=0/t root:diagnostics:ParValText/wave =  ParValText
			make/o/n=0/t root:diagnostics:ComParValText/wave =  ComParValText
			sq_LoadAttributesFromHDF(file_index[0], "InfoVal",  root:diagnostics:InfoValText)
			sq_LoadAttributesFromHDF(file_index[0], "ParVal",  root:diagnostics:parValText)
			sq_LoadAttributesFromHDF(file_index[0], "ComParVal",  root:diagnostics:ComParValText)

		else //& Recycle existing data
			numOldTime=(numpnts(t_series_old))
			make /o/n=(numOldTime) t_series_map=round(binarysearchinterp(t_series,t_series_old[p]))
			for (idex=0;idex<numDiag;idex+=1)
				if (waveexists($diag_list[idex]))
					duplicate /o $diag_list[idex],diag_tmp
					make /o/n=(numTime) $diag_list[idex]=nan
					wave dest=$diag_list[idex]
					for (jdex=0;jdex<numOldTime;jdex+=1)
						dest[t_series_map[jdex]]=diag_tmp[jdex]
					endfor
				endif
			endfor
//			killwaves /z t_series_map
		endif
		wave /z ionSingleStr=root:diagnostics:ionSingleStr
		wave /z ionSingleStr_logged=root:diagnostics:ionSingleStr_logged
		if (waveexists(ionSingleStr) &&  (numpnts(ionSingleStr) !=numpnts(ionSingleStr_logged)))	//^ edited  //&
			print "// Mismatch in point numbers! User single ion wave deleted!"
			killwaves /z ionSingleStr
			if (waveexists(ionSingleStr))
				redimension /n=(0) ionSingleStr
			endif
		endif		
	endif	// endif acorn  = 0
   
	numAcorn=numpnts(index_pos)
   
	for(idex=0;idex<numAcorn;idex+=1)
		if(index_pos[idex]==-1)
			continue
		endif
		p1=series_index[index_pos[idex]]
	   	for (jdex=0;jdex<numDiag;jdex+=1)
	   		wave /z dest=$diag_list[jdex]
	   		if (!waveexists(dest))
	   			continue
	   		endif
	   		switch (diag_loc[jdex][0])
	   			case 0:	// infoval
	   				dest[p1]=source0[idex][diag_loc[jdex][1]]
	   				break
	   			case 1:	// parval
	   				dest[p1]=source1[idex][diag_loc[jdex][1]]
	   				break
	    		case 3:	// Comparval		//1.48 // should not happen for old data sets with no ComParVal
	   				dest[p1]=source2[idex][diag_loc[jdex][1]]
	   				break
	  			case 2: //& Special cases
	   				strswitch (diag_list[jdex])
	   					case "ToFPulserInHz":
	   						dest[p1]=1/(source1[idex][4]*1e-6) //& will need updating if 2GHz data is used;  Time of Flight pulser Period in microseconds (us)
	   						break // 1/ParVal4*1e-6
	   					case "ptof_t0":		// modification in 1.48C to be backwards compatible with ComParVal
	//         			dest[p1]=cor3_t_offset+(source1[idex][7]*0.000001)-(0.5*source1[idex][14]/(source0[idex][17]>0?(source0[idex][17]):(source1[idex][45])))		// changed in 1.47B
							// 1.54D  change here for ePToF
							// ParVal7 is delay after chopper vefore data acquisition starts (us), ComParVal7 is the duty cycle of the chopper (typically 0.02), ComParVal37 is the default chopper frequency
							if( ComParValExists)
	//          			if (source1[idex][7]!=1)	// not ePToF  // 1.54D   Pedro assures me that this has been sorted out
	   							dest[p1]=(source1[idex][7]*0.000001)-(0.5*source2[idex][7]/(source2[idex][37]))	// cor3_t_offset+ removed 1.59E This is incorrect for ePToF runs.  This needs to be fixed after we fix ePToF_enabled	
	   							// for ePToF we can't fix it here because early data sets had ePToF_enabled, ParVal 106 saved incorrectly
								// source1[idex][7] = (8) Delay after chopper before data acquisition starts (us)
								// source2[idex][7] = (8) Duty Cycle of the Chopper
								// source2[idex][37] = (38) Default Chopper Frequency (Hz)
	//          			else  // ePToF
	//          				dest[p1]=0 // assume the alignment of the 'start of the chopper' and the ePToF segments is correct		
	//          			endif
	   						else		 // cor3_t_offset+(ParVal7*1e-6 - 0.5*ComParVal7/ComParVal37)
	   							dest[p1]=(source1[idex][7]*0.000001)-(0.5*source1[idex][14]/(source1[idex][45]))		// cor3_t_offset+removed 1.59E  user parval, not infoval
	   						endif	 //  cor3_t_offset+(ParVal7*1e-6 - 0.5*ParVal14/ParVal45)
	  						break
	   					case "ptof_step":
	   						dest[p1]=source1[idex][4]*0.000001*source1[idex][12]			
	   						break	// ParVal4*ParVal12*1e-6		ParVal4 is the time of flight pulser period in microseconds (us) ParVal12 is the number of coAdds
	// 1.54E we now load these directly from InfoVal
	//           					case "Res14":
	//           						dest[p1]=source0[idex][53]/selectnumber(source1[idex][93]-1,EXPECTED_RESOULTION_14_C,EXPECTED_RESOULTION_14_V,EXPECTED_RESOULTION_14_W)
	//           						break	// InfoVal53/expected resolution which is based on tof mode)
	//           					case "Res28":
	//           						dest[p1]=source0[idex][54]/selectnumber(source1[idex][93]-1,EXPECTED_RESOULTION_28_C,EXPECTED_RESOULTION_28_V,EXPECTED_RESOULTION_28_W)
	//           						break	// InfoVal54/expected resolution which is based on tof mode)
	//           					case "Res91":
	//           						dest[p1]=source0[idex][55]/selectnumber(source1[idex][93]-1,EXPECTED_RESOULTION_91_C,EXPECTED_RESOULTION_91_V,EXPECTED_RESOULTION_91_W)
	//           						break	// InfoVal55/expected resolution which is based on tof mode)
	//           					case "Res184":
	//           						dest[p1]=source0[idex][56]/selectnumber(source1[idex][93]-1,EXPECTED_RESOULTION_184_C,EXPECTED_RESOULTION_184_V,EXPECTED_RESOULTION_184_W)
	//           						break 	// InfoVal56/expected resolution which is based on tof mode)
	// 1.54E we now load these directly from InfoVal 
	//           					case "DutyCycleMS":
	//           						dest[p1]=source1[idex][80] && (source0[idex][4]!=-999) ?(source0[idex][4]):(nan)        // ParVal80 * (InfoVal4 or nan for older DAQs)
	//           						break
	//           					case "DutyCyclePToF":
	//           						dest[p1]=source1[idex][79] && (source0[idex][5]!=-999) ?(source0[idex][5]):(nan)       // ParVal79 * (InfoVal5 or nan for older DAQs)
	//           						break
	//           					case "DutyCycleBFSP":
	//           						dest[p1]=source1[idex][81] && (source0[idex][6]!=-999) ?(source0[idex][6]):(nan)      // ParVal81 * (InfoVal6 or nan for older DAQs)
	//           						break
	//           					case "DutyCycleGenAlt":
	//           						dest[p1]=(source0[idex][7]!=-999)? (source0[idex][7]):(nan)        // InfoVal7 or nan for older DAQs
	//           						break
	   					case "ch1ThresholdVolts":
	   						if (MajorDaqVersion<5)
	   							dest[p1]=256*source1[idex][24]/source1[idex][18]		// 256*ParVal27/ParVal20
	   						else
	     						dest[p1]=(2^16)*source1[idex][24]/source1[idex][18]		// 256*ParVal27/ParVal20
	  						endif
	   						break
	//           	case "ch2ThresholdVolts":		/// this should no longer be called in 1.55K
	//           		dest[p1]=256*source1[idex][27]/source1[idex][20]		// 256*ParVal27/ParVal20
	//           		break
	   					case "TimeMSOpen":
	   						if (dimsize(source0,1) < 100  || numtype(source0[idex][112])!=0 ) 		//1.59A 
	   							dest[p1]=source0[idex][11]*source1[idex][82]	// infoVal11*ParVal82 	// Fract Buffers Saved MS Open* Number of seconds spent averaging on the AP240in MS mode
	   						else
	   							dest[p1]=source1[idex][193]	//  When in fast mode, we need to use ParVal 193 =  FMS averaging time		//1.48D
	   						endif
	   						break
	
	   					case "TimeMSClosed":
	    						if (dimsize(source0,1) < 100  ||numtype(source0[idex][112])!=0 )	//1.59A 	// if we are NOT if fast mode
	   							dest[p1]=source0[idex][22]*source1[idex][82]	// infoVal22*ParVal82 	// Fract Buffers Saved MS Open* Number of seconds spent averaging on the AP240in MS mode
	   						else
	   							dest[p1]=source1[idex][193]	// When in fast mode, we need to use ParVal 193 =  FMS averaging time		//1.48D
	   						endif
	
	   						break											// unless you are in fast mode.  If you are in fast mode, you simply need to use // When in fast mode, we need to use ParVal 193 =  FMS averaging time
	   					case "TimePTOFSec":		
	//						Old, bad formulation.  New way to do things (10/2009 discussions with Jose) is given below		//1.47I
	//						dest[p1]=source0[idex][10]*source1[idex][10]*source1[idex][4]*source1[idex][12]*1e-6
						// t_ptof = (# times through PToF) * (# choppers/time through PToF) * (time/chopper)
					// where time/chopper = (# bins) * (# coadds) * (time/spectrum) * 10e-6   = sec   
							//= Info [10] * Par[10] * Info [16] * Info [14] * par[4] (is in us)] * 1e-6
	//             					dest[p1]=source0[idex][10]*source1[idex][10]*source0[idex][16]*source0[idex][14]*source1[idex][4]*1e-6  //1.56C
	     					dest[p1]=source0[idex][10]*source1[idex][10]*source0[idex][16]*source1[idex][12]*source1[idex][4]*1e-6
	    						break
	  					case "TimeAcquiringMSOpenInRun":
	   						if (dimsize(source0,1) < 100  || numtype(source0[idex][112])!=0 ) 		//1.59A 
	   							dest[p1]=source0[idex][11]*source1[idex][82]	// infoVal11*ParVal82 	// Fract Buffers Saved MS Open* Number of seconds spent averaging on the AP240in MS mode
	   						else
	   							dest[p1]=source1[idex][193]	//  When in fast mode, we need to use ParVal 193 =  FMS averaging time		//1.48D
	   						endif
	   						break	
	   					case "TimeAcquiringMSClosedInRun":
	    					if (dimsize(source0,1) < 100  ||numtype(source0[idex][112])!=0 )	//1.59A 	// if we are NOT if fast mode
	   							dest[p1]=source0[idex][22]*source1[idex][82]	// infoVal22*ParVal82 	// Fract Buffers Saved MS Open* Number of seconds spent averaging on the AP240in MS mode
	   						else
	   							dest[p1]=source1[idex][193]	// When in fast mode, we need to use ParVal 193 =  FMS averaging time		//1.48D
	   						endif	
	   						break											// unless you are in fast mode.  If you are in fast mode, you simply need to use // When in fast mode, we need to use ParVal 193 =  FMS averaging time
	   					case "TimeAcquiringPToFInRun":		
	     					dest[p1]=source0[idex][10]*source1[idex][10]*source0[idex][16]*source1[idex][12]*source1[idex][4]*1e-6
	    					break
	   				endswitch
	   		endswitch
	   	endfor

	endfor

	//^ added in 1.32 for Ron Brown data... waves deleted if not-good values exist
	wave /z ionizationType
	if (waveexists(ionizationType))
		WaveStats/q ionizationType
		if (V_max<0)		// we are using this daq
			killwaves/Z ionizationType, tps_Drift, tps_setFileMajor, tps_setFileMinor
			variable/g daqReleaseRonBrown	 = 1		// this flag is obsolete... now use existence of ionizationtype
		endif
	endif
	
	wave airbeam_logged,airbeam_ptof
	airbeam_logged=(airbeam_logged[p]==0)? nan : airbeam_logged[p]
	airbeam_ptof=(airbeam_ptof[p]==0)? nan : airbeam_ptof[p]

   	if (acorn==n_acorns-1)
   		killwaves /z diag_tmp
//   		duplicate /o t_series,t_series_old		// 1.48F this was moved out of this squirrel fetch  
		if (cor3_chamber<=0 || numtype(cor3_chamber)!=0)	//1.48D sanity check - this value is only used for PToF
			setdatafolder root:
			abort " The chamber length value (root:panel:cor3_chamber) is incorrect; some other diagnostic values may also be wrong. Aborting from sq_diagnostics"
		endif
		
		// 1.51F Fast mode timing glitch found by TimO
  		wave DurationOfRun = root:diagnostics:DurationOfRun
  		wave FastModeAvgTimeSec = root:diagnostics:FastModeAvgTimeSec
  		wave FastKey = root:diagnostics:FastKey
		// root:diagnostics:DurationOfRun = numtype(root:diagnostics:FastKey[p])==0 ? root:diagnostics:FastModeAvgTimeSec[p] : root:diagnostics:DurationOfRun[p]
  		DurationOfRun = numtype(FastKey[p])==0 ? FastModeAvgTimeSec[p] : DurationOfRun[p]

		if (!ComParValExists)		//1.57H
			wave timeResolvedBuffers = root:diagnostics:timeResolvedBuffers
			fastop timeResolvedBuffers = (nan)
		endif

	// deal with misc timing things		
	// 1.59E moved to this section so if user pressed Get Diagnostics again these waves are updated.  Originally from sq_initializeAfterGetIndex()

		// 1.46B error found when Ed tried to process one run (total)
		wave t_series = root:index:t_series
		wave imt_series = root:index:imt_series
		if (numpnts(t_series)==1)				// error found in 1.47B	
			wave/wave Timewaves = sq_GetDAQTimes()
			wave TimeMSOpen = TimeWaves[0]
			wave TimeMSClosed = TimeWaves[1]
			wave TimePToF = TimeWaves[2]

			tempVar = numtype(TimePToF[0])!=0 ? 0 : TimePToF[0]
			tempVar += numtype(TimeMSClosed[0])!=0 ? 0 : TimeMSClosed[0]
			tempVar += numtype(TimeMSOpen[0])!=0 ? 0 : TimeMSOpen[0]
			tempVar = numtype(tempVar)!=0 ? 30 : tempVar		// 30 is really any old non-zero value
		 	imt_series[0] = t_series[0] - tempVar
		endif
		
		wave/z DAQVersionMajor = root:diagnostics:DAQVersionMajor			//1.57H
		if ( WaveExists(DAQVersionMajor) && WaveMax(DAQVersionMajor)<4)
			wave ePToF_enabled = root:diagnostics:ePToF_enabled			
			wave ePToF_oversampling =root:diagnostics:ePToF_oversampling	
			fastop ePToF_enabled=0
			fastop ePToF_oversampling=0
		endif

		//1.59E
		sq_CheckTimeWavesForNans(root:diagnostics:TimeAcquiringPToFInRun, 1)
		sq_CheckTimeWavesForNans(root:diagnostics:TimeAcquiringMSClosedInRun, 1)
		sq_CheckTimeWavesForNans(root:diagnostics:TimeAcquiringMSOpenInRun, 1)

		//1.53A
		wave/z ePToF_oversampling = root:diagnostics:ePToF_oversampling
		wave/z ePToF_enabled = root:diagnostics:ePToF_enabled
		if (WaveMax(ePToF_enabled)<0 && WaveMin(ePToF_oversampling)<0)
			ePToF_enabled=0
		endif
   	endif
  	
	sq_fix_ePToF_t0()		//1.55E
	setdatafolder root:
	killwaves/z Timewaves
End


// Added in 1.59E
Function sq_CheckTimeWavesForNans(Timewave, FixBadTime)
wave Timewave
variable FixBadTime

	Wavestats/q/M=1 Timewave
	if (V_numNans>0 && FixBadTime!=0)
		duplicate/o Timewave root:BadTimeWave/wave=BadTimeWave
		BadTimeWave = numtype(Timewave[p])==0
		if (FixBadTime!=0)
			print "// The wave "+GetWavesDataFolder(Timewave,2)+" had "+num2str(V_numNans)+" many Nans. This is unusual and may indicate other oddities associated with these runs."
			print "// To identify these runs, execute the function CheckTimWavesForNans with FixNans variable set to 0."	
			Timewave = BadTimeWave[p] ? Timewave[p] : 0
		else
			sq_create_todo("BadTimeWave","NansInMode")
			wave NansInMode
			edit/N=RunsWithNanTime NansInMode
			Killwaves/z BadTimeWave
			DoAlert, 0, "The runs for which nans occurred in the wave "+(GetWavesDataFolder(Timewave,2))+" are displayed in the table RunsWithNanTime."
		endif
	elseif(V_min<0)
		duplicate/o Timewave root:BadTimeWave/wave=BadTimeWave
		BadTimeWave = Timewave[p]<=0
		if (FixBadTime!=0)
			print "// The wave "+GetWavesDataFolder(Timewave,2)+" had "+num2str(V_numNans)+" many Nans. This is unusual and may indicate other oddities associated with these runs."
			print "// To identify these runs, execute the function CheckTimWavesForNans with FixNans variable set to 0."	
			Timewave = BadTimeWave[p] ?Timewave[p] : 0
		else
			sq_create_todo("BadTimeWave","NegsInMode")
			wave NegsInMode
			edit/N=RunsWithNegTime NegsInMode
			Killwaves/z BadTimeWave
			DoAlert, 0, "The runs for which negatives occurred in the wave "+(GetWavesDataFolder(Timewave,2))+" are displayed in the table RunsWithNegTime."
		endif
	endif
	
End


//& Prepare the list of diagnostics to make. Makes the diagnostics code more streamlined.
// changed in 1.44B MCP_V now comes from ParVal.  Added filament current, daq version
// 0 is infoval, 1 is parval, 2 is done ' by hand'
// modified in 1.48C to be backwards compatible with ComParVal
Function sq_diag_list_init()

	// any DAQ major version 4 and &lower ParVal82 is good (maybe)

	wave squirrel_index = root:index:squirrel_index	
	string diaglist,listitem
	variable idex,num, ComParValExists
	ComParValExists =  FindDimlabel(squirrel_index,2,"comParVal")>=0
	
	nvar MajorDaqVersion = root:diagnostics:MajorDaqVersion
	
// redone in 1.48B cus it all the edits make it too confusing!
//	diaglist="mStart,1,35;mFinish,1,36;flowrate,0,18;ionSingleStr_logged,0,25;ToFPulserInHz,2,0;MCP_Gain,0,20;"
////	diaglist+="MCP_V,0,21;ChopperFreq,1,45;CPC,0,30;mzSlope,0,43;mzInt,0,44;so4_log,0,46;no3_log,0,47;"		// changed in 1.44B
////	diaglist+="MCP_V,1,144;ChopperFreq,1,45;CPC,0,30;mzSlope,0,43;mzInt,0,44;so4_log,0,46;no3_log,0,47;"	// error in 1.46E  wrong MCP_V value (should be 143),  use info val to see actual setting not parval which is last sent command
//	diaglist+="MCP_V,0,21;ChopperFreq,3,37;CPC,0,30;mzSlope,0,43;mzInt,0,44;so4_log,0,46;no3_log,0,47;"
////	diaglist+="MCP_V,0,21;ChopperFreq,1,45;CPC,0,30;mzSlope,0,43;mzInt,0,44;so4_log,0,46;no3_log,0,47;"
//	diaglist+="nh4_log,0,48;orgL_log,0,49;orgH_log,0,50;ionEff_logged,1,42;HeaterBias,1,136;airbeam_logged,0,29;"
////	diaglist+="airbeam_ptof,0,28;ptof_vg,1,38;ptof_vl,1,39;ptof_dx,1,40;ptof_b,1,41;ptof_t0,2,0;ptof_step,2,0;toftype,1,93;"
//	diaglist+="airbeam_ptof,0,28;ptof_vg_logged,3,32;ptof_vl_logged,3,33;ptof_dx_logged,3,34;ptof_b_logged,3,36;ptof_t0,2,0;ptof_step,2,0;toftype,1,93;"// change in 1.48A
////	diaglist+="airbeam_ptof,0,28;ptof_vg_logged,1,38;ptof_vl_logged,1,39;ptof_dx_logged,1,40;ptof_b_logged,1,41;ptof_t0,2,0;ptof_step,2,0;toftype,1,93;"
//	diaglist+="Res14,2,0;Res28,2,0;Res91,2,0;Res184,2,0;PeakPosCal1,1,31;PeakPosCal2,1,33;DutyCycleMS,2,0;"
//	diaglist+="DutyCyclePToF,2,0;DutyCycleBFSP,2,0;DutyCycleGenAlt,2,0;analogIn00,0,35;analogIn01,0,36;analogIn02,0,37;"
//	diaglist+="analogIn03,0,38;analogIn04,0,39;analogIn05,0,40;analogIn06,0,41;analogIn07,0,42;ch1ThresholdVolts,2,0;"
//	diaglist+="ch2ThresholdVolts,2,0;ch1FullScaleVolts,1,18;ch2FullScaleVolts,1,20;ptofCoAdd,1,12;"
//	diaglist+="ptofNumSpectraPerChop,1,9;ptofNumTimesThrough,0,10;ionizationType,1,161;tps_Drift,1,164;"
//	diaglist+="tps_setFileMajor,1,165;tps_setFileMinor,1,166;"
////& Added 1.39
//	diaglist+="SavingIntervalTime,0,3;SecsInPToF,1,1;SecsInMS,1,2;PercentTimeMSOpen,1,85;"
//	diaglist+="FractionBuffersSavedMSOpen,0,11;FractionBuffersSavedMSClosed,0,22;SampledTime,0,1;"	// error found in 1.42D, FractionBuffersSavedMSClosed was set to column 23 instead of 22
//	diaglist+="TimeMSOpen,2,0;TimeMSClosed,2,0;TimePToFSec,2,0;"
//	//^ added in 1.42D
//	diaglist+="FastKey,0,71;"
//	//^ added in 1.43B	
//	diaglist+="FilamentEmission,0,72;"
//	//^ added in 1.43I	
//	diaglist+="MSOpenLSCounter,0,73;MSClosedLSCounter,0,74;PToFLSCounter,0,75;"
//	diaglist+="TimeAcquiringMSOpenInRun,0,76;TimeAcquiringMSClosedInRun,0,77;TimeAcquiringPToFInRun,0,78;TimeAcquiringBFSPInRun,0,79;DurationOfRun,0,80;"
//	//^ added in 1.44B
//	diaglist+="DAQSamplingType,1,162;"
//	//^  added in 1.46D
//	diaglist+="ratio40over28,0,24;ratio32over28,0,25;"			// Pete wanted these
//	diaglist+="reflectronBackPlateVolts,1,138;reflectronGridVolts,1,139;"		// intended to help distinguish 'VHR' modes
//	//^  added in 1.46E
//	diaglist+="MCP_V_set,1,143"			// The MCP_V_set value is the setting sent by the user - the MCP_V is the measured value.  MCP_V is the one plotted in the diagnostics graph

	// 0 is infoval, 1 is parval, 2 is done ' by hand', 3 is ComParVal.  Next number is column in data set matrix counting from 0
	// In Joel's documentation infoVal is the only data set that counts from 0. 
	diaglist=""
	// general mass spec, menu settings
	diaglist+="mStart,1,35;mFinish,1,36;"			
//	diaglist+="flowrate,0,18;ionSingleStr_logged,0,25;" //ionSingleStr_logged =  Avg. Single Ion, bits*ns
	diaglist+="flowrate,0,18;ionSingleStr_logged,1,43;" //ionSingleStr_logged =  Avg. Single Ion, bits*ns		//1.56C  was 0,25
	diaglist+="ToFPulserInHz,2,0;"					//  1/(source1[idex][4]*1e-6) 	//1.55K  //1.56A
//	diaglist+="ToFPulserInHz,1,4;"					//  1/(source1[idex][4]*1e-6)   saved value is in us

//	diaglist+="CPC,0,30;"							// Average of the CPC (p/cm3)    //1.56C
	diaglist+="ionEff_logged,1,42;HeaterBias,1,136;"	// Estimated Ionization and Transmission Efficiency, Heater bias voltage
	diaglist+="toftype,1,93;ionizationType,1,161;"	//Mode in which ToF is used (0=C-ToF, 1=V-ToF, 2=W-ToF), Indicates the ion source type (0=EI; 1=sEI; 2=VUV; 3=Li; 4=Neg)
	diaglist+="DAQSamplingType,1,162;"			//Indicates the sampling type; accepts values 0-5 to represent user-defined types
	diaglist+="FastKey,0,71;"						//Fast MS: Current Chopper Position
	if (MajorDaqVersion>=3)  	// 1.60B  was ==
		diaglist+="ionSingleStr_auto,0,105;"			// added in 1.48B	  Auto SI Area calculation (bit-ns), most recent value
	else
		diaglist+="ionSingleStr_auto,1,43;"			// 1.59
	endif
	
	//MCP
//	diaglist+="MCP_Gain,0,20;MCP_V,0,21;"		// MCP Gain,  MCP Voltage (Input)		//1.56C
	diaglist+="MCP_V,0,86;"		// MCP Gain,  MCP Voltage (last recorded)
	diaglist+="MCP_V_set,1,143;"		// The MCP_V_set value is the setting sent by the user - the MCP_V is the measured value.  MCP_V is the one plotted in the diagnostics graph  //1.54E  forgot a colon

	// logged species & air results
//	diaglist+="so4_log,0,46;no3_log,0,47;nh4_log,0,48;orgL_log,0,49;orgH_log,0,50;chl_log,0,51;chl_log,0,52;"    //1.55K typgo
	diaglist+="so4_log,0,46;no3_log,0,47;nh4_log,0,48;orgL_log,0,49;orgH_log,0,50;h2o_log,0,51;chl_log,0,52;"    //1.54E  added h2o and chlorine
	diaglist+="ratio40over28,0,23;ratio32over28,0,24;"			// Pete wanted these	//1.48F bug fix
	
	// airbeams
	diaglist+="airbeam_logged,0,29;airbeam_ptof,0,28;"
	
	// PToF stuff
	diaglist+="ptof_t0,2,0;"	// Depends! cor3_t_offset+(source1[idex][7]*0.000001)-(0.5*source1[idex][14]/(source1[idex][45]))	OR  same but with ComParVal
	diaglist+="ptof_step,2,0;"		// source1[idex][4]*0.000001*source1[idex][12]
	diaglist+="ptofCoAdd,1,12;ptofNumSpectraPerChop,1,9;ptofNumTimesThrough,0,10;"	//Number of Spectra to Co-Add together per segment, Number of TOF spectra acqired per chopper cycl, Number of choppers to read per average before reading frome

	// mass spec resolutions	
	diaglist+="mzSlope,0,43;mzInt,0,44;"
	diaglist+="PeakPosCal1,1,31;PeakPosCal2,1,33;" //ion time of flight bin number for center of Mass 1 peak, Mass 2 peak

//	diaglist+="Res14,2,0;Res28,2,0;Res91,2,0;Res184,2,0;" // i. e. source0[idex][53]/selectnumber(source1[idex][93]-1,EXPECTED_RESOULTION_14_C,EXPECTED_RESOULTION_14_V,EXPECTED_RESOULTION_14_W)
	diaglist+="Res14,0,53;Res28,0,54;Res91,0,55;Res184,0,56;" ////1.54D

	// gen alt and duty cycles, timing
	diaglist+="TotalTimeElapsedInRun,0,3;"		//1.56C  reinstated in 1.56J  was formerly called SavingIntervalTime
	diaglist+="SecsInPToF,1,1;SecsInMS,1,2;"
	if (MajorDaqVersion<5)	
		diaglist+="PercentTimeMSOpen,1,85;"
		diaglist+="FractionBuffersSavedMSOpen,0,11;FractionBuffersSavedMSClosed,0,22;"
	else
		diaglist+="numBuffersSavedMSOpen,0,11;numBuffersSavedMSClosed,0,22;"
	endif
	
	diaglist+="SampledTime,0,1;"
	//1.51F  notes from discussion with joel April, 2011
	// these TimeAcquiring... waves are the ones we want to use to find the exact time in these modes
//	1.55K diaglist+="TimeAcquiringMSOpenInRun,0,76;TimeAcquiringMSClosedInRun,0,77;TimeAcquiringPToFInRun,0,78;TimeAcquiringBFSPInRun,0,79;DurationOfRun,0,80;"
//	diaglist+="TimeAcquiringMSOpenInRun,0,76;TimeAcquiringMSClosedInRun,0,77;TimeAcquiringPToFInRun,0,78;TimeAcquiringBFSPInRun,0,79;DurationOfRun,0,80;"  // 1.56C
	if (MajorDaqVersion<=3) 	// 1.60B  was ==	
		diaglist+="TimeAcquiringMSOpenInRun,2,0;TimeAcquiringMSClosedInRun,2,0;TimeAcquiringPToFInRun,2,0;DurationOfRun,2,0;"	
	else
		diaglist+="TimeAcquiringMSOpenInRun,0,76;TimeAcquiringMSClosedInRun,0,77;TimeAcquiringPToFInRun,0,78;DurationOfRun,0,80;"	
	endif
	
// 1.54E change to not do the calculations
//	diaglist+="DutyCycleMS,2,0;" 			// source1[idex][80] && (source0[idex][4]!=-999) ?(source0[idex][4]):(nan) 
//	diaglist+="DutyCyclePToF,2,0;"		// source1[idex][79] && (source0[idex][5]!=-999) ?(source0[idex][5]):(nan)
//	diaglist+="DutyCycleBFSP,2,0;"		// source1[idex][81] && (source0[idex][6]!=-999) ?(source0[idex][6]):(nan)
//	diaglist+="DutyCycleGenAlt,2,0;"		// (source0[idex][7]!=-999)? (source0[idex][7]):(nan)
//	diaglist+="DutyCycleMS,0,4;DutyCyclePToF,0,5;DutyCycleBFSP,0,6;DutyCycleGenAlt,0,7;"  //1.55A  Pedro says these are garbage in the newDAQ version  //1.56
//	diaglist+="DutyCycleMS,0,4;DutyCyclePToF,0,5;		//1.56C
	diaglist+="DutyCycleGenAlt,0,7;"  //1.55A  Pedro says these are garbage in the newDAQ version

	// these TimeMS
	// 1.55K
//	diaglist+="TimeMSOpen,2,0;"			// source0[idex][11]*source1[idex][82]   //1.55A  Pedro says these are garbage in the newDAQ version
//	diaglist+="TimeMSClosed,2,0;"			// source0[idex][22]*source1[idex][82]   //1.55A  Pedro says these are garbage in the newDAQ version
	diaglist+="TimePToFSec,2,0;"			// source0[idex][10]*source1[idex][10]*source0[idex][16]*source0[idex][14]*source1[idex][4]*1e-6
	diaglist+="FastModeAvgTimeSec,1,193;"	// ParVal 193 =  FMS averaging time 			//1.48D fix
	
	// analog ins
	diaglist+="analogIn00,0,35;analogIn01,0,36;analogIn02,0,37;analogIn03,0,38;analogIn04,0,39;analogIn05,0,40;analogIn06,0,41;analogIn07,0,42;"
	
	// Ch1 and Ch2 voltage settings
	diaglist+="ch1ThresholdVolts,2,0;"		// 256*source1[idex][24]/source1[idex][18]
//.155K	diaglist+="ch2ThresholdVolts,2,0;"		// 256*source1[idex][27]/source1[idex][20]

//  1.55K 	diaglist+="ch1FullScaleVolts,1,18;ch2FullScaleVolts,1,20;"	
	diaglist+="ch1FullScaleVolts,1,18;"
	
	// tps
	diaglist+="tps_Drift,1,164;"		
		
	if (MajorDaqVersion>=4)
		//^ filament
		diaglist+="FilamentEmission,0,72;"		
		//^ Light Scattering
		diaglist+="MSOpenLSCounter,0,73;MSClosedLSCounter,0,74;PToFLSCounter,0,75;"
	else
		//^ filament
		diaglist+="FilamentEmission,1,155;"		
		//^ Light Scattering
		diaglist+="MSOpenLSCounter,0,91;MSClosedLSCounter,0,91;PToFLSCounter,0,91;"		// blanks
	endif
	
	//^ reflectrion (w mode) settings
	diaglist+="reflectronBackPlateVolts,1,138;reflectronGridVolts,1,139;"		// intended to help distinguish 'VHR' modes

	if (MajorDaqVersion>3)
		diaglist+="fastMSTimeWithinCycle,0,111;fastMSRunWithinCycle,0,112;"		// 1.50E  fast mode number of runs since sart of fast mode cycle.  If computer clock changes in the middle of a fast cycle
	endif
	
	diaglist+="numPtsRawSpectra,1,11;"		// added in 1.51G

	diaglist+="ChopperFreq_read,0,17;"		// added in 1.56F  was it read at, not what it was set at

	diaglist+="DAQVersionMajor,0,66;"		// added in 1.56F
	diaglist+="DAQVersionMinor,0,67;"		// added in 1.56F
	diaglist+="DAQVersionFix,0,68;"		// added in 1.56F		1.57Z1 This should be called DAQVersionRevision, but need to be backwards compatible
	diaglist+="DAQVersionFixMinor,0,69;"		// added in 1.57Z1  In OLDER DAQS, this was an unused parameter with the attribute ToF-AMS Operating Menu Version
		
	// to keep things backwards compatible, we need to isolate those values that are now saved in ComParVal
	if (ComParValExists)
//		diaglist+="tps_setFileMajor,3,70;tps_setFileMinor,3,71;"	//tps_setFileMajor and tps_setFileMinor changed in 1.48B	  //1.56C
		diaglist+="ChopperFreq,3,37;"
		diaglist+="ptof_vg_logged,3,32;ptof_vl_logged,3,33;ptof_dx_logged,3,34;ptof_b_logged,3,35;"		//  error in 1.48A, ptof_b_logged
	else
//		diaglist+="tps_setFileMajor,1,165;tps_setFileMinor,1,166;"	  //1.56C
		diaglist+="ChopperFreq,1,45;"
		diaglist+="ptof_vg_logged,1,38;ptof_vl_logged,1,39;ptof_dx_logged,1,40;ptof_b_logged,1,41;"		
	endif
	
	//ePToF things
	diaglist+="ePToF_enabled,1,106;"		//1.52D		  107 when counting from 0
	
	diaglist+="PToF_delay_us,1,7;"	//1.57H  this is only used for regular pToF for finding PToF_t0

	if (ComParValExists)	
		wave/t file_index = root:index:file_index
		sq_GetDAQFileVersion( file_index[0])		
		nvar DaqVersionMajorVar =  root:diagnostics:DaqVersionMajorVar		// ToF-AMS DAQ Version Major
		nvar DaqVersionMinorVar = root:diagnostics:DaqVersionMinorVar 			// ToF-AMS DAQ Version Minor
		nvar DaqVersionFixVar = root:diagnostics:DaqVersionFixVar  		// ToF-AMS DAQ Version Fix
		if (DaqVersionMajorVar>=5 && DaqVersionMinorVar>=0 && DaqVersionFixVar>=5 )
			diaglist+="ePToF_oversampling,1,13;"	//1.56
		else			
			diaglist+="ePToF_oversampling,3,169;"	//1.52D
	//		diaglist+="ePToF_oversampling,1,169;"	//1.56J  see email from Joel
		endif
		diaglist+="timeResolvedBuffers,3,167;"	//1.57H

	else
		diaglist+="ePToF_oversampling,0,90;"	//1.55K  fixed this bug.... change to an unused parameter
		diaglist+="timeResolvedBuffers,0,0;"	//1.57H  will be nanned in sq_diagnostics if it doesn't exist 
	endif
	
	if (MajorDaqVersion>=5)			//1.53N
		diaglist+="nSecMSsamplingInterval,1,15;"	//1.52L  nanosecond sampling interval
		diaglist+="HeaterBiasReadOrSet,1,127;"	//1.57Z2 see Joel email of Oct 11, 2016. Can only be read on DAQ versions since March 2015
		//  "...you may not know whether somebody has HB control from TPS2, and therefore whether infoval(127) is set or monitor. "
	endif
	
	if (MajorDaqVersion<=3)			//1.557K
		diaglist+="TimeMSOpen,2,0;TimeMSClosed,2,0;TimePToFSec,2,0;"	//1.52L  nanosecond sampling interval
	endif

	NewDataFolder/o/s root:diagnostics
	num=itemsinlist(diaglist)
	make /o/n=(num)/t diag_list
	make /o/n=(num,2) diag_loc
	for (idex=0;idex<num;idex+=1)
		listitem=stringfromlist(idex,diaglist)
		diag_list[idex]=stringfromlist(0,listitem,",")
		diag_loc[idex][]=str2num(stringfromlist(q+1,listitem,","))
	endfor

End



///////////////////////////////////////////////////////////////////////////////
//////////////  TODO WAVES/BLACKLIST//////////////
///////////////////////////////////////////////////////////////////////////////

//@ function to return a list of todo waves
Function/s sq_getToDoWaves()

	string toDoList, wnote, wvList, DFstr
	variable idex, num
	
	DFREF saveDFR = GetDataFolderDFR()	// Save
	SetDataFolder root:

	todolist=""
	wvList = wavelist ("*", ";", "INTEGER:1" )  // 1.51N
	num = itemsInList(wvList)
	
	for (idex=0;idex<num;idex+=1)
		wave temp=$(stringfromlist(idex,wvlist))
		wnote=note(temp)
		wnote=stringbykey("TYPE",wnote)
		if(cmpstr(wnote,"todo")==0 && numpnts(temp)>0)			//1.60Y
			todolist+=stringfromlist(idex, wvList )+";"
		endif
	endfor
	todolist = RemoveFromList("all", todolist) //^ remove all to put it first
	todolist = "all;"+ todolist
	
	SetDataFolder saveDFR			// and restore		//1.51N
	
	return todolist

End


Function sq_pop_toDoList(controlName,popNum,popStr) : PopUpMenuControl
	string controlName
	variable popNum
	string popStr
	
	svar sq_toDoList=root:panel:sq_toDoList
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	
	if ( stringmatch( popStr, "Get List") )
		sq_todolist=SQ_getTODOwaves()
		if (strlen(sq_todolist)>0)
			PopupMenu ams_toDoList_pop,win=ams_panel,mode=1,popvalue=stringfromlist(0,sq_todolist)
			PopupMenu/Z HRGen_todolist_pop,win=HR_Analysis_panel,mode=1,popvalue=stringfromlist(0,sq_todolist)	// 1.46D
			sq_toDoWvNm=stringfromlist(0,sq_todolist)
			//^execute /q ("PopupMenu ams_toDoList_pop, win=ams_panel,value=\""+sq_toDoList+"Get List;\"")  
			PopupMenu ams_toDoList_pop, win=ams_panel,value=root:panel:sq_toDoList+"Get List;"	//^ execute strings are limited to 400 characters
			PopupMenu/Z HRGen_todolist_pop,win=HR_Analysis_panel,value=root:panel:sq_toDoList+"Get List;"// 1.46D
		endif
	else
		wave/z todo =$"root:"+PopStr		//1.59C
		if (WaveExists(todo))
			sq_setTof0_PToFePToFtitle(todo)
			sprintf sq_toDoWvNm, "%s", popStr
			PopupMenu ams_toDoList_pop,win=ams_panel,mode=1,popvalue=PopStr
			PopupMenu/Z HRGen_todolist_pop,win=HR_Analysis_panel,mode=1,popvalue=PopStr		// squirrel HR, 1.40B
		endif
	endif

End


//@ add one run to the blacklist
//^ Modified in 1.35, modified in 1.47 to separate out the actual blacklisting, so that one can blacklist an entire wave more easily (for Fast mode)
// fixed small bug 1.47A
Function sq_butt_addToBlacklist(controlname) : Buttoncontrol
	string  controlname
	
	sq_GetIndexNotDoneYet()
	
	svar toDo_makeFromRuns_sv=root:panel:toDo_makeFromRuns_sv
	
	doAlert 2, "Users should Blacklist only runs that are truly pathological; It is difficult to unblacklist a run. You may want to save the experiment before you blacklist. Press Yes to continue, No to abort"
	if (V_flag != 1)
		return 0
	endif

	sq_create_todo("blacklist or "+toDo_makeFromRuns_sv,"blacklist")		// add run to blacklist wave

	sq_blacklist()	 // go through all todos and remove all runs in blacklist
	
	print "// This run was blacklisted: "+toDo_makeFromRuns_sv + " at "+date() + " " + time()+". The number of points in the all todo wave is "+Num2str(numpnts(root:all))

End


// a general function for blacklisting entire todo waves
// modified from MJC's original version of the code, faster and cleaner in 1.47
// new in 1.47
Function sq_blacklistwave(wav)	// from Donna during ARCTAS (note MJC 3/6/09)
wave wav
	
	doAlert 2, "You are about to blacklist all runs in "+NameofWave(wav)+" Users should Blacklist only runs that are truly pathological. Press Yes to continue, No to abort"
	if (V_flag != 1)
		return 0
	endif

	sq_create_todo("blacklist or "+NameofWave(wav),"blacklist")		// add run to blacklist wave
	
	sq_blacklist()		// goes through all existing todo waves to remove all runs in blacklist
	    
	print "// The runs in wave "+NameofWave(wav) +" were blacklisted."
	
End 


// new in 1.46, for use in blacklisting
Function sq_blacklist()

	string savedDataFolder, wavList, wavNote
	variable idex, num

	savedDataFolder = GetDataFolder(1)	//^ 1.35  make sure we are in root for the later wavelist call
	SetDataFolder root:						//^ 1.35

	//^ now blacklist runs from all waves
	wavList = wavelist ("*", ";", "INTEGER:1" )
	 
	num = itemsInList( wavList )
	
	for (idex=0;idex<num;idex+=1)
		wave temp=$(stringfromlist(idex,wavlist))
		wavNote=note(temp)
//		wavNote=stringbykey("TYPE",wavNote)
		if(cmpstr(stringbykey("TYPE",wavNote),"todo")==0)
			sq_create_todo(nameofwave(temp)+" and not blacklist",nameofwave(temp))
			Note/k temp wavNote		//1.53
		endif
	endfor

	SetDataFolder savedDataFolder		//^ 1.35

End


//> makes table of currently selected toDo wave, or makes one from scratch
Function sq_butt_toDo_edit(controlName) : ButtonControl
	string controlName
	
	sq_GetIndexNotDoneYet()
	setdatafolder root:
	
	string toDo, wvList = wavelist("*",";",""), toDoList, thisNote
	variable idex
	
	dowindow/k toDoTable
	edit/n=toDoTable/k=1/w=(50,50,450,350) as "ToDoWavesTable"
	
	for(idex=0;idex<itemsinlist(wvList);idex+=1)
		toDo=stringfromlist(idex, wvList)
		thisNote = stringbykey("type", note($toDo), ":")
		if ( stringmatch(thisNote, "todo") )
			appendtotable $toDo
		endif
	endfor

End


//> makes graph of toDo waves
//^  modified alot to show time series of toDo intervals
Function sq_butt_toDo_graph(controlName) : ButtonControl
	string controlName
	
	sq_GetIndexNotDoneYet()
	
	dowindow/F toDoGraph
	if (V_flag)		// window exists
		return 0
	endif

	sq_toDoGr_butt_Init("")	// creates the plot_todo waves

	display/n=ToDoGraph/w=(50,50,450,350) as "ToDoGraph"
	wave plot_ToDoSelect =  root:panel:plot:plot_ToDoSelect
	plot_ToDoSelect=1
	sq_todoGr_butt_PlotTodos("")

	kbcolorizetraces(.5,1,0)		// Igor 6.03 change
	ModifyGraph mode=3, marker=10
	ModifyGraph userticks(left)={root:panel:plot:plot_TodoLabelNum,root:panel:plot:plot_TodoLabelValue}	
	ModifyGraph margin(left)=72
	Label left ""
	Label bottom " "

	ControlBar/L 150
	Button buttonCheckTodo,pos={5,10},size={120,40},proc=sq_toDoGr_butt_Init, title="Check/Update\rToDo wave list"
	Button buttonPlotTodo,pos={10,250},size={130,20},proc=sq_todoGr_butt_PlotTodos,title="Plot todos on left axis"
	TitleBox titleSelectTodo,pos={14,52},size={112,39},title="Select the todo waves.\rUse the shift for multiple\rselections."
	TitleBox titleSelectTodo,frame=0
	ListBox listActiveTodos,pos={10,96},size={131,148}
	ListBox listActiveTodos,listWave=root:panel:plot:plot_ToDoListWave
	ListBox listActiveTodos,selWave=root:panel:plot:plot_ToDoSelect,mode= 4
	TitleBox titleZeroPtTodo,pos={14,302},size={106,39},title="ToDo waves with zero\rnumber of runs (will\rnot be plotted):"
	TitleBox titleZeroPtTodo,frame=0
	ListBox listZeroPtTodos,pos={10,347},size={130,61}
	ListBox listZeroPtTodos,listWave=root:panel:plot:plot_ToDoListWaveZeroPts

End


Function sq_todoGr_butt_PlotTodos(ctrlName) : ButtonControl
	String ctrlName

	wave/t plot_ToDoListWave = root:panel:plot:plot_ToDoListWave
	wave plot_ToDoSelect =  root:panel:plot:plot_ToDoSelect
	wave/t plot_TodoLabelValue=  root:panel:plot:plot_TodoLabelValue
	wave plot_TodoLabelNum =  root:panel:plot:plot_TodoLabelNum
	wave t_series = root:index:t_series
	
	string TraceList, TraceStr
	variable idex, num, numSelected, numToDos
	
	numToDos = numpnts(plot_ToDoListWave)
	// remove all traces
	TraceList = TraceNameList("", ";" ,1)
	num=ItemsInList(traceList)
	for (idex=0;idex<num;idex+=1)
		RemoveFromGraph $StringFromList(idex, TraceList)
	endfor

	plot_TodoLabelValue=""
	plot_TodoLabelNum=nan
	// add traces	
	numSelected =0
	num=numpnts(plot_ToDoListWave)
	for (idex=0;idex<num;idex+=1)
		if (plot_ToDoSelect[idex]==1)
			plot_TodoLabelValue[numSelected]=plot_ToDoListWave[idex]
			plot_TodoLabelNum[numSelected]=numSelected+1
			wave myToDoPlot = $"root:panel:plot:plot_"+plot_ToDoListWave[idex]
			myToDoPlot = myToDoPlot/myToDoPlot * (numSelected+1)
			appendToGraph/W=ToDoGraph myToDoPlot vs t_series		
			numSelected+=1
		endif
	endfor

	if (numSelected>0)
		kbcolorizetraces(.5,1,0)		// Igor 6.03 change
		ModifyGraph mode=3, marker=10
		ModifyGraph userticks(left)={root:panel:plot:plot_TodoLabelNum,root:panel:plot:plot_TodoLabelValue}	
		ModifyGraph margin(left)=72
		Label left ""
		Label bottom " "
		SetAxis left numSelected+1, 0
		
		if (numSelected <numToDos)
			plot_TodoLabelValue[numSelected,]=""
			plot_TodoLabelNum[numSelected,]=nan
		endif
		
		plot_ToDoSelect=0
	endif
	
	ShowInfo
	
End


Function sq_toDoGr_butt_Init(ctrlName) : ButtonControl
	String ctrlName

	wave run_series =  root:index:rn_series
	svar sq_toDoList = root:panel:sq_toDoList

	string toDoStr=""
	variable idex, num, kdex, numToDo, numRuns, numGoodToDos

	SetDataFolder root:
	
	sq_todolist=SQ_getTODOwaves()

	num = itemsinlist(sq_todolist+"blacklist;")
	numRuns = numpnts(run_series)

	NewDataFolder/o root:panel:plot  //^ tuck away these simple waves 

	//^ make a wave and append to plot for all todos
	make/o/t/n=(num) root:panel:plot:plot_ToDoListWave=""
	make/o/n=(num) root:panel:plot:plot_ToDoSelect=1
	make/t/o/n=(num) root:panel:plot:plot_TodoLabelValue=""	// on graph
	make/o/n=(num) root:panel:plot:plot_TodoLabelNum=p+1	// on graph
	make/t/o/n=(0) root:panel:plot:plot_ToDoListWaveZeroPts=""
	wave/t plot_ToDoListWave = root:panel:plot:plot_ToDoListWave
	wave/t plot_TodoLabelValue = root:panel:plot:plot_TodoLabelValue
	wave/t plot_ToDoListWaveZeroPts = root:panel:plot:plot_ToDoListWaveZeroPts
	wave/t plot_ToDoListWaveZeroPts = root:panel:plot:plot_ToDoListWaveZeroPts
	wave plot_ToDoSelect = root:panel:plot:plot_ToDoSelect
	wave plot_TodoLabelNum = root:panel:plot:plot_TodoLabelNum

	numGoodToDos=0
	// initial all plotting of todo waves
	for(idex=0;idex<num;idex+=1)
		toDoStr=stringfromlist(idex, sq_todolist+"blacklist;")
		make/o/n=(numRuns) $"root:panel:plot:plot_"+todoStr
		wave myToDoPlot = $"root:panel:plot:plot_"+todoStr
		myToDoPlot = nan

		wave todowave = $"root:"+toDoStr		//1.44B
		numToDo=numpnts(toDoWave)
		if (numToDo>0) //  we want to plot only the todo waves that have >0 number of runs 
			plot_ToDoListWave[numGoodToDos]=toDoStr
			plot_TodoLabelValue[numGoodToDos]=toDoStr
			sq_makeMaskFromTodofindRun(myToDoPlot,todowave)
//			for (kdex=0;kdex<numToDO;kdex+=1)			//1.59D
//				myToDoPlot[binarysearch(run_series,toDoWave[kdex])]=1
//			endfor
			myToDoPlot*=idex+1
			numGoodToDos+=1		
		else
			deletePoints numGoodToDos, 1, plot_ToDoListWave, plot_ToDoSelect, plot_TodoLabelValue, plot_TodoLabelNum
			insertPoints numGoodToDos, 1, plot_ToDoListWaveZeroPts
			plot_ToDoListWaveZeroPts[idex-numGoodToDos]=toDoStr
		endif
	endfor

	DoWindow/F ToDoGraph
	if (V_flag)
		sq_todoGr_butt_PlotTodos("") 
	endif
	
End


//> make a to do list from reference runs and entered name
//^ New function built from sq_butt_makeToDoFromRuns; generalized this function quite 
//^ a bit to handle the new +ToDo and -ToDo buttons.
Function sq_butt_ToDoFromRuns(controlName) : ButtonControl
	string controlName

	svar toDo_makeFromRuns_sv=root:panel:toDo_makeFromRuns_sv
	svar toDo_makeFromName_sv=root:panel:toDo_makeFromName_sv
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	svar sq_todolist=root:panel:sq_todolist
	
	string strtmp, dataFolderStr

	sq_GetIndexNotDoneYet()
	//1.44B fix
	dataFolderStr = GetDataFolder(1) 
	SetDataFolder root:
	
	//^ check todo wave name
	if ( FindListItem(lowerStr(toDo_makeFromName_sv), "all;new;blacklist") >= 0  )		// cleaner, changed in 1.43B
		Abort "Please do not use the reserved todo wave names \"new\" , \"all\"  or \"blacklist\"  - Aborting from sq_butt_ToDoFromRuns"
	endif
	
	if (!stringmatch(toDo_makeFromName_sv, CleanupName(toDo_makeFromName_sv,0)  )  )
		Abort " Please use only alphanumeric characters, no spaces and begin the name with an alphabetic character. - Aborting from sq_butt_ToDoFromRuns"
	endif
	
	if (strlen(toDo_makeFromName_sv) > 16 )	// check added in 1.43E
		DoAlert 1,  "Users are advised to keep the length of the todo wave name to under 16 characters.  Do you wish to use this todo wave name? "
		if (V_flag==2)
			Abort "The user chose to quit."
		endif
	endif

	sq_create_todo(toDo_makeFromRuns_sv+" and all",toDo_makeFromName_sv)
	
	//^ set current toDo wave as the one just generated and repopulate pop up menu
	sq_pop_toDoList("",0,"Get List")
	strtmp=SQ_getTODOwaves()
//	sq_pop_toDoList("",itemsinlist(strtmp,";"),stringfromlist(itemsinlist(strtmp,";")-1,strtmp,";"))		1.44B change
	sq_pop_toDoList("",itemsinlist(strtmp,";"),toDo_makeFromName_sv)
	
	//1.41B fix
	wave LatestTodo = $"root:"+sq_toDoWvNm
	if (numpnts(LatestTodo)==0)
		DoAlert 0, "Beware!  The latest todo wave that you created, called "+sq_toDoWvNm+", has zero many runs in it!!"
	endif
	
	// 1.43B addition, 1.44B fix
	print "// The todo wave named "+toDo_makeFromName_sv+" was created or overwritten using the runs or formula '"+toDo_makeFromRuns_sv +"' and contains "+num2str(numpnts(LatestTodo))+" runs."
	
	SetDataFolder $dataFolderStr

End


//^  Add run numbers in todoWave toDo_makeFromRuns_sv; doesn't duplicate runs.
// obsolete in 1.44B?
//Function sq_todoWaveAddRuns(toDoWave, toDo_makeFromRuns_sv)
//	wave toDoWave
//	string toDo_makeFromRuns_sv
//
//	wave run_index=root:index:run_index		//^ has all run numbers, including blacklist
//	 
//	variable idex, num, jdex, runStart, runEnd, numToDo, loc, npts
//	string runStr
//	
//	num = itemsinlist( toDo_makeFromRuns_sv, ",")		//^ s and single values should be comma separated.
//
//	for (idex=0;idex<num;idex+=1)
//	
//		runStr = stringfromlist(idex, toDo_makeFromRuns_sv,"," )
//		runStart = str2num(stringfromlist(0,runStr,"-"))
//		
//		if (itemsinlist(runStr,"-")==2)	//^ interval
//			runEnd = str2num(stringfromlist(1,runStr,"-"))
//			if (runStart>runEnd)
//				print "// Did not understand the run string "+runStr+ " and did not process."
//				continue
//			endif
//			for (jdex=runStart;jdex<=runEnd;jdex+=1)
//				loc = sq_findRun(run_index,jdex)
//				if (loc>=0)
//					loc = sq_findRun(toDoWave,runStart)
//					if (loc<0)
//						npts = numpnts(toDoWave)-1
//						insertpoints npts, 1, toDoWave
//						toDoWave[npts]=jdex
//					endif
//				endif
//			endfor
//		elseif (itemsinlist(runStr,"-")==1)	//^ single run
//			loc = sq_findRun(run_index,runStart)
//			if (loc>=0)
//				loc = sq_findRun(toDoWave,runStart)
//				if (loc<0)
//					npts = numpnts(toDoWave)
//					insertpoints npts, 1, toDoWave
//					toDoWave[npts]=runStart
//				endif
//			endif
//		else
//			print "// Did not understand the run string "+runStr+ " and did not process."
//		endif
//
//	endfor
//		
//End


//^ Removes run numbers in todoWave indicated by toDo_makeFromRuns_sv; 
//^ doesn't complain if a run number doesn't exist in toDo wave.
// obsolete in 1.44B ?
// Function sq_todoWaveRemoveRuns(toDoWave, toDo_makeFromRuns_sv)
//	wave toDoWave
//	string toDo_makeFromRuns_sv
//
//	variable idex, kdex, num, pt, runStart, runEnd
//	string runStr, runNotInToDoStr = ""
//	
//	num = itemsinlist( toDo_makeFromRuns_sv, ",")		//^ run intervals and single values should be comma separated.
//
//	for (idex=0;idex<num;idex+=1)
//	
//		runStr = stringfromlist(idex, toDo_makeFromRuns_sv,"," )
//		runStart = str2num(stringfromlist(0,runStr,"-"))
//		
//		if (itemsinlist(runStr,"-")==2)	//^ interval
//			runEnd = str2num(stringfromlist(1,runStr,"-"))
//			if (runEnd - runStart >0)
//				for(kdex=runStart;kdex<=runEnd;kdex+=1)		//^ loop through run interval
//					pt = binarysearch(toDoWave, kdex)
//					if (pt>=0)
//						deletepoints pt,1, toDoWave 
//					else
//						runNotInToDoStr+=num2str(kdex)+","
//					endif
//				endfor
//			else
//				print "// Did not understand the run interval "+runStr+ " and did not process."
//				continue
//			endif
//		elseif (itemsinlist(runStr,"-")==1)	//^ single run
//			pt = binarysearch(toDoWave, runStart)
//			if (pt>=0)
//				deletepoints pt,1, toDoWave 
//			else
//				runNotInToDoStr+=num2str(runStart)+","
//			endif
//		else
//			print "// Did not understand the run string "+runStr+ " and did not process."
//		endif
//
//	endfor
//	
//	if (strlen(runNotInToDoStr)>0)
//		print "// The run number(s) were not in this toDo wave:" +NameofWave(toDoWave)+runNotInToDoStr[0, min(strlen(runNotInToDoStr), 300)]
//	endif
//	
//	if (numpnts(toDoWave)==0)
//		print "// There are no runs in the toDo wave "+NameofWave(toDoWave)+". Perhaps you should kill this wave."  
//	endif
//
//End


//^ Sets global toDo_makeFromRuns_sv for future use of making the runs blacklisted or added/movedcreating a todo wave.
//  renamed from sq_csr_setRunIntevals
Function sq_butt_csrSetRunIntervals(ctrlName) : ButtonControl
	String ctrlName

	string savedDataFolder = GetDataFolder(1)	//^ 1.35
	SetDataFolder root:						//^ 1.35

	wave run_series=root:index:rn_series
	svar toDo_makeFromRuns_sv=root:panel:toDo_makeFromRuns_sv

	variable ptA, ptB, runNumA, runNumB, val
	val = sq_CsrOnWave()
	if  (val==1)
		abort "Please place the cursors on the save wave with the the circle cursor on the left - Aborting from ButtonProc_setRunsViaCursors"
	endif
	string str1, str2
	
	ptA = pcsr(A)
	ptB = pcsr(B)
	
	if(ptA>ptB)
		Abort "Please place the cursors on the save wave with the the circle curosr on the left - Aborting from ButtonProc_setRunsViaCursors"
	endif
	runNumA = run_series[ptA]
	runNumB = run_series[ptB]
	sprintf str1, "%d" , runNumA		// small bug, things can go wrong with run numbers > 1e6
	sprintf str2, "%d" , runNumB		// small bug, things can go wrong with run numbers > 1e6
	
	if (runNumA == runNumB)		//^ one point
		if (stringmatch(ctrlName, "ams_butt_RunsFromCsrNew")==1)
			toDo_makeFromRuns_sv =str1
		elseif (stringmatch(ctrlName, "ams_butt_RunsFromCsrAppend")==1)
			toDo_makeFromRuns_sv += " or "+str2
		else
			Abort "There is something wrong with the name of the control:"+ctrlName+" - Aborting from ButtonProc_setRunsViaCursors"
		endif
	else		//^ more than one point
		if (stringmatch(ctrlName, "ams_butt_RunsFromCsrNew")==1)
			toDo_makeFromRuns_sv = str1+"-"+ str2
		elseif (stringmatch(ctrlName, "ams_butt_RunsFromCsrAppend")==1)
			toDo_makeFromRuns_sv += " or "+str1+"-"+ str2
		else
			Abort "There is something wrong with the name of the control:"+ctrlName+" - Aborting from ButtonProc_setRunsViaCursors"
		endif
	endif
	DoWindow /f ams_panel

	SetDataFolder savedDataFolder		//^ 1.35

End

//^ Returns a "0" if the cursors on the top graph are on the same wave  and returns a "1" if not.
Function sq_csrOnWave()
	
	Variable returnVal = 0

	string waveAStr=CsrWave(A), waveBStr=CsrWave(B)
	
	if(strlen(waveAStr)==0 )
		returnVal = 1
	endif
	if (strlen(waveBStr)==0)
		returnVal = 1
	endif	
	if (cmpstr(waveAStr, waveBStr) )
		returnVal = 1
	endif	
	
	return(returnVal)

End


//^ Appends a control bar and two buttons for entering run number values via cursors
//Function sq_addCntrl_RunsFromCsrs()
//
//	ControlBar 30
//	Button ams_butt_RunsFromCsrNew pos={20,5},size={160,18}, proc=sq_butt_CsrSetRunIntervals, title="New Run Interval From Csrs"
//	Button ams_butt_RunsFromCsrNew help={"This will delete any values in the Run Interval entry in the panel and will put the run intervals on and between the cursors to this entry"}
//	Button ams_butt_RunsFromCsrAppend pos={195,5},size={160,18},proc=sq_butt_CsrSetRunIntervals, title="Append Run Interval From Csrs"
//	Button ams_butt_RunsFromCsrAppend  help={"This will append the run intervals on and between the cursors to the Run Interval entry in the panel"}
//
//End


///////////////////////////////////////////////////////////////////////////////
///////////  DUMP TO/DELETE FROM MEM //////////////////
///////////////////////////////////////////////////////////////////////////////

//> PopUpMenu for choosing data wave you'd like to dump to memory
Function sq_pop_dump2memList(controlName,popNum,popStr) : PopUpMenuControl
	string controlName
	variable popNum
	string popStr
	
	svar sq_dump2memList=root:panel:sq_dump2memList 		// the list
	svar sq_dump2memWvNm=root:panel:sq_dump2memWvNm	// currently chosen name

	if (!waveexists( root:index:squirrel_index) )
		Abort  "You need to create data index wave first  - Aborting from sq_pop_dump2memList"
	else
		wave squirrel_index = root:index:squirrel_index
	endif
	
	variable idex,lim				// slight change in 1.43B
	string dimlabel

	lim = dimsize( squirrel_index,2)
	if ( stringmatch( popStr, "Get List") )
		sq_dump2memList=""
		for (idex=0;idex<lim;idex+=1)
			dimlabel = getdimlabel(squirrel_index,2,idex)
			if (!stringmatch("_d", dimlabel[strlen(dimlabel) - 2, strlen(dimlabel) - 1])  )		//1.43B
				sq_dump2memList += dimlabel + ";"		
			endif
		endfor
		dimlabel=getdimlabel(squirrel_index,2,0)		// set to first item in list
		PopupMenu misc_dump2mem_pop, win=ams_panel,mode=1,popvalue=dimlabel,value=root:panel:sq_dump2memList+"Get List;"	//^ 1.40D fix
		sq_dump2memWvNm = dimlabel
	else
		sq_dump2memWvNm = popStr
	endif

End


//> function to dump wave specified in associated pop up menu
Function sq_butt_dump2mem(controlName) : ButtonControl
	string controlName
	
	sq_GetIndexNotDoneYet()
	svar sq_dump2memWvNm=root:panel:sq_dump2memWvNm
	svar todoStr=root:panel:sq_toDoWvNm
	wave todo=$"root:"+todoStr		//1.44B fix

	string paramstr

	paramstr =  "dest:"+sq_dump2memWvNm+"_d"		// minor reorganization
	sq_journal_new("Dump2Mem")
	squirrel_fetch(todo,sq_dump2memory,paramstr,sq_dump2memWvNm)
	print "// The data set "+sq_dump2memWvNm+" was successfully dumped to memory."		// 1.43B change  
	sq_pop_dump2memList("",1,"Get List")
	sq_journal_end()

End


//@ function to remove data from memory and squirrel index
//Function sq_butt_deleteFromMem(controlName): ButtonControl
//	string controlname
//	
//	sq_GetIndexNotDoneYet()

//	svar sq_dump2memWvNm=root:panel:sq_dump2memWvNm
//	wave squirrel_index=root:index:squirrel_index
//	wave/z data=$("root:"+sq_dump2memWvNm)
//

//	variable idex,num=dimsize(squirrel_index,2)
//	string dimlabel
//
//	sq_journal_new("DeleteFromMem")
//	
//	if(waveexists(data))
//		killwaves/z data
//		if(!waveexists(data))
//			for(idex=0;idex<num;idex+=1)
//				dimlabel=getdimlabel(squirrel_index,2,idex)
//				if(cmpstr(sq_dump2memWvNm,dimlabel)==0)
//					deletepoints /m=2 idex,1,squirrel_index
//					print "// The data set "+dimlabel+" was successfully deleted from memory."		// 1.43B change  
//					break
//				endif
//			endfor
//		else
//			doalert 0, "Data in use, can't delete!"
//		endif
//	endif
//	sq_pop_dump2memList("",1,"Get List")
//	sq_journal_end()
//
//End

//> Sends request to squirrel for mem dump
Function sq_dump2Memory(index_pos,paramstr,acorn,n_acorns) 
	wave index_pos
	string paramstr
	variable acorn,n_acorns
	
	wave source=$stringbykey("acorn_0",paramstr)
	string dest = stringbykey("dest", paramstr )
	squirrel_mem_write(index_pos,source,dest,dest)

End

///////////////////////////////////////////////////////////////////////////////
////////////////////  COMMON BUTTONS /////////////////////////
///////////////////////////////////////////////////////////////////////////////


Function sq_Pieber_ButtonProc(ctrlName) : ButtonControl
	String ctrlName
	Abort "This is not yet completed. For now, read the paper at http://pubs.acs.org/doi/abs/10.1021/acs.est.6b01035"



End

// Go to website to download squirrel
//Function sq_butt_url(ctrlName) : ButtonControl
//	String ctrlName
//	
//	browseurl /z "http://cires.colorado.edu/jimenez-group/ToFAMSResources/ToFSoftware/index.html#Analysis2"
//
//End
//
//

// Go to website for squirrel info
//Function sq_butt_url_FAQ(ctrlName) : ButtonControl
//	String ctrlName
//
////	browseurl /z "http://cires.colorado.edu/jimenez-group/ToFAMSResources/ToFSoftware/SquirrelInfo/"		1.50A fix


//	browseurl /z "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software"
//

//End


//@ Button to bring up credits window
Function sq_butt_credits(ControlName): ButtonControl
	string ControlName

	DoWIndow/F AMS_credits
	if (V_flag==0)
		sq_panel_credits()
	endif
	
End


// new in 1.52
Function sq_CreateReviewBatchTable()

	wave/z calfac_list = root:frag:calfac_list
	if (!WaveExists(calfac_list))
		abort "Cannot find batch waves in the root:frag folder. aborting from 	sq_CreateReviewBatchTable"
	endif
	SetFormula calfac_list, " 1/ (root:frag:IEfac_list* root:frag:CEfac_list)" //^ users may inadvertantly remove the dependency when editing the table.
	wave/z CEWave_list = root:frag:CEWave_list
	if (!WaveExists(CEWave_list))
		make/o/t/n=(numpnts(calfac_list)) root:frag:CEWave_list=""		
	endif
	edit/N=ReviewBatchTable/k=1 root:frag:specname_list,root:frag:spec_list,root:frag:frag_list as "ReviewBatchTable"		//root:frag:tof_list
	appendtotable root:frag:iefac_list,root:frag:calfac_list,root:frag:cefac_list,root:frag:CEWave_list,root:frag:speccorr_list,root:frag:speccorr_list

End


//@ creates table showing batch info
Function sq_butt_reviewBatch(ControlName) : ButtonControl
	string controlname
	
	string Mylist
	DoWindow/F ReviewBatchTable
	if (V_flag==0)					
		if(waveexists(root:frag:specname_list)) 
			sq_CreateReviewBatchTable()
		else
			Abort " Cannot find the waves in the frag folder - Aborting from sq_butt_reviewBatch"
		endif
	else // if batch table exists make sure it has the CEwave_list
		Mylist=WaveList("*", ";","WIN:")
		if (WhichListItem("CEWave_List", Mylist)<0)	//
			wave/z CEWave_List = root:frag:CEWave_List
			wave/z CEfac_List = root:frag:CEfac_List
			if (!WaveExists(CEWave_List))
				make/t/o/n=(numpnts(CEfac_List)) root:frag:CEWave_List=""
				wave/z CEWave_List = root:frag:CEWave_List
			endif
			DoWindow/K ReviewBatchTable
			sq_CreateReviewBatchTable()		
		endif
	
	endif

End


//@ creates table showing frag info  	//^ significantly overhauled in 1.41B
Function sq_butt_reviewFrags(ControlName) : ButtonControl
	string controlname
	
	variable pt, i, numFrags
	string FragWaves

	if(!datafolderexists("root:frag:"))
		abort "The frag data folder does not exist!  Aborting from  sq_butt_reviewFrags"
	endif

	DoWindow/F FragPanel
	
	if (V_flag==0)
		variable/g root:frag:fragTableFont=12
		variable/g root:frag:fragTableWidth=100
		sq_FragPanel_make() 
	endif
	
End


//@ Default button for MS t_series species
Function sq_butt_MSSpeciesDefault(controlname) : buttonControl
	string controlname
	
	svar ms0_speclist=root:panel:ms0_speclist
	ms0_speclist=MSTSERIES_SPECIES_DEFAULT_LIST		//sq_MSTSeriesSpeciesDefault is a constant defined at top

End


//@ Default button for ToF#1 species
Function sq_butt_ToFSpeciesDefault(controlname) : buttonControl
	string controlname
	
	svar tof1_speclist=root:panel:tof1_speclist
	tof1_speclist=MSTSERIES_SPECIES_DEFAULT_LIST			//1.46E

End


Function sq_butt_ToFSpeciesMSDefault(ctrlName) : ButtonControl
	String ctrlName

	svar tof1_speclist=root:panel:tof1_speclist
	tof1_speclist=PTOFAVE_SPECIES_DEFAULT_LIST			//sq_ToFAveSpeciesDefault is a constant defined at top

End


//@ Default button for MS ave species
Function sq_butt_MSAveSpeciesDefault(ControlName): ButtonControl
	string controlname

	svar ms0_speclist=root:panel:ms0_speclist
	ms0_speclist=MSAVE_SPECIES_DEFAULT_LIST		//sq_MSAveSpeciesDefault is a constant defined at top

End


//@ Button for apply graph defaults to current graph
// colors traces to species colors, makes lines thick, addes zero line, etc.
Function sq_butt_appGraphDefs(ctrlName) : ButtonControl
	string ctrlName
	
	dowindow /f $stringfromlist(0,winlist("*",";","WIN:1"))
	string wavlist=tracenamelist("",";",1)

	sq_applyGraphDefs(wavlist)

End


Function sq_applyGraphDefs(AppendWList)		//1.60Y
string AppendWList

	nvar gdef_line_thick=root:panel:gdef_line_thick		// set variable
	nvar gdef_stick_thick=root:panel:gdef_stick_thick// set variable
	nvar gdef_zline=root:panel:gdef_zline			// checkbox
	nvar gdef_cursors=root:panel:gdef_cursors   	// checkbox
	nvar gdef_scale=root:panel:gdef_scale 			// checkbox  scale to zero
	nvar gdef_leg=root:panel:gdef_leg				// checkbox
//	nvar gdef_cbut=root:panel:gdef_cbut
	nvar gdef_gaps=root:panel:gdef_gaps				// checkbox//1.43I
	nvar dontColorTraces=root:panel:dontColorTraces	// checkbox//1.43I
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm

	variable idex,jdex,num,specno,barflag, numold
	string wavlist,listitem, listitem_lesstodoname,itemStr,allMSWaveStr, errMSWaveStr, OldWavesList, doList

	dowindow /f $stringfromlist(0,winlist("*",";","WIN:1"))
	wavlist=tracenamelist("",";",1)
		
	OldWavesList = gen_RemoveItemsInListFromList(AppendWList, wavlist)
	numold = itemsInLIst(OldWavesList)
	
	if (dontColorTraces)  // leave old ones alone
		doList = AppendWList
	else
		doList = wavlist
	endif
	
	num=itemsinlist(dolist)
	
	for (idex=itemsinlist(dolist)-1;idex>=0;idex-=1)
		if (WhichListItem(stringfromlist(idex,dolist),wavlist)>=0 )
			if (str2num(stringbykey("mode(x)",traceinfo("",stringfromlist(idex,dolist),0),"=",";")))
				modifygraph lsize($stringfromlist(idex,dolist))=gdef_stick_thick
			else
				modifygraph lsize($stringfromlist(idex,dolist))=gdef_line_thick
			endif
		endif
	endfor
//	if (!dontColorTraces && numold>0)		// it is a new graph
		if (str2num(getuserdata("","","nozero"))!=1)
			if (strlen(axisinfo("","left"))>0)			//1.43I check that the left axis exists
				modifygraph zero(left)=gdef_zline
			endif
			if (strlen(stringbykey("SETAXISFLAGS",axisinfo("","left")))>0)
				setaxis /a/e=(gdef_scale) left
			endif
		endif
//	endif

	if (!dontColorTraces)  // colorize things
//		if (str2num(getuserdata("","","nocol"))!=1)
			kbcolorizetraces(.5,1,0)	// Igor 6.03 change
	endif
			wave /z/t col_names=root:frag:col_names
//			wavlist=tracenamelist("",";",1)
			if (waveexists(col_names))
				wave col_r=root:frag:col_r
				wave col_g=root:frag:col_g
				wave col_b=root:frag:col_b
				num=itemsinlist(doList)
				for (idex=0;idex<num;idex+=1)
					listitem=upperstr(stringfromlist(idex,doList))
					listitem_lesstodoname = ReplaceString(sq_toDoWvNm, listitem, "")
					jdex=sq_findstr(col_names,listitem_lesstodoname,2-(0&1))
					if (jdex>-1)
						modifygraph rgb($listitem)=(col_r[jdex],col_g[jdex],col_b[jdex])
					endif
				endfor
			endif
			//& Special cases
			allMSWaveStr=getuserdata("","","allMSWaveStr")
			num = ItemsInList(allMSWaveStr)
			for (idex=0;idex<num;idex+=1)
				itemStr = stringfromlist(idex, allMSWaveStr)
				wave allWave = $itemStr
				ModifyGraph/Z rgb($nameofwave(allWave))=(65280,65280,0)		// make  all waves yellow
			endfor
			errMSWaveStr=getuserdata("","","errMSWaveStr")
			if (strlen(errMSWaveStr)>0)
				wave errWave = $errMSWaveStr
				ModifyGraph/Z rgb($nameofwave(errWave))=(65280,65280,065280)		// make error waves white
			endif
			
//		endif

// 1.60Y
//		barflag=str2num(getuserdata("","","barflag"))
//		if (!numtype(barflag))
//			if (gdef_cbut  && !barflag)
////				sq_addCntrl_RunsFromCsrs()
//				setwindow $"",userdata(barflag)="1"
//			elseif (!gdef_cbut && barflag)
//				KillControl ams_butt_RunsFromCsrNew
//				KillControl ams_butt_RunsFromCsrAppend
//				ControlBar 0
//				setwindow $"",userdata(barflag)="0"			
//			endif
//		endif
	
		ModifyGraph gaps=gdef_gaps

//	endif

	if (gdef_leg)
		Legend	
	endif

	if (gdef_cursors)
		Showinfo
	else
		Hideinfo
	endif

End


// added in 1.47
Function sq_MSAvgGr_25butt(ctrlName) : ButtonControl
	String ctrlName

	variable leftExists, leftMin, leftMax, rightExists, rightMin, rightMax, factor
	string winStr = winName(0,1)
	
	GetAxis/Q/W=$winStr left
	leftExists = !V_flag
	leftMin = V_min
	leftMax = V_max
	GetAxis/Q/W=$winStr right
	rightExists = !V_flag
	rightMin = V_min
	rightMax = V_max

	factor = selectNumber(stringmatch(ctrlName, "expand25"), 0.75, 1.25)

	if (leftExists)
		SetAxis/W=$winStr left leftmin*factor, leftmax*factor
	endif
	if (rightExists)
		SetAxis/W=$winStr right rightmin*factor, rightmax*factor
	endif
	
End


///////////////////////////////////////////////////////////////////////////////
///////////////////  CORRECTIONS //////////////////////////////////
///////////////////////////////////////////////////////////////////////////////

//> Buttons on Corrections Tab
Function sq_butt_corrections( ctrl ) : ButtonControl
	string ctrl
	
	sq_GetIndexNotDoneYet()
	
	svar pre_corr=root:panel:precorr
	svar post_corr=root:panel:postcorr
		
	nvar airbeam_corr_ck=root:panel:airbeam_corr_ck 
	nvar airbeam_plot_ck=root:panel:airbeam_plot_ck
	nvar airbeam_autoSet_ck=root:panel:airbeam_autoSet_ck		//1.46A
	svar airbeam_refRuns_sv=root:panel:airbeam_refRuns_sv		//1.46A

	nvar error_ms_ck=root:panel:error_ms_ck		//1.38
	nvar error_ptof_ck=root:panel:error_ptof_ck
	nvar error_sigma=root:panel:error_sigma
	nvar error_noise=root:panel:error_noise

	nvar cor4_flowRateFind_ck=root:panel:cor4_flowRateFind_ck
	nvar cor5_IE2ABFind_ck=root:panel:cor5_IE2ABFind_ck
//	nvar cor6_ThresholdCorrFind_ck=root:panel:cor6_ThresholdCorrFind_ck
	wave squirrel_index=root:index:squirrel_index

	nvar cor3_dcmarker1=root:panel:cor3_dcmarker1
	nvar cor3_dcmarker2=root:panel:cor3_dcMarker2
	nvar cor3_dcmarker3=root:panel:cor3_dcmarker3
	nvar cor3_dcmarker4=root:panel:cor3_dcmarker4
	nvar ptof_dcUseBinNumUnits = root:panel:ptof_dcUseBinNumUnits
	svar cor3_region1channels=root:panel:cor3_region1channels
	svar cor3_region2channels=root:panel:cor3_region2channels
	nvar cor3_overrideDC=root:panel:cor3_overrideDC

	nvar cor3_recalcD=root:panel:cor3_recalcD		// diameter

	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$("root:"+todoStr)

	string savedDataFolder, str1="", param=""		//1.52O
	variable checkp, tempVar

	if ( !waveexists(todo)  &&numpnts(todo)>0 )
		Abort "Todo wave not found or is of zero length - Aborting from sq_butt_corrections"
	endif		
	
	if(cor3_overrideDC)	// 1.42E
		if  (FindDimlabel(squirrel_index,2,"ptof_stick_p")< 0 )			//1.12N  now not true for ePToF but we will let it go
			Abort "The PToF data must be pre-processed before corrections to the DC markers can be applied.- Aborting from sq_butt_corrections"
	  	elseif(sq_checkTodoForPToF(todo)==0)
			Abort "There are no runs with PToF data in the current todo wave. - Aborting from sq_butt_corrections"
	 	endif
	 endif

	// another sanity check added in 1.46A
	if ( airbeam_corr_ck && airbeam_autoSet_ck && strlen(airbeam_refRuns_sv)==0)
		Abort "No airbeam reference runs were identified.   - Aborting from sq_butt_corrections"
	endif

	if (error_ptof_ck)		//1.46E
		Abort "Cannot calculate PToF errors at this time.   - Aborting from sq_butt_corrections"
	endif

	wave /z corr_fact= root:diagnostics:corr_fact		//1.59
	if (!waveexists(corr_fact) && error_ms_ck && !airbeam_corr_ck)
		DoAlert 1, "You are attempting to generate UMR errors, but the airbeam correction has not been calculated.  If you later generate an AB correction wave, these errors will be incorrect.  Proceed?"
		if (V_flag==2)
			return 0
		endif
	endif	
		
	savedDataFolder = GetDataFolder(1)		//^ 1.35
	SetDataFolder root:						//^ 1.35

	sq_journal_new("Corrections")
	sq_journal_add("ToDo:"+todostr)
	
	execute/q/z pre_corr
	if(v_flag!=0)
		Print "// ALERT!! User defined PRE-correction function not found or returned error "+num2str(V_flag)+"! Carrying out remaining corrections."
	else
		sq_journal_add("pre_corr:"+pre_corr)
	endif

	print "//** The Do Corrections processing on the todo wave "+todoStr+" began at", time()+" using Squirrel version "+SQVERSION+"with the following checked: "
	print "//     Do Flow Rate - Find new flow rate errors=", cor4_flowRateFind_ck
	print "//     Do Airbeam - Perform Correction=", airbeam_corr_ck
	print "//     Do PToF - Recalculate dVa=", cor3_recalcD, "; Override DC Markers=", cor3_overrideDC
	if (cor3_overrideDC)		//1.41B
		print "//     The DC Marker settings were: Region 1 start-stop "+num2str(cor3_dcmarker1)+ "-"+num2str(cor3_dcmarker2)+", Region 2 start-stop"+num2str(cor3_dcmarker3)+ "-"+num2str(cor3_dcmarker4)+"; the PToF use Bin # checkbox:"+num2str(ptof_dcUseBinNumUnits)
		print "//     The DC Marker settings were: Region 1 only" +cor3_region1channels+", Region 2 only" +cor3_region2channels
	endif 
	print "//     Do Errors - Find MS errors=", error_ms_ck, "; Find PToF errors=", error_PToF_ck
	print "//     Do IE Cals - Find IE to AB correction=", cor5_IE2ABFind_ck
//	print "//     Do Threshold correction=", cor6_ThresholdCorrFind_ck

// moved to be the first correction to be done 1.43B	
	if (cor4_flowRateFind_ck)		//1.38
		 sq_findNewFlowRate()
	endif
	
	if ( airbeam_corr_ck )
		checkp=FindDimlabel(squirrel_index,2,"MSSDiff_p")
		if(checkp>-1)		// cleaned up in 1.44B
			nvar airbeam_curr_mz=root:panel:airbeam_curr_mz
			sq_journal_add("airbeam_corr:1;airbeam_mz:"+num2str(airbeam_curr_mz))
			sq_ms_airbeamCorr()
			wave corr_fact = root:diagnostics:corr_fact
			// We will have problems if, for example the last run did not have any raw closed spectra.  If we try to average, and the corr_fact is nan/inf, everything goes bad.
			// on the other hand, we need to be careful of blacklisted items.  -- Allison's prob.			  
//			corr_fact	= selectnumber(numtype(corr_fact[p])==0, nan, corr_fact[p])// nan out values whereby we may have infs/nans due to no closed spectra at the very beginning or end 
//			sq_interpolateWaveSameMode(corr_fact, corr_fact)
			if ( airbeam_plot_ck )
				sq_plot_corr()
			endif
		else
			print "//	MSSDiff_p not found, Airbeam correction not calculated.  Perhaps you need to preprocess?"
		endif
	endif
	
	if(cor3_recalcD==1)
		sq_journal_add("cor3_recalcD:1")
		sq_recalcDA()
	endif
	
	//& Override DC markers
	if (cor3_overrideDC)		//1.42E
		 tempVar =sq_verifyTodoForPToF(todo)		//1.43I, bug fix in 1.44B
		if (tempVar==0)
			print "// The todo wave did not have any PToF runs so no DC marker corrections were applied. "
		elseif(tempVar<0)
			wave allPToF = root:allPToF
			sq_create_todo(NameofWave(todo)+" and allPToF","todo_temp")
			wave todo=root:todo_temp				
		endif
	
		if (cor3_dcmarker1==0 && cor3_dcmarker2==0 && cor3_dcmarker3==0 && cor3_dcmarker4==0 && ptof_dcUseBinNumUnits==1)  //
			cor3_dcmarker1 = 5
			cor3_dcmarker2 = 15
			cor3_dcmarker3 = -15
			cor3_dcmarker4 = -5		/// defaults				
		endif
		// add a check that dc marker values make sense
		
		param="dc1:"+num2str(cor3_dcmarker1)+";dc2:"+num2str(cor3_dcmarker2)+";dc3:"+num2str(cor3_dcmarker3)+";dc4:"+num2str(cor3_dcmarker4)+";"
		param+="region1only:"+cor3_region1channels+";region2only:"+cor3_region2channels+";"
		param+="text:PToF;hz_op:1;hdf_op:1;duty_op:1;dest:PToF_stick_p;applyDC:1;"	
			
		// a big section added in 1.153N
		nvar ams_sqprog = root:panel:ams_sqprog
		wave rn_series = root:index:rn_series
		wave/z ePToF_enabled = root:diagnostics:ePToF_enabled
		wave/z ePToF_oversampling = root:diagnostics:ePToF_oversampling
		string PToFGrpList, param_ePToF
		variable ePToF_exists, pos, isEPToF, firstRunPos, num, idex, ePToF_flag, ePToF_OS
		PToFGrpList = WaveList("allPToFGrp*",";","") + WaveList("allePToFGrp*",";","")
		PToFGrpList = SortList(PToFGrpList) 
		num = itemsInList(PToFGrpList)
		for (idex=0;idex<num;idex+=1)		//for each PToF group
			ams_sqprog=100*( idex/num)		//1.52O5

			wave PToFGroup = $"root:"+stringfromList(idex, PToFGrpList)
			sq_create_todo(todoStr+" and "+stringfromList(idex, PToFGrpList),"tempPToFTodo")	//1.50H fix  //1.51N fix  needed " and " instead of "and "
			wave preproc = root:tempPToFTodo
			
			if (numpnts(preproc) >0)			// success, the todo wave is a subset of one of the PToF group todo waves							
				ePToF_exists = (WaveExists(ePToF_oversampling) && (WaveExists(ePToF_enabled)	) && Wavemin(ePToF_enabled)!=0	&& Wavemax(ePToF_enabled)!=0)  //1.53M
				pos = sq_findRun(rn_series,todo[0])
				isEPToF = ePToF_exists && ePToF_oversampling[pos]>0 && abs(ePToF_enabled[pos])>0   		//1.55B
				firstRunPos = sq_findRun(rn_series,preproc[0])		//1.53M
				if (ePToF_exists && ePToF_oversampling[firstRunPos]>0 && abs(ePToF_enabled[firstRunPos])>0)		    		//1.55B			
					ePToF_flag = 1
					ePToF_OS = ePToF_oversampling[firstRunPos]
				else
					ePToF_flag = 0
					ePToF_OS = 0
				endif

				if(ePToF_flag && ePToF_OS>0)
					param_ePToF="ePToF_flag:"+num2str(ePToF_flag)+";ePToF_OS:" + num2str(ePToF_OS)+";"	// consider ePToF
				else
					param_ePToF=""
				endif

				squirrel_fetch(preproc,sq_insert_Matrix,param+param_ePToF,"PToF_stick")	//^important bug in 1.37C//		sq_journal_add("cor3_overrideDC:1;Secondary(ptof_stick_p):1;"+param)
		//		squirrel_fetch(todo,SQ_DCMarkers,param+"dest:ptof_stick_p;","ptof_stick_p")
			endif
		endfor
		killwaves/z todo_temp, preproc
		wave todo=$("root:"+todoStr)
	endif
	
	if (error_ms_ck)
		wave/wave TimeWaves=sq_GetModifiedTimes()
		wave TimeMSOpen = TimeWaves[0]
		wave TimeMSClosed = TimeWaves[1]
		wave TimePToF = TimeWaves[2]
		if (!(waveMax(TimeMSOpen)>=0))		//1.55K
			sq_createTableTimeWaves()
			abort "The waves in the diagnostic folder root:diagnostics:TimeAcquiringMSOpenInRun or root:diagnostics:TimeMSOpen are problematic.  Aborting from sq_butt_corrections"
		endif
		if (!(waveMax(TimeMSClosed)>=0))
			sq_createTableTimeWaves()
			abort "The waves in the diagnostic folder root:diagnostics:TimeAcquiringMSClosedInRun or root:diagnostics:TimeMSClosed are problematic.  Aborting from sq_butt_corrections"
		endif
//		WaveStats/q/m=1 timeMSClosed	// earlier versions of the daq saved these values differently
//		if (V_max==0 || V_numNans==numpnts(timeMSClosed))			// all zeros (older daq) or something else is fishy	
//			sq_createTableTimeWaves()
//			abort " Could not calculate errors because there are bad values in the sample time wave"+GetWavesDataFolder(timeMSClosed, 2)
//		endif
//		if (V_min<=0)		// we did not save some closed spectra for some runs
//			duplicate/o timeMSClosed root:diagnostics:timeMSClosed_logged
//			// there is no consensus as to how to assign a time stamp to the closed spectra when none is taken	//1.38E
//			timeMSClosed = selectnumber(timeMSClosed[p]==0, timeMSClosed[p], nan)		// make 0s nans
//			sq_interpolateWave(timeMSClosed, timeMSClosed,1)		//JDA change, 1.47G, sq_interpolateWave has added parameter 
//		endif

		nvar/z PutInMemory = root:panel:PutInMemory// bug in 1.49A, fixed in 1.49B1  //1.47E
		variable PutInMemory_temp = (NVar_exists(PutInMemory) == 0) ? 0 : 1		// 1.47E  If the variable exists, it should always be 0, unless we implement an easy way for users to go back and forth
	//	Default behavior is to put MSSDiff_p in memory.

	// deal with unit mass squirrel baseline sticks  // added  in 1.50M
		wave/z allMS = root:allMS 					// in case we have runs with only PToF
		if (WaveExists(allMS))				//1.52O
			str1= "and allMS"
			sq_create_todo(todoStr+" and allMS","TempTodoMS")
			wave todo = root:TempTodoMS
		endif

		sq_preproc_check("MSSOpenBaseL_p","MSSOpenBaseL_todoTemp",todo)
		wave/z MSSOpenBaseL_todoTemp = root:MSSOpenBaseL_todoTemp
		sq_preproc_check("MSSClosedBaseL_p","MSSClosedBaseL_todoTemp",todo)
		wave/z MSSClosedBaseL_todoTemp = root:MSSClosedBaseL_todoTemp	
		sq_preproc_check("MSSDiffBaseL_p","MSSDiffBaseL_todoTemp",todo)
		wave/z MSSDiffBaseL_todoTemp = root:MSSDiffBaseL_todoTemp	
	
		if ( numpnts(MSSOpenBaseL_todoTemp)!=0 || numpnts(MSSOpenBaseL_todoTemp)!=0 )  
			abort "You must recalculate your unit resolution sticks with the baseline option checked in order to calculate baselines with errors. aborting from sq_butt_corrections"
		endif
	
		param="dest0:MSSClosed_p_err;dest1:MSSDiff_p_err;"
		param+="sigma:"+num2str(error_sigma)+";noise:"+num2str(error_noise)+";"
		param+="PutInMemory:"+num2str(PutInMemory_temp)+";"		//1.49B1
//		param+="samptime0:root:diagnostics:timeMSClosed;samptime1:root:diagnostics:timeMSOpen;"
//		wave/z TimeMSOpen=root:diagnostics:TimeAcquiringMSOpenInRun	// root:diagnostics:TimeMSOpen	//1.53N
//		if (!WaveExists(TimeMSOpen) || waveMax(TimeMSOpen)<0)
//			wave/z TimeMSOpen=root:diagnostics:TimeMSOpen		//1.53N
//			if (!WaveExists(TimeMSOpen) || ! (waveMax(TimeMSOpen) >=0))		//1.55K
//				abort "The waves in the diagnostic folder root:diagnostics:TimeAcquiringMSOpenInRun or root:diagnostics:TimeMSOpen are problematic.  Aborting from sq_MS_concentration"
//			endif
//		endif
//		wave/z TimeMSClosed=root:diagnostics:TimeAcquiringMSClosedInRun  // root:diagnostics:TimeMSClosed	//1.53N
//		if (!WaveExists(TimeMSClosed)  || waveMax(TimeMSClosed)<0)
//			wave/z TimeMSClosed=root:diagnostics:TimeMSClosed		//1.53N
//			if (!WaveExists(TimeMSClosed) || ! (waveMax(TimeMSClosed) >=0))		//1.55K
//				abort "The waves in the diagnostic folder root:diagnostics:TimeAcquiringMSClosedInRun or root:diagnostics:TimeMSClosed are problematic.  Aborting from sq_MS_concentration"
//			endif
//		endif
		param+="samptimeClosed:"+ReplaceString(":", GetWavesDataFolder(timeMSClosed,2),"/")+";"		//1.58E
		param+="samptimeOpen:"+ReplaceString(":", GetWavesDataFolder(timeMSOpen,2),"/")+";"  	//1.58E
		sq_checkSamplingTimeVals(todo)	//1.55F
		
//		squirrel_fetch(todo,sq_err_calc,param,"MSSOpen_p;MSSClosed_p;MSSOpenBaseL_p;MSSClosedBaseL_p")	// slightly changed in 1.50M to save open errors  1.52O ERROR!  order of parameters is wrong!!
		sq_makeRawSpectraGroups()		//1.51F creates todo waves raw spectraXX where XX is the number of points in the raw spectra
	// We will want to do our squirrel fetches with todo waves that have the same number of points in the raw spectra to avoid
	// having to redimension things within a fetch (i.e. raw spectra points of 80,000 and 40,000)  
		string RawSpectraTodoList = waveList("RawSpectra*", ";", "")
		variable numRawList = itemsInList(RawSpectraTodoList)
		funcref squirrel_proto sq_f=sq_err_calc

		sq_iterateOverList(todo, RawSpectraTodoList, itemsINLIst(RawSpectraTodoList), param, "MSSClosed_p;MSSDiff_p;MSSOpenBaseL_p;MSSClosedBaseL_p", sq_f)
		sq_KillWavesInList(RawSpectraTodoList)	

// 		squirrel_fetch(todo,sq_err_calc,param,"MSSClosed_p;MSSDiff_p;MSSOpenBaseL_p;MSSClosedBaseL_p")	// slightly changed in 1.50M to save open errors

		if (WaveExists(allMS))
			wave/z todo=$("root:"+todoStr)
		endif

		killwaves/z root:MSSOpenBaseL_todoTemp, root:MSSClosedBaseL_todoTemp, root:MSSDiffBaseL_todoTemp, root:TempTodoMS,root:TempTodo
		killwaves/z Timewaves
		
	endif
	
	if (error_PToF_ck)
		wave/z sampletime = root:diagnostics:TimePTOFSec
		if (!WaveExists(sampletime))
			abort " Could not calculate errors because the wave root:diagnostics:TimePTOFSec doesn't exist - press update diagnostics."
		endif
		WaveStats/q/m=1 sampletime
		if (V_max==0 || V_numNans>0)		
			abort " Could not calculate errors because there are bad values in the sample time wave root:diagnostics:TimePTOFSec"
		endif
		param="dest0:PToF_stick_p_err;"
		param+="sigma:"+num2str(error_sigma)+";noise:"+num2str(error_noise)+";"
		param+="samptime0:root:diagnostics:TimePTOFSec"

		sq_checkSamplingTimeVals(todo)	//1.55F
		squirrel_fetch(todo,sq_err_calc,param,"PToF_stick_p;")
	endif

	if (cor5_IE2ABFind_ck)			//1.38
		sq_findIE2ABratio()
	endif
	
	execute/q/z post_corr
	if(v_flag!=0)
		Print "// ALERT! User defined POST-correction function not found or returned error "+num2str(V_flag)+"! Other corrections applied."
	else
		sq_journal_add("Post_corr:"+post_corr)
	endif

	print "//** The Do Corrections processing ended at", time()
	
	sq_journal_end()

	SetDataFolder savedDataFolder	

End


//^ When recalcing sticks, if Use new mz fitting parameters was checked, you need to make sure that the fitting waves exist and
// are non-nan. This returns a string of modified wave name/declarations which should be used as 'input' to the param string for the 
// squirrel fetch
Function/S sq_checkMzFittingWaves(todoWave, useNew)			// added a todo wave parameter in 1.43B
	wave todoWave
	variable UseNew

	string returnstr
	
	if (useNew)
		wave/z t_series = root:index:t_series
		wave/z mzSlope=root:mzFitting:mz_FitSlope
		wave/z mzInt=root:mzFitting:mz_FitIntercept
		wave/z mzPower=root:mzFitting:mz_FitPower
		if (WaveExists(mzSlope)==0 )	//^ User requests to use new parameters, but they haven't been created yet.  Assumes that if one doesn't exist, none do.
			Abort "You must calculate new parameters using the Check m/z button - Aborting from sq_CheckMzFittingWaves"
		elseif( numpnts(t_series) != numpnts(mzPower) )		// 1.44D
			Abort "The number of points in the wave root:mzFitting:mz_FitSlope does not equal the number of points in root:index:t_series - Aborting from sq_CheckMzFittingWaves"
		else		// altered in 1.43B		// check only slope values, assume if non-nan than power and intercept are non-nan also
			make/o/n=(numpnts(mzSlope)) mzSlope_Key		
			sq_makeMaskFromTodofindRun(mzSlope_Key,todowave)	
			mzSlope_Key =mzSlope/mzSlope_Key		// we divide by zeros and 1s
			wavestats/q/m=1 mzSlope_Key
			if (V_npnts != numpnts(todoWave))  //^ waves were created but mz fitting not performed... V_avg is nan

				mzSlope_Key =mzSlope/mzSlope_Key		// we divide by zeros and 1s

				Abort  "The mz fitting parameters for "+num2str(numpnts(todoWave)-V_npnts) +" run in todowave "+NameofWave(todowave)+" have bad values!  - Aborting from sq_CheckMzFittingWaves"
			endif			
		endif
		killwaves/z mzSlope_Key
		returnStr="Slope:root:mzFitting:mz_FitSlope;Int:root:mzFitting:mz_FitIntercept;Power:root:mzFitting:mz_FitPower;"				
	else
		wave mzSlope=root:diagnostics:mzSlope
		wave mzInt=root:diagnostics:mzInt
		wave/z mzPower = root:diagnostics:mzPower
		if (WaveExists(mzPower)==0  || numpnts(mzPower) !=numpnts(mzSlope))		//1.48F fix
			make/o/n=(numpnts(mzSlope)) root:diagnostics:mzPower
			wave mzPower = root:diagnostics:mzPower
			mzPower = 0.5
		endif
		returnStr="Slope:root:diagnostics:mzSlope;Int:root:diagnostics:mzInt;Power:root:diagnostics:mzPower;"				
	endif
	
	return returnStr

End


//^ sets the airbeam wave from the mass values found in the sticks matrix
Function sq_setAB(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn 
	variable n_acorns
	
	wave source=$stringbykey("acorn_0",paramstr)   
	wave series_index=root:index:series_index
	wave airbeam = root:diagnostics:airbeam
	wave t_series = root:index:t_series

	redimension/n=(numpnts(t_series)) airbeam        // 1.48D fix //1.50 fix by JDA, was previously redimension/n=(numpnts(series_index)) airbeam	
   
	variable idex, num,mz
   
	num=numpnts(index_pos)
	mz=numberbykey("mz",paramstr)-1

//1.50C now done in sq_butt_reset_AB
//	if (acorn==0)        //^ we should have another think about how to handle things if the all to do wave is not selected.
//		redimension/n=(numpnts(t_series)) airbeam     //1.50C fix by JDA, was previously redimension/n=(numpnts(series_index)) airbeam
//		airbeam=nan       
//	endif

	string oldNote = Note(airbeam)	//1.59F
	if (strlen(oldNote)>0 && (acorn==0) && numberbykey("mz",oldNote) !=numberbykey("mz",paramstr) )
		airbeam=nan		// re-initialize it
	endif

	for (idex=0;idex<num;idex+=1)
		if(index_pos[idex]==-1)
			continue
		endif
		airbeam[series_index[index_pos[idex]]]=source[idex][mz]
	endfor
	
	Note/K airbeam, "mz:"+num2str(mz+1)		//1.59F

End


//@ function to override tof cal parameters, with the option of inputting a mask wave
//^ In 1.35 I modified to change the parameters for only the runs in the todo wave
//^ I kept the mask functionality as a hidden feature, but this should be made more clear in later versions
Function sq_recalcDA()
	string param="vg;vl;dx;b"

	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$("root:"+todoStr)
	wave rn_series=root:index:rn_series

	variable idex, kdex, numTodo,numRuns, newVal
	string paramStr
	
	numTodo = numpnts(todo)
	numRuns = numpnts(rn_series)
	
	// make a wave that indicates whether or not a run is in the selected todo wave.
	make/o/n=(numRuns) myTempRunMask = 0
	for(idex=0;idex<numToDo;idex+=1)
		kdex = sq_findRun(rn_series,todo[idex])
		if (kdex>=0)
			myTempRunMask[kdex] = 1
		endif
	endfor
	
	for(idex=0;idex<4;idex+=1)
		paramStr = stringfromlist(idex,param)
		svar str=$("root:panel:cor3_"+paramStr)		//^ string variable in panel
		wave/z wav=$("root:diagnostics:ptof_"+paramStr)
		wave/z wav_logged=$("root:diagnostics:ptof_"+paramStr+"_logged")
		wave/z wav_userDefined=$("root:"+paramStr)		// may not exist - hidden feature
		newVal = str2num(str)
		//^ attempt at being backwards compatible
		if (WaveExists(wav) ==0 &&  WaveExists(wav_logged) ==1 )		//^ 1.35
			duplicate wav_logged $("root:diagnostics:ptof_"+paramStr)
			wave wav=$("root:diagnostics:ptof_"+paramStr)			// 1.41 bug
		endif
		if(waveexists(wav_userDefined))
			if(numpnts(wav_userDefined)==numpnts(wav) )
				if (WaveExists(wav_logged)==0)		//^ 1.35
					duplicate wav $("root:diagnostics:ptof_"+paramStr+"_logged")
           				wave/z wav=$("root:diagnostics:ptof_"+paramStr) //&		// 1.36
				endif
				wav=wav_userDefined[p]			//^ overwrites daq logged values to the mask values
			else
				Print "// The number of points in the wave root:"+str+" did not match the number of points in the wave root:diagnostics:ptof_"+str+".  so these values were not changed."
			endif
		elseif(newVal>0)
			if (WaveExists(wav_logged)==0)		//^ 1.35
				duplicate wav $("root:diagnostics:ptof_"+paramStr+"_logged")
			endif
			wav = myTempRunMask[p]==1? newVal : wav[p] 		//^ overwrites daq logged values to the mask values
		endif
	endfor

	killwaves/z myTempRunMask

End


//@ button to recalculate AB correction only (no sticks etc)
Function sq_butt_reset_AB(ControlName) : Buttoncontrol
	string controlname

	nvar airbeam_curr_mz =  root:panel:airbeam_curr_mz
	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$("root:"+todoStr)
	sq_journal_new("Reset_AB")
	sq_journal_add_var("root:panel:sq_toDoWvNm")
	sq_journal_add_var("root:panel:airbeam_curr_mz")
	wave airbeam_logged = root:diagnostics:airbeam_logged

	//1.50C  setting the airbeam to nan was originally part of the sq_setAB function.
	wave/z airbeam = root:diagnostics:airbeam
	if (!WaveExists(airbeam))// first time 
		make/o/n=(numpnts(airbeam_logged)) root:diagnostics:airbeam
		wave airbeam = root:diagnostics:airbeam
	endif
	airbeam=nan
	
	squirrel_fetch(todo, sq_setAB,"mz:"+num2str(airbeam_curr_mz),"MSSDiff_p")
//	sq_splitdiags("airbeam;")		1.41C change
	sq_journal_end()

End


//^ makes  and calculates IonEff_ref, corr_fact,  corr_fact_flow
//& Updated for multiple detectors
//& Will need further expansion for time dependent user reference values
//^ Untouched from James' 1.34 version, but will need consolidation after James gets back
Function sq_ms_airbeamCorr()

	svar airbeam_refRuns_sv=root:panel:airbeam_refRuns_sv
	nvar airbeam_autoSet_ck=root:panel:airbeam_autoSet_ck
//	nvar airbeam_ref_ionEff_sv=root:panel:airbeam_ref_ionEff_sv		//1.52H
//	nvar airbeam_ref_MSab_sv=root:panel:airbeam_ref_MSab_sv
//	nvar airbeam_ref_ToFab_sv=root:panel:airbeam_ref_ToFab_sv
//	nvar airbeam_ref_flow_sv=root:panel:airbeam_ref_flow_sv
//	nvar ref_singleion_sv=root:panel:ref_singleion_sv
	nvar airbeam_ref_flowOffset_sv=root:panel:airbeam_ref_flowOffset_sv
	nvar airbeam_corrFlow_ck=root:panel:airbeam_corrFlow_ck
	nvar airbeam_smooth_ms=root:panel:airbeam_smooth_ms
	nvar airbeam_smooth_flow=root:panel:airbeam_smooth_flow

	wave rn_series=root:index:rn_series	
	wave flowrate=root:diagnostics:flowrate
	wave t_series= root:index:t_series			
	
	//^ These were created in the diagnostics section, sq_makeToDoAllVW()
	nvar VWSwitching =  root:diagnostics:VWSwitching
	wave/z TofTypeVKey = root:diagnostics:TofTypeVKey
	wave/z TofTypeWKey = root:diagnostics:TofTypeWKey

	//^ settings from panel
	wave airbeamCorrToFTypeValue = root:panel:airbeamCorrToFTypeValue
	nvar airbeam_corrToFTypeVar = root:panel:airbeam_corrToFTypeVar

	wave airbeam=root:diagnostics:airbeam					//the wave from the MSDiff_p mass values
	wave airbeam_ptof=root:diagnostics:airbeam_ptof

	wave /z ionizationType = root:diagnostics:ionizationType
	svar/z detectorsused=root:diagnostics:detectorsused
	wave/z detector_num=root:diagnostics:detector_num

	svar sq_toDoList = root:panel:sq_toDoList

	variable IonizationTypeExists, numDetectorsUsed,interpolateFlag
	variable start_r, end_r, start_n,end_n,isW,jdex, loc, numRuns, isTodo=0
	string menuType

	numRuns = numpnts(rn_series)
	IonizationTypeExists = waveexists(ionizationType)
	numDetectorsUsed=WaveExists(detector_num) ? max(itemsinlist(detectorsused),1) : 1

	if (airbeam_autoSet_ck && strlen(airbeam_refRuns_sv)==0)
		Abort "No airbeam reference runs were identified.   - Aborting from sq_ms_airbeamCorr"
	endif

	killwaves/z root:ABtodoTemp		//1.59A
	
//	Wave blacklist = root:blacklist
//	Wave/z allFastClosed = root:allFastClosed
//	Wave/z allMS = root:allMS
//	WaveStats/q airbeam
//	if (WaveExists(allFastClosed) && (V_numNans> numpnts(blacklist)+numpnts(allFastClosed)) )  // 1.59F not fullproof
//		Abort "It appears as if you haven't preprocessed all your MS data yet.  Please do this before you generate an MS airbeam correction wave."
//	elseif(WaveExists(allMS) && (V_numNans> numpnts(allMS)+numpnts(blacklist)))			// 1.59F not fullproof
//		Abort "It appears as if you haven't preprocessed all your MS data yet.  Please do this before you generate an MS airbeam correction wave."	
//	elseif (V_numNans>numpnts(blacklist))			// 1.59F not fullproof
//		Abort "It appears as if you haven't preprocessed all your MS data yet.  Please do this before you generate an MS airbeam correction wave."
//	endif

//	make/free/o/n=(numRuns) blacklistMask_temp
//	sq_makeBlacklistMask(blacklistMask_temp)	//^ a wave of ones and nans

	// bug fix and more stringent sanity check in 1.46A 
	if (!airbeam_autoSet_ck)	// user enters their own values, make sure that they are > 0
		for (jdex=0;jdex<numDetectorsUsed;jdex+=1)
			if (airbeamCorrToFTypeValue[0][jdex]==0 || airbeamCorrToFTypeValue[1][jdex]==0 || airbeamCorrToFTypeValue[4][jdex]==0 )
				abort "In performing the airbeam correction the user deselected autoset but entered a zero value for the "+num2str(jdex)+ " type - aborting from  sq_ms_airbeamCorr"
			endif		// 1.52 added sanity checks if user entered nans
			if (numtype(airbeamCorrToFTypeValue[0][jdex])!=0 || numtype(airbeamCorrToFTypeValue[1][jdex]!=0) || numtype(airbeamCorrToFTypeValue[4][jdex])!=0 )
				abort "In performing the airbeam correction the user deselected autoset but entered a nan value for the "+num2str(jdex)+ " type - aborting from  sq_ms_airbeamCorr"
			endif
			if (numtype(airbeamCorrToFTypeValue[0][jdex])!=0 ||  airbeamCorrToFTypeValue[0][jdex]<=0  )		// check ioneff row
				DoAlert 2,  "For the AB correction the user has deselected auto-set, but ion eff. entries for different modes (columns) are not good.   Continue? (only adv. users should continue)"
				if (V_flag==1)
					Abort "The user chose to abort"
				endif
			endif
			if (numtype(airbeamCorrToFTypeValue[1][jdex])!=0 ||  airbeamCorrToFTypeValue[1][jdex]<=0  )		// check ioneff row
				DoAlert 2, "For the AB correction the user has deselected auto-set, but airbeam_Hz entries for different modes (columns) are not good.  Continue? (only adv. users should continue)"			
				if (V_flag==1)
					Abort "The user chose to abort"
				endif
			endif
		endfor
	else	// use AB ref runs
		isTodo = WhichListItem(lowerStr(airbeam_refRuns_sv), lowerStr(sq_toDoList))>=0			//1.58c
		if (!isTodo)
			if (itemsinlist(airbeam_refRuns_sv,"-")==2)
				start_r=str2num(stringfromlist(0,airbeam_refRuns_sv,"-"))
				start_r=max(start_r,WaveMin(rn_series))		// make sure the run number exists within rn_series
				end_r=str2num(stringfromlist(1,airbeam_refRuns_sv,"-"))
				end_r=min(end_r,WaveMax(rn_series))
			elseif (itemsinlist(airbeam_refRuns_sv,"-")==1)
				start_r=str2num(airbeam_refRuns_sv)
				FindValue/z/I=(start_r) root:all
				if (V_Value<0)
					abort "The AB reference run you chose must exist in the all todo wave - aborting from sq_ms_airbeamCorr"
				endif		
			endif
			
			sq_create_todo(airbeam_refRuns_sv+" and all","ABtodoTemp")
			wave ABtodoTemp
		else
			wave ABtodoTemp = $"root:"+airbeam_refRuns_sv
		endif
		
		if (numpnts(ABtodoTemp) == 0)
			abort "The AB ref run entry '"+airbeam_refRuns_sv+"' results in a todo wave of zero length.  Aborting from sq_ms_airbeamCorr"  //1.59D
		endif

//		make mask wave for this AB ref todo
		make/free/o/n=(numRuns) maskABtodoTemp
		sq_makeMaskFromTodofindRun(maskABtodoTemp,ABtodoTemp)
		if (IonizationTypeExists==1)		// we have multiple ionization schemes, kinda rare
			for (jdex=0;jdex<numDetectorsUsed;jdex+=1)
				make/o/free/n=(numruns) tempWave = maskABtodoTemp*(detector_num[p]==jdex)
				Wavestats/q/m=1 tempWave
				if ( !(V_sum>0) )
					abort "The reference runs you chose, "+airbeam_refRuns_sv+" must have all detector types - aborting from sq_ms_airbeamCorr"
				endif		
			endfor
		endif
		
		if (VWSwitching)
			make/o/free/n=(numruns) tempWave =maskABtodoTemp*TofTypeVKey
			Wavestats/q/m=1 tempWave
			if ( !(V_sum>0))
				abort "The AB reference todo wave you chose must have V mode runs - aborting from sq_ms_airbeamCorr"
			endif		
			make/o/free/n=(numruns) tempWave = maskABtodoTemp*TofTypeWKey
			Wavestats/q/m=1 tempWave
			if ( !(V_sum>0) )
				abort "The AB reference todo wave you chose must have W mode runs - aborting from sq_ms_airbeamCorr"
			endif		
		endif
	endif

	sq_journal_add_var("root:panel:airbeam_refRuns_sv")
	sq_journal_add_var("root:panel:airbeam_autoSet_ck")
//	sq_journal_add_var("root:panel:airbeam_ref_ionEff_sv")
//	sq_journal_add_var("root:panel:airbeam_ref_MSab_sv")
//	sq_journal_add_var("root:panel:airbeam_ref_ToFab_sv")
//	sq_journal_add_var("root:panel:airbeam_ref_flow_sv")
	sq_journal_add_var("root:panel:airbeam_ref_flowOffset_sv")
	sq_journal_add_var("root:panel:airbeam_corrFlow_ck")
	sq_journal_add_var("root:panel:airbeam_smooth_ms")
	sq_journal_add_var("root:panel:airbeam_smooth_flow")	
	sq_journal_add_var("root:panel:airbeam_corrToFTypeVar")

	wave /z ion_wave=root:diagnostics:ionSingleStr
	if (!waveexists(ion_wave) || numpnts(ion_wave)==0)
		wave ion_wave=root:diagnostics:ionSingleStr_logged
	endif
	
	wave/z ionEff_logged=root:diagnostics:ionEff_logged
	if (!WaveExists(ionEff_logged))
		duplicate/o root:diagnostics:ionEff root:diagnostics:ionEff_logged
	endif
	wave/z airbeam_logged=root:diagnostics:airbeam_logged		// the wave from the parval
	if (!WaveExists(airbeam_logged))
		duplicate/o root:diagnostics:airbeam root:diagnostics:airbeam_logged
	endif
	
	// 1.51M addition for fast mode and runs with PToF only data
	interpolateFlag = 0
	make/free/o/n=(numRuns) tempNanKey=1
	wave/z allMS = root:allMS
	if (WaveExists(allMS))		// we want to nan and then interpolate between runs with only PToF
		interpolateFlag=1
		sq_makeMaskFromTodofindRun(tempNanKey,allMS)
	endif
	wave/z allfastClosed = root:allfastClosed
	if (WaveExists(allfastClosed))		// we want to nan and then interpolate between allFastOpen
		if (interpolateFlag)			// we have an allMS
			make/free/o/n=(numRuns) tempNanKeyFast
			sq_makeMaskFromTodofindRun(tempNanKeyFast,allfastClosed,oppositeFlag=1)
			tempNanKey*=tempNanKeyFast	
		else		// we don't have an allMS
			interpolateFlag=1	
			sq_makeMaskFromTodofindRun(tempNanKey,allfastClosed,oppositeFlag=1)
		endif
	endif

	make/o/n=(numRuns) root:diagnostics:ionEff, root:diagnostics:corr_fact
	wave ionEff=root:diagnostics:ionEff
	wave corr_fact=root:diagnostics:corr_fact
	
	FastOp ionEff = ionEff_logged		// 1.42E precaution for the case where the user entered bad AB ref runs.
	FastOp corr_fact = (nan)
		
	make/o/free/n=(numruns) tempWave, airbeam_temp, NotBlacklisted												
	sq_makeMaskFromTodofindRun(NotBlacklisted,root:all)
	
	if (airbeam_autoSet_ck)		// find the averages ourselves
				
//		make/o/free/n=(numruns) ABtodoMask/// only needed for when we find the averages ourselves
//		sq_makeMaskFromTodofindRun(ABtodoMask,ABtodoTemp)

		if (IonizationTypeExists==1)		// we have multiple ionization schemes, kinda rare
			for (jdex=0;jdex<numDetectorsUsed;jdex+=1)
				tempWave = maskABtodoTemp*(detector_num[p]==jdex)
				airbeamCorrToFTypeValue[0][jdex]=sq_FindAvgUseMaskWave(ionEff_logged, tempWave)
				airbeamCorrToFTypeValue[1][jdex]=sq_FindAvgUseMaskWave(airbeam, tempWave)
				airbeamCorrToFTypeValue[2][jdex]=sq_FindAvgUseMaskWave(airbeam_ptof, tempWave)
				airbeamCorrToFTypeValue[3][jdex]=sq_FindAvgUseMaskWave(ion_wave, tempWave) 			
				airbeamCorrToFTypeValue[4][jdex]=sq_FindAvgUseMaskWave(flowrate, tempWave) 			
			endfor
		endif
		if (VWSwitching)
			tempWave = maskABtodoTemp*TofTypeVKey
			airbeamCorrToFTypeValue[0][0]=sq_FindAvgUseMaskWave(ionEff_logged, tempWave)
			airbeamCorrToFTypeValue[1][0]=sq_FindAvgUseMaskWave(airbeam, tempWave)
			airbeamCorrToFTypeValue[2][0]=sq_FindAvgUseMaskWave(airbeam_ptof, tempWave)
			airbeamCorrToFTypeValue[3][0]=sq_FindAvgUseMaskWave(ion_wave, tempWave)
			airbeamCorrToFTypeValue[4][0]=sq_FindAvgUseMaskWave(flowrate, tempWave)

			tempWave = maskABtodoTemp*TofTypeWKey
			airbeamCorrToFTypeValue[0][1]=sq_FindAvgUseMaskWave(ionEff_logged, tempWave)
			airbeamCorrToFTypeValue[1][1]=sq_FindAvgUseMaskWave(airbeam, tempWave)
			airbeamCorrToFTypeValue[2][1]=sq_FindAvgUseMaskWave(airbeam_ptof, tempWave)
			airbeamCorrToFTypeValue[3][1]=sq_FindAvgUseMaskWave(ion_wave, tempWave)
			airbeamCorrToFTypeValue[4][1]=sq_FindAvgUseMaskWave(flowrate, tempWave)
		else		
			airbeamCorrToFTypeValue[0][0]=sq_FindAvgUseMaskWave(ionEff_logged, maskABtodoTemp)
			airbeamCorrToFTypeValue[1][0]=sq_FindAvgUseMaskWave(airbeam, maskABtodoTemp)
			airbeamCorrToFTypeValue[2][0]=sq_FindAvgUseMaskWave(airbeam_ptof, maskABtodoTemp)
			airbeamCorrToFTypeValue[3][0]=sq_FindAvgUseMaskWave(ion_wave, maskABtodoTemp)	//^1.35 change from earlier versions - we know averages instead of finding first non-nan
			airbeamCorrToFTypeValue[4][0]=sq_FindAvgUseMaskWave(flowrate, maskABtodoTemp)	//^1.35 change from earlier versions - we know averages instead of finding first non-nan
		endif		// endif we dont have different ionization schemes
	endif

// values in the table should be filled in.	
	if (IonizationTypeExists==1)		// we have multiple ionization schemes, i.e. SP and regular AMS
		for (jdex=0;jdex<numDetectorsUsed;jdex+=1)
			tempwave = (detector_num[p]==jdex) * NotBlacklisted
			airbeam_temp = airbeam/tempwave		
			gen_InterpolateAcrossTime(t_series,airbeam_temp)			
			if (airbeam_smooth_ms > 0)	// smooth airbeams
				sq_smooth_nans( airbeam_temp, airbeam_smooth_ms )
			endif

			corr_fact= tempwave[p] ? airbeamCorrToFTypeValue[1][jdex]/airbeam_temp[p] : corr_fact[p]		
			ionEff = tempwave[p] ? airbeamCorrToFTypeValue[0][detector_num[p]] : ionEff[p]
		endfor
	endif

	if (VWSwitching)
		tempWave = TofTypeVKey*NotBlacklisted
		airbeam_temp = airbeam/tempWave		
		gen_InterpolateAcrossTime(t_series,airbeam_temp)			
		if (airbeam_smooth_ms > 0)	// smooth airbeams
			sq_smooth_nans( airbeam_temp, airbeam_smooth_ms )
		endif

		corr_fact= TofTypeVKey[p] ? airbeamCorrToFTypeValue[1][0]/airbeam_temp[p] : corr_fact[p]		
		ionEff = TofTypeVKey[p] ? airbeamCorrToFTypeValue[0][0] : ionEff[p]

		tempWave = TofTypeWKey*NotBlacklisted
		airbeam_temp = airbeam/tempWave		
		gen_InterpolateAcrossTime(t_series,airbeam_temp)			
		if (airbeam_smooth_ms > 0)	// smooth airbeams
			sq_smooth_nans( airbeam_temp, airbeam_smooth_ms )
		endif

		corr_fact= TofTypeWKey[p] ? airbeamCorrToFTypeValue[1][1]/airbeam_temp[p] : corr_fact[p]		
		ionEff = TofTypeWKey[p] ? airbeamCorrToFTypeValue[0][1] : ionEff[p]
	else		
		airbeam_temp = airbeam/NotBlacklisted		
		gen_InterpolateAcrossTime(t_series,airbeam_temp)			
		if (airbeam_smooth_ms > 0)	// smooth airbeams
			sq_smooth_nans( airbeam_temp, airbeam_smooth_ms )
		endif

		corr_fact= airbeamCorrToFTypeValue[1][0]/airbeam_temp[p]	
		ionEff =  airbeamCorrToFTypeValue[0][0]
	endif		// endif we dont have different ionization schemes
	
	Note/K ionEff		//1.38 imp for IE2AB ratio correction, we kill wave note

	// we now have average values for each mode, whether via auto set or not  
	// Now find the corr_fact wave .  This depends upon whether we smooth or not
	// do flow rate correction
	//& No need to handle the detection types seperately, as this should be constant.
	if ( airbeam_corrFlow_ck )		
		make/o/n=(numRuns)  root:diagnostics:corr_fact_flow/Wave=corr_fact_flow
		if ( airbeam_smooth_flow > 0 )
			duplicate/o flowrate root:diagnostics:flowrate_smoothed/wave = flowrate_smoothed
			flowrate_smoothed/=NotBlacklisted
			sq_smooth_nans( flowrate_smoothed, airbeam_smooth_flow )		
			corr_fact_flow=(flowrate_smoothed+airbeam_ref_flowOffset_sv)/(airbeamCorrToFTypeValue[4][0]+airbeam_ref_flowOffset_sv)
		else
			corr_fact_flow=(flowrate+airbeam_ref_flowOffset_sv)/(airbeamCorrToFTypeValue[4][0]+airbeam_ref_flowOffset_sv)
		endif

		corr_fact_flow/=NotBlacklisted
		//1.51M addition
		gen_InterpolateAcrossTime(t_series,corr_fact_flow)			
		corr_fact *= corr_fact_flow
	endif

//	killwaves/z blacklistMask_temp, keyWave_temp, airbeam_temp		// to be used and filled in later

	make/o/free/n=(dimsize(airbeamCorrToFTypeValue,1)) Avgs = airbeamCorrToFTypeValue[1][p]
	wavestats/q Avgs
	if (V_numNans>0)
		abort "There is something wrong with the MS airbeam averages found in the airbeam correction factor wave - Nans exist!" 
	endif

	killwaves/z root:ABtodoTemp		//1.60E
End


//^ Returns an average of values in wave2Avg that are only in mask wave between 2 points
//^  Accomodates mask waves that are nans and 1s or 0s and 1s
Function sq_findAvgUseMaskWave(wave2Avg, MaskWave)
wave wave2Avg, MaskWave

	duplicate/o/free wave2Avg wave2AvgTemp
	wave2AvgTemp*=MaskWave/MaskWave					//1.58c	
	wavestats/q/m=1 wave2AvgTemp
	return V_avg
	
End


//^  previously sq_popMenuProcABToFType
//Function sq_pop_AB_ToFType(ctrlName,popNum,popStr) : PopupMenuControl
//	String ctrlName
//	Variable popNum
//	String popStr
//	
//	sq_makeToDoIonizationType()		// reset every time			//1.52H (amber)
//	if (stringmatch(popStr, "Initialize"))
//	else
//		nvar airbeam_corrToFTypeVar = root:panel:airbeam_corrToFTypeVar
//		airbeam_corrToFTypeVar=popNum-1	//^ c and v types get the same value
//	
//		wave airbeamCorrToFTypeValue = root:panel:airbeamCorrToFTypeValue
////		nvar airbeam_ref_ionEff_sv = root:panel:airbeam_ref_ionEff_sv
////		nvar airbeam_ref_MSab_sv = root:panel:airbeam_ref_MSab_sv
////		nvar airbeam_ref_ToFab_sv = root:panel:airbeam_ref_ToFab_sv
////		nvar airbeam_ref_flow_sv = root:panel:airbeam_ref_flow_sv
//		nvar ref_singleion_sv = root:panel:ref_singleion_sv
//	
////		airbeam_ref_ionEff_sv = airbeamCorrToFTypeValue[0][airbeam_corrToFTypeVar]
////		airbeam_ref_MSab_sv = airbeamCorrToFTypeValue[1][airbeam_corrToFTypeVar]
////		airbeam_ref_ToFab_sv = airbeamCorrToFTypeValue[2][airbeam_corrToFTypeVar]
//		ref_singleion_sv = airbeamCorrToFTypeValue[3][airbeam_corrToFTypeVar]
//		airbeam_ref_flow_sv = airbeamCorrToFTypeValue[4][airbeam_corrToFTypeVar]
//	endif
//
//End


//@ Function controlling the stick re-calc selectors
//^ slightly edited
//Function sq_ck_controlSticks(ctrlName,checked) : CheckBoxControl
//	String ctrlName
//	Variable checked
//	

//	nvar recalcSticks_MS_ck=root:panel:recalcSticks_MS_ck
//	nvar recalcSticks_PToF_ck=root:panel:recalcSticks_PToF_ck
//	nvar recalcSticks_ePToF_ck=root:panel:recalcSticks_ePToF_ck
//	nvar load_preProcessStick_MS_ck=root:panel:load_preProcessStick_MS_ck		// 1.44D
//	nvar load_preProcessStick_PToF_ck=root:panel:load_preProcessStick_PToF_ck
//	


//	if(recalcSticks_MS_ck==0 || load_preProcessStick_MS_ck==0)
////		CheckBox load_OCStick_MS,win=ams_panel,disable=2		// removed in 1.50K
//		CheckBox load_recalcSticks_UseNewMz_MS,win=ams_panel,disable=2
//		CheckBox load_recalcSticks_UseBkFit,win=ams_panel,disable=2
//	else
////		CheckBox load_OCStick_MS,win=ams_panel,disable=0 	// removed in 1.50K
//		CheckBox load_recalcSticks_UseNewMz_MS,win=ams_panel,disable=0
//		CheckBox load_recalcSticks_UseBkFit,win=ams_panel,disable=0
//	endif
//	if(recalcSticks_PToF_ck==0 || load_preProcessStick_PToF_ck==0)
//		CheckBox load_recalcSticks_UseNewMz_PToF,win=ams_panel,disable=2
//		CheckBox load_recalcSticks_UseBkFit_pToF,win=ams_panel,disable=2		// JDA, 1.47I
//	else
//		CheckBox load_recalcSticks_UseNewMz_PToF,win=ams_panel,disable=0
//		CheckBox load_recalcSticks_UseBkFit_pToF,win=ams_panel,disable=0		// JDA, 1.47I
//	endif
//	

//End

//  Sets the values of insert and insertflag.  insert is the maximum value of mStart for all runs indexed by index_pos
Function sq_insertStick_check(index_pos,insert,mStart,series_index,insertflag)
wave index_pos,mStart,series_index
variable &insert,&insertflag

	variable idex,num
	num=numpnts(index_pos)
	make/FREE/o/n=(num) mstartDup=(index_pos[p]<0 ?  nan :(mStart[series_index[index_pos[p]]]) )		//1.51Q fix.  Was >0 not >=0
	wavestats/q/m=1 mstartDup
	insert=V_max
	insertflag = ! (V_min==V_max)

// old code, fixed in 1.48D
//    for(idex=0;idex<num;idex+=1)
//        if(index_pos[idex]==-1)
//            continue
//        endif
//        insert=max(mStart[series_index[index_pos[idex]]],insert)
//        if(insertflag==0)
//            insertflag=(mStart[series_index[index_pos[idex]]]!=insert)? 1 : 0
//        endif
//    endfor

End 


//^
Function sq_doesPToFDataExist(RunNum)
variable RunNum

	wave ptofNumTimesThrough =root:diagnostics:ptofNumTimesThrough
	wave run_series = root:index:rn_series
	variable sPos

	sPos = sq_findRun(run_series, RunNum)
	if (sPos>=0)
		if (ptofNumTimesThrough[sPos]>0)
			return 1
		else
			return 0
 		endif
 	else
		return -1		// run number doesn't exist in rn_series
	endif	

End


// Returns 1 if the todo wave has only ptof data or if the user wants to continue despite not having PToF data for some runs.  
// Returns 0 if user chooses to quit.  
Function sq_checkTodoForPToF(todowave)
wave todowave

	wave/z allPToF = root:allPToF
	if (!waveExists(allPToF) )
		sq_makeToDoAllPToF()
		wave/z allPToF = root:allPToF
		if (!waveExists(allPToF) )	// we have ptof data for every run
			return 1		// the todowave allPToF doesn't exist, so all runs have ptof data.
		endif
	endif

	// combine allPToF with current todo and see if we get the same number of points
	wave allPToF = root:allPToF
	sq_create_todo(NameofWave(todowave)+" and allPToF","todo_temp")
	wave todo_temp = root:todo_temp
	
	if (numpnts(todo_temp) != numpnts(todowave) )
		killwaves/z todo_temp
		DoAlert 1, "The current todowave contains runs where no PToF data exists.  You may want to choose a todowave that has only PToF data.   Press Yes to continue, no to quit"
		if (V_flag==2)
			return 0
		else	// the current todo wave has runs with no ptof data but the user wants to continue anyway
			return 1
		endif
	else		// the case where the existing todowave has only ptof data
		killwaves/z todo_temp
		return 1
	endif	

End			


// similar to sq_checkTodoForPToF but without the doAlert
// returns 0 if there are not PToF runs in todo wave
// returns 1 if the todo wave has PToF data for every run
// returns -n if the todo wave has runs where no PToF data exists.
Function sq_verifyTodoForPToF(todowave)
wave todowave

	variable returnVal
	wave/z allPToF = root:allPToF
	
	wave TimeAcquiringPToFInRun=root:diagnostics:TimeAcquiringPToFInRun		//1.50M
	if (sum(TimeAcquiringPToFInRun)==0)
		return 0
	endif
	
	if (!waveExists(allPToF) )
		sq_makeToDoAllPToF()
		wave/z allPToF = root:allPToF
		if (!waveExists(allPToF) )	// we have ptof data for every run
			return 1		// the todowave allPToF doesn't exist, so all runs have ptof data.
		endif
	endif

	// combine allPToF with current todo and see if we get the same number of points
	wave allPToF = root:allPToF
	sq_create_todo(NameofWave(todowave)+" and allPToF","todo_temp")
	wave todo_temp = root:todo_temp
	
	if (numpnts(todo_temp) ==0)
		killwaves/z todo_temp
		return 0
	else		// the case where the existing todowave has only ptof data
		returnVal = numpnts(todo_temp) - numpnts(todowave)
		killwaves/z todo_temp
		if (returnVal==0)				// fixed1.44A 
			returnVal = numpnts(todowave)	
		else		// bug in 1.46E
			return returnVal	// case of where returnVal is negative - we have runs in todowave that do not have PToF data.
		endif	
//		if (returnVal>0)		//1.44A
//			return returnVal
//		else
//			return 1
//		endif
	endif	

End	


Function sq_applyDCmarkers(ptof,index_pos,kill,dc1,dc2,dc3,dc4,region1only,region2only, ePToFFlag, UseallMzReg2, WriteFlag, [PossibleTimeAvg])		//1.59 added WriteFlag
//& A few optimisations added 1.46A
	wave ptof,index_pos
	variable kill,dc1,dc2,dc3,dc4, ePToFFlag, UseallMzReg2,WriteFlag, PossibleTimeAvg
	string region1only,region2only
	
	UseallMzReg2=UseallMzReg2>0
	wave squirrel_index = root:index:squirrel_index
//	wave ptof_t0=root:diagnostics:ptof_t0		//1.59E
//	wave ptof_step=root:diagnostics:ptof_step
	wave series_index=root:index:series_index
	wave ptof_dcMarkersPtWave=root:panel:ptof_dcMarkersPtWave
	
	nvar/z PToF_ePToF_TestRegion=root:panel:PToF_ePToF_TestRegion		// for display, not calculations
	if (!NVar_exists(PToF_ePToF_TestRegion))
		sq_initializeGlobalNVar("root:panel:PToF_ePToF_TestRegion", 0.25)	
		nvar/z PToF_ePToF_TestRegion=root:panel:PToF_ePToF_TestRegion
	endif

	nvar ptof_dcRegion1Allnot2 = root:panel:ptof_dcRegion1Allnot2		//1.59E

	variable idex,jdex,sPos, objectionOverRide
	variable p1,p2,p3,p4,a1,a2, numRuns, numSizeBins, numMasses//, ave, nTot, n1, n2  // 1.46A
	variable numLayers, layerNum, colNum, totolnum, D1Avg, D2Avg
	string str

	colNum = 0			// can use other columns
	objectionOverRide=1	
	
	numRuns =dimsize(ptof,0)
	numSizeBins =dimsize(ptof,1)
	numMasses = dimsize(ptof,2)
	numLayers = DimSize(squirrel_index, 2 )

	if (ePToFFlag && mod(numSizeBins, 127)!=0)
		abort "The number of points in the ePToF data seems to be wrong.  It should be a multiple of 127 and is instead "+num2str(numSizeBins) +"aborting from sq_applyDCmarkersEPToF"	
	endif
	
	make/FREE/o/n=(numRuns,numMasses) DCregion1=nan, DCregion2=nan, 	DCregionAvg=nan
		//1.46A

	for (idex=0;idex<numLayers;idex+=1)
	 	str = GetDimLabel(root:index:squirrel_index, 2,idex)
		if (strsearch(lowerstr(str), "ptof", 0)>=0) //^ the dim label is most often ptof_stick, but I didn't want to assume this name & capitalization 
			layerNum = idex
			break
		endif
	endfor
	
	wave/z DCregion1Start = root:diagnostics:DCregion1Start
	wave/z DCregion1Stop = root:diagnostics:DCregion1Stop 
	wave/z DCregion2Start = root:diagnostics:DCregion2Start
	wave/z DCregion2Stop = root:diagnostics:DCregion2Stop
	totolnum=dimsize(squirrel_index,0)
	
	if (!WaveExists(DCregion1Start) )
		make/o/n=(totolnum) root:diagnostics:DCregion1Start=nan
		make/o/n=(totolnum) root:diagnostics:DCregion1Stop=nan 
		make/o/n=(totolnum) root:diagnostics:DCregion2Start=nan
		make/o/n=(totolnum) root:diagnostics:DCregion2Stop=nan
		wave DCregion1Start = root:diagnostics:DCregion1Start
		wave DCregion1Stop = root:diagnostics:DCregion1Stop 
		wave DCregion2Start = root:diagnostics:DCregion2Start
		wave DCregion2Stop = root:diagnostics:DCregion2Stop
	elseif (numpnts(DCregion1Start)!=totolnum )		// we added more points
		InsertPoints numpnts(DCregion1Start), totolnum-numpnts(DCregion1Start), DCregion1Start, DCregion1Stop, DCregion2Start, DCregion2Stop
	endif
	
	//1.55J
	wave/z/t DCregion1Only = root:diagnostics:DCregion1Only
	wave/z/t DCregion2Only = root:diagnostics:DCregion2Only 
	if (!WaveExists(DCregion1Only) )
		make/t/o/n=(totolnum) root:diagnostics:DCregion1Only/wave=DCregion1Only		//1.56B
		make/t/o/n=(totolnum) root:diagnostics:DCregion2Only/wave=DCregion2Only
	elseif (numpnts(DCregion1Only)!=totolnum )		// we added more points
		InsertPoints numpnts(DCregion1Only), totolnum-numpnts(DCregion1Only),  DCregion1Only, DCregion2Only
	endif

	//1.46A JDA added these two lines 
	make /o/n=(nummasses) DC_tmp // Index for which masses to use which DC regions for
	if (ptof_dcRegion1Allnot2)			//1.19E
		DC_tmp=(findlistitem(num2str(p+1),region2only,",")>=0) ? 2 : 1  //1.60E
	else
		DC_tmp=(findlistitem(num2str(p+1),region1only,",")>=0)?(1):((findlistitem(num2str(p+1),region2only,",")>=0)?(2):(0))
	endif
	
	for(idex=0;idex<numRuns;idex+=1)	// for each run
		if (!PossibleTimeAvg)
			if(index_pos[idex]==-1 && objectionOverRide)		// for ucsd folks who have a run number of zero.
				continue
			endif
			sPos=series_index[index_pos[idex]]				
		endif
		
		if (ePToFFlag) ///  && UseallMzReg2)
			ptof_dcMarkersPtWave[0]=nan
			ptof_dcMarkersPtWave[1]=nan
			ptof_dcMarkersPtWave[2]=round(numSizeBins*(1-PToF_ePToF_TestRegion))
			ptof_dcMarkersPtWave[3]=numSizeBins-1
			objectionOverRide=1
		else
			objectionOverRide = sq_dcMarkersExamine(spos)		// sets & checks ptof_dcMarkersPtWave 1.40D
 		endif
 		
		p1=ptof_dcMarkersPtWave[0]		// left edge of region 1
		p2=ptof_dcMarkersPtWave[1]		// right edge of region 1
		p3=ptof_dcMarkersPtWave[2]		// left edge of region 2
		p4=ptof_dcMarkersPtWave[3]		// right edge of region 2
//			print p1, p2, p3, p4		// for debugging
		if (!PossibleTimeAvg)
			DCregion1Start[sPos]=p1			//1.51Q
			DCregion1Stop[sPos]=p2
			DCregion2Start[sPos]=p3
			DCregion2Stop[sPos]=p4
	
			DCregion1Only[sPos]=region1only		//1.55J
			DCregion2Only[sPos]=region2only		//1.55J
		endif
		
 		if (squirrel_index[index_pos[idex]][colNum][layerNum]>0 && objectionOverRide)
			
			for(jdex=0;jdex<numMasses;jdex+=1)	//for each mass
				imagetransform /g=(idex) /p=(jdex) getrow ptof		//1.46A change
				wave W_ExtractedRow
				if (!ePToFFlag || !UseallMzReg2)
					switch (DC_tmp[jdex])
						case 0: // Both regions
							wavestats /q/m=1/r=[p1,p2] W_ExtractedRow
							D1avg = V_avg
							wavestats /q/m=1/r=[p3,p4] W_ExtractedRow
							D2avg=v_avg
							W_ExtractedRow[0,max(0, p1-1) ]=nan  //1.61F
							W_ExtractedRow[p2+1,p3-1]=nan
							W_ExtractedRow[min(numsizebins-1,p4+1),numsizebins-1]=nan			//1.58G			
							wavestats /q/m=1 W_ExtractedRow
							if (!PossibleTimeAvg)
								DCregionAvg[idex][jdex]=v_avg
								DCregion1[idex][jdex]=D1avg
								DCregion2[idex][jdex]=D2avg
							endif
							break
						case 1: // Region 1 only
							W_ExtractedRow[0,max(0, p1-1) ]=nan
							W_ExtractedRow[p2+1,numsizebins-1]=nan
							wavestats /q/m=1 W_ExtractedRow
							if (!PossibleTimeAvg)
								DCregion1[idex][jdex]=v_avg
								DCregion2[idex][jdex]=nan
								DCregionAvg[idex][jdex]=v_avg
							endif
							break
						case 2: // Region 2 only
							W_ExtractedRow[0,p3-1]=nan
							W_ExtractedRow[min(numsizebins-1,p4+1),numsizebins-1]=nan
							wavestats /q/m=1 W_ExtractedRow
							if (!PossibleTimeAvg)
								DCregion1[idex][jdex]=nan
								DCregion2[idex][jdex]=v_avg
								DCregionAvg[idex][jdex]=v_avg
							endif
							break
					endswitch
				else		// eptof and use region 2 only
					W_ExtractedRow[0,p3-1]=nan
//					W_ExtractedRow[p4+1,numsizebins-1]=nan   //1.59D
					wavestats /q/m=1 W_ExtractedRow
					if (!PossibleTimeAvg)
						DCregion1[idex][jdex]=nan
						DCregion2[idex][jdex]=v_avg
						DCregionAvg[idex][jdex]=v_avg
					endif
				endif
				
				ptof[idex][][jdex]-=v_avg
			
			endfor // for each mass
		
		endif  // we have ptof data 
		
	endfor
	
	//1.14M  UMR
	if (WriteFlag)
		squirrel_hdf_write(index_pos,DCregion2,"DCregion2")		//1.51Q
		squirrel_hdf_write(index_pos,DCregion1,"DCregion1")		//1.51Q
		squirrel_hdf_write(index_pos,DCregionAvg,"DCregionAvg")		//1.51Q
	endif	
	if (kill)
		killwaves /z DC_tmp, W_ExtractedRow
	endif

End


//^ The values dumped into the diagnostics waves were not set correctly.
Function sq_fixPToFDiagWaves()

	wave ptofNumTimesThrough = root:diagnostics:ptofNumTimesThrough
	wave ptofNumSpectraPerChop= root:diagnostics:ptofNumSpectraPerChop
	
	wave squirrel_index = root:index:squirrel_index
	wave rn_series = root:index:rn_series
	wave series_index = root:index:series_index
	wave l_series=root:index:l_series		// 1.41 addition
	
	variable sPos, colNum=0, idex, layerNum, num, numLayers, ptofStickExists
	string str

	num = numpnts(rn_series)	
	numLayers = DimSize(squirrel_index, 2 )
 
	layerNum=-1			//1.53C
	for (idex=0;idex<numLayers;idex+=1)
	 	str = GetDimLabel(root:index:squirrel_index, 2,idex)
		if (strsearch(lowerstr(str), "ptof", 0)>=0) //^ the dim label is most often ptof_stick, but I didn't want to assume this name & capitalization 
			layerNum = idex
			break
		endif
	endfor
	
	if (layerNum<0)
		print "// No PToF data is present."
		return 0
	endif
	
	for (idex=0;idex<num;idex+=1)
		sPos = l_series[idex]		// 1.41 addition, l_series used in stead of series_index
		ptofStickExists = squirrel_index[sPos][colNum][layerNum] 
		ptofNumTimesThrough[idex] = ptofStickExists>0? max (ptofNumTimesThrough[idex], ptofStickExists):0	// will be 0 or the real number of times through
		ptofNumSpectraPerChop[idex] = squirrel_index[sPos][4][layerNum]
	endfor
End


//^ a simple routine for calculating dc markers.  fills in ptof_dcMarkersPtWave
// we calculate and check the PToF Bins corresponding to the start and stop values of region 1 and region 2
Function sq_dcMarkersExamine(runNumPos)
variable runNumPos

	nvar dc1=root:panel:cor3_dcmarker1
	nvar dc2=root:panel:cor3_dcMarker2
	nvar dc3=root:panel:cor3_dcmarker3
	nvar dc4=root:panel:cor3_dcmarker4
	
	nvar ptof_dcUseBinNumUnits = root:panel:ptof_dcUseBinNumUnits
	
	make/free DVa_wave
	sq_GetPToFParams(DVa_wave, runNumPos)

	wave ptof_dcMarkersPtWave=root:panel:ptof_dcMarkersPtWave

	variable p1,p2,p3,p4, MaxSizeInUs	// ps correspond to actual PToF bin values
	string str1
				
	MaxSizeInUs = 1e6*(DVa_wave[%t0] + DVa_wave[%t0]*DVa_wave[%step])
	
	make/free/n=(DVa_wave[%numPToFBins]) ptof_BinTime_temp
	ptof_BinTime_temp = 1e6*(DVa_wave[%t0]+ p*DVa_wave[%step])////ptofCoAdd[runNumPos])		// gives granular view - one entry is one ptof size bin  needs to be changed if go to 2 GHz			
// not considering tw deconvolution for this usage

	if (dc1> dc2 || dc3>dc4)	
		Abort "There is something wrong with the start and stop values of your dc markers.  Make sure start < stop.   aborting from sq_dcMarkersExamine"
	endif

	if (ptof_dcUseBinNumUnits)		// use bin numbers, easy peasy

		p1=dc1==0 ? 5: round(dc1)			// 5 points in this is default		
		p2=dc1==0 ? 15: round(dc2)	
		if (dc3<0)	// count less than numSizeBins
			 p3 = DVa_wave[%numPToFBins]+round(dc3)
		elseif(dc3==0)	// default, dc3= -15
			p3 = DVa_wave[%numPToFBins]-15		// changed from 15 to 11  //1.52J
		elseif(dc3>=DVa_wave[%numPToFBins]-1)
			abort "The DC marker region 2 start value of "+num2str(dc3)+", in units of bin #, is larger than the number of ptof bins, "+num2str(DVa_wave[%numPToFBins]) +". Perhaps change the units from bin # to PToF time.  Check step 4 of the DC marker graph.  aborting from sq_dcMarkersExamine"
		else	
			p3 = round(dc3)
		endif
		p3 = min(p3, DVa_wave[%numPToFBins]-1)
		if (dc4<0)
			 p4 = DVa_wave[%numPToFBins]+round(dc4)
		elseif(dc4==0)
			p4 = DVa_wave[%numPToFBins]-1	// changed from 5 to 1  //1.52J
		elseif(dc4>=DVa_wave[%numPToFBins]-1)
			dc4= DVa_wave[%numPToFBins]-1		// change the value in the apnel
			p4 = DVa_wave[%numPToFBins]-1	// changed from 5 to 1  //1.52J
		else
			p4 = round(dc4)
		endif
//		p3 = min(p4, numSizeBins-1)
	
	else	//Use us units 
	
		//^ 1.42D significant change.
		// We no longer allow the "use us units to have default values.
		
		//^ Behavior changed in 1.42 to prevent screwy cases.
		p1 = max(0,floor(binarysearchinterp(ptof_BinTime_temp, dc1)))
		p1 = numtype(p1)!=0 ?  0: p1
		p2=  max(0,ceil(binarysearchinterp(ptof_BinTime_temp, dc2)))
		p2 = numtype(p2)!=0 ?  0: p2
		p3 = min(floor(binarysearchinterp(ptof_BinTime_temp, dc3)), DVa_wave[%numPToFBins]-1)
		p3 = numtype(p3)!=0 ?  DVa_wave[%numPToFBins]-1: p3
		p4=  min(ceil(binarysearchinterp(ptof_BinTime_temp, dc4)), DVa_wave[%numPToFBins]-1)
		p4 = numtype(p4)!=0 ?  DVa_wave[%numPToFBins]-1: p4
		 	
	endif	// now we have point numbers
	
	//^ sanity checks
	if(p3<p2)
		wave rn_series = root:index:rn_series
		sprintf str1, "%d" , rn_series[runNumPos]		// small bug, things can go wrong with run numbers > 1e6
		STRUCT WMButtonAction ba; sq_butt_PToFDCGr_show(ba) 
		Abort "Regions 1 and 2 overlap, which is not good. The problem is at run "+str1+ " and bins "+num2str(p2)+" "+num2str(p3)+" Try different values. - Aborting from sq_dcMarkersExamine"
		return 1
	elseif (p1 == p2)
		wave rn_series = root:index:rn_series
		sprintf str1, "%d" , rn_series[runNumPos]		// small bug, things can go wrong with run numbers > 1e6
		if (p2==0)		//1.46B
			Abort "Perhaps the DC marker units should be bin # instead of PToF time. Verify your DC parameters! - Aborting from sq_dcMarkersExamine"			
		endif
		Abort "Region 1 consists of one bin, which is not good. The problem is at run "+str1+" and bins "+num2str(p1)+" "+num2str(p2)+" Try different values. - Aborting from sq_dcMarkersExamine"
	elseif (p3 == p4)
		wave rn_series = root:index:rn_series
		sprintf str1, "%d" , rn_series[runNumPos]		// small bug, things can go wrong with run numbers > 1e6
		if (p3==DVa_wave[%numPToFBins]-1) 	//1.46B 
			Abort "Your Region 2 seems to begin at the last PToF bin. Perhaps the DC marker units should be bin # instead of PToF time?  - Aborting from sq_dcMarkersExamine"			
		endif
		Abort "Region 2 consists of one bin, which is not good. The problem is at run "+str1+" and bins "+num2str(p3)+" "+num2str(p4)+" Try different values. - Aborting from sq_dcMarkersExamine"
	endif
		
	ptof_dcMarkersPtWave[0] = p1 
	ptof_dcMarkersPtWave[1] = p2
	ptof_dcMarkersPtWave[2] = p3 
	ptof_dcMarkersPtWave[3] = p4 
	
	return 1
	
End



//^ a simple routine for ptof_dcMarkersPtWave
Function sq_dcMarkersExamine_ePToF(runNumPos)
variable runNumPos

	wave ptofNumSpectraPerChop=root:diagnostics:ptofNumSpectraPerChop
	wave ptof_dcMarkersPtWave=root:panel:ptof_dcMarkersPtWave
	wave/z deconvolveType=root:diagnostics:deconvolveType
	wave/z EPToF_testregion=root:diagnostics:EPToF_testregion
	if ( !waveExists(EPToF_testregion) || !waveExists(deconvolveType))
		make/o/n=(numpnts(ptofNumSpectraPerChop))  root:diagnostics:EPToF_testregion=nan		
		make/o/n=(numpnts(ptofNumSpectraPerChop))  root:diagnostics:deconvolveType=nan		
		wave EPToF_testregion = root:diagnostics:EPToF_testregion
		wave deconvolveType = root:diagnostics:deconvolveType
	endif

	nvar PToF_ePToF_TestRegion=root:panel:PToF_ePToF_TestRegion

	ptof_dcMarkersPtWave[0,1]=nan
	ptof_dcMarkersPtWave[3]=ptofNumSpectraPerChop[runNumPos]
	
	variable dc3
	if (WaveExists(deconvolveType) && deconvolveType[runNumPos]>0)
		dc3 = (1-EPToF_testregion[runNumPos])*ptof_dcMarkersPtWave[3]
	else		// deconvolved in ms_conc fetch call
		dc3 = (1-PToF_ePToF_TestRegion)*ptof_dcMarkersPtWave[3]
	endif
	ptof_dcMarkersPtWave[2] = round(dc3)

End


//  function called from either the HDF or corrections - PToF tab that displays DCMarkerGr
Function sq_butt_PToFDCGr_show(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			sq_GetIndexNotDoneYet()
			DoWindow/F DCMarker_gr 
			if (V_flag==0)
				// check to see that the Get Index button was pressed 		//1.42D
				if (!DataFolderExists("root:index"))
					Abort "You must press the Get Index button before this functionality is available - Aborting from sq_butt_checkDCmarkers"
				endif
				sq_globalsDCMarkerGr()
				sq_DCMarkerGr()
				wave/z ePToF_enabled = root:diagnsotics:ePToF_enabled		//1.20N
				if (WaveExists(ePToF_enabled) && WaveMax(ePToF_enabled)>0)
					sq_initializeDeconvolveRadio() //1.20L
				endif
			endif
			break
	endswitch

	return 0

End


// creates and initializes globals for DCMarkerGr
Function sq_globalsDCMarkerGr()

	wave all = root:all

	// variable displayed in graph
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_t0",nan)
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_tstep",nan)
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_numBins",nan)
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_mzChoice",28)
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_runNumber",all[0])
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_minMz",nan)
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_maxMz",nan)
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_maxMz",nan)
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_UseRegions","")
	
	sq_initializeGlobalNVar("root:panel:PToF_DCMarkerDuration",nan)		//1.51P

	// selectable variables
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_RunInfo","")
//	sq_initializeGlobalNVar("root:panel:PToF_DCgr_DAQsticks",1)

	string/g root:panel:PToF_DCgr_Info0, root:panel:PToF_DCgr_Info0A
	string/g root:panel:PToF_DCgr_Info1, root:panel:PToF_DCgr_Info1A
	string/g root:panel:PToF_DCgr_Info2, root:panel:PToF_DCgr_Info2A
	string/g root:panel:PToF_DCgr_Info3, root:panel:PToF_DCgr_Info3A
	string/g root:panel:PToF_DCgr_Info4, root:panel:PToF_DCgr_Info4A
	
	svar PToF_DCgr_Info0 = root:panel:PToF_DCgr_Info0 
	svar PToF_DCgr_Info0A = root:panel:PToF_DCgr_Info0A
	svar PToF_DCgr_Info1 = root:panel:PToF_DCgr_Info1
	svar PToF_DCgr_Info1A = root:panel:PToF_DCgr_Info1A
	svar PToF_DCgr_Info2 = root:panel:PToF_DCgr_Info2 
	svar PToF_DCgr_Info2A = root:panel:PToF_DCgr_Info2A
	svar PToF_DCgr_Info3 = root:panel:PToF_DCgr_Info3
	svar PToF_DCgr_Info3A = root:panel:PToF_DCgr_Info3A
	svar PToF_DCgr_Info4 = root:panel:PToF_DCgr_Info4
	svar PToF_DCgr_Info4A = root:panel:PToF_DCgr_Info4A

	root:panel:PToF_DCgr_Info0 = "Step 0. Read the following if you need guidance."
	root:panel:PToF_DCgr_Info0A=""
	root:panel:PToF_DCgr_Info0A += "The application of PToF DC markers can happen in two places: the\r"
	root:panel:PToF_DCgr_Info0A += "pre-process step, and the corrections step. This graph aides the user\r"
	root:panel:PToF_DCgr_Info0A += "in visualizing the math that is performed in either case.\r"
	root:panel:PToF_DCgr_Info0A +="\r"
//	root:panel:PToF_DCgr_Info0A +="Proper interpretation of PToF data requires a surrogate for closed spectra.\r"
//	root:panel:PToF_DCgr_Info0A +="This surrogate is accomplished through the setting of DC markers.\r" 
//	root:panel:PToF_DCgr_Info0A +="Average PToF stick values in region 1 and 2 are subtracted from\r"
//	root:panel:PToF_DCgr_Info0A += "each PToF m/z column for each run.\r"
	root:panel:PToF_DCgr_Info0A +="Region 1 should encompass a gas phase signal; region 2 should\r"
	root:panel:PToF_DCgr_Info0A +="reflect background signal (sizes bigger > largest transmitted particle).\r"
	root:panel:PToF_DCgr_Info0A +="\r"
	root:panel:PToF_DCgr_Info0A += "Historically, default DC markers settings were: to use PToF bin numbers,\r"
	root:panel:PToF_DCgr_Info0A +="     region 1 start = 5      region 2 start = n-15\r"
	root:panel:PToF_DCgr_Info0A +="     region 1 stop = 15     region 2 stop = n-5\r"
	root:panel:PToF_DCgr_Info0A +="where n is the number of PToF bins.\r"
	root:panel:PToF_DCgr_Info0A +="These default settings are identical to default settings of zero in all four\r"
	root:panel:PToF_DCgr_Info0A +="region start/stop variables.\r"
	root:panel:PToF_DCgr_Info0A +="If using PToF bin numbers as units, one can enter negative values in\r"
	root:panel:PToF_DCgr_Info0A +="region 2 start and stop variables, and they will be treated as n-value\r" 
	root:panel:PToF_DCgr_Info0A +="(as in the default setttings, region 2 start = n-15).\r"
	root:panel:PToF_DCgr_Info0A +="\r"
	root:panel:PToF_DCgr_Info0A +="A better approach is to use ion time-of-flight (iToF) units, not bin numbers.\r"
	root:panel:PToF_DCgr_Info0A +="The PToF settings (and thus the bin number-to-iToF conversion) \r"
	root:panel:PToF_DCgr_Info0A +="may change during an experiment, but the instrument response time to\r"
	root:panel:PToF_DCgr_Info0A +="air < small particles < large particles is more constant."
	
	root:panel:PToF_DCgr_Info1 = "Step 1. Select either DAQ or pre-processed PToF sticks."
	root:panel:PToF_DCgr_Info2 = "Step 2. Select a run with PToF data."
	root:panel:PToF_DCgr_Info2A = "Black dots in the graph below represent each PToF bin.\r"
	root:panel:PToF_DCgr_Info2A += "Parameters for this PToF run are displayed below."
	root:panel:PToF_DCgr_Info3 = "Step 3. Select a m/z value to view signal vs time of flight."
	root:panel:PToF_DCgr_Info3A = "Step 3A. (Rare!) Edit list of region 1 and 2 only m/z values."
	root:panel:PToF_DCgr_Info4 = "Step 4. Choose DC markers (region 1 and 2 endpoints)."
	root:panel:PToF_DCgr_Info4A = "Yellow shaded areas indicate DC marker regions.\rBlack vertical lines indicate ~ 10, 100, 1000nm"

	make/o/n=0 root:panel:PToF_DCgr_displayX		// is x axis for other traces in graph
	make/o/n=0 root:panel:PToF_DCgr_displayY		// shows black dots for size locations
	make/o/n=0 root:panel:PToF_DCgr_oneMz		// shows one m/z size profile
	make/o/n=0 root:panel:PToF_DCgr_regionY		// colored region 1 and 2

	make/o/n=(1,1) root:panel:PToF_DCgr_onePToFMatrix	// 1.51N

	sq_SetePToFExists()

//	make/o/n=100 root:panel:DCgr_demuxPrefilterXwave, root:panel:DCgr_demuxPrefilterYwave		//1.57G
//	make/o/n=100 root:panel:DCgr_demuxADenoiseXwave, root:panel:DCgr_demuxADenoiseYwave 	//1.57G
//	make/o/n=1 root:panel:DCgr_demuxPrefilterXpt, root:panel:DCgr_demuxPrefilterYpt
//	make/o/n=1 root:panel:DCgr_demuxADenoiseXpt, root:panel:DCgr_demuxADenoiseYpt
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_ECLulim",3)	//1.57H
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_BLmax",30)	 	//1.57H
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_DNulim",4)	//1.57H
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_DNmax",5)	 	//1.57H
//	ePTOF_demuxGrUPdates("",nan,"","")

	sq_initializeGlobalNVar("root:panel:ePToF_postmatrixInvDC", 1)
	
	killstrings/z root:panel:PToF_DCgr_Info2A, root:panel:PToF_DCgr_Info2, root:panel:PToF_DCgr_Info2, root:panel:PToF_DCgr_Info2A
	
	sq_initializeGlobalNVar("root:panel:ms0_mz_saved_regrid", 1)
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info2", "Step 0. Select a run or todo")
	root:panel:PToF_DCgr_Info2= "Step 0. Select a run or todo"
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info2A", "Step 1. if ePToF run, elect deconvolve options (DAQ)")
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info3A", "")
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info4", "")
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info4A", "")
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_RunInfo", "")
	sq_initializeGlobalSVar("root:panel:ePToF_Info", "")

	sq_initializeGlobalNVar("root:panel:deconvolveNone", 1)		
	sq_initializeGlobalNVar("root:panel:deconvolveJoel", 0)		
	sq_initializeGlobalNVar("root:panel:deconvolveMike", 0)		
	sq_initializeGlobalNVar("root:panel:deconvolve", 0)			// rich	

	sq_initializeGlobalNVar("root:panel:PToF_ePToF_Mulitplier", nan)	
//	sq_initializeGlobalNVar("root:panel:PToF_ePToF_Denoise", 0)		//1.57G default changed from 1 to 0
//	sq_initializeGlobalNVar("root:panel:PToF_ePToF_Sharpening", 0)	//1.57G default changed from 1 to 0
	sq_initializeGlobalNVar("root:panel:PToF_ePToF_TestRegion", 0.25)	
	sq_initializeGlobalNVar("root:panel:PToF_ePToF_confidLim", nan)	
	sq_initializeGlobalNVar("root:panel:eptof_appendCopied", 1)		

	sq_initializeGlobalSVar("root:panel:ePToF_waveNamePrefix", "")
	sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info2Z", "DC marker calcs not performed.")			// rich	
	sq_initializeGlobalSVar("root:panel:DCGr_ePToFInfoStr", "")			// rich	

//	make/o/n=2 root:panel:PToF_DCgr_confidLim=nan
	
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_ECLulim", 3)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_BLmax", 15)    //1.57G
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_DNulim", 4)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_DNmax", 5)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_adaptiveDenoise", 0)

//	sq_initializeGlobalNVar("root:panel:ePToF_demux_FirstECL", 0)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_SecondECL", 0)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_ThirdECL", 0)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_FirstPkVsEcl", 0)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_BLwid", 0)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_SecondPkVsEcl", 0)
//	sq_initializeGlobalNVar("root:panel:ePToF_demux_DenoiseCalc", 0)		

	sq_initializeGlobalNVar("root:panel:PToF_DCgr_IsEPToF", 0)	
	
	sq_initializeGlobalNVar("root:panel:PToF_DCgr_MikeNormalization", 0)	

	sq_initializeGlobalNVar("root:panel:PToF_ePToFSumDiffMz",nan)
	sq_initializeGlobalNVar("root:panel:PToF_ePToFDeconvolvedMz",nan)
	sq_initializeGlobalNVar("root:panel:PToF_ePToFSumDiffScalarMz",nan)

End


// checkbox control function for DCMarkerGr
// user opts to select DAQ (un DC corrected or DC corrected sticks)

//Function sq_ck_PToF_DCgr_DAQSticks(ctrlName,checked) : CheckBoxControl
//	String ctrlName
//	Variable checked
//
//	nvar PToF_DCgr_DAQsticks=root:panel:PToF_DCgr_DAQsticks
//	PToF_DCgr_DAQsticks = strsearch(ctrlName, "DAQ", 0)>=0
//	Checkbox PToF_DCgr_UseDAQ value = PToF_DCgr_DAQsticks
//	Checkbox PToF_DCgr_UsePreProc value = ! PToF_DCgr_DAQsticks
//	if (strlen(ctrlName)>3)		// a true button press
//		sq_PToFDCgr_GetThisMatrix()
//	endif
//End




//^ pops up a simple graph to aid in DC marker selection
Function sq_butt_DVaGraph(ctrlName) : ButtonControl
	String ctrlName
	
	sq_GetIndexNotDoneYet()
	
	doWIndow/F dVa_gr
	if (v_flag==1)
		if (stringmatch(ctrlName,"" ))
			MoveWindow/W=dVa_gr 0, 0, 0, 0  //minimizes the window
		elseif(strlen(WinLIst("PToFDataSetPanel", "*", "WIN:69"))>0)
 			gen_MoveIt("dVa_gr","PToFDataSetPanel") 
 		endif
		return 1
	endif

	wave/z ptof_dVaDisplayTime = root:panel:ptof_dVaDisplayTime
	if (!WaveExists(ptof_dVaDisplayTime))
		abort "You must first examine the diameter values via the graphs."
	endif
	
	// window not open.  Create globals for this panel
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm		// 1.40D change to a value that hasn't been placklisted.
	wave todowave = $"root:"+sq_toDoWvNm
	sq_initializeGlobalNVar("root:panel:DVa_vl",nan)
	sq_initializeGlobalNVar("root:panel:DVa_vg",nan) 
	sq_initializeGlobalNVar("root:panel:DVa_dx",nan)
	sq_initializeGlobalNVar("root:panel:DVa_b",nan)
	sq_initializeGlobalNVar("root:panel:DVa_t0",nan)
	sq_initializeGlobalNVar("root:panel:DVa_tstep",nan)
	sq_initializeGlobalNVar("root:panel:DVa_run_number",nan)
	sq_initializeGlobalNVar("root:panel:PToF_DCMarkerDuration",nan)

	sq_initializeGlobalsVar("root:panel:Dva_str1","")
	sq_initializeGlobalsVar("root:panel:Dva_str2","")
	sq_initializeGlobalsVar("root:panel:Dva_str3","")
	sq_initializeGlobalsVar("root:panel:DVa_PToFInfo","")
	
	nvar DVa_vl = root:panel:DVa_vl
	nvar DVa_vg = root:panel:DVa_vg
	nvar DVa_b = root:panel:DVa_b
	nvar DVa_dx = root:panel:DVa_dx
	nvar DVa_t0 = root:panel:DVa_t0
	nvar DVa_tstep = root:panel:DVa_tstep
	nvar DVa_run_number = root:panel:DVa_run_number
	nvar PToF_DCMarkerDuration = root:panel:PToF_DCMarkerDuration
	
	svar Dva_Str1 = root:panel:Dva_Str1
	svar Dva_Str2 = root:panel:Dva_Str2
	svar Dva_Str3 = root:panel:Dva_Str3
	svar DVa_PToFInfo = root:panel:DVa_PToFInfo
	
	Dva_Str1 ="If vp = (chamber length/PToF time t) then\rAerodyn Diam = Dx*((((vg - vl) / (vp - vl)) - 1) ^ (1/b))"
	
	DVa_PToFInfo = ""
	
	make/o/n=0 root:panel:ptof_dVaDisplayTime
	make/o/n=0 root:panel:ptof_dVaDisplaySize
	
	//1.41C
	if ( 1==sq_checkTodoForPToF(todowave) )		// all runs have ptof data
		DVa_run_number =todowave[0]			// 1.42E fix
	else	
		wave allPToF = root:allPToF
		sq_create_todo(NameofWave(todowave)+" and allPToF","todo_temp")
		wave todo_temp = root:todo_temp
		DVa_run_number = todo_temp[0]		// 1.42E fix	
		killwaves/z todo_temp
	endif

	nvar DVa_run_number =root:panel:DVa_run_number
	wave all = root:all
	if (BinarySearch(all, DVa_run_number)<0)
		DVa_run_number=all[0]
	endif
	
	NewPanel/N=dVa_gr /W=(500,83,805,458) as "dVa_gr"
//	ModifyPanel fixedSize=1		//1.57L
	TitleBox title0,pos={14,114},size={244,26},fSize=10,frame=0
	TitleBox title0,variable= root:panel:Dva_str1
	SetVariable setvarRunNumber,pos={9,20},size={220,16},bodyWidth=60,proc=sq_DVaGraph_SetVar,title="PToF info for run number"
	SetVariable setvarRunNumber,value= root:panel:DVa_run_number
	
	GroupBox group0,pos={5,1},size={292,146},title="PToF diameter calculations"
	GroupBox group0,fSize=14,fColor=(1,1,1)
	TitleBox title_NumTimesThruPToF,pos={230,22},size={91,13},fSize=10,frame=0
	TitleBox title_NumTimesThruPToF,variable= root:panel:DVa_PToFInfo
	SetVariable setvar_Vl,pos={188,43},size={100,16},title="Vl (m/s)"
	SetVariable setvar_Vl,help={"Position of DC marker 1 (begin region 1)"},fSize=10
	SetVariable setvar_Vl,limits={0,inf,0},value= root:panel:DVa_vl,noedit= 1
	SetVariable setvar_Vg,pos={188,61},size={100,16},title="Vg (m/s)"
	SetVariable setvar_Vg,help={"Position of DC marker 1 (begin region 1)"},fSize=10
	SetVariable setvar_Vg,limits={0,inf,0},value= root:panel:DVa_vg,noedit= 1
	SetVariable setvar_Dx,pos={188,78},size={100,16},title="Dx (nm)"
	SetVariable setvar_Dx,help={"Position of DC marker 1 (begin region 1)"},fSize=10
	SetVariable setvar_Dx,limits={0,inf,0},value= root:panel:DVa_dx,noedit= 1
	SetVariable setvar_b,pos={188,96},size={100,16},title="b (unitless)"
	SetVariable setvar_b,help={"Position of DC marker 1 (begin region 1)"},fSize=10
	SetVariable setvar_b,limits={0,inf,0},value= root:panel:DVa_b,noedit= 1
	SetVariable setvar_chamberlength,pos={15,60},size={150,16},title="Chamber length (m)"
	SetVariable setvar_chamberlength,help={"Chamber length"},fSize=10
	SetVariable setvar_chamberlength,limits={0,inf,0},value= root:panel:cor3_chamber,noedit= 1
	SetVariable setvar_t0,pos={15,78},size={150,16},title="t0 (offset in s)"
	SetVariable setvar_t0,help={"PToF offset in seconds"},fSize=10
	SetVariable setvar_t0,limits={0,inf,0},value= root:panel:DVa_t0,noedit= 1
	SetVariable setvar_tstep,pos={17,96},size={150,16},title="t step (s)"
	SetVariable setvar_tstep,help={"PToF step in seconds"},fSize=10
	SetVariable setvar_tstep,limits={0,inf,0},value= root:panel:DVa_tstep,noedit= 1
	SetVariable setvar_numberPToFBins,pos={17,43},size={150,16},title="# PToF bins"
	SetVariable setvar_numberPToFBins,help={"Chamber length"},fSize=10
	SetVariable setvar_numberPToFBins,limits={0,inf,0},value= root:panel:DVa_NumPToFBins,noedit= 1
	TabControl PToDVa_tab,pos={6,151},size={296,223},tabLabel(0)="Diameter Plot"
	TabControl PToDVa_tab,tabLabel(1)="Time Series DVa params",value= 0
	TabControl PToDVa_tab proc=sq_DvaTab
	Button button_sq_DVaDiamGraph,pos={264,146},size={30,20},title="Pop", proc=sq_butt_popThis
	Button button_sq_DVaDiamTable,pos={258,124},size={40,20},proc=sq_butt_PToF_DVaTable,title="Table"

	nvar DVa_run_number = root:panel:DVa_run_number
	sq_DVaGraph_SetVar("",DVa_run_number,"","")
	
	Display/W=(10,180,294,365)/HOST=# 
	RenameWindow #,DVaDiam		
	sq_populate_DVaDiamGraph() 
	SetActiveSubwindow ##

End


// used within dVa_gr and not used for any calculations using spectra
Function sq_DVaGraph_SetVar(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName	

	wave ptof_dVaDisplayTime = root:panel:ptof_dVaDisplayTime		// used for 10, 100 1k nm size
	wave ptof_dVaDisplaySize = root:panel:ptof_dVaDisplaySize
	wave rn_series = root:index:rn_series
	
	nvar lc = root:panel:cor3_chamber	
	svar DVa_PToFInfo = root:panel:DVa_PToFInfo
	nvar DVa_vl = root:panel:DVa_vl
	nvar DVa_vg = root:panel:DVa_vg
	nvar DVa_dx = root:panel:DVa_dx
	nvar DVa_b = root:panel:DVa_b
	nvar DVa_NumPToFBins = root:panel:DVa_NumPToFBins		//1.51Q
	nvar DVa_t0 = root:panel:DVa_t0
	nvar DVa_tstep = root:panel:DVa_tstep

	variable idex, existsVar
	make/o/n=10/FREE DVa_wave
	idex = sq_FindRun(rn_series, varNum)
	if (idex>=0)
		sq_GetPToFParams(DVa_wave, idex)		
		DVa_NumPToFBins=DVa_wave[%NumPToFBins]
		Redimension/n=(DVa_NumPToFBins) ptof_dVaDisplaySize, ptof_dVaDisplayTime
		ptof_dVaDisplayTime = DVa_wave[%t0] + p*DVa_wave[%step]
		ptof_dVaDisplaySize = sq_ptof2dva(lc,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],ptof_dVaDisplayTime[p])

//		ptof_dVaDisplayTime*=1e6		// convert from s to us		//1.59E
		DVa_vl = DVa_wave[%vl]
		DVa_vg = DVa_wave[%vg]	
		DVa_dx = DVa_wave[%dx]	
		DVa_b = DVa_wave[%b]
		DVa_t0 = DVa_wave[%t0]
		DVa_tstep = DVa_wave[%step]
	else
		DVa_vl =  nan
		DVa_vg =  nan	
		DVa_dx =  nan	
		DVa_b =  nan
		DVa_t0 =  nan	
		DVa_tstep =  nan	
		DVa_NumPToFBins = 0
		ptof_dVaDisplayTime = nan
		ptof_dVaDisplaySize = nan
	endif
		
	existsVar = sq_doesPToFDataExist(varNum)
	if (existsVar==-1)
		DVa_PToFInfo=""
	else
		DVa_PToFInfo="PToF ? "+num2str (existsVar)
	endif
	
End


// new in 1.52 
// General helper function for retrieving PToF parameters for a run
Function sq_GetPToFParams(DVa_wave, runPos, [HRPToFMatrixRow])  //1.60T
	wave DVa_wave
	variable runPos, HRPToFMatrixRow

	// order is not important
	redimension/n=15 DVa_wave		// 1.61G
	SetDimLabel 0,0,vl,DVa_wave
	SetDimLabel 0,1,vg,DVa_wave
	SetDimLabel 0,2,b,DVa_wave
	SetDimLabel 0,3,dx,DVa_wave
	SetDimLabel 0,4,t0,DVa_wave
	SetDimLabel 0,5,step,DVa_wave
	SetDimLabel 0,6,numPToFBins,DVa_wave
	SetDimLabel 0,7,isEPToF,DVa_wave
	SetDimLabel 0,8,coAdd,DVa_wave
	SetDimLabel 0,9,ChopperFreqHz,DVa_wave
	SetDimLabel 0,10,ePToFOS,DVa_wave
	SetDimLabel 0,11,ePToFenabled,DVa_wave
	SetDimLabel 0,12,chamberLen,DVa_wave
		
	if (runPos<0)
		DVa_wave=nan
		return 0
	endif
	
	nvar cor3_chamber=root:panel:cor3_chamber	// not in panel, loaded in get index
	DVa_wave[%chamberLen]=cor3_chamber

	wave/z vl=root:diagnostics:ptof_vl	
	if (!WaveExists(vl))
		wave vl=root:diagnostics:ptof_vl_logged
		duplicate/o vl root:diagnostics:ptof_vl
	endif
	DVa_wave[%vl] = vl[runPos]		// 1.41C

	wave/z vg=root:diagnostics:ptof_vg
	if (!WaveExists(vg))
		wave vg=root:diagnostics:ptof_vg_logged
		duplicate/o vg root:diagnostics:ptof_vg
	endif
	DVa_wave[%vg] = vg[runPos]		// 1.41C

	wave/z b=root:diagnostics:ptof_b	
	if (!WaveExists(b))
		wave b=root:diagnostics:ptof_b_logged
		duplicate/o b root:diagnostics:ptof_b
	endif
	DVa_wave[%b] = b[runPos]		// 1.41C

	wave/z dx=root:diagnostics:ptof_dx
	if (!WaveExists(dx))
		wave dx=root:diagnostics:ptof_dx_logged
		duplicate/o dx root:diagnostics:ptof_dx
	endif
	DVa_wave[%dx] = dx[runPos]		// 1.41C
	
	wave/z ePToF_enabled = root:diagnostics:ePToF_enabled
	DVa_wave[%isEPToF] = WaveExists(ePToF_enabled) && ePToF_enabled[runPos]

	wave ptof_t0 = root:diagnostics:ptof_t0
//	variable real_PToF_t0 = (WaveExists(ePToF_enabled) && ePToF_enabled[runPos]) ? 0 : ptof_t0[runPos]			//1.59E
	DVa_wave[%t0] =ptof_t0[runPos] //  real_PToF_t0
	
	wave ptof_step = root:diagnostics:ptof_step
	DVa_wave[%step] = ptof_step[runPos]		// 1.41C

	wave ptofNumSpectraPerChop = root:diagnostics:ptofNumSpectraPerChop
	DVa_wave[%numPToFBins] = ptofNumSpectraPerChop[runPos]

	wave ptofCoAdd = root:diagnostics:ptofCoAdd
	DVa_wave[%coAdd] =ptofCoAdd[runPos]

	wave ChopperFreq = root:diagnostics:ChopperFreq			//1.60X
	DVa_wave[%ChopperFreqHz] =ChopperFreq[runPos]

	wave ePToF_Oversampling = root:diagnostics:ePToF_Oversampling			//1.60X
	DVa_wave[%ePToFOS] =ePToF_Oversampling[runPos]

	wave ePToF_enabled = root:diagnostics:ePToF_enabled			//1.60X
	DVa_wave[%ePToFenabled] =ePToF_enabled[runPos]
	
	if (!ParamIsdefault(HRPToFMatrixRow))		//1.60T   // by definition this has to be regular PToF not ePToF
		wave PToFDataSetMatrixFlag = root:PToF:PToFDataSetMatrixFlag
		wave PToFDataSetStartPt = root:PToF:PToFDataSetStartPt
		wave PToFDataSetStopPt = root:PToF:PToFDataSetStopPt
		variable numNewbins = PToFDataSetMatrixFlag[HRPToFMatrixRow]
		variable numDelta = floor( (PToFDataSetStopPt[HRPToFMatrixRow] - PToFDataSetStartPt[HRPToFMatrixRow]+1)/numNewbins)
		numDelta *= ptof_step[runPos]
		DVa_wave[%t0] =ptof_t0[runPos] +ptof_step[runPos]*PToFDataSetStartPt[HRPToFMatrixRow]
		DVa_wave[%step] = numDelta*ptof_step[runPos]	
	endif
	
End


//1.59E
Function sq_fix_ePToF_t0()
	wave ePToF_enabled = root:diagnostics:ePToF_enabled
	wave PToF_t0 = root:diagnostics:PToF_t0
	wave/z PToF_delay_us = root:diagnostics:PToF_delay_us			// parval 7, added in 1.57H
	wave/z/t ComParValText = root:diagnostics:ComParValText
	wave ChopperFreq = root:diagnostics:ChopperFreq
	wave ePToF_oversampling = root:diagnostics:ePToF_oversampling
	nvar chopper_duty = root:diagnostics:chopper_duty
//	1.59E		
//	case "ptof_t0":		
//	if( ComParValExists)
//		dest[p1]=(ParVal[idex][7]*0.000001)-(0.5*CommonParVal[idex][7]/(CommonParVal[idex][37]))  // cor3_t_offset+ removed 1.59E This is incorrect for ePToF runs.  This needs to be fixed after we fix  ePToF_enabled
// ParVal[][7] =(8) Delay after chopper before data acquisition starts (us)
// CommonParVal[][7] =(8) Duty Cycle of the Chopper
// CommonParVal[][37] =(38) Default Chopper Frequency (Hz)
//	else
//		dest[p1]=(ParVal[idex][7]*0.000001)-(0.5*ParVal[idex][14]/(ParVal[idex][45]))  // cor3_t_offset+removed 1.59E  user parval, not infoval
// ParVal[][7] =(8) Delay after chopper before data acquisition starts (us)
// ParVal[][14] = (14) Duty cycle of the chopper 
// ParVal[][45] = (46) Default Chopper frequency (Hz)
//	ptof_t0 = (WaveExists(ComParValText) && WaveExists(ePToF_enabled) && ePToF_enabled[p]) ? -0.5*(1/254)/ChopperFreq[p] : ptof_t0[p]			//1.59E
//	ptof_t0 = (WaveExists(ComParValText) && WaveExists(ePToF_enabled) && ePToF_enabled[p]) ? -(0.5*chopper_duty/ChopperFreq[p])+-0.5*(1/254)/ChopperFreq[p] : ptof_t0[p]			//1.59E

	pToF_t0 = (WaveExists(ComParValText) && WaveExists(ePToF_enabled) && ePToF_enabled[p])  ? -0.5*(1/127)/ChopperFreq[p]  : ptof_delay_us[p]*0.000001 - 0.5*chopper_duty/ChopperFreq[p]		//1.58B  cor3_t_offset + removed in 1.59E
	// 1.60X fix  discussions and email with Mike C indicate that for tw deconvolved, we need slightly different value for PToF t0
//	pToF_t0 = (WaveExists(ComParValText) && WaveExists(ePToF_enabled) && ePToF_enabled[p])  ? -(1/2)*(1/ePToF_oversampling[p])*(1/127)/ChopperFreq[p]  : ptof_delay_us[p]*0.000001 - 0.5*chopper_duty/ChopperFreq[p]		//1.58B  cor3_t_offset + removed in 1.59E


End


//^ changed in 1.36 after email from Joel confirming the values that the DAQ uses.
Function sq_initializeResolutionParams()

	nvar/z resolution_R0 = root:diagnostics:resolution_R0
	nvar/z resolution_dm = root:diagnostics:resolution_dm
	nvar/z resolution_m0 = root:diagnostics:resolution_m0

	if (NVar_Exists(resolution_R0) && NVar_Exists(resolution_dm)  && NVar_Exists(resolution_m0) )// 1.41A
		return 0
	endif
	
	variable/g root:diagnostics:resolution_R0
	variable/g root:diagnostics:resolution_dm
	variable/g root:diagnostics:resolution_m0
	nvar resolution_R0 = root:diagnostics:resolution_R0
	nvar resolution_dm = root:diagnostics:resolution_dm
	nvar resolution_m0 = root:diagnostics:resolution_m0
	
	nvar AMSType = root:AMSType
	
//change in .148
		resolution_R0 = 350			
		resolution_dm = 50 		
		resolution_m0 =  75		

//  Note in Silke's thesis she uses
// R0=964
// m0=26
// dm = 114.5
	
End


// retained in 1.44B to be compatible with 1.04 Pika -
//^ puts values into mz_peak, mz_start, mz_end waves in anticipation of finding peaks or stick compliment
//^ Note that mz_peak, mz_start, mz_end correspond to integer mass values counting from 1, not 0
//  Modified in 1.40D
Function sq_stickCalcPrep(MS, MSres, MSaxis, startMZ, find_op, peakIntegrationDelta, mz_peak, mz_start, mz_end)
	wave MS, MSres, MSaxis, mz_peak, mz_start, mz_end
	variable startMZ, find_op, peakIntegrationDelta
	
	nvar/z bk_ck_AdditionalStickComp = root:baselineFitting:bk_ck_AdditionalStickComp
	nvar/z bk_UseMassDefect = root:baselineFitting:bk_UseMassDefect		//1.34

	variable mz,idex,len,ptof=dimsize(ms,1)>0,num, Int1, Int2
	variable startPt, stopPt
	
	mz_peak=nan
	mz_start=nan
	mz_end=nan

	if (find_op && !ptof) //& find peak rather than using the nominal values //^ not incorporating mass defect for now
		for(idex=startmz;idex<len;idex+=1)
			mz=binarysearchinterp(MSaxis,idex)
			findpeak/p/b=3/q/r=[mz-5,mz+5] MS
			mz_peak[idex-1]=(V_flag==0)? V_peakloc : mz
		endfor
	else
		if (NVar_Exists(bk_UseMassDefect) && bk_UseMassDefect==1)	//1.34
			wave/z sr_MassDefect = root:stickRecalc:sr_MassDefect
			if (WaveExists(sr_MassDefect)==1)
				mz_peak[startmz,]=binarysearchinterp(MSaxis,sr_MassDefect[p])
			else
				Abort "Cannot find mass defect wave root:stickRecalc:sr_MassDefect - Aborting from sq_StickCalcPrep"
			endif
		else
			mz_peak[startmz,]=binarysearchinterp(MSaxis,p+1)		//^ gets set to nan if out of range
		endif
	endif

	mz_start[startmz,]=binarysearchinterp(MSaxis,MSaxis[mz_peak[p]]-min(peakIntegrationDelta,((p+1)/(2*MSres[mz_peak[p]]))))
	mz_end[startmz,]=binarysearchinterp(MSaxis,MSaxis[mz_peak[p]]+min(peakIntegrationDelta,((p+1)/(2*MSres[mz_peak[p]]))))

	if (!NVar_Exists(bk_ck_AdditionalStickComp) || !bk_ck_AdditionalStickComp)		// 1.41A
		return 0
 	endif

	wave/z bk_RemoveFromStickCompStart = root:baselineFitting:bk_RemoveFromStickCompStart
	wave/z bk_RemoveFromStickCompStop = root:baselineFitting:bk_RemoveFromStickCompStop
	wave/z bk_RemoveFromStickCompNMLFlag = root:baselineFitting:bk_RemoveFromStickCompNMLFlag
	
	if (WaveExists(bk_RemoveFromStickCompStop)==0)
		return 0		// The user checked this box but the waves don't exist.
	endif
	
	num = numpnts(bk_RemoveFromStickCompStart)

	for(idex=0;idex<num;idex+=1)
		startPt = binarysearch(MSaxis, bk_RemoveFromStickCompStart[idex])
		stopPt = binarysearch(MSaxis, bk_RemoveFromStickCompStop[idex])
		if (startPt < stopPt && bk_RemoveFromStickCompNMLFlag[idex]>=1)
			Int1 = round(bk_RemoveFromStickCompStart[idex])
			Int2 = round(bk_RemoveFromStickCompStop[idex])
			// the stopPt my need to be put into mz_start
			if ( stopPt > mz_start[Int1-1] && stopPt< mz_peak[Int1-1]  )
				mz_start[Int1-1] = stopPt
			endif
			//  the startPt may need to be put into mz_end
			if (startPt < mz_end[Int2-1] && startPt> mz_peak[Int2-1] )
				mz_end[Int2-1] = startPt
			endif
		endif
	endfor

End


//^ puts values into pt_start, pt_end waves in anticipation of integration or baseline fitting
//^ Note that pt_start, pt_end correspond to integer mass values counting from 1, not 0
//  Modified significantly in 1.44B
Function sq_stickCalcPrepRegion(MS, MSaxis, startMZ, endMz, Region_startmz, Region_stopmz,  pt_start, pt_end)
	wave MS, MSaxis, Region_startmz, Region_stopmz,  pt_start, pt_end
	variable startMZ, endMz
		
	pt_start[0, startmz-1]=nan		
	pt_end[0, startmz-1]=nan	

	variable LastP = dimsize(pt_end,0)-1			//1.59D
	variable LastRegionP = dimsize(Region_startmz,0)-1			//1.59D
	
	if (LastP!=LastRegionP)		//1.59D
		LastP = min(LastP,LastRegionP) 	
	endif
	
	pt_start[startmz,min(LastP,endmz-1)]=binarysearchinterp(MSaxis,Region_startmz[p])		//1.158G
	pt_end[startmz,min(LastP,endmz-1)]=binarysearchinterp(MSaxis,Region_stopmz[p])			//1.158G

	if (endmz< LastP)		// added if statement 1.49E
		pt_start[endmz+1,]=nan
		pt_end[endmz+1,]=nan
	endif
End


//& Assumes baseline already applied
//^ Simple stick calculation function - all we do is find the area 
Function sq_stickCalc(rawMS,stickMS, startMZ, kill, pt_start, pt_end, [nSecMSsampling])
	wave rawMS,stickMS, pt_start, pt_end
	variable startMZ, kill, nSecMSsampling			//DTS nSecMSsampling added
	
	variable ptofFlag, idex, num

	if (ParamIsDefault(nSecMSsampling) )
		nSecMSsampling=1
	endif

	ptofFlag=dimsize(rawMS,1)>0
	
	stickMS[0,startmz-1][]=0
	if (ptofFlag) //& Handles ptof data - 1.47g Transposed
		num=dimsize(rawMS,1)		// number of PToF bins
		for (idex=0;idex<num;idex+=1)		//^ for each ptof size bin
			imagetransform /g=(idex) getcol rawMS		// JDA change in 1.47G
			wave W_ExtractedCol
			stickMS[startMZ,][idex]=area(W_ExtractedCol,pt_start[p],pt_end[p]) 		// *nSecMSsampling  1.53M		//1.53H
		endfor
	else
		stickMS[startMZ, ]=area(rawMS,pt_start[p],pt_end[p]) 		// *nSecMSsampling  1.53M    //&  	//1.53H
	endif
	
	stickMS=numtype(stickMS)?(0):(stickMS) //&
 
	if(kill)
		killwaves/z W_ExtractedCol
	endif
	
End 

//@ function to recalculate MS/PToF sticks, and dc marker correction //WIP
//^  Significantly modified
//& Modified 1.47g to allow for baseline subtraction
// PToF sticks have the dimensions:
// row = run
// col = size (or increasing time - big particles = bigger time)
// layer = m/z 
// only called when we recalcualte PToF sticks!
Function sq_PToFstick(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns

	//@ globals and waves
	wave mzInt = $ReplaceString("/", StringByKey("Int", paramstr),  ":")
	wave mzSlope = $ReplaceString("/", StringByKey("Slope", paramstr),  ":")
	wave mzPower= $ReplaceString("/", StringByKey("Power", paramstr), ":")
		
	wave series_index=root:index:series_index
	wave mStart=root:diagnostics:mStart
//	wave mFinish = root:diagnostics:mFinish

	wave ptofNumTimesThrough=root:diagnostics:ptofNumTimesThrough
	wave rn_series=root:index:rn_series
	wave TofTypeWKey=root:diagnostics:TofTypeWKey		//1.19E

	wave/z nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.53H
	if (!WaveExists(nSecMSsamplingInterval)   || !waveMax(nSecMSsamplingInterval) >0) 
		make/o/n=(numpnts(mStart))  root:diagnostics:nSecMSsamplingInterval=1		// default - old card always at 1ns
		wave nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.53H
	endif

	variable kill= (acorn==n_acorns-1) && numberbykey("kill",paramstr)
	variable raw_flag=numberbykey("raw_flag",paramstr) // Raw (non-processed) mass spectra are being used
	variable hz_op=numberbykey("hz_op",paramstr)
	variable duty_op=numberbykey("duty_op",paramstr)
	
	variable maxMz =  numberbykey("maxMz",paramstr)
	variable minMz =  numberbykey("minMz",paramstr)
	variable stickBL_op=numberbykey("stickBL_op",paramstr) 		// JDA 1.47G
	variable smoothBackground=numberbykey("smoothpnts",paramstr)	// JDA 1.47G
	variable spline_op=numberbykey("spline_op",paramstr)	// JDA 1.47G

	variable ePToF_flag=numberbykey("ePToF_flag",paramstr)	// JDA 1.47G
	variable ePToF_OS=numberbykey("ePToF_OS",paramstr)	// JDA 1.47G
	variable applyDC=numberbykey("applyDC",paramstr)==1
		
	variable bk_UseTofwerk=numberbykey("bk_UseTofwerk",paramstr)==1

	string destStr = StringByKey("dest", paramstr)

	//1.57D
	variable collapsePToF_op=numberbykey("collapsePToF_op",paramstr)
	variable collapsePToF_Avg=numberbykey("collapsePToF_Avg",paramstr)
	string collapsePToF_dest=stringbykey("collapsePToF_dest",paramstr)
//	variable collapsePToF_ChopDuty=numberbykey("collapsePToF_ChopDuty",paramstr)

	variable idex, numRuns, numInPToF, numInRawSpectra, sPos, startMZ, iToF_offset, iToF_min, iToF_max		//1.49A
	variable run_int,run_sl,run_pow, goodPToFMS, nSecMSsampling, SamplingInterval		//DTS 1.53H
	variable isWflag
	string str1
	
	make/o/n=(maxMz)/Free NanStick=nan		//1.53D
	
	sq_ams_stat_upd("Recalculating PToF Sticks")
	sq_ams_prog_upd(100*acorn/n_acorns)
	
	wave PToFraw_acorn=$stringbykey("acorn_0",paramstr)

	numRuns = dimsize(PToFraw_acorn,0)
	numInPToF=dimsize(PToFraw_acorn,1)
	numInRawSpectra=dimsize(PToFraw_acorn,2)

//	iToF_offset = 0 // -5450			// 1.49A for CalNex fix... for when the DAQ saves the raw spectra with an offset
//	iToF_min = max(0, iToF_offset) 		   //  = 0 if iToF_offset is negative
//	iToF_max = min(numInRawSpectra, numInRawSpectra+iToF_offset)-1  	// = numInRaw if iToF_offset is positive

	make/o/n=(numInRawSpectra) axis_temp, BaselineMask_temp
	make/o/n=(numRuns ,numInPToF, maxmz) Dest_ptof_stick=nan
	make/o/n=(numInRawSpectra, numInPToF) MS_temp=nan		//i.e. 25,000 x 300
	make/o/n=(maxmz, numInPToF) Stick //Transposed	// JDA 1.47G
	make/o/n=(maxmz ,numInPToF, numRuns) Dest_ptof_stickTRANSP
	make/o/n=(maxmz) pt_start, pt_end
	make/o/n=(maxmz, numInPToF) NanStick=nan
	
	if (stickBL_op)		// calculate the baseline.... sticks for oen PToF run, one PToFBin, 
		make/o/n=(numInRawSpectra, numInPToF) BaselineMatrix_temp
		make/o/n=(numRuns ,numInPToF, maxmz) Dest_ptof_stick_BaseL=nan
		make/o/n=(maxmz, numInPToF) stickBL=nan
		make/o/n=(maxmz, numInPToF, numRuns) Dest_ptof_stick_BaseLTRANSP=nan
		struct Tofware#tw_bsl_smooth_var f	
	endif 

	minMz = numtype(minMz)==0 ? minMz : MZ_START_VALUE

	SamplingInterval = sq_nSecMSsamplingIntervalConst()

	// step (0) 
	if (raw_flag && hz_op)
		sq_hz(index_pos,PToFraw_acorn)
	endif
	
	// step (1) 
	if (acorn == 0)
		sq_initializeResolutionParams()  // 1.52O  for the odd case where this hasn't been done via MS first
		sq_stickCalcGetRegions(maxMz)
	endif
	
	wave StickRegion_startmz = root:baselineFitting:StickRegion_startmz
	wave StickRegion_stopmz = root:baselineFitting:StickRegion_stopmz
 	wave BaselineRegion_startmz = root:baselineFitting:BaselineRegion_startmz  	// JDA 1.47G
	wave BaselineRegion_stopmz = root:baselineFitting:BaselineRegion_stopmz  	// JDA 1.47G
	
// be careful for 1  run waves
	ImageTransform/G=3 TransposeVol PToFraw_acorn  // mode = 3 means output=w[r][q][p]; Old rows= runs are new layers
	wave M_VolumeTranspose // has dimensions rawmz x ptofbins x runs 

// to make the calculations easier we generate sticks with the mz unit, dimension as the row.  We convert to mz dimension = layer after the for loop	
	for(idex=0;idex<numRuns;idex+=1)		//^ go through the runs
		if(index_pos[idex]==-1)
			continue
		endif
		// step (2) 
		sPos=series_index[index_pos[idex]]
		run_int=mzInt[sPos]
		run_sl=mzSlope[sPos]
		run_pow=mzPower[sPos]	
		nSecMSsampling=nSecMSsamplingInterval[sPos]	
		startMZ = mStart[sPos]
		isWFlag = TofTypeWKey[sPos]
		nSecMSsampling= nSecMSsamplingInterval[sPos]		//1.53H

		if (!numtype(run_int) && !numtype(run_sl) && !numtype(run_pow)) //& Only calculate if a valid intercept and slope exist
			multithread axis_temp =( ( p -run_int)/run_sl )^(1/run_pow)			// 1.49E  iToF_offset	
			if (run_int>0)			//1.14I
				axis_temp[0,ceil(run_int)]=0
			endif
			// step (3)
			ImageTransform /P=(idex) getPlane M_VolumeTranspose		// do NOT use /D=MS_temp, /D is for data wave, not used with getPlane
			wave M_ImagePlane
			multithread MS_temp = M_ImagePlane
			goodPToFMS = numtype(MS_temp[0][0])==0

			if (goodPToFMS) 
				sq_StickCalcPrepRegion(MS_temp, axis_temp, startMZ, maxMz, StickRegion_startmz, StickRegion_stopmz, pt_start, pt_end)	//1.49E
				//  we do not require the user to have the same integration  regions for PToF as for MS
				// in MS we save the start and end points that we used to calc the sticks.... make an option to use same regions for faster processing
				
				// step (4)
				sq_StickCalc(MS_temp,stick,startMZ, kill, pt_start, pt_end, nSecMSsampling=nSecMSsampling)
				
				//& Do baselines
				if (stickBL_op)
					// step (5) 
					if (!bk_UseTofwerk)
	 					bk_createStickComplimentMask(BaselineMask_temp, BaselineRegion_startmz, BaselineRegion_stopmz, axis_temp)
						BaselineMatrix_temp=BaselineMask_temp[p]
						ImageTransform /P=(idex) getPlane M_VolumeTranspose	// do NOT use /D=MS_temp, /D is for data wave, not used with getPlane
						wave M_ImagePlane
						fastop MS_temp = M_ImagePlane*BaselineMatrix_temp
						bk_makeBkZeroBeyondMassX(axis_temp, MS_temp, 4)		// 4 indicates PToF in this function
						bk_fitStickCompliment(MS_temp, 0, 0, kill, smoothBackground,spline_op)
					else
						duplicate/o/free MS_temp MS_tempBL
						bk_twbaseline(MS_temp, MS_tempBL, f)
						Multithread MS_temp-= MS_tempBL
					endif
					
					// step (6) 
					sq_StickCalc(MS_temp,stickBL,startMZ,kill, pt_start, pt_end, nSecMSsampling=nSecMSsampling)

					Fastop Stick = stick - stickBL
					ImageTransform /P=(idex)/D=stickBL setPlane Dest_ptof_stick_BaseLTRANSP		//  /D is for data wave
				endif
				
				ImageTransform /P=(idex)/D=stick setPlane Dest_ptof_stickTRANSP		//  /D is for data wave  Dest_ptof_stickTRANSP is mz x ptof bin x run
			else		// we don't have good raw PToF spectra
				if (ptofNumTimesThrough[sPos]>0)	//^1.37C This means we should have had PToF data for this run, but we can't find the raw ptof data
					sprintf str1, "%d" , rn_series[spos]		// small bug, things can go wrong with run numbers > 1e6
					print "// There seems to be a problem calculating PToF sticks for run number "+str1+" Check the location of the raw ptof hdf file."
				endif
				ImageTransform /P=(idex)/D=NanStick setPlane Dest_ptof_stickTRANSP// Dest_ptof_stick		//  /D is for data wave
				if (stickBL_op) 
					ImageTransform /P=(idex)/D=NanStick setPlane Dest_ptof_stick_BaseLTRANSP  // Dest_ptof_stick_BaseL		//  /D is for data wave
				endif 

			endif	
		else		// we don't have good mz parameters
			ImageTransform /P=(idex)/D=NanStick setPlane Dest_ptof_stickTRANSP		//  /D is for data wave
			if (stickBL_op) 
				ImageTransform /P=(idex)/D=NanStick setPlane Dest_ptof_stick_BaseLTRANSP		//  /D is for data wave
			endif 
		endif
	endfor	// loop for every run in acorn
	
	ImageTransform/G=3 TransposeVol Dest_ptof_stickTRANSP  // mode = 3 means output=w[r][q][p]; Old rows= runs are new layers
	fastOP Dest_ptof_stick = M_VolumeTranspose
//	MatrixOP/O/FREE Dest_ptof_stick=transposevol(Dest_ptof_stickTRANSP,3)  // mode = 3 means output=w[r][q][p]; Old rows= runs are new layers

	if (stickBL_op) 
//		MatrixOP/O/FREE Dest_ptof_stick_BaseL=transposevol(Dest_ptof_stick_BaseLTRANSP,3)  // mode = 3 means output=w[r][q][p]; Old rows= runs are new layers
		ImageTransform/G=3 TransposeVol Dest_ptof_stick_BaseLTRANSP  // mode = 3 means output=w[r][q][p]; Old rows= runs are new layers
		fastOP Dest_ptof_stick_BaseL = M_VolumeTranspose
	endif 

	sq_correctSamplingTimeUnit(index_pos,Dest_ptof_stick, nSecMSsamplingIntervalVal=SamplingInterval)		//1.54D
	if (stickBL_op)
		sq_correctSamplingTimeUnit(index_pos,Dest_ptof_stick_BaseL, nSecMSsamplingIntervalVal=SamplingInterval)		//1.54D		//1.57K
	endif
	
	//  we want to do the duty cycle before the ePToF dconvolving so that we don't have to do DC marker stuff
	if (duty_op)
		sq_dutycyclecorr(Dest_ptof_stick,kill)
		if (stickBL_op)
			sq_dutycyclecorr(Dest_ptof_stick_BaseL,0)
		endif
	endif
	
	if (collapsePToF_op)
		sq_create_MS_PToF(index_pos, Dest_ptof_stick, collapsePToF_Avg, hz_op, 0, collapsePToF_dest, acorn==n_acorns-1)	
	endif

	if(ePToF_flag && ePToF_OS>0)	// ePToF
		if (applyDC)		// checkbox is for both apply DC and deconvolve ePToF
			sq_preProcessEPToF(index_pos,Dest_ptof_stick, ePToF_OS, 1 ,acorn==n_acorns-1)
			if (stickBL_op) 
				sq_preProcessEPToF(index_pos,Dest_ptof_stick_BaseL, ePToF_OS,0,acorn==n_acorns-1)
			endif 
		else		// we flag that we have not deconvolved ePToF data
			sq_NoDCPreprocPToF(index_pos, 1 )
			//sq_AvgAcrossPToF(index_pos, Dest_ptof_stick, acorn==n_acorns-1)
			sq_create_MS_PToF(index_pos, PToFraw_acorn, ePToF_OS*127, 0,duty_op,"MSSePToFSum_p", acorn==n_acorns-1)
		endif
	else			// not  ePToF

		if (applyDC) //& Apply DC markers		//^ section moved in 1.37C	// in theory we could do DC markers with eptof joel deconvolve method

			variable dc1=numberbykey("dc1",paramstr)
			variable dc2=numberbykey("dc2",paramstr)
			variable dc3=numberbykey("dc3",paramstr)
			variable dc4=numberbykey("dc4",paramstr)
			string region1only=stringbykey("region1only",paramstr)
			string region2only=stringbykey("region2only",paramstr)
		
			sq_ams_stat_upd("Applying DC markers")
			sq_ApplyDCmarkers(Dest_ptof_stick,index_pos,acorn==n_acorns-1,dc1,dc2,dc3,dc4,region1only,region2only, ePToF_flag, ePToF_OS,1)		
		else
			sq_NoDCPreprocPToF(index_pos, 0)
		endif
	endif

	//@ write the data to memory/hdf
	sq_ams_stat_upd("Dumping ptof data")
	//1.14M  UMR
	squirrel_hdf_write(index_pos,Dest_ptof_stick, "PToF_stick_p")	//^ destStr should always be 'PToF_stick_p'	
	if (stickBL_op) 
		//1.14M  Raw spectra or UMR
		squirrel_hdf_write(index_pos,Dest_ptof_stick_BaseL, "PToFBaseL_p")	//^ destStr should always be 'PToF_stick_p'	
	endif 

	if (kill)		//^ just kill these at the end
		killwaves/z axis_temp, BaselineMask_temp
		killwaves/z Dest_ptof_stick,MS_temp
		killwaves/z Stick
		killwaves/z mz_peak, pt_start, pt_end
		killwaves/z Dest_ptof_stick_BaseL, stickBL
		killwaves/z duty_tmp	
		killwaves/z M_VolumeTranspose, M_ImagePlane
		killwaves/z Dest_ptof_stickTRANSP, Dest_ptof_stick_BaseLTRANSP
		killwaves/z NanStick, BaselineMatrix_temp	
	endif

End


//@ function to recalculate MS sticks, apply duty cyle correction, and resize stick matrices
// This function will only be called if the MS Stick Recalc checkbox is checked.
// Here is how sticks are recalculated if new m/z parameters and baselines are used.
// (1) First sq_stickCalcGetRegions(maxMz) is called to set up the stick integration and baseline regions in *m/z* space
// The 4 waves generated by sq_stickCalcGetRegions do not change with different m/z params.
// (2) For each run get the m/z slope, intercept and power and make an m/z axis for this run.  For simplicity we do *not*
// use separate m/z parameters for open and closed spectra.  The different m/z params should be close enough that the
// stick integration region and the baseline regions should be the almost identical.
// (3) Grab a raw open spectra
// (4) Calc the open stick *without the baseline subtracted*
// (5) If using baselines make a baseline mask wave.  This mask wave will be used for open, closed, diff.  Do any other special baseline calcs.
// (6) Find the open baseline stick and subtact the baseline stick from the open (no baseline) stick
// Then do steps 3 - 6 with the closed and the diff.
// significantly edited in 1.44B
//& Rehash 1.47G on how the smoothing works
Function sq_MSstick(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn,n_acorns
	
	//@ globals and waves
	wave mzInt = $StringByKey("Int", paramstr)
	wave mzSlope = $StringByKey("Slope", paramstr)
	wave mzPower = $StringByKey("Power", paramstr)
	
	string dest_OpenStr = StringByKey("dest_OpenStr", paramstr)
	string dest_ClosedStr = StringByKey("dest_ClosedStr", paramstr)
	string dest_DiffStr = StringByKey("dest_DiffStr", paramstr)
	
	string dest_OpenBLStr = StringByKey("dest_OpenBLStr", paramstr)
	string dest_ClosedBLStr = StringByKey("dest_ClosedBLStr", paramstr)
	string dest_DiffBLStr = StringByKey("dest_DiffBLStr", paramstr)
		
	if (strlen(dest_OpenStr)==0)		// default case... for regular MS data		//1.60L
		dest_OpenStr = "MSSOpen_p"
		dest_ClosedStr = "MSSClosed_p"
		dest_DiffStr = "MSSDiff_p"
		dest_OpenBLStr = "MSSOpenBaseL_p"
		dest_ClosedBLStr = "MSSClosedBaseL_p"
		dest_DiffBLStr = "MSSDiffBaseL_p"
	endif
	
	wave series_index = root:index:series_index
	wave mStart = root:diagnostics:mStart
//	wave mFinish = root:diagnostics:mFinish
	wave/z nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.53H
	if (!WaveExists(nSecMSsamplingInterval) ||  !waveMax(nSecMSsamplingInterval) >0 )
		make/o/n=(numpnts(series_index)) root:diagnostics:nSecMSsamplingInterval=1		// default - old card always at 1ns
		wave nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.53N
	endif

//	nvar UseOpenClosed = root:panel:recalcSticks_OC_MS_ck // obsolete 1.53D

	variable idex,numRuns,numInRawSpectra, sPos, startMZ, isWflag,sumClosedTemp, sumOpenTemp		//^ i runs over the number of rows in the acorn - max = j
	variable run_int,run_sl,run_pow

	variable kill= (acorn==n_acorns-1) && numberbykey("kill",paramstr)
	variable raw_flag=numberbykey("raw_flag",paramstr) // Raw (non-processed) mass spectra are being used
	variable hz_op=numberbykey("hz_op",paramstr)
	variable duty_op=numberbykey("duty_op",paramstr)
	
	variable maxMz =  numberbykey("maxMz",paramstr)
	variable stickBL_op=numberbykey("stickBL_op",paramstr) 		// JDA 1.47G
	variable smoothpnts=numberbykey("smoothpnts",paramstr)	// JDA 1.47G
	variable spline_op=numberbykey("spline_op",paramstr)	// JDA 1.47G
	
	variable fillblank_op=numberbykey("fillblank_op",paramstr)			// I don't believe that this is used any more 1.52O
	variable goodOpenRawMS, goodClosedRawMS, nSecMSsampling
		
	wave TofTypeWKey=root:diagnostics:TofTypeWKey			// 99% of the time this will be moot because we use rawspectra data sets now
	if (WaveExists(TofTypeWKey)==0 )
		duplicate/o series_index, tempTofTypeWKey
		wave TofTypeWKey = root:tempTofTypeWKey
		TofTypeWKey = 0		
	endif
	
	nvar bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk
	
	//^ finally, everything is prepped
	sq_ams_stat_upd("Recalculating MS Sticks")
	
	wave open_acorn=$stringbykey("acorn_0",paramstr)
	wave closed_acorn=$stringbykey("acorn_1",paramstr)	
	numRuns=dimsize(open_acorn,0)
	numInRawSpectra = dimsize(open_acorn,1)
	
	make/o/n=(numInRawSpectra) axis_temp, BaselineMask_temp
	make/o/n=(numInRawSpectra) MS_Diff_temp, MS_Open_temp,MS_Closed_temp
	make/o/n=(numRuns,maxMz) destDiff=nan, destOpen=nan,destClosed=nan
	make/o/n=(numRuns,maxMz) destPtStart=nan,destPtEnd=nan
	make/o/n=(maxMz) DiffStick, OpenStick, ClosedStick
	make/o/n=(maxMz) pt_Start, pt_End			//^ contains point numbers
 	
	make/o/n=(maxMz)/FREE NanStick = nan  //1.53D
	
	variable samplingInterval= sq_nSecMSsamplingIntervalConst()			//1.57K
		//^ Get ready to make sticks	
	if (raw_flag && hz_op)
		sq_Hz(index_pos,open_acorn)
		sq_Hz(index_pos,closed_acorn)
	endif
	
	// step (1) 
	sq_initializeResolutionParams()  // 1.51L
	sq_stickCalcGetRegions(maxMz)		// set the integration regions and the baseline regions once.
	wave BaselineRegion_startmz = root:baselineFitting:BaselineRegion_startmz
	wave BaselineRegion_stopmz = root:baselineFitting:BaselineRegion_stopmz
	wave StickRegion_startmz = root:baselineFitting:StickRegion_startmz
	wave StickRegion_stopmz = root:baselineFitting:StickRegion_stopmz
	
//	if (stickBL_op)
		make/o/n=(numRuns,maxMz)/free destDiffBaseL=nan, destOpenBaseL=nan, destClosedBaseL=nan
		make/o/n=(maxMz)/free DiffStickBaseL=nan, OpenStickBaseL=nan, ClosedStickBaseL=nan
		make/o/n=(numRuns, numInRawSpectra)/free Openbk_tmp, Closedbk_tmp, Diffbk_tmp
//	endif

	struct UMR_integration UMR
	UMR.kill = acorn - n_acorns-1
	UMR.smoothpts = smoothpnts
	UMR.spline_op = spline_op
	UMR.stickBL_op = stickBL_op
	UMR.bk_UseTofwerk = bk_UseTofwerk

	wave UMR.runaxis = axis_temp
	wave UMR.runBLMask = BaselineMask_temp
	wave UMR.StartBL_Mz = BaselineRegion_startmz
	wave UMR.StopBL_Mz = BaselineRegion_stopmz
	wave UMR.Start_Mz = StickRegion_startmz
	wave UMR.Stop_Mz = StickRegion_stopmz
	wave UMR.Start_p  = pt_Start			//^ contains point numbers
	wave UMR.Stop_p  = pt_End			//^ contains point numbers

	for(idex=0;idex<numRuns;idex+=1)
		sq_ams_prog_upd(100*(acorn+(idex/numRuns))/n_acorns)
		if(index_pos[idex]==-1)
			continue
		endif
		
		// step (2) 
		sPos=series_index[index_pos[idex]]
		run_int=mzInt[sPos]
		run_sl=mzSlope[sPos]
		run_pow=mzPower[sPos]
		startMZ = mStart[sPos]
		isWFlag = TofTypeWKey[sPos]
		nSecMSsampling= nSecMSsamplingInterval[sPos]		//1.53H
		
		UMR.startMZVal = startMZ
		UMR.maxMzVal = maxMz
		UMR.nSecMSsampling = nSecMSsampling

		if (!numtype(run_int) && !numtype(run_sl) && !numtype(run_pow)) //& Only calculate if a valid intercept and slope exist
			
			multithread axis_temp=((p-run_int)/run_sl)^(1/run_pow)	//1.57K	// notice that we do NOT distinguish with using separate open and closed parameters.  For UMR this should be irrelevant
			if (run_int>0)
				axis_temp[0,run_int]=0		//1.14I
			endif
			
			//^ Open
			// step (3)

			ImageTransform/O/G=(idex) GetRow open_acorn
			wave W_ExtractedRow
			multithread MS_Open_temp=W_ExtractedRow		// from FastOp  //1.57K
			
			goodOpenRawMS = numtype(MS_Open_temp[0])==0   // we have a real numerical value as the first point in the raw spectra
			if (goodOpenRawMS)		// 1.42E  we could be in fast mode
				UMR.DataTypeFlag = 2  	// spectypeflag: 4=PToF data   1=Diff  2=Closed  3 = Open
				wave UMR.runrawMSBL = W_ExtractedRow
				wave UMR.runrawMS = MS_Open_temp
				wave UMR.runStickMS = OpenStick
				wave UMR.runStickMSBL = OpenStickBaseL
				
				sq_UMR_integration(UMR)
				
				if (UMR.stickBL_op)
					ImageTransform/O/D=OpenStickBaseL/G=(idex) putRow destOpenBaseL
					multithread OpenStick-=OpenStickBaseL
				endif
				
				ImageTransform/O/D=OpenStick/G=(idex) putRow destOpen

			else		// we don't have good raw spectra
				multithread OpenStick = NanStick		 // from FastOp  //1.57K // for use in calc diff later
				ImageTransform/O/D=OpenStick/G=(idex) putRow destOpen
				if (stickBL_op) 
					ImageTransform/O/D=NanStick/G=(idex) putRow destOpenBaseL
				endif 
			endif  
						
			//^ Closed
			ImageTransform/O/G=(idex) GetRow closed_acorn
			wave W_ExtractedRow
	 		multithread MS_Closed_temp = W_ExtractedRow  	 // from FastOp  //1.57K // for use in calc diff later

			goodClosedRawMS = numtype(MS_Closed_temp[0])==0
			//^ peak integration start and end point values already found
	
			if (goodClosedRawMS)		//^ we assume that if the first point of the raw data is nan, the whole wave is
				//^ get peak integration start and end point values once, here. 
				if (  !(goodOpenRawMS) )		// if we start in closed fast mode, we need to set waves pt_start, pt_end
					sq_StickCalcPrepRegion(MS_Closed_temp, axis_temp, startMZ, maxMz, StickRegion_startmz, StickRegion_stopmz, pt_start, pt_end)
					ImageTransform/O/D=pt_start/G=(idex) putRow destPtStart
					ImageTransform/O/D=pt_end/G=(idex) putRow destPtEnd
				endif

				UMR.DataTypeFlag = 3  	// spectypeflag: 4=PToF data   1=Diff  2=Closed  3 = Open
				wave UMR.runrawMSBL = W_ExtractedRow
				wave UMR.runrawMS = MS_Closed_temp
				wave UMR.runStickMS = ClosedStick
				wave UMR.runStickMSBL = ClosedStickBaseL
				
				sq_UMR_integration(UMR)

				if (UMR.stickBL_op)
					ImageTransform/O/D=ClosedStickBaseL/G=(idex) putRow destClosedBaseL
					multithread ClosedStick-=ClosedStickBaseL
				endif
				
				ImageTransform/O/D=ClosedStick/G=(idex) putRow destClosed

			else		// we don't have good raw spectra
				multithread ClosedStick = NanStick		 // from FastOp  //1.57K // for use in calc diff later
				ImageTransform/O/D=ClosedStick/G=(idex) putRow destClosed
				if (stickBL_op) 
					ImageTransform/O/D=NanStick/G=(idex) putRow destClosedBaseL
				endif 
			endif  
			
			//^ Diff
			if( !goodOpenRawMS ||  !goodClosedRawMS )  //if the open sticks sum to 0, (no data) there is no data for this run, set destw to 0 without subtracting the closed
				ImageTransform/O/D=NanStick/G=(idex) putRow destDiff
				if (stickBL_op) 
					ImageTransform/O/D=NanStick/G=(idex) putRow destDiffBaseL
				endif 
			else
				multithread DiffStick=OpenStick - ClosedStick    	
				if (stickBL_op)		// calculate the baseline 
					multithread DiffStickBaseL = OpenStickBaseL - ClosedStickBaseL    	
					ImageTransform/O/D=DiffStickBaseL/G=(idex) putRow destClosedBaseL
				endif 				
				ImageTransform/O/D=DiffStick/G=(idex) putRow destDiff
			endif
			
		else		// no valid slope, intercept, power are available  // I don't think this ever happens... we screen for good mz cal parameters before we get here
			ImageTransform/O/D=NanStick/G=(idex) putRow destDiff
			ImageTransform/O/D=NanStick/G=(idex) putRow destOpen
			ImageTransform/O/D=NanStick/G=(idex) putRow destClosed
			if (stickBL_op) 
				ImageTransform/O/D=NanStick/G=(idex) putRow destOpenBaseL
				ImageTransform/O/D=NanStick/G=(idex) putRow destClosedBaseL
				ImageTransform/O/D=NanStick/G=(idex) putRow destDiffBaseL
				ImageTransform/O/D=NanStick/G=(idex) putRow destPtStart
				ImageTransform/O/D=NanStick/G=(idex) putRow destPtEnd
			endif 
		endif
	endfor
	
	if (duty_op)
		sq_dutycyclecorr(destdiff,0)
		sq_dutycyclecorr(destopen,0)
		sq_dutycyclecorr(destclosed,kill)
		if (stickBL_op)
			sq_dutycyclecorr(destOpenBaseL,0)
			sq_dutycyclecorr(destClosedBaseL,0)
			sq_dutycyclecorr(destDiffBaseL,kill)
		endif 
	endif

	sq_correctSamplingTimeUnit(index_pos,destdiff, nSecMSsamplingIntervalVal=samplingInterval)		//1.54D		//1.57K
	sq_correctSamplingTimeUnit(index_pos,destopen, nSecMSsamplingIntervalVal=samplingInterval)
	sq_correctSamplingTimeUnit(index_pos,destclosed, nSecMSsamplingIntervalVal=samplingInterval)
	if (stickBL_op)
		sq_correctSamplingTimeUnit(index_pos,destOpenBaseL, nSecMSsamplingIntervalVal=samplingInterval)
		sq_correctSamplingTimeUnit(index_pos,destClosedBaseL, nSecMSsamplingIntervalVal=samplingInterval)
		sq_correctSamplingTimeUnit(index_pos,destDiffBaseL, nSecMSsamplingIntervalVal=samplingInterval)
	endif 

	//@ write the data to memory/hdf
	sq_ams_stat_upd("Dumping MS Stick data")
	nvar/z PutInMemory = root:panel:PutInMemory// bug in 1.49A, fixed in 1.49B1  //1.47E  // 1.50C
	if (!NVar_Exists(PutInMemory) || (NVar_Exists(PutInMemory) && PutInMemory==1)  )
		squirrel_mem_write(index_pos,destDiff,dest_DiffStr,dest_DiffStr)  //^MSSDIff stays in memory, open/closed do not	
	else
		//1.14M  UMR
		squirrel_hdf_write(index_pos,destDiff,dest_DiffStr)		//1.60L
	endif
	//1.14M  UMR
	squirrel_hdf_write(index_pos,destOpen,dest_OpenStr)		//1.60L
	squirrel_hdf_write(index_pos,destClosed,dest_ClosedStr)		//1.60L
	
	if (stickBL_op)
		//1.14M  UMR		//1.60L
		squirrel_hdf_write(index_pos,destOpenBaseL,dest_OpenBLStr)		//1.60L
		squirrel_hdf_write(index_pos,destClosedBaseL,dest_ClosedBLStr)		//1.60L
		squirrel_hdf_write(index_pos,destDiffBaseL,dest_DiffBLStr)		//1.60X
		squirrel_hdf_write(index_pos,destPtStart,"StickPtStart")
		squirrel_hdf_write(index_pos,destPtEnd,"StickPtEnd")		// was amuMzEnd in pre-1.44B
	endif 

	if (fillblank_op) // & Search for blanks and make the fillblank waves
		sq_findblanks(index_pos,destClosed,acorn==0,acorn==n_acorns-1)
	endif

	if (kill)
		killwaves /z MS_Diff_temp, MS_Open_temp,MS_Closed_temp,axis_temp,res_temp, BaselineMask_temp
		killwaves /z destDiff, destOpen,destClosed
		killwaves /z DiffStick, OpenStick, ClosedStick
		killwaves /z mz_Peak, pt_Start, pt_End
		killwaves /z destDiffBaseL, destOpenBaseL, destClosedBaseL
		killwaves /z DiffStickBaseL, OpenStickBaseL, ClosedStickBaseL
		killwaves /z destPtStart, destPtEnd
		killwaves /z W_ExtractedRow
	endif

End

//^  Calls sq_ApplyDCmarkers and writes hdf
//Function sq_dcMarkers(index_pos,paramstr,acorn,n_acorns)
//	wave index_pos
//	string paramstr
//	variable acorn,n_acorns
//	
//	wave PToF_stick=$stringbykey("acorn_0",paramstr)	
//	string destStr = stringbykey("dest",paramstr)
//	
//	variable kill= acorn==n_acorns-1
//	
//	variable dc1=numberbykey("dc1",paramstr)
//	variable dc2=numberbykey("dc2",paramstr)
//	variable dc3=numberbykey("dc3",paramstr)
//	variable dc4=numberbykey("dc4",paramstr)
//	string region1only=stringbykey("region1only",paramstr)
//	string region2only=stringbykey("region2only",paramstr)
//	
//	sq_ams_stat_upd("Applying DC markers")
//	sq_ApplyDCmarkers(PToF_stick,index_pos,kill,dc1,dc2,dc3,dc4,region1only,region2only)
//
//	//@ write the data to memory/hdf
//	sq_ams_stat_upd("Dumping ptof data")
//	squirrel_hdf_write(index_pos,PToF_stick, destStr)	//^ destStr should always be 'PToF_stick_p'
//	
//End

//& Generic version of the duty cycle correction. Works on either data type.
//& Changed so that it is called from within another function
//& Need to expland to take care of raw MS data but we need a policy on that
Function sq_dutyCycleCorr(datawav,kill_op)
	wave datawav
	variable kill_op
	nvar dutycycle_mz=root:panel:dutycycle_mz
	
	make /o/n=3 duty_dims=dimsize(datawav,p)
	
	if (duty_dims[2]>0)
	//& PToF data
		make /o/n=(duty_dims[0],(duty_dims[2]>0?(duty_dims[2]):(duty_dims[1]))) duty_tmp=sqrt(dutycycle_mz /(q+1))
		imagetransform /g=1 transposevol datawav
		wave m_volumetranspose
		matrixop /o datawav=m_volumetranspose*duty_tmp
		imagetransform /g=1 transposevol datawav
		matrixop /o datawav=m_volumetranspose
	else
	//& MS data
		datawav*=sqrt(dutycycle_mz /(q+1))
	endif

	if (kill_op)
		killwaves /z duty_tmp,m_volumetranspose, duty_dims
	endif

End


//////////////////////////////////////////////////////////////////////
///////////////////// MASS SPEC DATA //////////////////
//////////////////////////////////////////////////////////////////////

Function/s sq_MSCalc_TSeriesMSMatricies(waveNameSuffix, maxMz) 
string waveNameSuffix
variable maxMz	
		
	svar ms0_speclist=root:panel:ms0_speclist
	nvar ms0_ion2mass=root:panel:ms0_ion2mass
	nvar ms0_corr=root:panel:ms0_corr
	nvar ms0_dataType=root:panel:ms0_dataType		//ms0_source	1.46B
	nvar ms0_appendErrorBars=root:panel:ms0_appendErrorBars		//ms0_source	1.46B

	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$"root:"+todoStr			//1.44B
	wave/z/t spec_list=root:frag:spec_list
	wave squirrel_index= root:index:squirrel_index

	string paramStr, dummyStr, specList, datastr, deststr, paramStrA, t_base, timeWtStr, maxColStr
	variable kdex, idex
	
	setdatafolder root:	
	sq_journal_new("MS_timeSeriesSpectra")
 	
	ms0_speclist = replaceString(" ",ms0_speclist,"")
	
	if (strlen(ms0_speclist)==0)		// 1.53L
		ms0_speclist="all"
	endif
		
	t_base=sq_tbase()

	paramStrA=""
	paramStrA+="t_base:"+t_base+";"
	paramStrA+="cache_op:0;"  // removed cache_op functionality //paramstr+="cache_op:"+num2str(SQ_checkfragmod(speclist))+";"
	paramStrA+="filter_op:0;"	// 1.46E In practice, with the new sparse matrix paradigm, this is not feasible... May still use this sanity testing in the frag table panel??
//	paramStrA+="filter_op:1;"	//& The 'filter negatives' SHOULD be used - this is NOT simply filtering out negative contributions or clipping to zero.
//							//& This option removes any mz from the frag matrices that contain no positive contributions - this shouldn't happen
//							//& if the frag tables are set up right.
	paramStrA+="corr_op:"+num2str(ms0_corr)+";"
	paramStrA+="product_type:3;"	
	paramStrA+="ug_op:"+num2str(ms0_ion2mass)+";"

//	paramStrA+="maxMz:"+num2str(round(maxMz))+";"		//1.47I
	maxColStr="max_cl:"+num2str(max(1,round(maxMz-1)))+";"		// fixed in 1.49E

	// deal with open, closed or diff choice
	// we don't save MSSOpen, so if Open data type is chosen, we need to create by adding Diff and Closed
//  1.57B
//	datastr = SelectString(ms0_dataType-2 ,  "MSSDiff_p", "MSSOpen_p", "MSSClosed_p")
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList		//  "Diff;Open;Closed;sumePToFDiff"
	svar MSTimeAvgList = root:panel:MSTimeAvgList

	datastr = stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu
//  1.57B
		
	if(ms0_appendErrorBars)
		datastr+=";"+datastr+"_err;"
	endif

	dummyStr=""
	paramStr=""
	speclist=ms0_speclist
	SQ_GetParamStr(paramStr,specList,1, dummyStr)		// sets RIEList, and other things, dummyStr won't be further used
	deststr=""
	for (idex=0;idex<itemsinlist(speclist,",");idex+=1)
		deststr+="Mat"+datastr[3]+"_"+waveNameSuffix+"_"+stringfromlist(idex,speclist,",")+"/"
	endfor
//  1.57B
	timeWtStr="timeweight_op:"+stringFromList(ms0_dataType-1, MSTimeAvgList)+";"
//	if (ms0_dataType<=3)
//		timeWtStr+=SelectString(ms0_dataType-2 ,  "3", "1",  "2")+";" //1.48F for better time averaging, 3 = diff, 1 = open, 2 = closed
//	else
//		timeWtStr+="4;"	// PTOF
//	endif

	//1.55L
	if (stringmatch(datastr[0,4], "SPToF") )		// we are dealing with averaged PToF sticks
	// datastr = PToFDataSetForMS_returnDataSet(ms0_dataType)
		maxColStr="max_cl:"+PToFDataSetForMS_returnMaxCol(datastr)+";"	
//		timeWtStr ="timeweight_op:4;"
	endif

	paramStr+=timeWtStr+"destlist:"+destStr+";"+paramStrA+maxColStr
	squirrel_fetch(todo,sq_MS_concentration,paramStr,datastr)

	sq_journal_end()	

	return destStr  //1.50L

End


Function sq_butt_MS_Calc(controlname) : Buttoncontrol
string controlname

	sq_GetIndexNotDoneYet()
	
	nvar ms0_corr=root:panel:ms0_corr
	nvar ms0_appendErrorBars=root:panel:ms0_appendErrorBars	
	nvar ms0_msTseries_suffix_ck=root:panel:ms0_msTseries_suffix_ck
	// dont need convert to ug/m3 checkbox for any sanity checks
	svar ms0_speclist=root:panel:ms0_speclist
	nvar ms0_graphOutputType=root:panel:ms0_graphOutputType
	// 1 = plot single
	// 2 = plot multiple
	// 3 = append
	// 4 = update
	// 5 = do nothing	
	nvar ms0_dataType=root:panel:ms0_dataType		//1.57C  now gets updated via MSStickList
	// 1 = Diff
	// 2 = Open
	// 3 = Closed
	// 4 = ePToFSum
	// 5 = ePToFSumDiff
	nvar ms0_sv_numStdDev=root:panel:ms0_sv_numStdDev
	// we need these globals for checking the average MS case
	nvar ms0_AvGraphType=root:panel:ms0_AvGraphType
	// 1 = Sticks
	// 2 = Sticks+Raw
	// 3 = Raw vs m/z
	// 4 = Raw vs iToF
	// 5 = Mass Defect
	nvar ms0_mz_refit=root:panel:ms0_mz_refit
	nvar ams_time_saved=root:panel:ams_time_saved
	nvar ams_time_custom=root:panel:ams_time_custom
	nvar/z ms0_promptForTSMSmaxmz = root:panel:ms0_promptForTSMSmaxmz		//1.47I		//used differently 1.50L, is now a PMF itx flag 
	
	wave squirrel_index = root:index:squirrel_index
	svar todoStr=root:panel:sq_toDoWvNm
	wave todo=$"root:"+todoStr		

	string waveNameSuffix, WaveListToPlotStick,WaveListToPlotRaw, myWinName, myPlotName, myWinList, tempList, tempSpecList,helpStr
	string Wave2PlotList
	variable idex,MSCalcType, maxMz
	
//	it is important that the button controls on the main ams panel do not change from these values.
	MSCalcType = WhichListItem(controlName, "ms0_button_diurnalCalc;ms0_button_TseriesCalc;ms0_button_avcalc;ms0_button_TseriesMassSpec;ms0_button_f43vf44;ms0_button_f44vf60;ms0_butt_ExportRawSpectra")  //1.60Q
	// This is not a popup menu item, but rather an internal code for use in the sq_conc function
	// 0 = ms0_button_diurnalCalc
	// 1 = ms0_button_TseriesCalc
	// 2 = ms0_button_avcalc
	// 3 = ms0_button_TseriesMassSpec
	// 4 = ms0_button_f43vf44
	// 5 = ms0_button_f44vf60
	// 6 = ms0_butt_ExportRawSpectra  //
	 
	//1.50L addition
	if (MSCalcType <0)
		abort "Could not find the data type (mass spectra or time series.  Aborting from sq_butt_ms_calc"
	endif	 

	//^ airbeam correction checkbox checked, see if correct wave exists before preparing for squirrel fetch
	if (ms0_corr)
		sq_ABsanity()
	endif

	if (!waveexists(todo) || numpnts(todo) == 0 )
		abort  "Todo wave does not exist or is of zero length - Aborting from sq_butt_MS_Calc"
	endif

	if (MSCalcType==3 && ams_time_custom && ms0_promptForTSMSmaxmz )
		abort "You may not select a custom time base when exporting values for PMF  - Aborting from sq_butt_MS_Calc"
	endif

//1.57C
	string datastr, timeWtStr
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList
	datastr = stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu
	timeWtStr="timeweight_op:"+stringFromList(ms0_dataType-1, MSTimeAvgList)+";"
//1.57C

	// for all calcs exept averaging raw mass spec, we need sticks
	if (MSCalcType!= 2 || (MSCalcType==2 && ms0_AvGraphType<3) )			// if not average mass spec OR average mass spec with sticks
		if(FindDimlabel(squirrel_index,2,datastr)<0)
			abort "Preprocessed sticks not found.  Perhaps you need to preprocess?  - Aborting from sq_butt_MS_Calc"
		endif
		if (StringMatch("open", stringFromList(ms0_dataType-1 , MSStickList)  ))// Open spectra earlier versions did not save MSSOpen_p
			if (FindDimlabel(squirrel_index,2,datastr)<0 )
				abort "Preprocessed open sticks not found. Preprocess again (original preprocessed step used squirrel versions < 1.43). - Aborting from sq_butt_MS_Calc"		
			endif
			if (ms0_appendErrorBars && FindDimlabel(squirrel_index,2, datastr+"_err")<0 )		// originally from 1.43
				abort "Error sticks not found.  Please do error calculations again  - Aborting from sq_butt_MS_Calc"		
			endif
		endif		
	endif
	if (ms0_appendErrorBars && FindDimlabel(squirrel_index,2, datastr+"_err")<0 )
		abort datastr+" error sticks not found.  Please do error calculations again  - Aborting from sq_butt_MS_Calc"		
	endif
		
	// we need something in the species list, except for average mass spectra
	ms0_speclist = replaceString(" ",ms0_speclist,"")
	if (MSCalcType!= 2)	 	// if not average mass spec
		if(WhichListItem("all", ms0_speclist , ",")>=0)			//1.43I
			abort "Do not use the species 'all' - Aborting from sq_butt_MS_Calc"	
		elseif (itemsinlist(ms0_speclist,",")==0 && MSCalcType!=3 )		//1.53L
			abort "No species were identified - Aborting from sq_butt_MS_conc"	 
		endif
	endif
	
	// sanity checks for error bars
	if (ms0_appendErrorBars)	
		if (MSCalcType!= 0)	// calc error bars for all but diurnal calcs
			if(FindDimlabel(squirrel_index,2,"MSSDiff_p_err")<0)
				abort "Error values not found.  Perhaps you need to calculate errors from Corrections tab?  - Aborting from sq_butt_MS_Calc"
			endif
			if (MSCalcType==2 && ms0_sv_numStdDev <= 0 || ms0_sv_numStdDev >= 10)		// 10 is arbitrary
				ms0_sv_numStdDev=1
			endif			
		endif
	endif

	// sanity checks for pmf output
	if (MSCalcType==3  && ms0_promptForTSMSmaxmz )	// ms0_button_TseriesMassSpec
		if (ms0_appendErrorBars==0)
			ABORT "You must have the 'Calc, plot 1sigma prec. error checkbox checked to generate an itx for PMF" 
		elseif (ms0_appendErrorBars && FindDimLabel(root:index:squirrel_index, 2, "MSSDiff_p_err")<0)
			Abort "You must have already calculated the errors in the corrections tab to generate an itx for PMF" 
		endif
		if (!ms0_corr && Exists("root:diagnostics:corr_fact") )
			Abort "If the Airbeam correction factor wave exists (root:diagnostics:corr_fact) you must use the AB correction factor to generate an itx for PMF" 
		endif
		if (ItemsInList(ms0_speclist, ",")>1)
			Abort "You must select only one species to generate an itx for PMF" 
		endif
	endif
	
	// for doing diurnal plots, we want to NOT try do calcs with non-auto save time base
	if (MSCalcType == 0 && ams_time_saved!=1)
		abort "Cannot do diurnal calculations with a time base that is not the as-saved option. - Aborting from sq_butt_MS_Calc"	
	endif
	
	//	Get user input if needed
	if (ms0_msTseries_suffix_ck)
	 	waveNameSuffix = sq_getWaveNameSuffix()
//		if (strlen(waveNameSuffix)==0 || stringMatch("X", waveNameSuffix) )		// presumes that a cancel means to bail
//			abort "The user cancelled or chose an empty string for the waveName Suffix. Aborting from sq_butt_MS_Calc"
//		endif
 	else
 		waveNameSuffix = todoStr
 	endif

	myPlotName=""
	myWinName = WinName(0,1)		// get name of the top graph, need it for appending or checking to see if the graph already exists
	
	//1.60Q sanity checks for 2D raw spectra
	if (MSCalcType==6)
		nvar ms0_mz_reg=root:panel:ms0_mz_reg
		nvar ms0_mz_reg_min=root:panel:ms0_mz_reg_min
		nvar ms0_mz_reg_max=root:panel:ms0_mz_reg_max
		nvar ms0_mz_reg_dm=root:panel:ms0_mz_reg_dm
//		if (!ms0_mz_reg) 		// needs to be not custom and not as saved
//			abort "Please choose the 'Defined grid' option for the m/z base - Aborting from sq_butt_MS_Calc"
//		else
		if(ms0_AvGraphType!=3)	// needs to be raw vs m/z
			abort "Please choose the 'Raw vs m/z' option for the spectra type - Aborting from sq_butt_MS_Calc"
//		elseif(!ms0_corr)	// should probably be airbeam corrected
		endif
	endif

	// start sanity checks regarding graphs. MSCalcType = 3 is time series mass spec
	if (MSCalcType!=3 && (ms0_graphOutputType==3 || ms0_graphOutputType==4)) // not time-series mass spec, and we append
		if ( strlen(myWinName)==0 )
			abort "It doesn't make sense to append results because no graphs exist - Aborting from sq_butt_MS_Calc"
		else
			if ( MSCalcType<=3 && WhichListItem("bottom", AxisList(myWinName )) < 0 )		// except triabngl plots
				abort "Squirrel cannot append results if no axis named 'bottom' does not exist in the top graph, "+myWinName+" - Aborting from sq_butt_MS_Calc"
			endif
		endif
		// at this point, we know that the window exists and it has a bottom axis. Find the min and max x-axis values
		GetAxis/Q/W=$myWinName bottom		// presumes that the bottom axis is named bottom  Sets V_min and V_max
	endif
	
	myWinList = WinList("*", ";", "WIN:1" )		// just a generic list of all graph windows
	
	// if we output a graph, find graph name
	switch (MSCalcType)
		case 0: //	0 is diurnal
			if(ms0_graphOutputType==3) // check to see that it makes sense to append request
				myPlotName = myWinName
				if (V_min <-1 || V_max >25)
					abort "It doesn't make sense to append a diurnal plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType ==1)	// new graph but we already have one of these
				myPlotName = "DiurnalGraph_"+waveNameSuffix
				if (CheckName(myPlotName, 6) )
					myPlotName = UniqueName(myPlotName,6,0)	// only apppend to graphs created in 1.46B
				endif
			endif
			
			// Finally, get to work!
			sq_MSCalcPlot_Diurnal(waveNameSuffix, myPlotName)
		
		break

		case 1: //	tseries
			if(ms0_graphOutputType==3) // check to see that it makes sense to append request
				myPlotName = myWinName
				if (V_min <3e9 || V_max >5e9)		// 3e9  and 5e9 are arbitrary
					abort "It doesn't make sense to append a time series plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType ==1)	// new graph but we already have one of these
				myPlotName = "TseriesGraph_"+waveNameSuffix
				if (CheckName(myPlotName, 6) )
					myPlotName = UniqueName(myPlotName,6,0)	// only apppend to graphs created in 1.46B
				endif
			endif
			
			// Finally, get to work!
			sq_MSCalcPlot_TSeries(waveNameSuffix, myPlotName)

		break

		case 2:		// average mass spectra.  Lots of things can go wrong.
			// first, is it feasible to do an average?
			if (sq_OnlyOneModeInTodo(todo)!=1 )		//^ 1.40A
				abort  "Cannot do mass averaging on a todo wave with different modes (v and w switching) - Aborting from sq_butt_MS_Calc"
			endif
			if (ms0_AvGraphType>2)		// we are averaging raw spectra
				if (Finddimlabel(squirrel_index,2,"MSOpen_p")<0 && Finddimlabel(squirrel_index,2,"MSOpen")<0  )	// neither pre-processed nor raw were found.  Could also use Closed
					abort "Raw open spectra not found. - Aborting from sq_butt_MS_Calc"
				endif
				if ( (ms0_AvGraphType ==2 || ms0_AvGraphType == 3 || ms0_AvGraphType == 4) && ms0_mz_refit)  // raw spectra is plotted vs m/z  //1.53G
				 	if ( Exists("root:mzFitting:mz_FitSlope") != 1)  // assume that if one exists, all three do
						abort "The new m/z parameters were chosen to use, but they do not exist - aborting from sq_butt_MS_Calc"
					else		// check to see that all m/z values in these runs have non-nans.
						sq_AreNansInWaveList(todo, "root:mzFitting:mz_FitSlope;root:mzFitting:mz_FitIntercept;root:mzFitting:mz_FitPower")
					endif
				endif
			endif
			
			// next, check about the feasibility of graphing the results
			if (ms0_graphOutputType==2)		// for now disable the plot multiple option, it makes things way too confusing with updating plots
				abort "Please reselect the graph output option. Plotting multiple graphs for average mass spec gets too confusing. - Aborting from sq_butt_MS_Calc"			
			elseif(ms0_graphOutputType==3)// check to see that it makes sense to append request
				if (ms0_AvGraphType==5)
					abort "It doesn't make sense to append a mass defect plot.  Perhaps you want to update?  - Aborting from sq_butt_MS_Calc"
				endif
				myPlotName	= myWinName	
				if (ms0_AvGraphType <=3 )		// we append and m/z bottom axis  //1.53G
					if( V_min < 0 || V_max > 5000) 	// it gets way to confusing to append sticks, but appending raw spectra is ok, as long as we plot raw vs m/z
						abort "It doesn't make sense to append a m/z mass spec plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
					endif
				elseif (V_min < 0 || V_max < 5000)		// we are appending raw spectra vs itof
					abort "It doesn't make sense to append an IToF mass spec plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType==4)// check to see that it makes sense to update
				myPlotName	= myWinName	
				if (ms0_AvGraphType <=3  || ms0_AvGraphType==5)		// we append and m/z bottom axis	//1.53G
					if( V_min < 0 || V_max > 5000) 	// it gets way to confusing to append sticks, but appending raw spectra is ok, as long as we plot raw vs m/z
						abort "It doesn't make sense to append a m/z mass spec plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
					endif
				elseif (V_min < 0 || V_max < 5000)		// we are appending raw spectra vs itof
					abort "It doesn't make sense to append an IToF mass spec plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType ==1)	// new graph but we already have one of these
				if (ms0_AvGraphType==5)		// mass Defect
					myPlotName = "MD_"+waveNameSuffix			//1.53G
				else
					myPlotName	="MSAvgGraph_"+waveNameSuffix		
				endif
			elseif(ms0_graphOutputType ==4)	// update
				myPlotName	=myWinName	
			endif
			
			// Now check that we aren't appending species that are already there 
			tempList = GetUserData(myWinName, "", "specList" )
			if(ms0_graphOutputType==3 && ! (ms0_AvGraphType==5)	 ) // we append
				if (ItemsInList(gen_IntersectLists(tempList, ReplaceString(",", ms0_speclist, ";"))) >0 && (MSCalcType==2 && ms0_AvGraphType<3 ) )
					abort "Squirrel cannot append average spectra of a species if that species is already plotted - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType==4 && ! (ms0_AvGraphType==5)	) // we update.  Make sure that the currently selected species are plotted.
				tempSpecList = ReplaceString(",", ms0_speclist, ";")
				for(idex=0;idex<ItemsInList(tempSpecList);idex+=1)
					if (WhichListItem(stringfromlist(idex,tempSpecList),tempList)<0 )
						abort "Squirrel cannot update an average spectra graph if the species "+stringfromlist(idex,tempSpecList)+" is not already plotted - Aborting from sq_butt_MS_Calc"
					endif
				endfor
			endif
		
			// Finally, get to work!
			sq_MSCalcPlot_Avg(waveNameSuffix, myPlotName)
			
		break
		case 3: //	tseries mass spec matricies, no plotting
			if (ms0_promptForTSMSmaxmz)
				maxMz=nan
				helpStr = "Users often generate a 2-dimensional Org matrix for input to PMF. The number of rows is the same as the t_series wave, and thus can be quite large.  Often the mass in m/z > ~200 is negligible, and can be discarded."
				prompt maxMz, "Enter the max m/z (# columns) for the 2-d matrix.  Enter NaN for all m/z"
				doPrompt/HELP=helpStr "For large data sets, one may run out of memory generating results." maxMz
				if (V_flag == -1)
					Abort "The user has canceled the operation. - Aborting from sq_butt_MS_Calc"
				endif
				if (maxMz<0 || numtype(maxMz)==2)		// if negative or nan, just set to regular max  1.49E
					maxMz=inf
				endif				  
				tempSpecList = sq_MSCalc_TSeriesMSMatricies(waveNameSuffix, maxMz)
				sq_TasksForPMFOutput(ReplaceString("/", tempSpecList, ""))
			else
//				wave mFinish = root:diagnostics:mFinish 
				maxMz= sq_findMaxMinMz(todo, 1, 0)// mFinish[sq_findRun(root:index:rn_series, todo[0] )]	// 1.60
				if (numtype(maxMz) !=0 || maxMz<0 || maxMz>1e8)		// 1e8 is arbitrary
					abort "The maximum Mz of "+num2str(maxMz)+" seems incorrect.  Aborting from sq_butt_MS_Calc" 
				endif		//1.60L
				tempSpecList = sq_MSCalc_TSeriesMSMatricies(waveNameSuffix, maxMz)
				print "// The following matricies were created and placed in the root data folder: "+ReplaceString("/", tempSpecList, ", ") // 1.50L		// 1.43A
			endif
		break
		case 4: //	f43 vs f44
			if (ms0_graphOutputType==2)
				abort "It doesn't make sense to choose multiple plots for the f43 vs f44 plot - Aborting from sq_butt_MS_Calc"
			elseif(ms0_graphOutputType==3) // check to see that it makes sense to append request
				myPlotName = myWinName
				if (V_min > 10)
					abort "It doesn't make sense to append a f43 vs f44 plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType ==1)	// new graph but we already have one of these
				myPlotName = "F43vsF44_"+waveNameSuffix
				if (CheckName(myPlotName, 6) )
					myPlotName = UniqueName(myPlotName,6,0)	// only apppend to graphs created in 1.46B
				endif
			endif
			
			// Finally, get to work!
			ms0_speclist="Org43,Org44,Org"
			Wave2PlotList = sq_MSCalc_Tseries(waveNameSuffix, 0) 		// generates Org43, Org44, Org
			wave Org43 = $stringfromlist(0,Wave2PlotList,";")
			wave Org44 = $stringfromlist(1,Wave2PlotList,";")
			wave Org = $stringfromlist(2,Wave2PlotList,";")
			duplicate/o Org43 $ReplaceString("Org43", NameOfWave(Org43), "f43")/wave = f43
			duplicate/o Org44 $ReplaceString("Org44", NameOfWave(Org44), "f44")/wave = f44  //1.55F
			f43/= Org
			f44/= Org
			killwaves/z Org
			sq_MSPlot_F43vsF44(f43, f44, myPlotName) 

		break
		case 5: //	f44 vs f60
			wave/t spec_list= root:frag:spec_list
			wave IEFac_list= root:frag:IEFac_list
			FindValue/Text="Org" spec_list
			variable val = IEFac_list[V_value]
			FD_modifyBatch("Org60", "Org60", "frag_organic[60]",num2str(val), num2str(1/val), "" )	//1.49E
			// assumes that user has same RIE for Org as Org44
			if (ms0_graphOutputType==2)
				abort "It doesn't make sense to choose multiple plots for the f44 vs f60 plot - Aborting from sq_butt_MS_Calc"
			elseif(ms0_graphOutputType==3) // check to see that it makes sense to append request
				myPlotName = myWinName
				if (V_min > 10)
					abort "It doesn't make sense to append a f44 vs f60 plot to the bottom axis on graph "+myWinName+" - Aborting from sq_butt_MS_Calc"
				endif
			elseif(ms0_graphOutputType ==1)	// new graph but we already have one of these
				myPlotName = "F44vsF60_"+waveNameSuffix
				if (CheckName(myPlotName, 6) )
					myPlotName = UniqueName(myPlotName,6,0)	// only apppend to graphs created in 1.46B
				endif
			endif
			
			// Finally, get to work!
			ms0_speclist="Org44,Org60,Org"
			Wave2PlotList = sq_MSCalc_Tseries(waveNameSuffix, 0) 		// generates Org44, Org60, Org
			wave Org44 = $stringfromlist(0,Wave2PlotList,";")
			wave Org60 = $stringfromlist(1,Wave2PlotList,";")
			wave Org = $stringfromlist(2,Wave2PlotList,";")
			duplicate/o Org44 $ReplaceString("Org44", NameOfWave(Org44), "f44")/wave = f44		
			duplicate/o Org60 $ReplaceString("Org60", NameOfWave(Org60), "f60")/wave = f60		//1.55F
			f44/= Org
			f60/= Org
			killwaves/z Org
			sq_MSPlot_F44vsF60(f44, f60, myPlotName) 

		break
		case 6: //	tseries RAW mass spec matricies, no plotting
				maxMz= sq_findMaxMinMz(todo, 1, 0)// mFinish[sq_findRun(root:index:rn_series, todo[0] )]	// 1.60
				if (numtype(maxMz) !=0 || maxMz<0 || maxMz>1e8)		// 1e8 is arbitrary
					abort "The maximum Mz of "+num2str(maxMz)+" seems incorrect.  Aborting from sq_butt_MS_Calc" 
				endif		//1.60L
				sq_MSCalc_avgRaw(waveNameSuffix, twoDFlag=1)
			break
		default :
			
			abort "There was a problem finding the name of the button you pressed. - aborting from  Aborting from sq_butt_MS_Calc"
	
	endswitch

	//1.49E
	nvar/z misc_KillAllInnms_mats = root:panel:misc_KillAllInnms_mats
	if (nvar_exists(misc_KillAllInnms_mats) && misc_KillAllInnms_mats)
		sq_butt_killWavesInFolder("root:ms_mats")
	endif

	//1.55D
	sq_Kill_ms_mats()

End


// 1..53G update; ms0_AvGraphType=5 now includes mass defect option
Function sq_MSCalcPlot_Avg(waveNameSuffix, myPlotName)
string waveNameSuffix, myPlotName

	nvar ms0_AvGraphType=root:panel:ms0_AvGraphType
	nvar ms0_graphOutputType=root:panel:ms0_graphOutputType
	nvar ms0_ck_AddControls = root:panel:ms0_ck_AddControls		
	nvar ms0_mz_custom = root:panel:ms0_mz_custom			//1.53G
	svar ms0_mz_custom_str = root:panel:ms0_mz_custom_str 		//1.53G		
	svar todoStr = root:panel:sq_toDoWvNm 		//1.53G		

	string tempStr, WaveListToPlotStick,WaveListToPlotFactors,WaveListToPlotRaw		// 1.47B correction for Leah W's comment on use of RIE in legend
	string wave2plotstr, wave2plotstr2, notestr

	// finally, get to work
	// deal with raw
	WaveListToPlotStick=""
	WaveListToPlotRaw=""
	WaveListToPlotFactors=""
	if (ms0_AvGraphType>=2)		// == 2,3,4 we need raw
		WaveListToPlotRaw = sq_MSCalc_avgRaw(waveNameSuffix) 
	endif

	// deal with sticks
	if (ms0_AvGraphType<3)		// == 1 or 2, we need sticks
		tempStr = sq_MSCalc_avgStick(waveNameSuffix) 		//1.47B
		WaveListToPlotStick=stringFromList(0, tempStr, ",")
		WaveListToPlotFactors=stringFromList(1, tempStr,",")	
	endif
	
	if ( ms0_AvGraphType==5)  // 1.53G
		wave2plotstr = stringFromList(0, WaveListToPlotRaw)
		wave2plotstr2 = stringFromList(1, WaveListToPlotRaw)	// possible baseline wave
		wave/z MS = $wave2plotstr
		wave/z MS_bsl = $wave2plotstr2
		if (ms0_mz_custom) // Custom m/z base wave
			wave mzbase = $"root:"+ms0_mz_custom_str
		else
			wave mzbase = $"root:mz_base_"+todoStr
		endif
		if (ms0_graphOutputType==1)  	// 1 = single
			tw_ea_makeMDTilePlot(myPlotName+"_"+waveNameSuffix, MS, mzbase, MS_bsl)
		else
			dfref datdfr = GetWavesDataFolderDFR(mzbase)
			NewDataFolder/O datdfr:MD_Tile
			dfref tiledfr = datdfr:MD_Tile
			notestr = "MS:"+stringFromList(0, WaveListToPlotRaw)+";"
			notestr += "MS_base:"+GetWavesDataFolder(mzbase, 2)+";"
			if (WaveExists(MS_bsl))
				notestr += "MS_bsl:"+stringFromList(1, WaveListToPlotRaw)+";"
			endif
			Wave MD_TileM = tiledfr:MD_TileM
			Note MD_TileM, notestr
			tw_ea_UpdMDTile(myPlotName)
		 endif
		return 0
	endif
	
	// now deal with displays for non Mass Defect plots
	if (ms0_graphOutputType==1 )			// 1 = single, 3 = append, 4 is update
		Display/n=$myPlotName as myPlotName
		myPlotName = S_name
		setwindow $myPlotName, userdata(stacklist)=""
		setwindow $myPlotName, userdata(specdata)=""
		setwindow $myPlotName, userdata(errorList)=""
		setwindow $myPlotName, userdata(rawList)=""
		setwindow $myPlotName, userdata(negMSWaveStr)=""
		setwindow $myPlotName, userdata(specList)=""
	endif
	if(ms0_graphOutputType==3 || ms0_graphOutputType==1)
		sq_MSAvgGraph_updateTraces(WaveListToPlotRaw, 0, myPlotName, PlotFactors="", waveNameSuffix=waveNameSuffix) //1.60Q		// we want raw to live "underneath", plot first
		sq_MSAvgGraph_updateTraces(WaveListToPlotStick, 1, myPlotName, PlotFactors=WaveListToPlotFactors) 		
	endif
	
	if(ms0_graphOutputType!=5)	// ms0_graphOutputType is 5 then do nothing
		DoWindow/F $myPlotName
		//1.49E
		if (ms0_ck_AddControls)
//			PopupMenu gr_sticks, value="All"
			sq_MSAvgGraph_updateControls("",0)
		endif
		sq_MSAvgGraph_updateLegend(myPlotName, WaveListToPlotStick, WaveListToPlotFactors) 		
	endif

End


//  Function that only calcs average sticks
// presumes almost all sanity checks were done in sq_butt_MS_avg
Function/S sq_MSCalc_avgStick(waveNameSuffix, [todoWave]) 
string waveNameSuffix
wave todoWave
	
	// globals common to time series and avg spectra
	nvar ms0_appendErrorBars=root:panel:ms0_appendErrorBars	
	svar ms0_speclist=root:panel:ms0_speclist
	nvar ms0_ion2mass=root:panel:ms0_ion2mass
	nvar ms0_corr=root:panel:ms0_corr
	nvar ms0_dataType=root:panel:ms0_dataType		//ms0_source	1.46B
//	nvar ms0_ck_trunc2zero=root:panel:ms0_ck_trunc2zero		//ms0_source	1.46B	//1.51B
	//nvar ms0_ck_AvgMSSpeciesErr=root:panel:ms0_ck_AvgMSSpeciesErr	// 1.46E

	if (ParamIsDefault(todoWave))
		svar todoStr=root:panel:sq_toDoWvNm
		wave todo=$"root:"+todoStr		
	else
		wave todo = todoWave
	endif
	
	wave amus= root:diagnostics:amus

	//1.55L
	//1.57C  Why do we need this check?
//	if (ms0_dataType<4)		// we are dealing with MS data
//		wave/z allMS = root:allMS
//	
//		if (WaveExists(allMS))
//			sq_create_todo(todostr+" and allMS","temptodo")
//			wave tempTodo
//			if (numpnts(tempTodo) == numpnts(Todo))
//				killwaves/z temptodo
//			else
//				wave todo=$"root:temptodo"	
//			endif
//		endif
//	else			// we are dealing with PToF data
//		wave/z allPToF = root:allPToF
//	
//		if (WaveExists(allPToF))
//			sq_create_todo(todostr+" and allPToF","temptodo")
//			wave tempTodo
//			if (numpnts(tempTodo) == numpnts(Todo))
//				killwaves/z temptodo
//			else
//				wave todo=$"root:temptodo"	
//			endif
//		endif
//	endif
	// define variables to be used later
	variable idex,num
	string deststr,datastr, speclist, waves2PlotFacList, errWaveList		//1.47B change, no longer using a dummyStr, but a more aptly named waves2PlotFacList
	string waves2plotlist, paramStr, paramStrA, timeWtStr, maxColStr  // for squirrel fetches
	
	setdatafolder root:	
	sq_journal_new("MS_Avg")
 	
	ms0_specList = RemoveFromList("all", ms0_specList, ",")  // 1.57A

	if (WhichListItem("total", ms0_specList, "," , 0)>=0)
		ms0_specList = RemoveFromList("total", ms0_specList, ",")  // 1.44A
		print "// In the calculation of an average mass spectra, the species 'total' was removed."
	endif

	// result waves will have a MSS prefix,  (O, C, or D),  "_", (todo wave or user editable wave 'suffix', "_", species name such as Org, NO3, etc
	//  If errors are calculated, the suffix _err is appended at the very end
	// max wave name is 31 chars
	// this means that there are often 9 chars automatically in filename, i.e., MSSD_XXX_Org, and that leaves 22 chars for extras (total species, long todo waves)	
	// this means that there are often 13 chars automatically in error filenames, i.e., MSSD_XXX_Org_err, and that leaves 18 chars for extras (total species, long todo waves)	
	// The placement of XXX before Org is so that spectra from the same todo wave would appear adjacent in the data browser.

	// put together full parameter string & do squirrel fetch
	paramStrA=""
	paramStrA+="cache_op:0;"  // removed cache_op functionality //paramstr+="cache_op:"+num2str(SQ_checkfragmod(speclist))+";"
	paramStrA+="filter_op:1;"	//& The 'filter negatives' SHOULD be used - this is NOT simply filtering out negative contributions or clipping to zero.
							//& This option removes any mz from the frag matrices that contain no positive contributions - this shouldn't happen
							//& if the frag tables are set up right.
	paramStrA+="corr_op:"+num2str(ms0_corr)+";"
	paramStrA+="product_type:2;"	
	paramStrA+="ug_op:"+num2str(ms0_ion2mass)+";"

	waves2PlotFacList=""
	paramStr=""
	speclist="all,"+ms0_speclist
	SQ_GetParamStr(paramStr,specList, 1, waves2PlotFacList)		// 1.47C change sets RIEList, and other things, waves2PlotFacList will be further used
	speclist=stringbykey("speclist",paramstr)					//1.48D fix for when non-existent speceis or typos were present in the user list
	speclist = replaceString("/", speclist, ",")
	if (itemsinlist(speclist,",")!=itemsinlist(ms0_speclist,",")+1)
		abort "Check for typos. If you were trying to calculate a single m/z value, simply enter that value, i.e. \"35\" , instead of mz35 - aborting from sq_butt_MS_conc"
	endif
	deststr=""
	
	// deal with open, closed or diff choice
	// we don't save MSSOpen, so if Open data type is chosen, we need to create by adding Diff and Closed
	//1.55L
	//1.57C
	sq_updateMSLists()
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList
	svar MSPrefixList = root:panel:MSPrefixList
	string prefixstr
	datastr = stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu
	prefixstr = stringFromList(ms0_dataType-1 ,MSPrefixList)	//	ms0_dataType is one higher because of the popmenu
	timeWtStr="timeweight_op:"+stringFromList(ms0_dataType-1, MSTimeAvgList)+";"

	deststr=""
	for (idex=0;idex<itemsinlist(speclist,",");idex+=1)
		deststr+="MSS"+prefixstr+"_"+waveNameSuffix+"_"+stringfromlist(idex,speclist,",")+"/"
	endfor
	if (stringMatch("SPToF", datastr[0,4]) )   // we are dealing with averaged PToF sticks
//		timeWtStr ="timeweight_op:4;"
//		datastr = PToFDataSetForMS_returnDataSet(ms0_dataType)
		maxColStr="max_cl:"+PToFDataSetForMS_returnMaxCol(datastr)+";"	
	else
//		datastr = SelectString(ms0_dataType-2 ,  "MSSDiff_p", "MSSOpen_p", "MSSClosed_p")
//		datastr = stringFromList(ms0_dataType-1, MSStickDataList)
//		timeWtStr="timeweight_op:"+SelectString(ms0_dataType-2 ,  "3", "1",  "2")+";" //1.48F for better time averaging, 3 = diff, 1 = open, 2 = closed
		variable m = sq_FindMaxMinMz(todo, 1,0)
		if (numtype(m) !=0 || m<0 || m>1e8)		// 1e8 is arbitrary
			abort "The maximum Mz of "+num2str(m)+" seems incorrect.  Aborting from sq_MSCalc_avgStick" 
		endif		//1.60L
		maxColStr="max_cl:"+num2str(m)+";"   //1.49E don't average over periods that don't match
//		for (idex=0;idex<itemsinlist(speclist,",");idex+=1)
//			deststr+=="MSS"+prefixstr+"_"+waveNameSuffix+"_"+stringfromlist(idex,speclist,",")+"/"
//		endfor
	endif
	
	paramStr+=maxColStr+timeWtStr  //1.56Q

	paramStr+="destlist:"+destStr+";"+paramStrA
	waves2plotlist=ReplaceString("/", deststr, ";")

//	print paramStr
	squirrel_fetch(todo,sq_MS_concentration,paramStr,datastr)

	sq_MinAvgMStoZero(todo,waves2plotlist)		//1.49E

	// an unfortunate compromise... instead of not calculating MSSD_allV_Org_err, for example, 		//1.46E
	// we simply kill these waves to prevent folks from thinking they are used in the graph, for example. 
//	if (!ms0_ck_AvgMSSpeciesErr && ms0_appendErrorBars)		1.47E
	if (ms0_appendErrorBars)
		speclist = RemoveFromList("all", speclist, ",")
		for (idex=0;idex<itemsinlist(speclist,",");idex+=1)
			wave/z Species_err = $(datastr[0,3]+"_"+waveNameSuffix+"_"+stringfromlist(idex,speclist,",")+"_err")
			killwaves/z Species_err
		endfor
	endif
	
	// sp2 folks often to out to amus >1000 - we need to check the max mz we are dealing with and make amus bigger if need be.
	// alternatively, we could simply do an x wave scaling and not plot spectra vs a wave, but will keep as is for now.
	wave ResultWave = $"root:"+StringFromList(0, waves2plotlist)
	if(numpnts(ResultWave) > numpnts(amus))
		redimension/n=(numpnts(ResultWave)) amus
	endif
	
	// 1.47C 
	if (!ms0_ion2mass)		// convert waves2PlotFacList to all 1s if not in units of ug/m3
		num=ItemsInList(waves2PlotFacList, "/")
		waves2PlotFacList=""
		for(idex=0;idex<num;idex+=1)	
			waves2PlotFacList+="1/"
		endfor	
	endif

	sq_journal_end()
	
	killwaves/z temptodo
	
	return waves2plotlist + ","+waves2PlotFacList	// now returns a factor list as well that has the RIE*CE values.

End


//1.49E
//in cases where we average over a todo wave but the daq settings were such that we have sticks at different starting point,
// we want to make sure that the average for the first few points are arbitrarily low (due to different daq settings)
// An example is when for runs 1 - 10 the mz start was 10 but for runs 11 - 10 mz start was 8
Function sq_MinAvgMStoZero(todo,wlist)
wave todo
string wlist

	variable idex, num, minMz
	
	num = itemsInList(wlist)
	minMz = sq_FindMaxMinMz(todo, 0,1)
	for(idex=0;idex<num;idex+=1)
		wave MSSWave = $stringfromlist(idex,wlist,";")
		MSSWave[0, minMz-1]=0
	endfor

End


Function/S sq_MSCalc_avgRaw(waveNameSuffix [,TwoDflag])		//1.60Q added TwoDFlag For case of getting time series x raw mass spec for PMF perhaps
string waveNameSuffix 
variable TwoDflag

	wave rn_series=root:index:rn_series
	wave l_series=root:index:l_series
	wave squirrel_index=root:index:squirrel_index
	svar todoStr=root:panel:sq_toDoWvNm
	wave todo=$"root:"+todoStr		
	
	nvar ms0_ion2mass=root:panel:ms0_ion2mass
	nvar ms0_corr=root:panel:ms0_corr
	nvar ms0_dataType=root:panel:ms0_dataType		//ms0_source	1.46B

	nvar ms0_mz_saved=root:panel:ms0_mz_saved		// as saved
	nvar ms0_mz_custom=root:panel:ms0_mz_custom	// user provides wave
	nvar ms0_mz_reg=root:panel:ms0_mz_reg			// regrid

	nvar ms0_mz_refit=root:panel:ms0_mz_refit
	nvar ms0_mz_saved_regrid=root:panel:ms0_mz_saved_regrid  // regrid checkbox
	nvar ms0_mz_area=root:panel:ms0_mz_area
	nvar ms0_mz_reg_min=root:panel:ms0_mz_reg_min
	nvar ms0_mz_reg_max=root:panel:ms0_mz_reg_max
	nvar ms0_mz_reg_dm=root:panel:ms0_mz_reg_dm
	svar ms0_mz_custom_str=root:panel:ms0_mz_custom_str
	wave/z mzbase=$"root:"+ms0_mz_custom_str

	nvar ms0_ck_findAvgBaseline=root:panel:ms0_ck_findAvgBaseline
	nvar ms0_AvGraphType=root:panel:ms0_AvGraphType
	
	wave/z allMS = root:allMS
	
	variable RawSpectraOnMzAxisFlag, firstrun, mz_int,mz_sl,mz_exp, npnts
	string waves2plotlist, paramStr, tempStr , dataStr, timeWtStr, prefixstr // for squirrel fetches  //1.57C  dataSuffix, 
	
// Why do we need this check?		//1.57C
//	if (WaveExists(allMS))
//		sq_create_todo(todostr+" and allMS","temptodo")
//		wave tempTodo
//		if (numpnts(tempTodo) == numpnts(tempTodo))
//			killwaves/z temptodo
//		else
//			wave todo=$"root:temptodo"	
//		endif
//	endif
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList
	svar MSPrefixList = root:panel:MSPrefixList
	dataStr = stringFromList(ms0_dataType-1 ,MSRawList)	//	1.57H ms0_dataType is one higher because of the popmenu
	if (FindDimLabel(squirrel_index, 2, dataStr)<0)				//1.59Z2  fix for Steven Howell's issue
		if (strsearch(dataStr, "_p", 0)>=0)			// perhaps the user hasn't preprocessed raw
			dataStr = ReplaceString("_p", dataStr, "")		// remove prefix
			if (FindDimLabel(squirrel_index, 2, dataStr)<0)	// i.e. diff raw spectra
				if (stringmatch("MSDiff", dataStr) )
					dataStr = "MSOpen_p"  // MSClosed_p;"		//1.60Q
				elseif (FindDimLabel(squirrel_index, 2, dataStr+"_p")<0)
					abort "Please preprocess the raw spectra for this todo wave to allow this to work correctly. If this is fast mode data, make sure this data type is valid. Aborting from sq_MSCalc_avgRaw"//1.59Z2  fix		
				endif
			endif		
		endif
	endif

	timeWtStr="timeweight_op:"+stringFromList(ms0_dataType-1, MSTimeAvgList)+";"
	prefixstr = stringFromList(ms0_dataType-1 ,MSPrefixList)	//	ms0_dataType is one higher because of the popmenu
	
	// all systems go, we are gonna do some calcs
	setdatafolder root:	
	sq_journal_new("MS_Avg")

	paramStr=""
//	dataSuffix=""
//	if (stringmatch("_p", ))   //  Could also use Closed
//	if (Finddimlabel(squirrel_index,2,"MSOpen_p")>=0)   //  Could also use Closed
//		dataSuffix="_p"
//	else
//		paramStr+="hz_op:1;"			// 1.57C for now I am shutting down the non-preprocess option
//	endif

//	sprintf tempStr, "%u", sq_findMaxMinSQIndex(todo, "MSOpen", 4, 1) //1.49E  // bug in 1.50, I hard coded my own todo wave, run4605, instead of the todo wave
	variable n = sq_findMaxMinSQIndex(todo, dataStr, 4, 1)		//1.60K
	if (numtype(n)!=0)
		abort "Either the data set "+dataStr+" doesn't exist or wasn't preprocessed for the runs in todo "+todoStr+".  Aborting from sq_MSCalc_avgRaw"
	endif
	sprintf tempStr, "%u",n //1.49E  // bug in 1.50, I hard coded my own todo wave, run4605, instead of the todo wave
	paramStr+="max_cl:"+tempStr+";"  //1.49E

	RawSpectraOnMzAxisFlag = ms0_AvGraphType == 2 || ms0_AvGraphType == 3  || ms0_AvGraphType == 5  // 1.53G
	
	// generate the m/z base wave
	if (RawSpectraOnMzAxisFlag)
		if (ms0_mz_custom) //& Custom m/z base wave
			if (!waveexists(mzbase))
				abort ("The specified m/z base wave "+ms0_mz_custom_str+" cannot be found")
			endif
		else
			wave mzbase=$(sq_FindRawMzBase(str2num(tempStr), todo, ms0_mz_refit, ms0_mz_saved, mz_reg_dm=ms0_mz_reg_dm, mz_reg_min=ms0_mz_reg_min, mz_reg_max=ms0_mz_reg_max, waveNameSuffix=waveNameSuffix))  //1.60Q
		endif
		if (ms0_mz_area)
			paramStr+="mz_w_op:1;"
		endif
		if (!ms0_mz_saved || ms0_mz_saved_regrid)
			paramStr+="mz_base:"+nameofwave(mzbase)+";"
			paramStr+="new_mz_cal:"+num2str(ms0_mz_refit)+";"
		endif
	endif

	// result waves will have a MS prefix,  (O, C, or D),  "_", (todo wave or user editable wave 'suffix'), "_all"
	// max wave name is 31 chars
	// this means that there are often 8 chars automatically in filename, i.e., MSD_XXX_all, and that leaves 23 chars for extras (total species, long todo waves)	
					
	// put together full parameter string & do squirrel fetch
	paramStr+="raw_flag:1;"  // small bug in 1.60T, the AB correction factor not applied
	paramStr+="corr_op:"+num2str(ms0_corr)+";"
	paramStr+="product_type:"+selectstring(!ParamIsDefault(TwoDflag) && TwoDflag, "2;","3;")		// 2D time series or regular avg mass spec		
//	paramStr+="findBaseline_op:"+num2str(ms0_ck_findAvgBaseline)+";"
	paramStr+="rawBaseline_flag:"+num2str(ms0_ck_findAvgBaseline)+";"		//1.46  change re Jose's insistence that we look only at DAQ-data
	paramStr+="ug_op:"+num2str(ms0_ion2mass)+";"
	//& There's nothing wrong with converting the raw to g if you want to. Just makes for some interesting units...
	paramStr+="fraglist:all/;rie_list:1/;ce_list:1/;speclist:all/;"
				
	paramStr+=timeWtStr	

	// deal with open, closed or diff choice

	waves2plotlist="MS"+prefixstr+ SelectString(!ParamIsDefault(TwoDflag) && TwoDflag, "","2D")+"_"+waveNameSuffix+";"
//	print paramStr+"destlist:"+waves2plotlist

// 1.60Q
	if (stringmatch(dataStr,"MSDiff_p"))
		squirrel_fetch(todo,sq_MS_concentration,paramStr+"destlist:"+waves2plotlist,dataStr)	
	elseif(stringmatch(prefixstr, "D"))
		squirrel_fetch(todo,sq_MS_concentration,paramStr+"destlist:TempOpen",dataStr)
		squirrel_fetch(todo,sq_MS_concentration,paramStr+"destlist:TempClosed",ReplaceString("Open", dataStr,"Closed"))
		wave O = $"root:TempOpen"
		wave C = $"root:TempClosed"
		duplicate/o o $ReplaceString(";", waves2plotlist,"")/wave=D
		D -= C
		killwaves/z O,C
		if (ms0_ck_findAvgBaseline)
			wave O = $"root:TempOpen_BL"
			wave C = $"root:TempClosed_BL"
			duplicate/o o $ReplaceString(";", waves2plotlist,"")+"_BL"/wave=D
			D -= C
			killwaves/z O,C
		endif
	else
		squirrel_fetch(todo,sq_MS_concentration,paramStr+"destlist:"+waves2plotlist,dataStr)	
	endif
		
	if(ms0_ck_findAvgBaseline)
		waves2plotlist+="MS"+prefixstr+"_"+waveNameSuffix+"_BL;"
	endif
	sq_journal_end()

//	killwaves/z mzbase

	//1.60Q
	if (TwoDflag)
		print "// The 2D matrix "+ReplaceString(";", waves2plotlist,"")+" and m/z wave "+NameofWave(mzbase)+" of raw spectra for todo wave "+todoStr+" has been created and put into the root folder."
	endif

	return waves2plotlist
End


//  appends traces, optionally colors them, add axis labels, optional control bar
// adds or changes important window userdata values, at the end calls sq_msAvgGraph_addControls()	or sq_butt_appgraphdefs("") // colors traces
Function sq_MSAvgGraph_updateTraces(WavesToPlotList, StickFlag, myPlotName [PlotFactors, waveNameSuffix]) 
string WavesToPlotList, myPlotName, PlotFactors, waveNameSuffix
variable stickFlag
		
	svar todoStr=root:panel:sq_toDoWvNm
//	nvar ms0_ck_trunc2zero = root:panel:ms0_ck_trunc2zero		//1.51B
	nvar ms0_dataType = root:panel:ms0_dataType	
	nvar ms0_AvGraphType = root:panel:ms0_AvGraphType	
	nvar ms0_ion2mass = root:panel:ms0_ion2mass	
	svar ms0_mz_custom_str = root:panel:ms0_mz_custom_str
	nvar ms0_mz_custom = root:panel:ms0_mz_custom
	nvar ms0_ck_addControls = root:panel:ms0_ck_addControls
	nvar ms0_sv_numStdDev=root:panel:ms0_sv_numStdDev
	nvar ms0_AppendErrorBars = root:panel:ms0_AppendErrorBars	
	wave amus = root:diagnostics:amus
	
	string myTraceList, wave2plotstr, wave2plotstr2, speciesList, specList, mystr, allMSWaveStr, negMSWaveStr, baseStr, errMSWaveStr
	variable idex, num2Plot, num, pos1, pos2, pos
	
	if (strlen(WavesToPlotList)==0)
		return 0
	endif
	
	DoWindow/F $myPlotName
	myTraceList = TraceNameList(myPlotName,";",1)		// regular traces only, no contours
	num2Plot = itemsinList(WavesToPlotList)
		
	if (!StickFlag)		// raw spectra, easy, there should always only be one spectra, open closed or diff per list

		wave2plotstr = stringFromList(0, WavesToPlotList)
		wave2plotstr2 = stringFromList(1, WavesToPlotList)	// possible baseline wave
		if (ms0_AvGraphType == 2 ||  ms0_AvGraphType == 3 ) 		// m/z base
			if (ms0_mz_custom) // Custom m/z base wave
				wave mzbase = $"root:"+ms0_mz_custom_str
			elseif(!ParamIsDefault(waveNameSuffix) && strlen(waveNameSuffix)>0)
				wave mzbase = $"root:mz_base_"+waveNameSuffix
			else
				wave mzbase = $"root:mz_base_"+todoStr
			endif
			if (WhichListItem(wave2plotstr,myTraceList)<0)		// is not currently plotted
				appendtograph/W=$myPlotName/r $wave2plotstr vs mzbase		// all raw are plotted on right
				setwindow $myPlotName, userdata(rawList)+=wave2plotstr+";"
			endif
		
			if (strlen(wave2plotstr2)>0 && WhichListItem(wave2plotstr2,myTraceList)<0)		// is not currently plotted
				appendtograph/W=$myPlotName/r $wave2plotstr2 vs mzbase		// all raw are plotted on right
				setwindow $myPlotName, userdata(rawList)+=wave2plotstr2+";"
			endif

			// set x axis to reasonable values
			SetAxis/W=$myPlotName bottom 1,mzbase[numpnts(mzbase)-1]

		elseif (WhichListItem(wave2plotstr,myTraceList)<0)		// is not currently plotted
			appendtograph/W=$myPlotName/r $wave2plotstr		// all raw are plotted on right
			setwindow $myPlotName, userdata(rawList)+=wave2plotstr+";"
		endif

	else		// stick

		// first plot every stick wave  that needs to be plotted, except additional neg stick wave that we create below, and error wave
		for (idex=0;idex<num2plot;idex+=1)			
			wave2plotstr = stringFromList(idex, WavesToPlotList)
			if (WhichListItem(wave2plotstr,myTraceList)<0)		// is not currently plotted
				appendtograph/W=$myPlotName $wave2plotstr vs amus		// all sticks are plotted on left
				modifygraph/W=$myPlotName mode($wave2plotstr)=1, tomode($wave2plotstr)=0		// set all tomode values to 0 initially
			endif
		endfor
		
		// some sticks are speciated 
		// first identify the all wave
		specList = ""
		myTraceList = TraceNameList(myPlotName,";",1)		// regular sticks only, no raw
		num = itemsinList(myTraceList)

		// remove raw spectra from trace list
		for (idex = num-1;idex>=0;idex-=1)		//1.47I fix.  When removing entities from lists, start at the back	// all speciated waves
			mystr = stringFromList(idex,myTraceList )
			if (!stringmatch(mystr[0,2], "MSS") )		// is an MS not an MSS
				myTraceList = RemoveFromList(mystr, myTraceList)
			endif
		endfor
		
		// next, find the base string with which to generate a neg spectra
		pos2 = strsearch(WavesToPlotList, "_all;", strlen(WavesToPlotList)-1, 1)		// find the "all" wave
		pos1 = strsearch(WavesToPlotList, "MSS", pos2, 1)		// find the start of the wave
		baseStr = WavesToPlotList[pos1, pos2]
						
		// remove any all waves from tracelist
		allMSWaveStr = baseStr+"all"
		myTraceList = RemoveFromList( allMSWaveStr, myTraceList)
		wave MSS_all = $"root:"+allMSWaveStr
		setwindow $myPlotName, userdata(allMSWaveStr) =allMSWaveStr

		// create, initialize, perhaps append neg wave. 
		make /o/n=(numpnts(MSS_all)) $("root:"+baseStr+"neg")  = 0
		wave MSS_neg=$("root:"+baseStr+"neg")		
		MSS_neg = MSS_all[p] <0 ? - MSS_all[p] : 0
		
		if (WhichListItem(baseStr+"neg",myTraceList)<0)		// is not currently plotted
			appendtograph/W=$myPlotName MSS_neg vs amus		// all sticks are plotted on left
			modifygraph mode($NameOfWave(MSS_neg))=1			
			setwindow $myPlotName, userdata(negMSWaveStr)+=nameofWave(MSS_neg)+";"
		 endif
	
		// remove any neg waves from tracelist
		negMSWaveStr = GetUserData(myPlotName, "", "negMSWaveStr" )
		for(idex=0;idex<ItemsinList(negMSWaveStr); idex+=1)
			myTraceList = RemoveFromList(stringFromList(idex, negMSWaveStr), myTraceList)
		endfor

		//error wave
		wave/z MSS_err=$nameofWave(MSS_all) + "_err"
		if (WaveExists(MSS_err))
			setwindow $myPlotName, userdata(errMSWaveStr)=nameofWave(MSS_all) + "_err"
		endif
		errMSWaveStr = GetUserData(myPlotName, "", "errMSWaveStr" )
		if (strlen(errMSWaveStr)>0)
			myTraceList = RemoveFromList(errMSWaveStr, myTraceList)
		endif

		// deal with speciated waves and further amend neg wave
		//put _all wave on bottom, change stick to mode to add to next
		num = itemsinList(myTraceList)		// if any waves remain in myTraceList, they must be Diff, because _all and _neg and raws have been removed.
		for (idex = num-1;idex>=0;idex-=1)		// all speciated waves
			mystr = stringFromList(idex,myTraceList )
			wave MSS_wave = $mystr
			baseStr = mystr[0, strsearch(mystr, "_", strlen(myStr)-1,1)]
			wave MSSD_all=$(basestr+"all")
			wave MSSD_Neg=$(basestr+"neg")
			ReorderTraces $mystr { $NameofWave(MSSD_all)}		// put all behind
			ReorderTraces $NameofWave(MSSD_Neg) {$mystr}		// put neg in front
			modifygraph/W=$myPlotName tomode($NameofWave(MSS_wave))=3
			pos = WhichListItem(mystr, WavesToPlotList)
			if (pos>=0)		// new species?
				setwindow $myPlotName, userdata(specdata) +=NameofWave(MSS_wave)+";"
				setwindow $myPlotName, userdata(specList) += mystr[strsearch(mystr, "_",  strlen(mystr)-1, 1)+1, strlen(mystr)-1]+";"
				setwindow $myPlotName, userdata(specFactorData) +=StringFromList(pos, PlotFactors, "/")+";"
			endif
			
			MSS_neg = MSS_wave[p] <0 ? max(MSS_neg, -MSS_wave[p]) :MSS_neg[p]		//1.48D fix in other versions the true/false answers were reversed.
//			if (ms0_ck_trunc2zero)
//				MSS_wave = MSS_wave[p] <0 ? 0 : MSS_wave[p]
//			endif
	
		endfor
			
		// lastly, possibly add error wave
		if (strlen(errMSWaveStr)>0 && WhichListItem(errMSWaveStr, TraceNameList(myPlotName,";",1)) < 0)
			wave MSS_err = $errMSWaveStr
			AppendToGraph/W=$myPlotName MSS_err vs amus
			ModifyGraph/W=$myPlotName mode($NameOfWave(MSS_err))=1, rgb($NameOfWave(MSS_err))=(65535,65535,65535)	
			//ModifyGraph/W=$myPlotName muloffset($NameOfWave(MSS_err))={0,ms0_sv_numStdDev}
			variable Ver_temp = str2num(StringByKey("IGORVERS", IgorInfo(0)))
			if (Ver_temp>6)
				ModifyGraph/W=myPlotName muloffset($NameOfWave(MSS_err))={0,ms0_sv_numStdDev}
			endif
		endif
			
		// set x axis to reasonable values
		SetAxis/W=$myPlotName bottom 1,numpnts(MSS_all)-1

	endif
	
	ModifyGraph/W=$myPlotName  nticks(bottom)=9,minor(bottom)=1

	// deal with graph labels
	if (ms0_AvGraphType==4)
//		label/Z/W=$myPlotName bottom "ion ToF (ns)"
		label/Z/W=$myPlotName bottom "ion ToF (samp. num.)"  //1.54E
	else
		label/Z/W=$myPlotName bottom "m/z"
	endif

	if (StickFlag)
		if (ms0_ion2mass)
			label/Z/W=$myPlotName left "Nitrate equivalent mass (g m\\S-3\\M)"
		else
			label/Z/W=$myPlotName left "Ion rate (Hz)"
		endif
		GetAxis/Q/W=$myPlotName bottom
		if (numpnts(MSS_all) < V_max) 
			Setaxis/W=$myPlotName bottom, V_min, numpnts(MSS_all)
		endif
	else		// raw flag
		if (ms0_ion2mass)
			label/Z/W=$myPlotName right "Nitrate equivalent mass (g m\\S-3\\M s\\S-1\\M)"
		else
//			label/Z/W=$myPlotName right "Ion rate (Hz s\\S-1\\M)"
			label/Z/W=$myPlotName right "Ion rate (Hz samp. time\\S-1\\M)"		//1.54E
		endif
	endif

	// use "Add Controls" checkbox, colorize species
	if (ms0_ck_addControls)
		sq_msAvgGraph_addControls()	
	else
		// note that PlotFactors was not sent to this function it defautls to an empty string
		sq_MSAvgGraph_updateLegend(myPlotName, WavesToPlotList, PlotFactors )
		sq_applyGraphDefs(WavesToPlotList)	// sq_butt_appgraphdefs("") // colors traces
	endif

End


// deal with negative sticks , truncating sticks to zero, update legend, reset species popvalue 
Function sq_MSAvgGraph_updateLegend(myPlotName, WaveListToPlotStick, WaveListToPlotFactor) 		
string myPlotName, WaveListToPlotStick, WaveListToPlotFactor

	nvar ms0_ck_trunc2zero = root:panel:ms0_ck_trunc2zero	
	nvar ms0_ion2mass = root:panel:ms0_ion2mass	
 	
 	variable idex, num, sumVal,pos, numNeg, specFactor, specPos
 	string negMSWaveStr, specList, specdata, textBoxStr, allMSWaveStr, dataStr, myTraceList, specFactorList
 	string tempStr, tempList
 	
  	allMSWaveStr = GetUserData(myPlotName, "", "allMSWaveStr")
  	negMSWaveStr = GetUserData(myPlotName, "", "negMSWaveStr")
 	specList = GetUserData(myPlotName, "", "specList")		// i.e. "Org;NO3"
 	specdata = GetUserData(myPlotName, "", "specdata")		// i.e. MSSD_mytodo_Org;MSSD_mytodo_NO3;
	specFactorList = GetUserData(myPlotName, "", "specFactorData")
	num = itemsInList(specList)
	numNeg= itemsInList(negMSWaveStr)
	
	wave/z datawave=$stringfromList(0,allMSWaveStr)		// see if any sticks are present
	if (!WaveExists(datawave))
		return 0
	endif
	
	// In the list of waves that were updated, check where the species appears in the SpecList, specData, and specFactorList
	num = ItemsInList(WaveListToPlotStick)
	for (idex=0;idex<num;idex+=1)
		tempStr = stringfromlist(idex, WaveListToPlotStick)	// typical name si MSSD_allV_Org
		tempStr = stringFromList(2, tempStr, "_")	//
		specPos = WhichListItem(tempStr, specList)
		if (specPos>=0)
			tempList =removeListItem(specPos, specFactorList)
			tempStr =stringFromList(idex, WaveListToPlotFactor, "/")
			tempList = AddListItem(tempStr, tempList,";", specPos)
//			specFactorList = UserData(myPlotName, "", "specFactorData")
			setwindow $myPlotName, userdata(specFactorData) =tempList
			specFactorList = tempList
		endif
	endfor
	
	// deal with the textbox first, so we can get accurate sums, then deal with truncating to 0
	textbox/W=$myPlotName/n=msAvgTextBx/k
	textbox/W=$myPlotName/n=msAvgTextBx
	textBoxStr=""

	myTraceList = TraceNameList(myPlotName, ";", 1 )

	//first do for all
	num = ItemsInList(allMSWaveStr)
	for(idex=0;idex<num;idex+=1)
		wave datawave=$stringfromList(idex,allMSWaveStr)		// see if any sticks are present
		sumVal = sum(datawave)
		dataStr = NameofWave(datawave)
		if (WhichListItem(dataStr, myTraceList)>=0)		// put in textbox only if wave is not hidden
			sprintf textBoxStr, "\s(%s) %s %+0.4f", dataStr, datastr[0,3]+" all", sumVal
			AppendText/W=$myPlotName/n=msAvgTextBx textBoxStr
		endif
	endfor
	
	// now do for species
	num = ItemsInList(specData)
	for (idex=num-1;idex>=0;idex-=1)
		dataStr = stringfromlist(idex,specData,";")
		wave datawave=$dataStr
		specFactor = ms0_ion2mass? str2num(stringFromList(idex, specFactorList)):1
		sumVal = sum(datawave)/specFactor	
		if (WhichListItem(dataStr, myTraceList)>=0)		// put in textbox only if wave is not hidden
			sprintf textBoxStr, "\s(%s) %s %+0.4f", NameofWave(datawave), datastr[0,3]+" "+stringfromlist(idex, specList), sumVal
			AppendText/W=$myPlotName/n=msAvgTextBx textBoxStr
		endif
	endfor

	if (ms0_ck_trunc2zero)			// we don't truncate any open or closed *_all waves - don't need to because they aren't stacked
		for (idex=0;idex<num;idex+=1)
			dataStr = stringfromlist(idex,specData,";")
			wave datawave=$dataStr
			if (stringmatch("MSSD",dataStr[0,3] ))		// only do this for diff species
				datawave=datawave[p]>0?(datawave[p]):(0)
			endif
		endfor
	endif

	// update popup window in case controls are displayed
	speclist = getuserdata(myPlotName,"","specList")
	ControlInfo/W=$myPlotName gr_sticks
	if(V_flag)
		string list = "All;"+speclist
		PopupMenu gr_sticks win=$myPlotName, value=#("\""+list+"\"")	// add Get List		//1.59B
		sq_MSAvgGraph_UpdateControls("",1)// 1 means show all
	endif
	
End


//creates waves DiurnalHours, DiurnalCounter, DiurnalIndexX all within the root:panel:diurnals subfolder
// new in 1.44B - it is good to isolate the task of identifying which run gets binned into which diurnal hour
// code stolen from PMF
Function sq_diurnalIndex()
	
	wave t_series =root:index:t_series

	variable numRows, hourDex, tempVal1, tempVal2
	
	numRows = numpnts(t_series)
	
	// do the prep work to figure out what data lives in which hour, temp waves to be killed later
	make/o/d/n=(numRows) diurnaltime_temp, roundtime_temp, timeIndex_temp
	wave/d diurnaltime_temp
	wave/d roundtime_temp
	wave/d timeIndex_temp
	
	roundtime_temp  = round(t_series)
	diurnaltime_temp = mod(roundtime_temp, 24*60*60)		//gives seconds after midnight
	timeIndex_temp = p
	Sort diurnaltime_temp, timeIndex_temp, diurnaltime_temp	// index wave gives us a method to go back to unsorted data values
	
	// temp wave to be killed later
	make/O/N=24 DiurnalTemp	 // make counter - wave, temporary hold the END point of the hour
	
	NewDataFolder/o root:panel:diurnals
	
	// this wave tells how many original data points we have each hour
	make/O/N=24 root:panel:diurnals:DiurnalCounter
	wave DiurnalCounter = root:panel:diurnals:DiurnalCounter
	
	 //	find out how many points we have for each hour... find DiurnalCounter
	DiurnalTemp = binarysearchInterp(diurnaltime_temp, (p+1)*60*60-.9)	// diurnaltime_temp has integer values, the -.9 helps find hourly max
	diurnalTemp = numtype(diurnalTemp[p])!=0 ? 0 : diurnalTemp[p]		// replace nans with 0s
	tempVal1 = floor(diurnaltime_temp[numRows-1]/(60*60) )
	DiurnalTemp[tempVal1] = numRows
	DiurnalTemp = round(DiurnalTemp)
//	DiurnalCounter[0] = DiurnalTemp[p]		//1.57J
	DiurnalCounter[1,tempVal1] =DiurnalTemp[p] - DiurnalTemp[p-1] 
	//  DiurnalCounter[tempVal1+2,] =0 
	if (tempVal1<23)		//1.49B fix, last value was always nan
		DiurnalCounter[tempVal1+1,] =0 
	endif
	
	make /O/N=(DiurnalCounter[0]) root:panel:diurnals:DiurnalIndex0
	wave DiurnalIndex = root:panel:diurnals:DiurnalIndex0
	DiurnalIndex = timeIndex_temp[p]		// get all the index points for this hour

	// create DiurnalIndex, one for each hour
	for (hourdex=1; hourdex<24; hourdex+=1)  // loop executes 23 times.... need to address first hour separately
		tempVal1 = DiurnalCounter[hourdex]		// number of data points for current hour
		tempVal2 = sum(DiurnalCounter, 0, hourdex-1)	// number of data points for previous hour
		// print hourdex, tempVal1, tempVal2
		make /O/N=(tempVal1) $("root:panel:diurnals:DiurnalIndex" +num2istr(hourdex))		// temporary wave, will be killed at the end
		wave DiurnalIndex = $("root:panel:diurnals:DiurnalIndex" +num2istr(hourdex))
		if (tempVal1>0)
			DiurnalIndex[0,tempVal1-1]  = timeIndex_temp[p+tempVal2]	//1.19C	// get all the index points for this hour
		endif
	endfor	

	// make wave to use in plotting
	make/O/N=24 root:panel:diurnals:DiurnalHours
	wave DiurnalHours = root:panel:diurnals:DiurnalHours
	DiurnalHours = p+1
//	setScale d, 0, 0, "Hour of Day", DiurnalHours

	killwaves/z diurnaltime_temp, roundtime_temp, timeIndex_temp, diurnalTemp

End


Function sq_MSCalcPlot_Diurnal(waveNameSuffix, newPlotName)
string waveNameSuffix, newPlotName

	string waves2plot
	waves2plot = sq_MSCalc_Diurnals(waveNameSuffix)
	sq_MSplot_DiurnalBoxPlot(waves2plot, newPlotName)

End


Function/s sq_MSCalc_Diurnals(waveNameSuffix)
string waveNameSuffix
	
	svar ms0_speclist = root:panel:ms0_speclist
	nvar ms0_whisker = root:panel:ms0_whisker
	wave t_series = root:index:t_series
	nvar ms0_msTseries_suffix_ck = root:panel:ms0_msTseries_suffix_ck

	variable nspecies, idex, kdex, percentile_1, percentile_2, hourdex 
	variable length, timepoint, count, numberpoints
	string specStr, destWaveList

	SetDataFolder root:

	sq_journal_new("DiurnalPlots")

	length = numpnts(t_series)
	if (ms0_whisker == 2)
		percentile_1 = 5
		percentile_2 = 95
	else
		percentile_1 = 0
		percentile_2 = 100
	endif
	
	// reworked in 1.44B
	sq_diurnalIndex()
	
	wave DiurnalCounter = root:panel:diurnals:DiurnalCounter
	make/o/n=0 root:panel:diurnals:hourdata_temp
	wave hourdata_temp = root:panel:diurnals:hourdata_temp
	
	// we need to be careful when calling the time series function so that we don't create new waves, etc
	destWaveList = sq_MSCalc_Tseries("temp", 1)	
		
	nspecies = itemsinlist(destWaveList)

	// loop through all selected species - for diurnal calcs reworked in 1.44B
	for (idex = 0; idex < nspecies; idex += 1)
		specStr = stringfromlist(idex, destWaveList)				
		wave/z datawave = $specStr
		specStr = ReplaceString("_temp", specStr, "_"+waveNameSuffix)
		
		// make median, min, max, percentile waves
		make /O/N=24 $(specStr + "_median") 
		wave medianw = $(specStr + "_median")
		make /O/N=24 $(specStr + "_mean") 
		wave meandata = $(specStr + "_mean")
		make /O/N=24 $(specStr + "_" + num2str(percentile_1) + "p")
		wave p1w = $(specStr + "_" + num2str(percentile_1) + "p")
		make /O/N=24 $(specStr + "_" + num2str(percentile_2) + "p")
		wave p2w = $(specStr + "_" + num2str(percentile_2) + "p")
		make /O/N=24 $(specStr + "_25p")
		wave p25w = $(specStr + "_25p")
		make /O/N=24 $(specStr + "_75p")
		wave p75w = $(specStr + "_75p")
		
		// calculate median, min, max, 25% and 75% percentiles
		for (hourdex=0; hourdex<24; hourdex+=1) 
			if (DiurnalCounter[hourdex]>0)
				// data exists for this hour
				redimension/N=(DiurnalCounter[hourdex]) hourdata_temp		// temporary wave, will be killed at the end
				wave DiurnalIndex = $("root:panel:diurnals:DiurnalIndex" +num2istr(hourdex))		// should be created in sq_diurnalIndex
				hourdata_temp = datawave[DiurnalIndex[p]]			
				sort hourdata_temp hourdata_temp		// any nans should appear at the bottom
				wavestats/q/m=1 hourdata_temp			// m=1 calcs average
				numberpoints=v_npnts
				
				medianw[hourdex] = hourdata_temp[((numberpoints+1)/2)-1]
				meandata[hourdex] = v_avg
				p25w[hourdex] = hourdata_temp[round(numberpoints*1/4)-1]
				p75w[hourdex] = hourdata_temp[round(numberpoints*3/4)-1]
				if (ms0_whisker != 2)
					p1w[hourdex] = hourdata_temp[0]
					p2w[hourdex] = hourdata_temp[numberpoints - 1]					
				else
					if (round(numberpoints*5/100)-1>=0)		//1.19C
						p1w[hourdex] = hourdata_temp[round(numberpoints*5/100)-1]
						p2w[hourdex] = hourdata_temp[round(numberpoints*95/100)-1]
					endif
				endif
			else			// no data, make blank
				medianw[hourdex] = nan
				meandata[hourdex] = nan
				p25w[hourdex] = nan
				p75w[hourdex] = nan
				p1w[hourdex] = nan
				p2w[hourdex] = nan
			endif
		endfor				
		
		killwaves/z datawave
		
	endfor
	
	sq_journal_end()

	destWaveList = replaceString("_temp", destWaveList, "_"+waveNameSuffix)
	
	return destWaveList		// note that we don't actually return all the waves for diurnal plots - the XXX_median waves, etc
	
End
	

// added in 1.44B; Separate function for plotting the diurnals box plots cuz it's tricky
Function sq_MSplot_DiurnalBoxPlot(destlist, newPlotName)
string destlist, newPlotName

	nvar ms0_ion2mass = root:panel:ms0_ion2mass
	nvar ms0_graphOutputType = root:panel:ms0_graphOutputType
	nvar ms0_whisker = root:panel:ms0_whisker
	wave DiurnalHours = root:panel:diurnals:DiurnalHours	
	
	variable percentile_1, percentile_2, idex, nspecies
	string species, textBoxStr, graphName
		
	nspecies = itemsinlist(destlist)
	
	switch(ms0_graphOutputType)		
		case 1:		// 1 is plot single, there is only one graph 
			display/N=$newPlotName as newPlotName
			break
		case 2:			// 2 is multiple; kill old window if exists
			for (idex = 0; idex < nspecies; idex += 1)
				species = stringfromlist(idex, destlist)
				graphName = "Diurnal_"+species
				doWindow/K $graphName
				display/N=$graphName as graphName				
				doWindow/F graphName 
				textBoxStr = ""
			endfor 
			break
		case 3:		// 3 is append, get current window name
			textBoxStr = ""
			break
		case 4:			// 4 is update
			return 0
			break
		case 5:			// 4 is do nothing
			return 0
			break
	endswitch
	
	if (ms0_whisker == 2)
		percentile_1 = 5
		percentile_2 = 95
	else
		percentile_1 = 0
		percentile_2 = 100
	endif
	
	for (idex = 0; idex < nspecies; idex += 1)
		species = stringfromlist(idex, destlist)
			
		if (ms0_graphOutputType==2)
			newPlotName = "Diurnal_"+species
		endif
		
		doWindow/F newPlotName
			
		wave medianw = $(species + "_median")
		wave meanw = $(species + "_mean")
		wave p1w = $(species + "_" + num2str(percentile_1) + "p")
		wave p2w = $(species + "_" + num2str(percentile_2) + "p")
		wave p25w = $(species + "_25p")
		wave p75w = $(species + "_75p")
		
		gen_fBoxPlot_graphAxNm(medianw,p75w, p25w, p2w, p1w, DiurnalHours, 0.3, 0, $"", $"", 0, 0, 0,newPlotName, "left")
		AppendToGraph/W=$newPlotName/L meanw vs DiurnalHours
		
		ModifyGraph minor(left)=1, nticks(bottom)=12
		ModifyGraph rgb=(0,0,0)
		setwindow kwtopwin,userdata(noleg)="1"
		
		if(ms0_graphOutputType==2)	// individual plots per species	
			textBoxStr =  "Diurnal Pattern of " + species + " (" + num2str(percentile_1) + "-" + num2str(percentile_2) + "% whiskers)"	
			TextBox/W=$newPlotName/C/N=text0/F=0/A=RT textBoxStr
			textBoxStr=""
		elseif (ms0_graphOutputType==1 && idex == nspecies-1 )		// one plot for many species
			textBoxStr =  "Diurnal Pattern of \r" + replacestring(";", destlist, "\r") + "(" + num2str(percentile_1) + "-" + num2str(percentile_2) + "% whiskers)"	
			TextBox/W=$newPlotName/C/N=text0/F=0/A=RT textBoxStr
		elseif (ms0_graphOutputType==3)	// append trace
			// for now users will just have to deal with not
		endif
		
		if (ms0_ion2mass)
			Label left "\\F'Symbol'm\\F'Arial'g /m3"
		else
			Label left "Signal, Hz"
		endif

		Label bottom "Diurnal Hour"		//1.48F typo fix

		sq_applyGraphDefs(destlist)	// sq_butt_appgraphdefs("")

	endfor

End


Function sq_MSCalcPlot_TSeries(waveNameSuffix, NewPlotName)
string waveNameSuffix, NewPlotName

	string Wave2PlotList
	Wave2PlotList = sq_MSCalc_Tseries(waveNameSuffix, 0) 
	sq_MSPlot_Tseries(Wave2PlotList, waveNameSuffix, NewPlotName) 

End


// Function to create time series for species/masses
// returns the list of created times series waves, not including possible error bar waves 
Function/S sq_MSCalc_Tseries(waveNameSuffix, diurnalFlag) 
string waveNameSuffix
variable diurnalFlag

	// globals common to time series and avg spectra
	svar ms0_speclist=root:panel:ms0_speclist
	nvar ms0_ion2mass=root:panel:ms0_ion2mass
	nvar ms0_corr=root:panel:ms0_corr
	nvar ms0_dataType=root:panel:ms0_dataType		//ms0_source	1.46B
	nvar ms0_graphOutputType=root:panel:ms0_graphOutputType
	nvar ms0_msTseries_suffix_ck=root:panel:ms0_msTseries_suffix_ck	// 1.42B
	nvar ms0_AppendErrorBars=root:panel:ms0_AppendErrorBars		//ms0_source	1.46B

	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$"root:"+todoStr			//1.44B
	wave/z/t spec_list=root:frag:spec_list

	variable idex,num
	string paramstr,datastr,speclist, destWaveList, specStr,t_base,  dummyStr, timeWtStr, maxColStr=""  //1.57C
	
	// one more check before we do some calcs
	t_base=sq_tbase()

//1.57C
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList

// dataStr="MSS"+selectstring(ms0_dataType-2,"Diff","Open","Closed")+"_p"
	datastr = stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu
	timeWtStr="timeweight_op:"+stringFromList(ms0_dataType-1, MSTimeAvgList)+";"
			
	if ( ms0_AppendErrorBars )	//
		if (FindDimLabel(root:index:squirrel_index, 2, datastr+"_err" ) <0)
			abort "Could not find the errors for data set "+datastr+ " Please recalculate the errors.  aborting from sq_MSCalc_Tseries"
		endif
		datastr+=";"+datastr+"_err"
	endif
	
	paramstr=""
	speclist=ms0_speclist
	dummyStr=""	
	SQ_GetParamStr(paramstr,speclist,0,dummyStr)		// sets RIE and CE
	
	paramstr+="filter_op:0;"
	paramstr+="corr_op:"+num2str(ms0_corr)+";"
	paramstr+="ug_op:"+num2str(ms0_ion2mass)+";"
	paramstr+="cache_op:"+num2str(0)+";"
	paramstr+="product_type:1;"
	paramstr+="t_base:"+t_base+";"
	
	speclist=stringbykey("speclist",paramstr)
	speclist = replaceString("/", speclist, ";")
	//last of the sanity checks
	if (strlen(speclist)==0)
		abort "Check for typos. If you were trying to calculate a single m/z value, simply enter that value, i.e. \"35\" , instead of mz35 - aborting from sq_butt_MS_conc"
	endif
	
	destWaveList=""
	num=itemsinlist(speclist)
	for(idex=0;idex<num;idex+=1)
		// get the name for the destination waves
		specStr=stringfromlist(idex,speclist)
		if(numtype(str2num(specStr))==0)
			specStr="mz"+specStr
		endif
		if (diurnalFlag || ms0_msTseries_suffix_ck && strlen(waveNameSuffix)>0) //1.42B
			specStr+="_"+waveNameSuffix						//1.42B
		endif		
		if(strlen(t_base)>0)
			specStr+="_"+t_base		//1.41B
		endif
		// note that in sq_MS_concentration these destination waves will be overwritten if they already exist
		destWaveList+=specStr+"/"
	endfor
	
	SetDataFolder root:						//^ 1.35
	sq_journal_new("MS_Conc")

	//1.55L
//	timeWtStr="timeweight_op:"+SelectString(ms0_dataType-2 ,  "3", "1",  "2")+";" //1.48F for better time averaging, 3 = diff, 1 = open, 2 = closed

	//1.55L  //1.57C
	if (stringMatch("SPToF", datastr[0,4]) )   // we are dealing with averaged PToF sticks
//		datastr = PToFDataSetForMS_returnDataSet(ms0_dataType)
		maxColStr="max_cl:"+PToFDataSetForMS_returnMaxCol(datastr)+";"	
//		timeWtStr ="timeweight_op:4;"
	endif

	paramstr+="destlist:"+destWaveList+";"+timeWtStr+maxColStr

	squirrel_fetch(todo,sq_MS_concentration,paramstr,datastr)	
	destWaveList=stringbykey("destlist",paramstr)	
	
	sq_journal_end()

	destWaveList = ReplaceString("/", destWaveList, ";")
	return destWaveList

End


// given list of time series waves generated by sq_MSCalc_Tseries, plot according to ms0_graphOutputType
Function sq_MSPlot_Tseries(destList, waveNameSuffix, NewPlotName)
string destList, waveNameSuffix, NewPlotName

	nvar ms0_appendErrorBars = root:panel:ms0_appendErrorBars
	nvar ms0_graphOutputType = root:panel:ms0_graphOutputType		// 1 - new, 2 = multiple, 3 = append, 4 = update
	nvar ms0_ion2mass = root:panel:ms0_ion2mass

	variable idex, num
	string t_base, destStr, myWinName
	
	t_base=sq_tbase()	// we calc again... not ideal... it was calced once already in the sq_MS_concentration function
	
	num = ItemsInList(destList)

	if(ms0_graphOutputType<4)		// if update we do nothing, not even bring a graph to the top window
		// get the x axis wave
		if(strlen(t_base)>0)
			wave x_wave=$("root:"+t_base)
		else
			wave x_wave=root:index:t_series
		endif
		
		// bring graph to front (for multiple graphs do nothing for now)
		if (ms0_graphOutputType==1)
			display/N=$NewPlotName as NewPlotName
		elseif(ms0_graphOutputType==3)
			DoWindow/F $NewPlotName
		endif

		// start appending traces
		for(idex=0;idex<num;idex+=1)
			
			// get wave to append
			destStr = stringfromlist(idex,destList,";")
			wave specitem=$("root:"+destStr)
			
			// if multiple plots create new plot for this species
			if(ms0_graphOutputType==2)
				destStr = destStr[0,min(15, strlen(destStr)-1)]
				NewPlotName = "TseriesGraph_"+destStr 
				DoWindow/K $NewPlotName
				display /N=$NewPlotName as NewPlotName
			endif
			
			appendtograph/W=$NewPlotName specitem vs x_wave		// add trace for new, multiple and append
			
			// error bars
			if (ms0_appendErrorBars)
				wave/z Spec_err = $("root:"+destStr+"_err")
				if (WaveExists(Spec_err))
					ErrorBars/W=$NewPlotName $NameOfWave(specitem) Y,wave=(Spec_err,Spec_err)
				endif
			endif
		
		endfor	
			
		// color to AMS colors and apply any other general AMS settings
	//	if (ms0_graphOutputType==2)
			sq_applyGraphDefs(destList) // SQ_Butt_appgraphdefs()
	//	endif
		
		// labels
		Label/W=$NewPlotName bottom "Date and Time"	
		if (ms0_ion2mass)
			Label/W=$NewPlotName left "g/m3"
		else
			Label/W=$NewPlotName left "signal, Hz"
		endif
	endif

End


//(0) Retrieve parameters
//(1) Sanity checks
//	Do preprocessed PToF sticks exist?	
//	If AB correction checked, does corr_fact exist and is it the correct length?	
//	Is the chosen todo wave of length >0?
//	Does the chosen todo wave have PToF runs in it?
//	If not 'as saved' diameter base is the menu X vs ToF or dXdlogDa vs logDa
//	Were any species listed in the species box? 
//	Custom diameter and time base sensible?
//	Are PToF DAQ parameters constant across todo wave?
//	If appending results, does top graph makes sense?
//(2) Prepare to fetch
//	If normalizing, check if runs have MS and PToF in same run
//	Get result waves name prefix
//(3) Fetch,calling MS_conc function
//(4)  Make diameter "edge of size bins" waves d_XaxisEdges, log_d_XaxisEdges
//	They will have 1 more point than data point dimension (they are edges)
//	If x axis is X vs ToF then d_XaxisEdges is in Time
//	Clean up diameter wave so it uses gp/pp boundary and doesn't have nans or infs
//	Create deltaLogDiamCenters_op which will have the proper weight for cross product
//		dimsize(deltaLogDiamCenters_op) should have 1 less then d_XaxisEdges
//(5) Apply size weighting and modify output if needed
//	A) If size avg spectra  multiply by deltaLogDiamCenters_op to keep units nice(r)
//	B) Else is size dist or image plot
//		Handle nans gracefully (if requested boundary was out of range)
//(6) Deal with normalization
//	A) Get MS info
//		Modify paramStr in preparation for fetch call			
//		Fetch the MS info			
//		If we have no MS for PToF runs
//			Interpolate and get correct values.
//			If size dist
//				Get Avg MS
//			Else image plot
//				Keep time series of MS
//	B) Apply normalization
//		If size distribution (one value) 
//			Get PToF totalArea = size dist x deltaLogDiamCenters_op		
//			Multiply by MSavg/PToFAvg
//		Else image plot (get time series of values)				
//			Get PToF norm time series
//			Find averages of MSAvg and PToF for time series and multiply this
//(7) Get Tim O's PToF stats
//	Present the user with table of PToF stats
//(8) Kill temporary waves
//(9) Plot results
//(10) Cleanup temp waves in mats folder
//
// Button function for ToF image, size average and mass spec size results
Function sq_butt_ToFConc(ControlName): ButtonControl
	string ControlName

	sq_GetIndexNotDoneYet()
	// Step 0. Retrieve panel parameters
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	svar tof1_speclist=root:panel:tof1_speclist
//	nvar tof1_dsmooth=root:panel:tof1_dsmooth
	nvar tof1_graphoption=root:panel:tof1_graphoption
	nvar tof1_datatype=root:panel:tof1_datatype		// X vs ToF or diameter
	nvar tof1_norm=root:panel:tof1_norm
	nvar tof1_ugconv=root:panel:tof1_ugconv
	nvar tof1_shownegs=root:panel:tof1_shownegs 
//	nvar tof1_sdsIgnore=root:panel:tof1_sdsIgnore  //1.51I
	nvar tof0_gppp=root:panel:tof0_gppp
	nvar tof0_corrop=root:panel:tof0_corrop		// AB correction
	nvar ams_time_saved=root:panel:ams_time_saved
	nvar tof0_d_saved = root:panel:tof0_d_saved		// what nm diameter range
	nvar chopper_duty=root:diagnostics:chopper_duty	// not in panel, loaded in get index
	nvar cor3_chamber=root:panel:cor3_chamber	// not in panel, loaded in get index

	nvar tof_stats = root:panel:tof_stats	
	nvar tof0_fragAirIs0 = root:panel:tof0_fragAirIs0	
	nvar tof0_suffix_ck = root:panel:tof0_suffix_ck
	nvar tof0_maxmz=root:panel:tof0_maxmz
	svar tof0_PToFePToFtitle=root:panel:tof0_PToFePToFtitle

//	nvar ePToFPostAvgFlag = root:panel:ePToFPostAvgFlag
//	nvar ePToFUseDAQ=root:panel:ePToFUseDAQ
	wave squirrel_index = root:index:squirrel_index
	wave rn_series = root:index:rn_series
	wave ptofNumTimesThrough = root:diagnostics:ptofNumTimesThrough		// 1.36E
	wave TimeAcquiringPToFInRun = root:diagnostics:TimeAcquiringPToFInRun
	wave/z ePToF_oversampling = root:diagnostics:ePToF_oversampling	//1.53M
	wave/z ePToF_enabled = root:diagnostics:ePToF_enabled		//1.53M
	wave/z deconvolveType = root:diagnostics:deconvolveType
	svar/z tof0_PToFePToFtitle = root:panel:tof0_PToFePToFtitle
	nvar/z PToF_DCgr_ePToFSumDiffScaling = root:panel:PToF_DCgr_ePToFSumDiffScaling
	wave/z/i todo=$"root:"+sq_toDoWvNm
	wave/z corr_fact=root:diagnostics:corr_fact

	nvar/z deconvolveJoel = root:panel:deconvolveJoel
	nvar/z deconvolveMike= root:panel:deconvolveMike

	variable idex,jdex,datatype,logop,ndex,baseval, runPos, ePToF_twflag
	variable nTodo, pTodo, startrun, lowcut, noMSRunsFlag=0	, hiCut	  //1.59D//1.51N
	string dummyStr ="", paramstr="", deststr="",speclist=tof1_speclist,prefix="",suffix,dataStr,normstr="", alertStr=""			//1.49E
	string d_base, t_base, legendStr="", str1, str2, mywinName, statsList=""
	string MSWavList="", PToFAreaList="", waveNameSuffix, ePToFTitleStr, strtw=""
	variable ePToF_exists, isEPToF, osFactor, PostAvgFlag, hasPToF, hasEPToF, twDecon=0
	
	sq_pop_toDoList("ams_todolist_pop",nan,sq_toDoWvNm)
	hasPToF = sq_TodoHasPToF(todo, ptofFlag=1)
	hasEPToF = sq_TodoHasPToF(todo, ptofFlag=0)

	Setdatafolder root:	

	// Step 1 Sanity checks

	// Does PToF_stick_p and corr_fact exit
	if(!waveexists(todo)|| numpnts(todo)==0)		//^ added numpnts conditional and changed to an abort
		Abort  "Todo wave not found or is of zero length.  - Aborting from sq_butt_TofConc"
	endif	
	
	if (tof0_corrop)		//1.60K
		sq_ABsanity()
	endif
	
	// Step 1C. Check the diameter request
	//^ make sure that if data is X vs ToF that the as saved diameter option is checked  //^1.36E
	if (!tof0_d_saved && tof1_datatype==2)
		Abort "If using a non-saved diameter base please select the data to plot to be dXdlogDa vs logDa"
	endif
	
	if (tof1_norm && tof1_datatype==2)
		Abort "You cannot normalize to MS data if the diamter axis is X vs PToF  - Aborting from sq_butt_ToFConc"		//1.59D
	endif

	// Check if todo wave has >0 PToF spectra.  We possibly reduce the selected todo wave to run that have PToF (todo = tempTodo)
	wave/z allPToF = root:allPToF	
	if (WaveExists(allPToF))
		sq_create_todo(sq_toDoWvNm+" and allPTOF","TempPToF")
		wave todo = root:TempPToF
		if (numpnts(todo)==0)
			killwaves/z root:tempTodo
			abort "There are no PToF runs in "+sq_toDoWvNm+".  Aborting from sq_butt_ToFConc"
		endif
	endif

	if (hasPToF && hasEPToF)
		abort "Cannot continue because the todo wave "+sq_toDoWvNm+" has both PToF and ePToF runs.  Aborting from sq_butt_ToFConc"
	endif	

 	if( FindDimlabel(squirrel_index,2,"PToF_stick_p")>=0)
		dataStr="PToF_stick_p;"
	else
		abort "PToF_stick_p not found. Perhaps you need to preprocess? - Aborting from sq_butt_ToFConc"
	endif

	osFactor=nan						
	PostAvgFlag=nan
	tof0_PToFePToFtitle = sq_setTof0_PToFePToFtitle(todo)

	sq_fix_ePToF_t0()		//1.59E
	sq_checkPToFparamsSameTodo(todo)
	runPos=sq_findrun(rn_series,todo[0])		// we need to set RunPos regardless as to whether it is custom dbase

	if( hasEPToF)
		osFactor=ePToF_oversampling[runPos]						
		TWEPToF_globals(OS=osFactor)		//1.60X
		PostAvgFlag=0		// default is to not deconvolve
		if( (strsearch(tof0_PToFePToFtitle, "NONSAME", 0)>=0)  )
			abort "Cannot proceed when ePToF deconvoluted differently."
		endif	// we have preprocessed correctly
		if (  strsearch(tof0_PToFePToFtitle, "Not decon", 0)>=0)
			if  (deconvolveJoel || deconvolveMike)  
				PostAvgFlag=1
			else
				DoAlert 1,"The ePToF data was not deconvolved in the preprocess step and the currently selection indicates that you do not want to deconvolve.  Are you sure?"
				if (V_flag==2)
					abort 
				endif
			endif
		endif
	endif
//Constant PostAvgFlag=0	// either we do not have ePToF data OR we have deconvoled in pre process step
//Constant PostAvgFlag=1	// avg across runs, deconvolve THEN apply frag ............ cannot have time dependent frags!
//Constant PostAvgFlag=2	// apply frag THEN deconvolve

	nTodo = numpnts(todo)  // todo is not limited to ony runs with PToF

	// Step 1D. Check species request
	// check that if plotting a size distribution we have a species we want to calculate // 1.43B added
	tof1_speclist = ReplaceString(" ", tof1_speclist, "")
	tof1_speclist = ReplaceString(".", tof1_speclist, ",")		//1.59F
	tof1_speclist = ReplaceString(";", tof1_speclist, ",")		//1.59F
	
	suffix=ControlName[5,6]		// will be appended to result waves
	strswitch(suffix)
		case "av":	//^ size distribution
			datatype=4
			break
		case "im":	//^ image plot
			datatype=5	
			break
		case "ms":	//^ size resolved mass spectra
			datatype=6
			break
		case "ex":	//^ export 3D matricies
			datatype=7
			break
	endswitch	

	if (strlen(tof1_speclist) == 0 && (datatype==4 || datatype==5) )
		abort "You must enter a species or m/z to perform this operation - Aborting from sq_butt_ToFConc " 
	endif
	
	if (tof0_suffix_ck)
	 	waveNameSuffix = sq_getWaveNameSuffix()
 	else
 		waveNameSuffix = sq_toDoWvNm
 	endif

	// Check that the diameter base is allowed
	d_base=sq_dbase()  // if nonDAQ then this wave contains the DVa EDGES, not the center points
	wave/z d =$d_base
	t_base=sq_tbase()  // if nonDAQ then this wave contains the time EDGES, not the center points.
	wave/z t =$t_base

	// we are finished with sanity checking, now get to work
	// select type of data produced
	suffix+="_"+waveNameSuffix[0, min(strlen(waveNameSuffix)-1,5)]		//1.61G
	switch(datatype)
		case 4:	//^ size distribution
			break
		case 5:	//^ image plot
			t_base=sq_tbase()
			if(strlen(t_base)>0)  // non DAQ time bae
				suffix+="_t"	// result wave name suffix
			endif
			break
		case 6:	//^ size resolvd mass spectra
			suffix+="_MS" // result wave name suffix
			break
		case 7:	//^ export 3D matricies
			if(strlen(t_base)>0) // non DAQ time bae
				suffix+="_3D" // result wave name suffix
			endif
			break
	endswitch	
	
	// Does it make sense to append data to top graph?
	if ( tof1_graphoption == 3  && datatype!=7)
		mywinName =winName(0,1)
		if (strlen(myWinName)==0)
			abort "Cannot append results - there is no top graph - aborting from sq_butt_ToFConc"
		endif
		GetAxis/Q/W=$mywinName bottom		
		switch(datatype)
			case 4:	//^ size dist
				if (V_max > 1e7)	// arbitrary, just make sure it is not a time-series - type axis
					abort "Cannot append results - the max value on bottom axis seems too big  - aborting from sq_butt_ToFConc"
				endif
			break
			case 5:	//^ image plot
				abort "Cannot append results - Please choose plot single, multiple, or update - aborting from sq_butt_ToFConc"
			break
			case 6:	//^ mass spec
				if (V_max > 1e7)	// arbitrary, just make sure it is not a time-series - type axis
					abort "Cannot append results - the max value on bottom axis seems too big  - aborting from sq_butt_ToFConc"
				endif
			break
		endswitch
	endif

//  Step 2.  Prepare to fetch ePToFSumDiff for ePToF TW deconvolution scaling
	if (hasEPToF && PToF_DCgr_ePToFSumDiffScaling && PostAvgFlag==1 && datatype!=6)
	//  for PToF:	case 4:	//^ size dist     case 5:	//^ image plot    case 6:	//^ size resolved mass spec
	//  for MS:	case 2 = Avg MS 	  case  3 = Avg MS vs time			  doesn't make sense

		paramstr=""
		speclist= "all"
		SQ_GetParamStr(paramstr,speclist,1,dummyStr)		// MS flag is 1... we deal in Hz first
		paramStr+="ePToF_flag:0;"		// "we have deconvoled in pre process step"
		paramStr+="PostAvgFlag:0;"
		paramStr+="corr_op:"+num2str(tof0_corrop)+";"
		paramStr+="ug_op:"+num2str(tof1_ugconv)+";"
		paramStr+="product_type:"+selectstring(datatype==4,"3","2") +";"
		paramStr+="t_base:"+t_base+";"
//		paramStr+=selectString(tof0_maxmz>0, "",  "min_ly:0;max_ly:"+num2str(tof0_maxmz-1)+";")  		
//		paramStr+= "speclist:all;"
		paramStr+="cache_op:0;"		// no longer necessary
		paramStr+="destlist:ePToFSumDiffAvg_temp;"
		paramStr+="timeweight_op:4;" //1.48F for better time averaging
//		paramStr+="max_lay:"+num2str(sq_FindMaxMinMz(todo, 1,0))+";"   //1.49E don't average over periods that don't match// bug fixed in 1.51K	
//		print paramStr
		squirrel_fetch(todo,sq_MS_concentration,paramstr,"MSSePToFSumDiff_p")
		if (datatype==4)		// single average MS
			wave ePToFSumDiffAvg_temp
			variable num = numpnts(ePToFSumDiffAvg_temp)
			redimension/n=(1,num) ePToFSumDiffAvg_temp
		endif
			
		// Note that the use of this result, ePToFSumDiffAvg_temp will happen WITHIN ms_conc!!!
		paramStr=""		
		speclist=tof1_speclist	
	endif

//  Step 2.  Prepare to fetch
	//1.51M		// to handle cases where there is any run with only PToF data and no MS data
	wave/z MStodo = sq_getMSWaveForPToFNorm(todo, tof1_norm, noMSRunsFlag)	

	// Get result waves name prefix
	if(tof1_ugconv==1)
		prefix="ug_"
	else
		prefix="sig_"
	endif
	if(tof1_datatype==1)		// ToF time or dXdlogDa vs logDa, NOT PToF
		logop=1
		prefix+="log_"
	endif

	if(strlen(d_base)>0)
		suffix+="_d"
	endif
		
	// Step 2C. Prep for the sq_conc function
//	PostAvgFlag==0  we have deconvol in preproc and this deconv was 
	ePToF_twflag = hasEPToF && ((PostAvgFlag==0 && strsearch(tof0_PToFePToFtitle, "TW decon", 0)>=0) || (PostAvgFlag>0 && deconvolveMike) )
	
	sq_journal_new("ToFConc")		
	//@ get paraStr values
	paramStr+="ePToF_flag:"+num2str(hasEPToF)+";"		//1.53N
	paramStr+="ePToF_twflag:"+num2str(ePToF_twflag)+";"		//1.61A
	paramStr+="PostAvgFlag:"+num2str(PostAvgFlag)+";"		//1.57L
	paramStr+="osFactor:"+num2str(osFactor)+";"		//1.57L
	paramStr+="lc:"+num2str(cor3_chamber)+";"
	paramStr+="corr_op:"+num2str(tof0_corrop)+";"
	paramStr+="ug_op:"+num2str(tof1_ugconv)+";"
	paramStr+="filter_op:"+num2str(tof1_shownegs)+";"
	paramStr+="product_type:"+num2str(datatype)+";"
	paramStr+="d_base:"+d_base+";"
	paramStr+="t_base:"+t_base+";"
	paramStr+="dlog_op:"+num2str(logop)+";"
	paramStr+="chop_duty:"+num2str(chopper_duty)+";"  
	paramStr+=selectString(tof0_maxmz>0, "",  "min_ly:0;max_ly:"+num2str(tof0_maxmz-1)+";")  
	if (hasEPToF)
		paramStr+="chopperDutyWave_op:1;"  
	endif	
	
	//@ check for presence of species in frags
	SQ_GetParamStr(paramstr,speclist,0,dummyStr)
	speclist = stringbykey("speclist",paramstr)
	speclist = replaceString("/", speclist, ",")
	if (itemsinList(speclist, ",")==0)
		tof1_speclist= speclist
		abort "There are no species listed. aborting from sq_butt_ToFConc"
	endif

	SQ_dataDestStr(destStr,prefix,suffix,speclist,1)
	
	paramStr+="cache_op:0;"		// no longer necessary
	paramStr+="destlist:"+destStr+";"
//	paramstr+="frag_exclude:frag_air;" //& More elegant way of excluding air from the frag table
	paramStr+="timeweight_op:4;" //1.48F for better time averaging
	variable m = sq_FindMaxMinMz(todo, 1,0)		//1.20L
	if (numtype(m) !=0 || m<0 || m>1e8)		// 1e8 is arbitrary
		abort "The maximum Mz of "+num2str(m)+" seems incorrect -  Aborting from sq_butt_ToFConc" 
	endif		//1.60L
	paramStr+="max_lay:"+num2str(m)+";"   //1.49E don't average over periods that don't match// bug fixed in 1.51K

	if (!tof0_fragAirIs0)		//1.52G
		paramstr+="frag_exclude:frag_air;" //& More elegant way of excluding air from the frag table
	endif	
	
//	print paramStr
	// Step 3.  Fetch  to get PToF results
	squirrel_fetch(todo,sq_MS_concentration,paramstr,datastr)

	sq_ePToFWaveNote(destStr)		//1.57N

	make/o/n=6/Free DVa_wave 
	sq_GetPToFParams(DVa_wave, runPos)

	variable twDeconFlag = DVa_wave[%ePToFenabled] && deconvolveMike

	if (strlen(d_base)==0)		// default diameter wave.  Note that even if PToF Avg mass spec is selected we need diameter info				
		make/free/o/n=(DVa_wave[%numPToFBins]+1) d_XaxisEdges, log_d_XaxisEdges, t_XaxisEdges	//1.51  defines EDGES of PToF regions, not middle
		t_XaxisEdges=DVa_wave[%t0]+((p-0.5)*DVa_wave[%step])
		if (twDeconFlag)
			twDecon=1
			sq_CorrectPToFTimeForTWDecon(DVa_wave, t_XaxisEdges)
		endif
		d_XaxisEdges= sq_ptof2dva(cor3_chamber,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],t_XaxisEdges[p]) 		//1.59E 
		log_d_XaxisEdges=log(d_XaxisEdges[p])

		make/FREE/o/n=(DVa_wave[%numPToFBins]) d_XaxisCenters, t_XaxisCenters
		t_XaxisCenters = DVa_wave[%t0]+((p)*DVa_wave[%step])
		if (twDeconFlag)
			sq_CorrectPToFTimeForTWDecon(DVa_wave, t_XaxisCenters)
		endif
		d_XaxisCenters=sq_ptof2dva(cor3_chamber,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],t_XaxisCenters[p]) //  1.53F
	else						// custom diameter wave - set interval or user defined diam wave in units of nm
		wave d_XaxisEdges=$("root:"+d_base)  // edges
		make/FREE /o/n=(numpnts(d_XaxisEdges)) log_d_XaxisEdges=log(d_XaxisEdges[p])  // EDGES of PToF regimes
		make/FREE/o/n=(numpnts(d_XaxisEdges)-1) d_XaxisCenters=sqrt(d_XaxisEdges[p+1]*d_XaxisEdges[p]) 	// PToF time edge points.  Note that the log_d_XaxisEdges still exists
	endif

	// modify edges of log_d_XaxisEdges to be particle and not gas phase; make deltaLogDiamCenters_op
	wavestats /q/m=1 log_d_XaxisEdges
	if (tof1_norm)		//1.56O
		lowcut=max(v_min,log(tof0_gppp)) // Enforce GP/PP boundary
		log_d_XaxisEdges=max(min(log_d_XaxisEdges[p],v_max),lowcut) // Protect algorithm from infs and -infs.
	endif
	
	// deltaLogDiamCenters_op (previously d_op) has the 'weights' for each size bin  dim size = 1 less than edges
	make/o/n=(numpnts(log_d_XaxisEdges)-1) deltaLogDiamCenters_op=log_d_XaxisEdges[p+1]-log_d_XaxisEdges[p]
	
	//1.59D
	if (hasEPToF && tof1_norm && tof0_d_saved && tof1_datatype==1)  // ePToF, norm to MS, Dva diam and diameter as saved
		hiCut = BinarySearch(d_XaxisEdges, ePToFMaxDVaNm)
		if (hiCut>0)				//1.59D
			d_XaxisEdges[hiCut,]=nan
			log_d_XaxisEdges[hiCut,]=0
			d_XaxisCenters[hiCut,]=nan
		endif
		if (tof0_gppp>0)
			hiCut = BinarySearch(d_XaxisEdges, tof0_gppp)
			if (hiCut>0)				//1.59D
				d_XaxisEdges[0,hiCut-1]=nan
				log_d_XaxisEdges[0,hiCut-1]=0
				d_XaxisCenters[0, hiCut-1]=nan
			endif
		endif
	endif
	
	// we now have all the parts we need to do any extra math on the results
	// Step 5.  Deal with avg mass spec case 
	if(datatype>=6)	// size resolved spectra	// 1.51A, not a normalization but an integration over the size domain so that results are true ug/m3 and not some funky ug/m3dlogdva
		// 1.22A changed from datatype==6
 		if (tof1_datatype==1)  // if dLog
 			sq_ApplyDeltaLogDiam(deststr, deltaLogDiamCenters_op) 	
		endif
		if (strlen(t_base)==0)
			wave t_baseWave =root:index:imt_series
		else
			wave t_baseWave=$("root:"+t_base) // i.e. tmin_10 or custom
		endif
		sq_ValidateImageAxisWave(t_baseWave) 
		if(tof1_datatype==1)	//^ dXdlogDa
			if (strlen(d_base)==0)
				strtw=SelectString(twDeconFlag , "dsig3D_", "dsigTw3D_")
				duplicate/o d_XaxisEdges $(strtw+waveNameSuffix)/wave=d_baseWave 
			else
				wave/z d_baseWave=$("root:"+d_base)
			endif
		else			//^ x vs tof
			strtw=SelectString(twDeconFlag , "tsig3D_", "tsigTw3D_")	
			duplicate/o t_XaxisEdges $(strtw+waveNameSuffix)/wave=d_baseWave 
		endif
		sq_ValidateImageAxisWave(d_baseWave)
	elseif (datatype<6)   //  disabled for mass specs... deal only with size distribution and PToF image plots here
	
	// Step 6		// deal with post fetch math  for size dist and image plots							
		// step 6A	
		if (tof1_norm)	  // is size Dist or image	// section significantly redone in 1.51N
				
			// from our prep work, all we know is that we have a todo wave referenced as MStodo ready.  
			// If noMSRunsFlag==1 we need to handle it ourselves "by hand" MStodo
				
			// Generate analogous MS waves.  Slightly revamp paramStr
			paramstr=replacestringbykey("PostAvgFlag",paramstr,"")
			paramstr=replacestringbykey("osFactor",paramstr,"")
			paramstr=replacestringbykey("ePToF_flag",paramstr,"")
			paramstr=replacestringbykey("ePToF",paramstr,"")

			paramstr=replacestringbykey("frag_exclude",paramstr,"")
			paramstr=replacestringbykey("timeweight_op",paramstr,num2str(3))		//1.51M  timeweight_op 3 is for open + closed time
			if (datatype==4)	// size distribution
				sq_dataDeststr(normStr,"TempNormFactor_","",speclist,1)			//1.51I    waves will be killed at the end
			else		// PToF image plot
				sq_dataDeststr(normStr,"MS4PToFNorm_"+waveNameSuffix+"_","",speclist,1)	//1.60D	//1.51I  t_series waves will be retained
			endif
			paramstr=replacestringbykey("destlist",paramstr,normStr)
			if (noMSRunsFlag)
			 	if (datatype == 4) 	//  for all size distribution
					paramstr=replacestringbykey("product_type",paramstr,"0")		// product type 0 is a single value	// 1.51 Change.		// product type 1 is a regular time series  
				else		// image plot AND custom time base
					// if custom t_base, the MS time wave will be bigger than it needs to be, all we know is that it will average 'all' MS runs
					// if we have a non 'as saved' t_base then we will just hope that the integration region is big enough to include some runs with real MS data
					//  we won't be able to pick and choose which MS runs near the PToF runs to look at
					// this meas for size distribution we need to collapse the avg MS ourselves into one number
					paramstr=replacestringbykey("product_type",paramstr,num2str(datatype-4))		// 1.51 Change.    
				endif
				//1.51N  later we will want to zero out any runs that don't have PToF
				make/FREE /o/n=(numpnts(rn_series)) PToFtodoMask_temp
				sq_makeMaskFromTodofindRun(PToFtodoMask_temp,todo)					
				PToFtodoMask_temp = numtype(PToFtodoMask_temp[p])==0 ? PToFtodoMask_temp[p] : 0 
			
			else		// typical
				paramstr=replacestringbykey("product_type",paramstr,num2str(datatype-4))		// 1.51 Change.    
				// product type 4 is size distr, product type 5 is image plot, 6 is mass spec in size bands
			endif

			squirrel_fetch(MStodo,sq_MS_concentration,paramstr,"MSSDiff_p")
				
 			sq_PTOFnormTraces(deststr, normstr, speclist, noMSRunsFlag, t_base, d_base, waveNameSuffix, dataType, deltaLogDiamCenters_op, sq_toDoWvNm, MSWavList, PToFAreaList)
		endif	// if normalization

		// do whether we normalize or not
		if (tof_stats)// Step 7 do PToF stats		 we do this AFTER normalization so that stats will reflect what the user sees
			for(idex=0;idex<itemsinlist(deststr,"/");idex+=1)		// for each species
				wave destwav=$stringfromlist(idex,deststr,"/")		// Size distrib or image of one species 
				if ( tof_stats && tof1_datatype==1) 		// diam type = nm
					// Step 4D. Find PToF stats					
					if (datatype==4)		//  size distribution
						duplicate/o destwav TempDestWave
						Redimension/n=(1,numpnts(TempDestWave)) TempDestWave		// redimension so that the call to sq_calc_PTOFimage_stats_ln is always passed a 2D wave.
						wave destwav=TempDestWave
					endif	// size distr
					statsList += sq_calc_PTOFimage_stats(destwav, d_XaxisEdges, log_d_XaxisEdges, deltaLogDiamCenters_op, sq_toDoWvNm, stringfromlist(idex,speclist,","), updateFlag = (tof1_graphoption==4) ) +"/"   //1.60T	
				endif	//	diam type  = nm  && do PToF stats
			endfor		// for each species
		endif
			
		if (dataType==5)  // image plot  d_baseWave, t_baseWave  	//1.61G
			if (strlen(t_base)==0)
				wave t_baseWave =root:index:imt_series
			else
				wave t_baseWave=$("root:"+t_base) // i.e. tmin_10 or custom
			endif
			sq_ValidateImageAxisWave(t_baseWave) 
			if (tof_stats || tof1_norm )
				if (strlen(t_base)==0)
					wave/d Centertwave = root:index:t_series			
				else
					make/d/o/n=(numpnts(t_baseWave)-1) $("root:"+t_base+"C")/wave=Centertwave
					Centertwave = (t_baseWave[P+1]+t_baseWave[P])/2			
				endif
			endif
			if(tof1_datatype==1)	//^ dXdlogDa
				if (strlen(d_base)==0)
					strtw=SelectString(twDeconFlag , "im_dsig_", "im_dsigTw_")
					duplicate/o d_XaxisEdges $(strtw+waveNameSuffix)/wave=d_baseWave 
				else
					wave/z d_baseWave=$("root:"+d_base)
				endif
			else			//^ x vs tof
				strtw=SelectString(twDeconFlag , "im_tsig_", "im_tsigTw_")	
				duplicate/o t_XaxisEdges $(strtw+waveNameSuffix)/wave=d_baseWave 
			endif
			sq_ValidateImageAxisWave(d_baseWave)
		elseif(dataType==4)  // size dist plot  d_baseWave	//1.61G
			if(tof1_datatype==1)	//^ dXdlogDa
				strtw=SelectString(twDeconFlag , "dsig_", "dsigTw_")
				if (strlen(d_base)==0)
					duplicate/o d_XaxisCenters $(strtw+waveNameSuffix)/wave=d_baseWave 
				else
					wave dbase = $("root:"+d_base)
					variable nd =numpnts(dbase)
					make/o/n=(nd-1) $("root:"+d_base+"Center")/wave=d_baseWave
					d_baseWave = sqrt(dbase[p+1]*dbase[p])
				endif
			else			//^ x vs tof
				strtw=SelectString(twDeconFlag , "tsig_", "tsigTw_")
				duplicate/o t_XaxisCenters $(strtw+waveNameSuffix)/wave=d_baseWave 
			endif		
		endif
	endif		// size distrib or image plots

	// Prepare output
	legendStr=""  //"// PToF values were calcuated on "+todoStr +" on "+date() +" "+ time()+"\r"
	// we do the normalization first, before we do the PToF stats

	if (tof_stats && tof1_datatype==1  && dataType<6)	
		if (dataType ==4)  // size distrib
			for(idex=0;idex<itemsinlist(deststr,"/");idex+=1)		
				wave statsWave = $stringfromlist(idex,statsList, "/")
				legendStr += "// PToF statistics of  todo "+sq_toDoWvNm+" with diameter "+selectString(strlen(d_base)==0, d_base, "as saved ") +selectString(tof1_norm, " ", "and MS normalization ")
				legendStr += stringfromlist(idex, speclist, ",")+ "  Integr. Area: "+num2str(statsWave[0][0]) + "   Mode Diam.: "+num2str(statsWave[0][1]) 
				legendStr += "   Geom. Mean Diam.: "+num2str(statsWave[0][2]) + "   Geom. Std. Dev. : "+num2str(statsWave[0][3]) 
				legendStr += "  \r"
				Killwaves/z statsWave
			endfor
			print legendStr
		elseif (tof1_graphoption!=4)		// if not update

			for(idex=0;idex<itemsinlist(deststr,"/");idex+=1)	// for each	
				str1= CleanUpName( "Table_"+stringfromlist(idex,statsList) ,0 )
				DoWindow/F $str1
				if (V_flag==0)
					Edit/N=$str1 as str1
					wave statsWave = $stringfromlist(idex,statsList, "/")
					appendtoTable statsWave
					ModifyTable horizontalIndex=2
				endif				
			endfor			
		endif
	endif

	// Step 9. Plot the results
	if(datatype==4)		// size distrib
		sq_plot_ptof1_av(destStr,d_baseWave, runPos, todo)
	elseif(datatype==5)	// image plot
		if (tof1_norm)
			sq_plot_ptof1_im(destStr,d_baseWave, t_baseWave, SelectString(tof_stats && tof1_datatype,  "", statsList ), Centertwave=Centertwave, MSNormWaveList=MSWavList, PToFNormWaveList=PToFAreaList)
		else
			sq_plot_ptof1_im(destStr,d_baseWave, t_baseWave, SelectString(tof_stats && tof1_datatype,  "", statsList ))
		endif
	elseif(datatype==6)	// size resolved mass spec
		sq_MinAvgMStoZero(todo,replaceString("/", destStr, ";"))		// 1.49E
		sq_plot_ptof1_MS(destStr,d_base,t_base)
	elseif(datatype==7)	// export the 3D matrix, one for each species 		// added in 1.43A
		print "// The following matricies were created and placed in the root data folder: "+destStr[0, strlen(destStr)-2]
		print "// and have the dimensions: time x mass spec x PToF size"
		print "// with run time edges in the wave "+GetWavesDataFolder(t_baseWave,2)+" and the PToF edges in the wave "+GetWavesDataFolder(d_baseWave,2)
	endif
	// Step 8
	killwaves /z deltaLogDiamCenters_op,log_d_basewav, log_d_XaxisEdges,  d_XaxisEdges
	killwaves/z TempDestWave, TempPToF, MStodoForPToFNorm_temp, destWave_temp
	killwaves/z ePToFSumDiffAvg_temp
	
	sq_journal_end()

	//1.49E  step 10
	nvar/z misc_KillAllInnms_mats = root:panel:misc_KillAllInnms_mats
	if (nvar_exists(misc_KillAllInnms_mats) && misc_KillAllInnms_mats)
		sq_butt_killWavesInFolder("root:ms_mats")
	endif
	
End


//1.22A
Function sq_ApplyDeltaLogDiam(DestList, deltaLogDiamCenters_op) 
string DestList
wave deltaLogDiamCenters_op

	variable idex //, jdex
	for(idex=0;idex<itemsinlist(DestList,"/");idex+=1)
		wave destwav=$stringfromlist(idex,DestList,"/")
//		for (jdex=0;jdex<dimsize(destwav,1);jdex+=1)
//			destwav[][jdex]*=deltaLogDiamCenters_op[q]			//1.58G// multiply jth column by the row ( a single value)
//		endfor
		if (dimsize(destwav,2) >=1)
			destwav*=deltaLogDiamCenters_op[r]
		else
			destwav*=deltaLogDiamCenters_op[q]
		endif
	endfor	

End


Function/wave sq_getMSWaveForPToFNorm(todo, tof1_norm, noMSRunsFlag)
wave todo
variable tof1_norm, &noMSRunsFlag

	if (!tof1_norm)
		return $""	
	endif
	
	wave/z allMS = root:allMS	
	if (WaveExists(allMS))	// we are only concerned when normalization checkbox is checked
		sq_create_todo(NameofWave(todo)+" and allMS","MStodoForPToFNorm_temp")
		wave MStodoForPToFNorm_temp = root:MStodoForPToFNorm_temp
		if (numpnts(MStodoForPToFNorm_temp)==0 || numpnts(MStodoForPToFNorm_temp)!=numpnts(todo))		// we have some runs where we don't have ms data
			svar sq_toDoList = root:panel:sq_toDoList
			string PToFNormMS		// modified in 1.56F
			prompt PToFNormMS, "Select a todo wave from which a subset will be used for normalization", popup sq_toDoList
			DoPrompt "Enter PToF normalization information", PToFNormMS //, PTofNormTimeDelta
			if (V_flag==1)		// user clicked cancel
				Abort "The user chose to abort"
			endif
			sq_create_todo(PToFNormMS+" and allMS","MStodoForPToFNorm_temp")
			wave MStodo = root:MStodoForPToFNorm_temp
			if (numpnts(MStodoForPToFNorm_temp)==0)
				abort "Cannot proceed with the PToF normalization using selected todo wave "+PToFNormMS+" because there are zero MS runs in this todo wave  - aborting from sq_butt_ToFConc" 
			endif
		endif
		noMSRunsFlag=1
		wave MStodo = root:MStodoForPToFNorm_temp		// for later use in fetch MS_conc call
	else			// if allMS does not exist then we assume every PToF run also has MS data
		wave MStodo = $NameofWave(todo)	// if we don't normalize we don't use this		// for later use in fetch MS_conc call
	endif	

	return MStodo
End


Function sq_PTOFnormTraces(deststr, normstr, speclist, noMSRunsFlag, t_base, d_base, waveNameSuffix, dataType, deltaLogDiamCenters_op, sq_toDoWvNm, MSWavList, PToFAreaList)
string destStr, normstr, speclist, t_base, d_base, waveNameSuffix, sq_toDoWvNm, &MSWavList, &PToFAreaList
variable &noMSRunsFlag, dataType
wave deltaLogDiamCenters_op

	variable idex, NormVal
	string specStr, str2, legendStr=""
	
	// Deal with the MS values for these PToF runs
	// finding the area is somewhat duplicated from the PToF stats call.  We have to do it separtely here, because we need the area BEFORE we normalize
	for(idex=0;idex<itemsinlist(deststr,"/");idex+=1)		// for each species

		specStr = stringfromlist(idex,speclist,",")	// ie. "org"
		
		wave destWav=$stringfromlist(idex,deststr,"/")		// PToF size distrib or image plot	
		wave MSWav=$stringfromlist(idex,normstr,"/")		// contains the MS time series points for the normalization wave
																	// named "MS4PToFNorm_"+waveNameSuffix+"_"			
		if (noMSRunsFlag)
			if ( strlen(t_base)!=0 && datatype ==5) //1.59D	// we have an MS time trace... We need to just interpolate over the runs with PToF data
				wave tWave = $t_base
				duplicate/o tWave $t_base+"ss"/wave=t_baseSS
				deletepoints 0, 1, t_baseSS		// 1.60D more accurately this should be dependent on whether data time stamp is the end.... it always is.
				gen_InterpolateAcrossTime(t_baseSS, MSWav)		// interpolate across PToF runs with no MS.  Will not have nans anymore
			endif
		endif

		// find the PToF_area for data types 4 and 5, size distrib and image plots
		switch (datatype)
			case 4: // Size distribution
				//  we want our dest wave to have nans in it if sizes are out of bounds, but we don't want our cals to have nans
				duplicate/o destwav destWave_temp
				destWave_temp = numtype(destwav[p])==0 ?  destwav[p] : 0 
				matrixop /o/FREE sizeDistArea = destWave_temp . deltaLogDiamCenters_op		// dot product, get 1 point wave		//1.48D fix
				
				NormVal = MSWav[0]/sizeDistArea[0]
				destwav*=NormVal
				legendStr = "// For size dist plot of todo "+sq_toDoWvNm+", "+specStr+" with diameter "+selectString(strlen(d_base)==0, d_base, "as saved ")
				legendStr += " Avg PToF loading is "+num2str(sizeDistArea[0])+"  Avg MS "+specStr + " loading is  "+num2str(MSWav[0])
				legendStr += "; normalization factor is "+num2str(NormVal) //+ "\r"
				print legendStr
				killwaves /z MSWav  // has only 1 point
				break
			case 5: // Size distribution vs time
				//  we want our dest wave to have nans in it if sizes are out of bounds, but we don't want our cals to have nans
				duplicate/o/FREE destwav destWave_temp
				destWave_temp = numtype(destwav[p][q])==0 ?  destwav[p][q] : 0 
				matrixop /o/FREE PToFArea2D = destWave_temp x deltaLogDiamCenters_op  	// dot product, get # time points wave
				
				str2 = CleanUpName( "PToFArea_"+waveNameSuffix+"_"+specStr,0)  // 1.60D  CleanUpName( "PToFArea_"+sq_toDoWvNm+"_"+str1,0)
				make/o/n=(dimsize(PToFArea2D,0)) $str2  /Wave=PToFArea		//1.51 N  users will want to  see these 
				PToFArea = PToFArea2D
				PToFArea = PToFArea[p]==0 ? nan : PToFArea[p][q] 
				wavestats/q/m=1 PToFArea		// a better way to do this is to do a smart average... take into consideration the duration each PToF run 
				NormVal = V_avg		// a temporary placeholder
				wavestats/q/m=1 MSWav		// don't care if it is original time stamp or not...
				destwav*=V_Avg/NormVal		// single value multiplied by all points in 2D wave
				legendStr += "// For image plot of todo "+sq_toDoWvNm+", "+specStr
				legendStr += " Avg PToF loading is "+num2str(NormVal)+"  Avg MS "+specStr + " loading is  "+num2str(V_Avg)
				legendStr += "; normalization factor is "+num2str(V_Avg/NormVal) + "\r"
				MSWavList+=NameOfWave(MSWav)+"/"
				PToFAreaList+=NameOfWave(PToFArea)+"/"
				print legendStr
				break
//				case 6: // Need to decide on what the best way of doing this is and whether we want to do it at all
//					matrixop /o norm_fac=normwav/(destwav x d_op)
//					destwave*=normwav[p]==0?(0):(norm_fac[p])
//					break
//				case 7: // Let's not even go there yet. Deal with type 6 first..					
//					break
		endswitch				
	endfor		// each species
	if (strlen(str2)>0)
		print "// The normalization waves "+str2+", etc. were created at "+date()+" "+time()
	endif

End


// 1.60X
Function sq_CorrectPToFTimeForTWDecon(DVa_wave, twPToFTime)
wave DVa_wave, twPToFTime
  	twPToFTime -=-1/(DVa_wave[%ChopperFreqHz]*DVa_wave[%ePToFOS]*127)/2	 // one half a PToF bin width 	//1.60X
End


//1.51I
// Functions by Tim Onasch given to Donna, June 2011
// From a 2D PToF image plot calculates the
// integrated value
// mode diameter
// geometric mean diameter
// geometric standard deviation of the mean
// Each of the 4 results is a column in the  result named PToF_image_stats
// Code will return nan for results that are just not feasible (i.e. geometric means > 5000nm)
// Code works whether or not the time base is the AMS one or a user defined one
//
// Calculate Statistical information on PTOF image (dM/dlnDp vs Dp vs time)
// NOTE, originally wrote this in log()/10^() space, but IGOR had a mathematical problem somewhere, works in ln()/exp() space...
Function/S sq_calc_PTOFimage_stats(PTOFimage, d_XaxisEdges, log_d_XaxisEdges, deltaLogDiamCenters_op, NameStr, specStr, [updateFlag]) 
	wave PTOFimage	  //dimensions = (np,nq)
	wave  d_XaxisEdges, log_d_XaxisEdges	//dimensions = nq+1  ONE MORE than the number of points in an avg size distribution.  These show edges
	wave  deltaLogDiamCenters_op  	//dimensions = nq
	string NameStr		// donna added
	string specStr		// donna added
	variable updateFlag  		//1.60T
		
	variable max_diameter = 5000 	//nm
	variable min_diameter = 5 //nm
	variable max_sigma = 8  // unitless

	variable i,j
	variable pointIndex
	variable np=dimsize(PTOFimage,0)	// number of rows (time)
	variable nq=dimsize(PTOFimage,1)	// number of PToF size cuts
	string resultName
	
	//Create diameter, lnDp, and dlnDp waves
	make/FREE/o/d/n=(nq) Dp, logDp, dlogDp
	Dp = 10^(log(d_XaxisEdges[p])+(log(d_XaxisEdges[p+1])-log(d_XaxisEdges[p]))/2)   // diameter centers
	logDp = log(Dp[p])		// log(diameter centers)
	dlogDp=log(d_XaxisEdges[p+1])-log(d_XaxisEdges[p])	// delta of diameter edges (last value in wave is incorrect)
			
	//Make Calculation Waves = int, mode, geom, geos
	make/FREE/o/d/n=(np) int=0, mode=NaN, geom=0, geos=0
	make/FREE/o/d/n=(nq) dist, dist_x_dlogDp, dist_x_dlogDp_x_logDp, dist_x_dlogDp_x_logDp_m_logGeom
	
//Integrate IMAGE and calculate mode and geometric mean diameters
	for (i=0;i<np;i+=1)
		dist = PTOFimage[i][p]
		wavestats/q/M=1 dist
		if (V_maxloc>0)
			mode[i] = Dp[V_maxloc]
		else
			mode[i] = NaN
		endif
		if (V_npnts==0)
			int[i] = NaN
			geom[i] = NaN
			geos[i] = NaN
		else
			dist_x_dlogDp = dist[p] * dlogDp[p]	// size distrib * delta (ln(size) = 'area' per size bin
			wavestats/q/M=1 dist_x_dlogDp
			int[i] = V_sum		// total area
			dist_x_dlogDp_x_logDp = dist_x_dlogDp[p] * logDp[p]		// area size bin * ln(size)
			wavestats/q/M=1 dist_x_dlogDp_x_logDp
			geom[i] = 10^(V_sum/int[i])						// exp(  sum(area size bin * ln(size) ) / total size  )
			dist_x_dlogDp_x_logDp_m_logGeom = dist_x_dlogDp[p]*(logDp[p]-log(geom[i]))^2    // (area size bin * ln(size)) * ( ln(center) - ln(mean ) )^2
			wavestats/q/M=1 dist_x_dlogDp_x_logDp_m_logGeom
			geos[i] = 10^(sqrt(V_sum/int[i]))	//Function for 1/N formulation			
		endif	
	endfor
	
	//Set some practical bounds
	mode = (mode[p] > max_diameter) || (mode[p] < min_diameter) ? (NaN):mode[p]
	geom = (geom[p] > max_diameter) || (geom[p] < min_diameter) ? (NaN):geom[p]
	geos = geos[p] > max_sigma ? (NaN):geos[p]			// not sure of this line from Tim... seems to always set values to nans
	
	//Make Output Wave
	if (updateFlag) 
		resultName = CleanUpName("PTOFstats_"+specStr+"_"+NameStr,0)  //1.60T
	else
		resultName = UniqueName("PTOFstats_"+specStr+"_"+NameStr,1, 0)  //1.60T
	endif
	resultName = resultName[0, min(strlen(resultName)-1, 30)]
	
	make/o/n=(np,4)/d $resultName/Wave=PTOFimage_stats
	SetDimLabel 1,0,Integration,PTOFimage_stats
	SetDimLabel 1,1,ModeDiameter,PTOFimage_stats
	SetDimLabel 1,2,GeometricMeanDiameter,PTOFimage_stats
	SetDimLabel 1,3,GeometricStandardDeviation,PTOFimage_stats
	PTOFimage_stats[][0] = int[p]
	PTOFimage_stats[][1] = mode[p]
	PTOFimage_stats[][2] = geom[p]
	PTOFimage_stats[][3] = geos[p]

	Return resultName

End


//^ modified to prevent too many mass spectra plots from automatically being generated.
Function sq_plot_ptof1_MS(destStr,dwave,twave)
	string destStr,dwave,twave
	
	nvar tof1_graphoption=root:panel:tof1_graphoption		//^ single, multiple, update
	nvar tof0_d_saved=root:panel:tof0_d_saved		//^ use saved diameter values
	nvar tof0_d_reg=root:panel:tof0_d_reg			//^ use values from the set interval (nm)
	nvar tof0_d_custom=root:panel:tof0_d_custom		//^ use custom diameter wave 
	
	nvar tof0_d_reg_n=root:panel:tof0_d_reg_n		//^ use number of custom diameter bins
	nvar tof0_d_reg_min=root:panel:tof0_d_reg_min	//^ minimum diamter value
	nvar tof0_d_reg_max=root:panel:tof0_d_reg_max		//^ maximum diameter value 

	nvar tof1_ugconv = root:panel:tof1_ugconv

	wave rn_series=root:index:rn_series
	svar todoStr=root:panel:sq_toDoWvNm
	
	wave/z todo=$"root:"+todoStr		//1.44B
	wave/z xwave=root:diagnostics:amus
	wave/z diamWave=$dwave
	wave/z source=$("root:"+stringfromlist(0,destStr,"/"))		//^ do this only to get dimsize
	
	variable idex,num=itemsinlist(destStr,"/"),startrun,diam_i, diam_n
	string title, myWinName
	
	diam_n=dimsize(source,1)
	myWinName = "PToF_ms_"+todoStr
	
	if(tof1_graphoption==4)	//^update
		return 0
	else
		if  ( (diam_n > 10) && (tof0_d_saved) ) 		//^ 10 is arbitrary
			doAlert 1, "Beware!  Because you selected \"As saved\" for the Diameter Base, "+num2str(diam_n)+" number of graphs will be generated.  Select yes to continue, no to quit."
			if (v_flag == 2)
				return 0		//^ exit function
			endif
		endif
	endif
	
	for(diam_i=0;diam_i<diam_n;diam_i+=1) //^ loop over diameters
		for(idex=0;idex<num;idex+=1)	// loop over species
			wave/z source=$("root:"+stringfromlist(idex,destStr,"/"))
			if(idex==0)
				display/N=$myWinName as myWinName
				myWinName = S_name
			endif
			appendtograph/W=$myWinName source[][diam_i] vs xwave
			ModifyGraph/W=$myWinName mode($(nameofwave(source)))=1,toMode($(nameofwave(source)))=3
		endfor
		modifygraph/W=$myWinName log(left)=1
		sq_applyGraphDefs("") // sq_butt_appgraphdefs("")
		if(waveexists(diamWave))
			title=num2str(diamWave[diam_i])+"nm - "+num2str(diamWave[diam_i+1])+" nm"
			TextBox/C/N=text0/A=MT/W=$myWinName title
		endif

		if (WaveExists(source))
			SetAxis/W=$myWinName bottom 0, dimsize(source,0)
		endif
		
		Label/W=$myWinName bottom "m/z"
	
		if (tof1_ugconv==1)
			Label/W=$myWinName left  "Nitrate equivalent mass (g m\\S-3\\M)"
		else
			Label/W=$myWinName left "Ion rate (Hz)"
		endif

	endfor

End

Function/s PToF_GrCaveat(specType)
string specType

	string str = ""
	if (strsearch(specType, "_", 0 )<0)
		str=" without HR PToF DC subtraction " 
	endif
	
	return str
End



Function sq_plot_ptof1_av(destStr,d_baseWave, runPos, PToFTodo, [HRflag, HRPlotPrefix, specType])		//1.61A
	string destStr,HRPlotPrefix, specType
	wave d_baseWave
	variable runPos, HRflag  //1.21G
	wave/z PToFtodo
	
	nvar tof0_showDC=root:panel:tof0_showDC		//1.51P
	nvar tof1_graphoption=root:panel:tof1_graphoption
	nvar tof1_datatype=root:panel:tof1_datatype
	nvar lc=root:panel:cor3_chamber // Chamber length
	nvar tof1_ugconv = root:panel:tof1_ugconv
	svar todoStr=root:panel:sq_toDoWvNm
//	nvar tof_stats = root:panel:tof_stats

	variable spos, idex,num,startrun,nTodo, isePToF	
	string strtw, myWinName, HRPToFSuffix=""
		
	HRflag = !ParamIsDefault(HRflag) && HRflag //1.21G	
	myWinName = selectstring(HRflag, "", "HR") +"SizeDist_"+todoStr
	if (HRflag)  //1.21G
		nvar tof1_graphoption = root:HR_panel:HRResults_graphOutputType
		nvar tof1_ugconv = root:HR_panel:HR_checkConvertTougm3
	endif
		
	if (HRflag)
		HRPToFSuffix=PToF_GrCaveat(specType)
	endif
	num=itemsinlist(destStr,"/")
	
	if (tof1_graphoption!=4)	// 4 means update, so don't mess with graphs 
		for(idex=0;idex<num;idex+=1)
			wave/z source=$("root:"+stringfromlist(idex,destStr,"/"))
			if(waveexists(source) && waveexists(d_baseWave))
				if(tof1_graphoption==2 || (tof1_graphoption==1 && idex==0))		// if plot multiple,  or plot single and it is the first time around
					display/N=$myWinName source vs d_baseWave as myWinName
					myWinName=S_name
					if(tof1_datatype==1)
						modifygraph/W=$myWinName log(bottom)=1
					endif
					if(tof1_graphoption==2)
	//					sq_butt_appgraphdefs("")
						if (tof1_datatype==1) // Modified 1.43F to place inside the 'if' statement
							Label/W=$myWinName bottom "PToF size (nm)"
							if (tof1_ugconv==1)
								Label/W=$myWinName left "d\f02M\M\f00/dlog\B10\M\f02d\Bva\M\f00 (g m\S-3\M)"+HRPToFSuffix	// dMdlog10dva (ugm-3)
							else
								Label/W=$myWinName left "d\f02S\M\f00/dlog\B10\M\f02d\Bva\M\f00 (Hz)"+HRPToFSuffix	// dSdlog10dva (Hz)
							endif
						else
							Label/W=$myWinName bottom "PToF time (s)"
							if (tof1_ugconv==1)
								Label/W=$myWinName left "d\f02M\M\f00/d\f02PToF\M\f00 (g m\S-3\M)"+HRPToFSuffix	// dMdPToF (ugm-3)
							else
								Label/W=$myWinName left "d\f02S\M\f00/d\f02PToF\M\f00 (Hz)"+HRPToFSuffix	// dSdPToF (Hz)
							endif
						endif
					endif
				else
					myWinName = WinName(0,1)		//1.47I
					appendtograph/W=$myWinName source vs d_baseWave
				endif
			endif	
		endfor
		sq_applyGraphDefs(ReplaceString("/", destStr, ";")) // sq_butt_appgraphdefs("")

		if (tof1_datatype==1) // Modified 1.43F to place inside the 'if' statement
			Label/W=$myWinName bottom "PToF size (nm)"
			if (tof1_ugconv==1)
				Label/W=$myWinName left "d\f02M\M\f00/dlog\B10\M\f02d\Bva\M\f00 (g m\S-3\M)"+HRPToFSuffix	// dMdlog10dva (ugm-3)
			else
				Label/W=$myWinName left "d\f02S\M\f00/dlog\B10\M\f02d\Bva\M\f00 (Hz)"+HRPToFSuffix	// dSdlog10dva (Hz)
			endif
		else
			Label/W=$myWinName bottom "PToF time (s)"
			if (tof1_ugconv==1)
				Label/W=$myWinName left "d\f02M\M\f00/d\f02PToF\M\f00 (g m\S-3\M)"+HRPToFSuffix	// dMdPToF (ugm-3)
			else
				Label/W=$myWinName left "d\f02S\M\f00/d\f02PToF\M\f00 (Hz)"+HRPToFSuffix	// dSdPToF (Hz)
			endif
		endif
	
		if (tof0_showDC)		//1.51P
			if (!HRflag)
				sq_AddDCmarker2Plot(PToFtodo, tof1_datatype==1, runPos)		// note that runPos is found much earlier and is the last PToF run in consideration
			endif
		endif
	endif

End


//Function sq_plot_ptof1_im(destStr,dwave,twave, StatsStr, [MSNormWaveList, PToFNormWaveList, twDeconFlag, HRflag])
Function sq_plot_ptof1_im(destStr,dwave,twave, StatsStr, [Centertwave, MSNormWaveList, PToFNormWaveList, HRflag])
	string destStr, StatsStr
	string MSNormWaveList, PToFNormWaveList
	variable HRflag
	wave dwave,twave, Centertwave
	
	nvar tof1_graphoption=root:panel:tof1_graphoption
	nvar tof1_datatype=root:panel:tof1_datatype
	nvar lc=root:panel:cor3_chamber // Chamber length
	nvar tof1_ugconv = root:panel:tof1_ugconv
	svar todoStr=root:panel:sq_toDoWvNm
//	svar tof1_specList=root:panel:tof1_specList	// 1.51N  1.61G

	wave rn_series=root:index:rn_series
	wave/z todo=$"root:"+todoStr		//1.44B
	
//	nvar tof_stats = root:panel:tof_stats		//1.51P		//1.56O

	variable idex,num,runPos, npts = numpnts(todo)
	string labelStr, unitsStr="", LegendStr="", str, strtw, myWinName	
	string myWinNamePrefix = "P" //"HR_"+todoStr	//1.51N  1.22A
	variable normFlag = !ParamIsDefault(MSNormWaveList) 
	
	if (!ParamIsDefault(HRflag) && HRflag )
		nvar tof1_graphoption=root:HR_panel:HRResults_graphOutputType
		nvar tof1_ugconv=root:HR_panel:HR_checkConvertTougm3
		// tof1_datatype is the same for SQ and Pk panel
	endif
//1.61G
//	if (tof1_graphoption!=3 && ItemsInList(tof1_specList, ",") != ItemsInList(destStr, "/"))		// don't touch graphs if updating selected
//		abort "The number of image plots generated does not match the number of species in the list aborting from sq_plot_ptof1_im"		//1.51N sanity check
//	endif

	if (tof1_datatype==1)
		unitsStr+= ", (nm)"
	else
		unitsStr +=", (s)"
	endif

//	wave/z StatsWave = $StatsStr
	num=itemsinlist(destStr,"/")
	if (tof1_graphoption!=3)		// don't touch graphs if updating selected
		for(idex=0;idex<num;idex+=1)
			wave/z source=$("root:"+stringfromlist(idex,destStr,"/"))
			wave/z stats=$("root:"+stringfromlist(idex,StatsStr,"/"))
			if(waveexists(source) && waveexists(twave) && waveexists(dwave))
				if(tof1_graphoption==2 || (tof1_graphoption==1 && idex==0))	//^ plot multiple or single, first time
					if (tof1_graphoption==2)		// 1.51N
//						myWinName = CleanUpName(myWinNamePrefix +"_"+stringFromList(idex,tof1_specList, ",") ,0)
						myWinName = CleanUpName(myWinNamePrefix +"_"+stringfromlist(idex,destStr,"/") ,0)  //1.61G
					else //(tof1_graphoption==1 && idex==0)		// plot multiple, this is the first
//						myWinName = CleanUpName(myWinNamePrefix +"_"+tof1_specList,0)
						myWinName = CleanUpName(myWinNamePrefix +"_"+stringfromlist(idex,destStr,"/"),0 )  //1.61G
					endif					
					myWinName = myWinName[0, min(strlen(myWinName)-2, 30)]
					
					display/N=$myWinName as myWinName
					myWinName = S_name 
					appendimage/W=$myWinName source vs {twave,dwave}
					ModifyImage/W=$myWinName $nameofwave(source) ctab= {0,*,Rainbow,1}
					labelStr = NameofWave(source)
					labelStr = RemoveFromList("sig_im_log_", labelStr, "_")		// sq_RemoveItemsInListFromList("ug_im_log_", labelStr, "_")
					labelStr = ReplaceString("im_", labelStr, "_")
					Label/W=$myWinName left labelStr+unitsStr
					Label/W=$myWinName bottom " "
					ModifyGraph/W=$myWinName lblPos(left)=50
					modifygraph/W=$myWinName freePos(left)=0
					if(tof1_datatype==1)	// nm size units
						modifygraph/W=$myWinName log(left)=1
					endif
					//1.51I
					if (strlen(StatsStr)>0 && !ParamIsDefault(Centertwave) )			// user requested stats					
							AppendToGraph stats[][%ModeDiameter] vs Centertwave
							AppendToGraph stats[][%GeometricMeanDiameter] vs Centertwave
//						if (strlen(twave)==0)		// AMS time base
//							AppendToGraph stats[][%ModeDiameter] vs root:index:t_series
//							AppendToGraph stats[][%GeometricMeanDiameter] vs  root:index:t_series
//						else	 // custom time wave
//							AppendToGraph stats[][%ModeDiameter] vs xwave
//							AppendToGraph stats[][%GeometricMeanDiameter] vs xwave
//							ModifyGraph offset($NameOfWave(stats))={(xwave[1] -xwave[0])/2 ,0}
//							ModifyGraph offset($NameOfWave(stats)#1)={(xwave[1] -xwave[0])/2,0}
//						endif
						ModifyGraph mode($NameOfWave(stats))=4,rgb($NameOfWave(stats))=(0,0,0)		// mode diameter is black crosses
						ModifyGraph mode=4,marker($NameOfWave(stats)#1)=8, rgb($NameOfWave(stats)#1)=(0,0,0)  	// mode diameter is black crosses
						if(tof1_graphoption==2 ||  (tof1_graphoption==1 && idex==num-1))	 	//^ plot multiple
							Legend/C/N=text0/J "\\s("+NameOfWave(stats)+") Mode\r\\s("+NameOfWave(stats)+"#1) Geom. Mean"
						endif
					endif
					if(tof1_graphoption==2)		//  && strlen(StatsStr)>0)	 	//^ plot multiple
						ModifyGraph mirror=2 
						 // sq_butt_appgraphdefs("")
						if (strlen(StatsStr)>0)
							Legend/C/N=text0/J "\\s("+NameOfWave(stats)+") Mode\r\\s("+NameOfWave(stats)+"#1) Geom. Mean"
						endif
					else
						ModifyGraph/W=$myWinName axisEnab(left)={(1.1*(num-idex-1))/((1.1*num)-0.1),((1.1*(num-idex-1))+1)/((1.1*num)-0.1)   }
					endif
					if (normFlag && !ParamIsDefault(Centertwave))		// we have normalization waves 	//1.51N
						wave PToFNormWave = $"root:"+stringFromList(idex,PToFNormWaveList, "/" )
						wave MSNormWave = $"root:"+stringFromList(idex,MSNormWaveList, "/" )
						appendtograph/W=$myWinName/r MSNormWave, PToFNormWave vs Centertwave
						ModifyGraph marker($NameOfWave(MSNormWave))=25, mode($NameOfWave(MSNormWave))=4
						ModifyGraph marker($NameOfWave(PToFNormWave))=28, mode($NameOfWave(PToFNormWave))=4
						ModifyGraph rgb($NameOfWave(PToFNormWave))=(47872,47872,47872)		// light gray
						ModifyGraph rgb($NameOfWave(MSNormWave))=(47872,47872,47872)// light gray
						Label/W=$myWinName right labelStr+unitsStr+ "Size integr. for Norm"
						ModifyGraph/W=$myWinName lblPos(right)=50
						modifygraph/W=$myWinName freePos(right)=0
//						ModifyGraph offset($NameOfWave(MSNormWave))={(xwave[1] -xwave[0])/2 ,0}
//						ModifyGraph offset($NameOfWave(PToFNormWave))={(xwave[1] -xwave[0])/2,0}
						SetAxis/A/E=3/W=$myWinName right
						if(tof1_graphoption==2 ) // && strlen(StatsStr)>0)	 	//^ plot multiple  //1.57N
							if (strlen(StatsStr)>0)
								LegendStr="\\s("+NameOfWave(stats)+") Mode\r\\s("+NameOfWave(stats)+"#1) Geom. Mean"
								if (normFlag)		// we have normalization waves		//1.51N
									LegendStr+="\r\\s("+NameOfWave(MSNormWave)+") MS time series \r\\s("+NameOfWave(PToFNormWave)+") PToF time series"
								endif
								Legend/C/N=text0/J LegendStr
							endif

						else
							ModifyGraph/W=$myWinName axisEnab(right)={(1.1*(num-idex-1))/((1.1*num)-0.1),((1.1*(num-idex-1))+1)/((1.1*num)-0.1)   }
						endif
					endif
				elseif(tof1_graphoption==1)		//^ plot single, after first time
					appendimage/W=$myWinName/l=$("left"+num2str(idex)) source vs {twave,dwave} // {xwave,ywave}
					ModifyImage/W=$myWinName $nameofwave(source) ctab= {0,*,Rainbow,1}
					labelStr = NameofWave(source)
					labelStr = RemoveFromList("sig_im_log_", labelStr, "_")		// sq_RemoveItemsInListFromList("ug_im_log_", labelStr, "_")
					labelStr = ReplaceString("im_", labelStr, "_")
					Label/W=$myWinName $("left"+num2str(idex)) labelStr+unitsStr
					Label/W=$myWinName bottom " "
					ModifyGraph/W=$myWinName freePos($("left"+num2str(idex)))=0
					ModifyGraph/W=$myWinName lblPos($("left"+num2str(idex)))=50
					if(tof1_datatype==1)		// nm size units
						modifygraph/W=$myWinName log($("left"+num2str(idex)))=1
					endif				
					//1.51I
					if (normFlag  && !ParamIsDefault(Centertwave))		// we have normalization waves		//1.51N
						wave PToFNormWave = $"root:"+stringFromList(idex,PToFNormWaveList, "/" )
						wave MSNormWave = $"root:"+stringFromList(idex,MSNormWaveList, "/" )
						appendtograph/W=$myWinName/r=$("right"+num2str(idex)) MSNormWave, PToFNormWave vs Centertwave
						ModifyGraph marker($NameOfWave(MSNormWave))=25, mode($NameOfWave(MSNormWave))=4
						ModifyGraph marker($NameOfWave(PToFNormWave))=28, mode($NameOfWave(PToFNormWave))=4
						ModifyGraph rgb($NameOfWave(PToFNormWave))=(47872,47872,47872)		// light gray
						ModifyGraph rgb($NameOfWave(MSNormWave))=(47872,47872,47872)// light gray
						Label/W=$myWinName $("right"+num2str(idex)) labelStr+unitsStr+ "Size integr. for Norm"
						ModifyGraph/W=$myWinName freePos($("right"+num2str(idex)))={10000000000,bottom}
						ModifyGraph/W=$myWinName lblPos($("right"+num2str(idex)))=50
//						ModifyGraph offset($NameOfWave(MSNormWave))={(xwave[1] -xwave[0])/2 ,0}
//						ModifyGraph offset($NameOfWave(PToFNormWave))={(xwave[1] -xwave[0])/2,0}
						SetAxis/A/E=3/W=$myWinName $("right"+num2str(idex))
						if(tof1_graphoption==2)	 	//^ plot multiple
	//						sq_butt_appgraphdefs("")
						else
							ModifyGraph/W=$myWinName axisEnab($("right"+num2str(idex)))={(1.1*(num-idex-1))/((1.1*num)-0.1),((1.1*(num-idex-1))+1)/((1.1*num)-0.1)   }
						endif
					endif
					if (strlen(StatsStr)>0 )			// user requested stats					
							AppendToGraph/W=$myWinName/l=$("left"+num2str(idex))  stats[][%ModeDiameter] vs Centertwave
							AppendToGraph/W=$myWinName/l=$("left"+num2str(idex))  stats[][%GeometricMeanDiameter] vs Centertwave
//						if (strlen(twave)==0)		// AMS time base
//							AppendToGraph/W=$myWinName/l=$("left"+num2str(idex))  stats[][%ModeDiameter] vs root:index:t_series
//							AppendToGraph/W=$myWinName/l=$("left"+num2str(idex))  stats[][%GeometricMeanDiameter] vs  root:index:t_series
//						else	 // custom time wave
//							AppendToGraph/W=$myWinName/l=$("left"+num2str(idex))  stats[][%ModeDiameter] vs xwave
//							AppendToGraph/W=$myWinName/l=$("left"+num2str(idex))  stats[][%GeometricMeanDiameter] vs xwave
//							ModifyGraph offset($NameOfWave(stats))={(xwave[1] -xwave[0])/2 ,0}
//							ModifyGraph offset($NameOfWave(stats)#1)={(xwave[1] -xwave[0])/2,0}
//						endif
						ModifyGraph mode($NameOfWave(stats))=4,rgb($NameOfWave(stats))=(0,0,0)		// mode diameter is black crosses
						ModifyGraph mode=4,marker($NameOfWave(stats)#1)=8, rgb($NameOfWave(stats)#1)=(0,0,0)  	// mode diameter is black crosses
						if(tof1_graphoption==2 || (tof1_graphoption==1 && idex==num-1))	 	//^ plot multiple
							LegendStr="\\s("+NameOfWave(stats)+") Mode\r\\s("+NameOfWave(stats)+"#1) Geom. Mean"
							if (normFlag)		// we have normalization waves		//1.51N
								LegendStr+="\r\\s("+NameOfWave(MSNormWave)+") MS time series \r\\s("+NameOfWave(PToFNormWave)+") PToF time series"
							endif
							Legend/C/N=text0/J LegendStr
						endif
					endif
					if(tof1_graphoption==2)	 	//^ plot multiple
//						sq_butt_appgraphdefs("")
					else
						ModifyGraph/W=$myWinName axisEnab($("left"+num2str(idex)))={(1.1*(num-idex-1))/((1.1*num)-0.1),((1.1*(num-idex-1))+1)/((1.1*num)-0.1)   }
					endif
					legend
				endif
			endif	
		endfor
		// sq_butt_appgraphdefs("")  1.51I
	endif
		
End


//Function/s sq_makePToFDiamCenterPts()
//
//	svar todoStr = root:panel:sq_toDoWvNm
//	nvar tof1_norm = root:panel:tof1_norm
//	nvar tof0_d_saved = root:panel:tof0_d_saved
//	nvar tof0_d_reg = root:panel:tof0_d_reg
//	nvar lc=root:panel:cor3_chamber // Chamber length
//	wave todowave = $"root:"+todoStr		//1.44B
//	wave rn_series =root:index:rn_series
//
//	string returnStr="", diamStr
//	variable startrun
//		
//	if (!tof0_d_saved)		// we are using custom diameter bins
//		diamStr  = sq_dbase()
//		wave diam_basewave = $diamStr		 // this wave has the edge points
//		returnStr = sq_dbase()+"_x"
//		make /o/n=(numpnts(diam_basewave)-1) $returnStr
//		wave diamWv= $returnStr 
//		diamWv=sqrt(diam_basewave[p+1]*diam_basewave[p])
//	else				// as saved
//		startrun=sq_findrun(rn_series,todowave[0])
//		returnStr = "dsig_"+todoStr
//		make/free DVa_wave		//1.59E	
//		sq_GetPToFParams(DVa_wave, startrun)
//		make /o/n=(DVa_wave[%numPToFBins]) $returnStr 
//		wave diamWv=$returnStr
//		diamWv=sq_ptof2dva(lc,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],DVa_wave[%t0]+(p*DVa_wave[%step]))
//	endif
//
//	return returnStr
//
//End


// Creates or overwrites one global variable, PToF_avgLoad
// which gives the average mass loadings from these techniques.
//Function sq_norm_getLoadingPtof( diamWv, ptofWv)			//1.56O
//wave diamWv, ptofWv
//	
//	svar todoStr = root:panel:sq_toDoWvNm
//	nvar tof0_gppp = root:panel:tof0_gppp
//	nvar tof0_d_saved = root:panel:tof0_d_saved
//	nvar tof0_d_reg= root:panel:tof0_d_reg
//	nvar tof0_d_custom = root:panel:tof0_d_custom	
//		
//	variable dMin, dMax
//	
//	variable/g PToF_avgLoad
//	nvar PToF_avgLoad = root:PToF_avgLoad
//	
//	duplicate/o diamWv diamWv_temp
//	duplicate/o ptofWv ptofWv_temp
//	
//	diamWv_temp = selectnumber(diamWv_temp[p]==0, diamWv_temp, nan)
//	diamWv_temp = selectnumber(numtype(diamWv_temp[p])!=0, diamWv_temp, nan)		//1.40D
//	sq_removeNaNsXY(diamWv_temp, ptofWv_temp)		// there seemed to be a problem with the area function when either wave has nans.
//	
//	if(numpnts(diamWv_temp)==0)
//		killwaves/z Log_diamWv, diamWv_temp, ptofWv_temp
//		return nan
//	endif
//	
//	make/o/n=(numpnts(diamWv_temp)) Log_diamWv
//	Log_diamWv = log(diamWv_temp)
//	
//	wavestats/q/m=1 diamWv_temp
//	dMin =V_min 
//	dMax = V_max
//	
//	if (numtype(tof0_gppp)==0)	// user has entered a non-Nan gas phase to particle phase boundary value
//		dMin = max(dMin, tof0_gppp)
//	endif
//	
//	PToF_avgLoad = areaxy(Log_diamWv, ptofWv_temp, log(dMin), log(dMax))
//
//	killwaves/z Log_diamWv, diamWv_temp, ptofWv_temp
//
//	return PToF_avgLoad
// 
//End 
//

//  A function that is used to ensure that the xwave and ywave used in image plots are monotonic.
//  This may cause some confusion with folks looking at diameter center values and diameter edge values.
//  It is on the Wavemetrics wish list to have Igor handle nans and infs in the x and ywaves of image plots more gracefully.
Function sq_ValidateImageAxisWave(w)
wave w
	
	Variable nbad, npm1, rangedp
	
	w = selectnumber (w[p]==0,  w[p], nan)		// remove zeros
	WaveStats/Q w
	
	nbad= V_numNans + V_numINFs
	if( nbad == 0 )
		return 0
	endif
	
	npm1= numpnts(w)-1
	rangedp= (V_max - V_min)/1000		// delta p for range extension
	
	if( V_minloc<V_maxloc )		// increasing ?
		if( V_minloc >0 )
			w[0,V_minloc-1]= V_Min - rangedp*(V_minloc - p)
		endif
		if( V_maxloc < npm1 )
			w[V_maxloc+1,*]= V_Max + rangedp*(p-V_maxloc)
		endif
	else
		if( V_maxloc >0 )
			w[0,V_maxloc-1]= V_Max + rangedp*(V_maxloc - p)
		endif
		if( V_minloc < npm1 )
			w[V_minloc+1,*]= V_Min - rangedp*(p-V_minloc)
		endif
	endif
end		


//////////////////////////////////////////////////////////////////////////////////////
///////////////////////// FRAG TABLE  //////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////


//  Significantly overhauled in 1.41B
Function sq_plot_diag()

	//1.44B change - make sure DiagnosticModeDisplayKey is always set
	wave/z DiagnosticModeDisplayKey = root:diagnostics:DiagnosticModeDisplayKey
	wave t_series = root:index:t_series
	if (!waveexists(DiagnosticModeDisplayKey))
		make/o/n=(numpnts(t_series)) root:diagnostics:DiagnosticModeDisplayKey=1	
	else
		Redimension/n=(numpnts(t_series)) DiagnosticModeDisplayKey
		DiagnosticModeDisplayKey=1
	endif
	
	DoWindow/F DiagnosticsPlot
	if (V_Flag==1)
		return 0
	endif
	
	display/N=DiagnosticsPlot/W=(50,50,700,400) as "DiagnosticsPlot"
 	 	
	ControlBar/L 140
	PopupMenu DiagPlot_popMenu_TofMode,pos={5,20},size={129,24},proc=sq_diag_popMenu_ModeType,title="Mode"
	PopupMenu DiagPlot_popMenu_TofMode,mode=1,popvalue="All Modes",value= #"\"All Modes;\"+root:diagnostics:detectorsUsed"
	CheckBox diagPlot_showLines,pos={15,55},size={43,14},proc=sq_diagostics_check_MarkerType,title="Lines"
	CheckBox diagPlot_showLines,value= 1,mode=1
	CheckBox diagPlot_showMarkers,pos={75,55},size={56,14},proc=sq_diagostics_check_MarkerType,title="Markers"
	CheckBox diagPlot_showMarkers,value= 0,mode=1

	CheckBox diag_check_flowRate,pos={5,90},size={66,14},title="Flow Rate", proc=sq_diag_check_plotGroup,value= 1
	CheckBox diag_check_airbeams,pos={5,120},size={61,14},title="Airbeams", proc=sq_diag_check_plotGroup,value= 1
	CheckBox diag_check_IonEff,pos={5,150},size={82,14},title="Ion Efficiency", proc=sq_diag_check_plotGroup, value= 1
	CheckBox diag_check_heaterBias,pos={5,180},size={73,14},title="Heater Bias", proc=sq_diag_check_plotGroup, value= 1
	CheckBox diag_check_MCP,pos={5,210},size={41,14},title="MCP", proc=sq_diag_check_plotGroup,value= 1
	CheckBox diag_check_channel,pos={5,240},size={78,14},title="Channel Info", proc=sq_diag_check_plotGroup,value= 1
	CheckBox diag_check_singleIon,pos={5,270},size={65,14},title="Single Ion", proc=sq_diag_check_plotGroup,value= 1
	CheckBox diag_check_peakPos,pos={5,300},size={122,14},title="m/z Cal Peak Position", proc=sq_diag_check_plotGroup, value= 1
	CheckBox diag_check_dutyCycle,pos={5,330},size={74,14},title="Duty Cycles", proc=sq_diag_check_plotGroup,value= 1
	CheckBox diag_check_FilamentEmission,pos={5,360},size={74,14},title="Filament Emission", proc=sq_diag_check_plotGroup,value= 1	// 1.51A
	
	sq_update_diagPlot()// puts plots on graph
	
 	sq_diagostics_check_MarkerType("diagPlot_showLines",1) // modifies traces
 
End


// removes and then appends all traces to the diagnostic plot
Function sq_update_diagPlot()

	DoWindow/F DiagnosticsPlot
	
	variable myMin, myMax
	GetAxis/q bottom
	if (V_flag)
		 myMin= V_min
		 myMax=V_max
	else
		 myMin= inf
		 myMax=-inf
	endif	
	
	sq_gen_removeAllTraces("DiagnosticsPlot")	
	
	wave flowrate=root:diagnostics:flowrate
	wave t_series=root:index:t_series
	wave ionEff_logged=root:diagnostics:ionEff_logged
	wave heaterBias=root:diagnostics:heaterBias
	wave airbeam_logged=root:diagnostics:airbeam_logged
	wave airbeam_ptof=root:diagnostics:airbeam_ptof
//	wave MCP_gain=root:diagnostics:MCP_gain  // 1.56I
	wave MCP_V=root:diagnostics:MCP_V
	wave Res14=root:diagnostics:Res14
	wave Res28=root:diagnostics:Res28
	wave Res91=root:diagnostics:Res91
	wave Res184=root:diagnostics:Res184
	wave PeakPosCal1=root:diagnostics:PeakPosCal1
	wave PeakPosCal2=root:diagnostics:PeakPosCal2
//	wave DutyCycleMS=root:diagnostics:DutyCycleMS			//1.56C
//	wave DutyCyclePToF=root:diagnostics:DutyCyclePToF
//	wave DutyCycleBFSP=root:diagnostics:DutyCycleBFSP
	wave DutyCycleGenAlt=root:diagnostics:DutyCycleGenAlt
	wave ch1ThresholdVolts=root:diagnostics:ch1ThresholdVolts
//	wave ch2ThresholdVolts=root:diagnostics:ch2ThresholdVolts		//1.55K
	wave ch1FullScaleVolts=root:diagnostics:ch1FullScaleVolts
//	wave ch2FullScaleVolts=root:diagnostics:ch2FullScaleVolts		//1.55K
	wave FilamentEmission=root:diagnostics:FilamentEmission		//1.51A
	
	wave /z ionSingleStr_logged=root:diagnostics:ionSingleStr_logged	// use ion_wave to indicate that the wave could be referring to either ionSingleStr or ionSingleStr_logged	

	variable flowRate_ck, airbeams_ck, ionEff_ck, heaterBias_ck, MCP_ck, singleIon_ck, channel_ck, res_ck, peakPos_ck, dutyCycle_ck
	variable numPlots, fractional, numPlotsSoFar, winheight, onePlotHt, filamentEm_ck
	string info
	
	ControlInfo diag_check_flowRate; 	flowRate_ck=V_value
	ControlInfo diag_check_airbeams; 	airbeams_ck=V_value
	ControlInfo diag_check_IonEff; 		ionEff_ck=V_value
	ControlInfo diag_check_heaterBias; heaterBias_ck=V_value
	ControlInfo diag_check_MCP; 		MCP_ck=V_value
	ControlInfo diag_check_singleIon;	singleIon_ck=V_value
	ControlInfo diag_check_channel;	channel_ck=V_value		
	ControlInfo diag_check_peakPos;	peakPos_ck=V_value
	ControlInfo diag_check_dutyCycle;	dutyCycle_ck=V_value
	ControlInfo diag_check_FilamentEmission; filamentEm_ck=V_value

	numPlots =flowRate_ck+airbeams_ck+ionEff_ck+heaterBias_ck+MCP_ck+singleIon_ck+channel_ck+res_ck+peakPos_ck+dutyCycle_ck+filamentEm_ck 
	if (numPlots==0)		//1.55K
		abort "Please select one or more values to display.  Abort from sq_update_diagPlot"
	endif
	
	fractional = 1/numPlots
	numPlotsSoFar=0

	onePlotHt = winheight/numPlots

	// build plot from the bottom up
	if (filamentEm_ck)
		appendtograph/W=DiagnosticsPlot/L=FilamentEmLeft FilamentEmission vs t_series	
		ModifyGraph/W=DiagnosticsPlot rgb(FilamentEmission)=(0,0,0)
		Modifygraph/W=DiagnosticsPlot axisEnab(FilamentEmLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(FilamentEmLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text10/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "Filament Emission"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text10		//1.59A
	endif
	if (dutyCycle_ck)
		appendtograph/W=DiagnosticsPlot/L=DutyCycleLeft DutyCycleGenAlt vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(DutyCycleGenAlt)=(65280,32768,32768)
		ModifyGraph/W=DiagnosticsPlot axisEnab(DutyCycleLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(DutyCycleLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text9/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "DutyCycles"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text9
	endif
	if (peakPos_ck)
		appendtograph/W=DiagnosticsPlot/L=PeakPos1Left PeakPosCal1 vs t_series
		appendtograph/W=DiagnosticsPlot/R=PeakPos2Right PeakPosCal2 vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(PeakPosCal1)=(65280,52224,52224)
		ModifyGraph/W=DiagnosticsPlot rgb(PeakPosCal2)=(32768,52224,65280)
		Modifygraph/W=DiagnosticsPlot axisEnab(PeakPos1Left)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(PeakPos1Left)={0,bottom}
		ModifyGraph/W=DiagnosticsPlot axisEnab(PeakPos2Right)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(PeakPos2Right)={0.05,kwFraction}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text8/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "m/z Cal Peak Position"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text8
	endif
	if (res_ck)
		appendtograph/W=DiagnosticsPlot/L=ResLeft Res14 vs t_series
		appendtograph/W=DiagnosticsPlot/L=ResLeft Res28 vs t_series
		appendtograph/W=DiagnosticsPlot/L=ResLeft Res91 vs t_series
		appendtograph/W=DiagnosticsPlot/L=ResLeft Res184 vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(Res14)=(0,12800,52224)
		ModifyGraph/W=DiagnosticsPlot rgb(Res28)=(52224,0,0)
		ModifyGraph/W=DiagnosticsPlot rgb(Res91)=(19456,39168,0)
		ModifyGraph/W=DiagnosticsPlot rgb(Res184)=(65280,0,52224)
		ModifyGraph/W=DiagnosticsPlot axisEnab(ResLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(ResLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text7/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "Resolving Power"		//1.49E
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text7
	endif
	if (singleIon_ck)
		appendtograph/W=DiagnosticsPlot/L=ionLeft ionSingleStr_logged vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(ionSingleStr_logged)=(12800,12800,52224)
		Modifygraph/W=DiagnosticsPlot axisEnab(ionLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(ionLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text6/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "Ion Strength (bit*ns)"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text6
	endif
//1.55K
	if (channel_ck)
		appendtograph/W=DiagnosticsPlot/L=thresholdLeft ch1ThresholdVolts vs t_series		// ch2ThresholdVolts
		appendtograph/W=DiagnosticsPlot/R=fullScaleRight ch1FullScaleVolts vs t_series		// ch2FullScaleVolts
		ModifyGraph/W=DiagnosticsPlot rgb(ch1ThresholdVolts)=(0,39168,0)
		ModifyGraph/W=DiagnosticsPlot rgb(ch1FullScaleVolts)=(0,26112,39168)
//		ModifyGraph/W=DiagnosticsPlot rgb(ch2ThresholdVolts)=(32768,65280,32768)
//		ModifyGraph/W=DiagnosticsPlot rgb(ch2FullScaleVolts)=(16384,48896,65280)
		ModifyGraph/W=DiagnosticsPlot axisEnab(thresholdLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(thresholdLeft)={0,bottom}
		ModifyGraph/W=DiagnosticsPlot axisEnab(fullScaleRight)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(fullScaleRight)={0.05,kwFraction}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text5/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "ch1 Threshold, Full Scale (v)"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text5
	endif
	if (MCP_ck)
	//	appendtograph/W=DiagnosticsPlot/L=MCPGainLeft MCP_gain vs t_series
		appendtograph/W=DiagnosticsPlot/L=MCPVoltRight MCP_V vs t_series
//		ModifyGraph/W=DiagnosticsPlot rgb(MCP_gain)=(0,0,65535)		//1.44B change
		ModifyGraph/W=DiagnosticsPlot rgb(MCP_V)=(0,0,0)
//		ModifyGraph/W=DiagnosticsPlot axisEnab(MCPGainLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(MCPGainLeft)={0,bottom}
		ModifyGraph/W=DiagnosticsPlot axisEnab(MCPVoltRight)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(MCPVoltRight)={0.05,kwFraction}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text4/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "MCP Voltage (V)"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text4
	endif
	if (heaterBias_ck)
		appendtograph/W=DiagnosticsPlot/L=HeaterBiasLeft HeaterBias vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(HeaterBias)=(0,65535,0)
		ModifyGraph/W=DiagnosticsPlot axisEnab(HeaterBiasLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(HeaterBiasLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text3/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "Heater Bias (V)"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text3
	endif
	if (ionEff_ck)
		appendtograph/W=DiagnosticsPlot/L=IonEffLeft ionEff_logged vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(ionEff_logged)=(65535,0,0)
		ModifyGraph/W=DiagnosticsPlot axisEnab(IonEffLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(IonEffLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text2/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100))  "Ionization Eff"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text2
	endif
	if (airbeams_ck)
		appendtograph/W=DiagnosticsPlot/L=AirbeamLeft airbeam_ptof vs t_series
		appendtograph/W=DiagnosticsPlot/L=AirbeamLeft airbeam_logged vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(airbeam_ptof)=(34816,34816,34816)
		ModifyGraph/W=DiagnosticsPlot rgb(airbeam_logged)=(65535,0,32768)
		ModifyGraph/W=DiagnosticsPlot axisEnab(AirbeamLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01}, freePos(AirbeamLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text1/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "Airbeam (Hz) pink = MS, gray = ptof airbeam"  //1.50C
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text1
	endif
	if (flowRate_ck)
		appendtograph/W=DiagnosticsPlot/L=FlowrateLeft flowrate vs t_series
		ModifyGraph/W=DiagnosticsPlot rgb(flowrate)=(0,0,65535)
		ModifyGraph/W=DiagnosticsPlot axisEnab(FlowrateLeft)={numPlotsSoFar*fractional+.01, (numPlotsSoFar+1)*fractional-.01},freePos(FlowrateLeft)={0,bottom}
		TextBox/W=DiagnosticsPlot/C/F=0/N=text0/A=LB/X=40/Y=(round(numPlotsSoFar*fractional*100)) "Flowrate (cc/s)"
		numPlotsSoFar+=1
	else
		TextBox/W=DiagnosticsPlot/K/N=text0
	endif

	ModifyGraph/W=DiagnosticsPlot mode=4,marker=19,msize=1	
	ModifyGraph/W=DiagnosticsPlot axisEnab(bottom)={0.05,0.95}
	ModifyGraph/W=DiagnosticsPlot dateInfo(bottom)={0,1,0}
	Label/W=DiagnosticsPlot bottom "Date and Time"
	
	info = IgorInfo(0)
	if (str2num(StringByKey("IGORVERS", info))>=6 )
		ModifyGraph mask={root:diagnostics:DiagnosticModeDisplayKey,1,1 }		
	else
		ModifyGraph/W=DiagnosticsPlot zmrkSize={root:diagnostics:DiagnosticModeDisplayKey,1,2,2,2 }
	endif

 	if (numtype(myMin)==0)
 		SetAxis bottom mymin, mymax		//1.52D
 	endif
 	ShowInfo
	ModifyGraph nticks(bottom)=9,minor(bottom)=1

End


// diagnostic plot radio button checkbox for whether display is lines or markers.
Function sq_diagostics_check_MarkerType(ctrlName,checked) : CheckBoxControl
	String ctrlName
	variable checked

	variable showMarkers = strsearch(ctrlName, "Markers",0)
	wave DiagnosticModeDisplayKey = root:diagnostics:DiagnosticModeDisplayKey
	DiagnosticModeDisplayKey/=DiagnosticModeDisplayKey
	
	if (showMarkers>0)
		ModifyGraph/W=DiagnosticsPlot zmrkSize={root:diagnostics:DiagnosticModeDisplayKey,1,2,2,2}	// let markers show  //1.44B fix
		ModifyGraph/W=DiagnosticsPlot lsize=0													// view only markers
		CheckBox diagPlot_showMarkers value =1		
		CheckBox diagPlot_showLines value =0		
	else
		ModifyGraph/W=DiagnosticsPlot zmrkSize={root:diagnostics:DiagnosticModeDisplayKey,1,1,0,0}	// let markers show  //1.44B fix
		ModifyGraph/W=DiagnosticsPlot lsize=2													// view only markers
		CheckBox diagPlot_showMarkers value =0		
		CheckBox diagPlot_showLines value =1		
	endif

	ModifyGraph gaps=0	//1.48F

End


// diagnostic plot checkbox control to show traces or not
Function sq_diag_check_plotGroup(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked
	 
	sq_update_diagPlot()
	ControlInfo/W=DiagnosticsPlot diagPlot_showLines
	if (V_value==0)
		sq_diagostics_check_MarkerType("diagPlot_showMarkers",1)
	else
		sq_diagostics_check_MarkerType("diagPlot_showLines",1)
	endif

End


// controls whether one plots v or w mode or both
Function sq_diag_popMenu_ModeType(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr

	wave DiagnosticModeDisplayKey = root:diagnostics:DiagnosticModeDisplayKey

	if(stringMatch(popStr, "All Modes"))	// all or not found
		DiagnosticModeDisplayKey=1
		return 0	
	endif
	
	// 
	wave/z ionizationType = root:diagnostics:ionizationType
	if (waveexists(ionizationType))	// we have multiple ionization schemes
		wave detector_num = root:diagnostics:detector_num
		DiagnosticModeDisplayKey = (popnum-2 == detector_num[p])		// we have to subtract 2; we count from 1 and the first one is all modes
		DiagnosticModeDisplayKey/=DiagnosticModeDisplayKey

	else	 // we don't have multiple ionization schemes		
		// first deal with v or w mode	
		wave/z TofTypeVorWKey = $("root:diagnostics:TofType"+popStr[0]+"Key") 
		if (waveexists(TofTypeVorWKey))
			DiagnosticModeDisplayKey=TofTypeVorWKey
		else	// we don't have v and w mode switching or cant find toftype
			DiagnosticModeDisplayKey=1
		endif
		// now deal with ionization types
		wave/z IonizationKey = $("root:diagnostics:ionization"+popStr[2,strlen(popStr)-1]+"Key")
		if (waveexists(IonizationKey))
			DiagnosticModeDisplayKey *= IonizationKey
		endif
		DiagnosticModeDisplayKey/=DiagnosticModeDisplayKey
	endif
	
End


// brings the graph Airbeam_Correction to the front if exists, creates it if it doesn't
//1.49E  finally updated with some code from Mike Cubison that appends the AB reference period to the graph=
Function sq_plot_corr()

	DoWindow/F Airbeam_Correction
	if (V_flag==1)
		return 0 		// do nothing
	elseif(waveexists(root:diagnostics:corr_fact))
		wave corr_fact=root:diagnostics:corr_fact
		wave t_series=root:index:t_series
		display/k=1/n=Airbeam_Correction corr_fact vs t_series as "Airbeam_Correction"
		Label left "Airbeam correction factor"
		Label bottom " "
		sq_applyGraphDefs("corr_fact") // SQ_Butt_appgraphdefs("")

	// MJC 12aug09 addition
		svar airbeam_refRuns_sv=root:panel:airbeam_refRuns_sv
		wave rn_series=root:index:rn_series
		
		if (itemsInList(airbeam_refRuns_sv, "-")==2)
			variable start_r, end_r, start_n, end_n
			start_r=str2num(stringfromlist(0,airbeam_refRuns_sv,"-"))
			wavestats/q/m=1 rn_series
			start_r=max(start_r,v_min)
			if (itemsinlist(airbeam_refRuns_sv,"-")==2)
				end_r=str2num(stringfromlist(1,airbeam_refRuns_sv,"-"))
				end_r=min(end_r,v_max)
			else
				end_r=start_r
			endif
			start_n=sq_findrun(rn_series,start_r)
			end_n=sq_findrun(rn_series,end_r)
			WaveStats/Q corr_fact
			Make/o/n=4/d $GetWavesDataFolder(corr_fact,2)+"_refperiod" = {V_max,V_max, t_series[start_n], t_series[end_n]}
			Wave refperiod = $GetWavesDataFolder(corr_fact,2)+"_refperiod"
			appendtograph refperiod[0,1] vs refperiod[2,3]	// MJC addition
			ModifyGraph lsize($nameofwave(refperiod))=1.5
			ModifyGraph rgb($nameofwave(refperiod))=(0,0,0)
			ModifyGraph mode($nameofwave(refperiod))=1

		endif

	// end MJC addition		

	else
		abort "The airbeam correction factor wave root:diagnostics:corr_fact does not exist  - aborting from sq_plot_corr"
	endif

End


// added back in 1.60Y
// *************************************************
// Returns a list with every item in removeList removed.
Function/s gen_RemoveItemsInListFromList(removeList, masterList)
	String removelist, masterList

	string newMasterList = masterList
	variable i, n
	
	n=itemsinlist(removelist)
	
	for(i=0;i<n;i+=1)
		newMasterList = RemoveFromList(StringFromList(i, removeList, ";"), newMasterList, ";")
	endfor
	
	return newMasterList

End



Function sq_butt_IEetalProjectGr(ctrlName) : ButtonControl
	String ctrlName
	
	sq_GetIndexNotDoneYet()
	wave t_series = root:index:t_series
	variable num = numpnts(t_series)

	DoWindow/F IEetalProjectGr
	if (V_flag==0)
		// check for the existence of some correction waves.  If they don't exists create them and set to defaults.
		if (WaveExists(root:diagnostics:corr_fact)==0)
			make/o/n=(num) root:diagnostics:corr_fact=1		// set default value to 1
		endif
		if (WaveExists(root:diagnostics:corr_fact_flow)==0)
			make/o/n=(num) root:diagnostics:corr_fact_flow=1		// set default value to 1
		endif
		if (WaveExists(root:diagnostics:ionEff)==0)
			wave ionEff_logged = root:diagnostics:ionEff_logged
			duplicate/o ionEff_logged root:diagnostics:ionEff	// set default value to ion_eff_logged
		endif
		if (WaveExists(root:diagnostics:ionSingleStr)==0)
			wave ionSingleStr_logged = root:diagnostics:ionSingleStr_logged
			duplicate/o ionSingleStr_logged root:diagnostics:ionSingleStr	// set default value to ion_eff_logged
		endif
		wave/z flowrate_logged =root:diagnostics:flowrate_logged
		wave/z flowrate =root:diagnostics:flowrate
		// pretty sticky situation whereby we want to make things backwards compatible, old code did not name logged flow rate and flowrate_logged
		if (WaveExists(flowrate_logged)==0)
			duplicate/o flowrate root:diagnostics:flowrate_logged
		else
			if (WaveExists(flowrate)==0)
				duplicate/o flowrate_logged  root:diagnostics:flowrate
			endif		
		endif
		// check the existence of IE cal (user input values)		//assumes that if one is missing, they all are
		if (WaveExists(root:diagnostics:IECalIEVal)==0)
			make/d/o/n=0 root:diagnostics:IECalIEVal, root:diagnostics:IECalABVal, root:diagnostics:IECalRefFlag, root:diagnostics:IECalTime,  root:diagnostics:IECalIE2ABRatio
			make/d/o/n=0 root:diagnostics:IECalFlowRate		// not actually used in caculations
			SetScale d 0,0,"dat",root:diagnostics:IECalTime
			make/o/n=(num) root:diagnostics:ioneff_to_ab_rel_ratio=1
		endif	
		
		make/o/n=(numpnts(t_series)) root:diagnostics:FDModeDisplayKey=1

		FD_IEetalProjectGr()
	
	endif
	
End


// Add controls to an average MS graph, changed in 1.46E
Function sq_MSAvgGraph_addControls()

	nvar ms0_AvGraphType = root:panel:ms0_AvGraphType
	string speclist, myWinName
	variable checks = 128		// initialize
	ControlBar 65
	
	checks = 16		// default to all checkbox controls being unchecked, except show neg
	if (ms0_AvGraphType>=2)
		checks += 8	
	endif
	
	myWinName = WinName(0,1)

	TitleBox title1 , win=$myWinName, variable=root:panel:MSAvgGrhelp,frame=0, pos={200,40}

	GroupBox yaxisgroup, win=$myWinName, pos={6,0},size={185,60},title="y-axis", fcolor = (1,1,1)
	Button expand25, win=$myWinName, pos={113,15},size={80,18},title="expand 25%",proc=sq_MSAvgGr_25butt
	Button shrink25, 	win=$myWinName, pos={113,37},size={80,18},title="shrink 25%",proc=sq_MSAvgGr_25butt

	CheckBox gr_log, win=$myWinName , pos={10,13},size={90,14},title="log scale",proc=sq_MSAvgGraph_updateControls,help={"Use logarithmic y-axis."},value=checks&1
	CheckBox gr_sc2zero,win=$myWinName , pos={10,28},size={90,14},title="scale to zero",proc=sq_MSAvgGraph_updateControls,help={"Show linear plot y-axis from zero."},value=(checks&2)>0
	CheckBox gr_auto,win=$myWinName , pos={10,43},size={90,14},title="auto range",proc=sq_MSAvgGraph_updateControls,help={"Automatically set the y-axis."},value=(checks&4)>0

	CheckBox gr_raw 	win=$myWinName,pos={200,5},size={110,14},title="Show raw spectrum",proc=sq_MSAvgGraph_showHide,help={"Display raw spectrum, if previously calculated."},value=(checks&8)>0
	CheckBox gr_showNegs,win=$myWinName, pos={200,20},size={110,14},title="Show neg spectrum",proc=sq_MSAvgGraph_showHide,help={"Display negative wave to plot."},value=(checks&16)>0

	CheckBox gr_showErrs,win=$myWinName, pos={330,5},size={110,14},title="Show Errors",proc=sq_MSAvgGraph_updateControls,help={"Display error spectrum to plot."},value=(checks&32)>0	//,fstyle=2
	SetVariable ms0_errFac, win=$myWinName, pos={330,20},size={115,16},title="# SD's for errors", fSize=10, help={"multiples of the total stick spectra error to plot, if previously calculated."}
	SetVariable ms0_errFac, win=$myWinName, limits={1,100,1},value= root:panel:ms0_sv_numStdDev, proc=sq_MSAvgGraph_StdDev

	speclist = getuserdata(myWinName,"","specList")
	string list = "All;"+speclist
	PopupMenu gr_sticks win=$myWinName,  value=#list	// add Get List
	PopupMenu gr_sticks win=$myWinName,  pos={440,0},title="Show",proc=sq_MSAvGraph_pop,mode=1,help={"Exclusively show data from a single species"}	
	
	sq_MSAvgGraph_UpdateControls("",1)// 1 means show all

End


// Add controls to an average MS graph, changed in 1.46E
Function sq_MSAvgGraph_StdDev(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName
	
 	nvar ms0_sv_numStdDev = root:panel:ms0_sv_numStdDev
 	
	string errorItem, myWinName
	
	errorItem = getuserdata("","","errMSWaveStr")
	myWinName = WInName(0,1)

	if (strlen(errorItem)>0)
		wave errWave=$errorItem
		variable Ver_temp = str2num(StringByKey("IGORVERS", IgorInfo(0)))
		// ModifyGraph/W=$myWinName muloffset($nameofwave(errWave))={0, ms0_sv_numStdDev}
		if (Ver_temp>6)
			ModifyGraph/W=myWinName muloffset($NameOfWave(errWave))={0,ms0_sv_numStdDev}
		endif
	endif

End


Function sq_MSAvGraph_pop(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr

	sq_MSAvgGraph_UpdateControls("",0)

End


//new in 1.46
Function sq_MSAvgGraph_showHide(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked

	variable idex, num
	string tempList, myWinName, myTraceList
		
	myWinName = WinName(0,1)
	myTraceList = traceNameList(myWinName, "", 1)
		
	if (stringmatch("gr_raw", ctrlName)) 
		tempList = getuserdata(myWinName,"","rawList")	
		num = itemsinList(tempList)
		for (idex=0;idex<num;idex+=1)
			if (WhichListItem(stringfromlist(idex, tempList), myTraceList)>=0)
				ModifyGraph/w=$myWinName hideTrace($stringfromlist(idex, tempList))=2*!checked
			endif
		endfor
	elseif (stringmatch("gr_showNegs", ctrlName) )		// should only be one
		tempList = getuserdata(myWinName,"","negMSWaveStr")	
		num = itemsinList(tempList)
		for (idex=0;idex<num;idex+=1)
			if (WhichListItem(stringfromlist(idex, tempList), myTraceList)>=0)
				ModifyGraph/w=$myWinName hideTrace($stringfromlist(idex, tempList))=2*!checked
			endif
		endfor
	endif

End


//& Graph control for avg mass spec graphs
Function sq_MSAvgGraph_updateControls(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked

	wave amus=root:diagnostics:amus

	nvar/z misc_graphline=root:panel:gdef_line_thick
	nvar/z misc_stick=root:panel:gdef_stick_thick
	nvar ms0_sv_numStdDev = root:panel:ms0_sv_numStdDev

	variable log_op,sc2zero_op,auto_op,raw_op, showNegs_op,showErrs_op,bars_op,idex,num
	string showstr, sticklist, traces, ErrorItem, negItem, myStr, myWinName, SpecData

	myWinName = WinName(0,1)
	if (!stringmatch("MSAvg", myWinName[0,4]) )
		abort "The top most graph is not named sit a 'MSAvg' prefix - aborting from sq_MSAvgGraph_updateControls"
	endif

// get current values
	controlinfo/W=$myWinName gr_log;log_op=v_value
	controlinfo/W=$myWinName gr_sc2zero;sc2zero_op=v_value
	controlinfo/W=$myWinName gr_auto;auto_op=v_value
	controlinfo/W=$myWinName gr_raw;raw_op=v_value
	controlinfo/W=$myWinName gr_showNegs;showNegs_op=v_value
	controlinfo/W=$myWinName gr_showErrs;showErrs_op=v_value
//	controlinfo/W=$myWinName gr_bars;bars_op=v_value
	controlinfo/W=$myWinName gr_sticks;showstr=s_value
		
	traces=tracenamelist("",";",1)

	negItem = getuserdata("","","negMSWaveStr")
	errorItem = getuserdata("","","errMSWaveStr")

// Selectively show sticks
	SpecData = getuserdata("","","specData")
	sticklist=getuserdata("","","allMSWaveStr")+";"+SpecData
	if(strlen(sticklist)==1)  // just a raw spectum, no sticks
		sticklist=""
	endif
	num=itemsinlist(sticklist)
	
	if (strlen(showstr)>0)
		if (stringMatch(showStr, "All"))
			for (idex=0;idex<num;idex+=1)
				wave /z stickwav=$stringfromlist(idex,sticklist)
				modifygraph/Z/W=$myWinName hideTrace($nameofwave(stickwav))=0
			endfor
		else
			for (idex=0;idex<num;idex+=1)
				myStr = stringfromlist(idex,sticklist)
				wave stickwav=$myStr
				if (strsearch(nameofwave(stickwav),"_"+showstr,0,2)>-1)
					modifygraph/Z/W=$myWinName hideTrace($nameofwave(stickwav))=0
					modifyGraph/Z/W=$myWinName toMode($nameofwave(stickwav))=0
				else
					modifygraph/Z/W=$myWinName hideTrace($nameofwave(stickwav))=1
					if (WhichListItem(myStr,SpecData)>=0 )
						modifyGraph/Z/W=$myWinName toMode($nameofwave(stickwav))=3		// stack on next
					endif
				endif
			endfor
		endif
	endif
	
	if (strlen(errorItem)>0)
		wave errWave=$errorItem
		if(showErrs_op)
			ModifyGraph/Z/W=$myWinName hideTrace($nameofwave(errWave))=0		// show errs
		else
			ModifyGraph/Z/W=$myWinName hideTrace($nameofwave(errWave))=1		// hide errs
		endif
		// ModifyGraph/W=$myWinName muloffset($nameofwave(errWave))={0,ms0_sv_numStdDev}
		variable Ver_temp = str2num(StringByKey("IGORVERS", IgorInfo(0)))
		if (Ver_temp>6)
			ModifyGraph/Z/W=myWinName muloffset($NameOfWave(errWave))={0,ms0_sv_numStdDev}
		endif
	endif
	
	// negative wave
	traces=tracenamelist(myWinName,";",1)
		
	// log scale
	modifygraph/z/W=$myWinName log(left)=log_op
	modifygraph/z/W=$myWinName log(right)=log_op		//^ if raw spectrum plotted on right 

	//^ disable and uncheck sc2zero if log option on
	if( log_op )
		checkbox/z gr_sc2zero, Win=$myWinName, disable=2
		sc2zero_op=0
	else
		checkbox/z gr_sc2zero, Win=$myWinName, disable=0
	endif
	
	//^ auto scaling & scale to zero
	if (auto_op&&sc2zero_op)
		setwindow kwtopwin,hook=sq_scale_hook
		sq_graph_auto_scale(1)
	elseif(auto_op)	//^ && !sc2zero
		setwindow kwtopwin,hook=sq_scale_hook
		sq_graph_auto_scale(2)
	elseif(sc2zero_op)	//^ && !auto_op
		setwindow kwtopwin,hook=sq_scale_hook
		sq_graph_auto_scale(3)
	else
		setwindow kwtopwin,hook=$""
	endif
	
	sq_applyGraphDefs(sticklist) // sq_butt_appGraphDefs("")

	ControlInfo gr_showNegs
	sq_MSAvgGraph_showHide("gr_showNegs",V_Value)
	ControlInfo gr_raw
	sq_MSAvgGraph_showHide("gr_raw",V_Value)

End


//& Hook function for auto scaling
Function sq_scale_hook(info)
	string info
	
	if (stringmatch(stringbykey("EVENT",info),"modified"))
		sq_graph_auto_scale(0)
	endif
	return 0

End


//& Auto-set the y axis of an MS graph - upgraded to handle any and all traces
//& only works for monotonic x axes
Function sq_graph_auto_scale(option)
	variable option

	nvar ms0_ck_lastOption=root:panel:ms0_ck_lastOption
	
	string wavlist,wav,wavinfo, recStr
	variable l_top=-inf,l_bottom=inf,r_top=-inf,r_bottom=inf,idex,num, ptLeft,ptRight,nwav, islog,l_log,r_log, x_min,x_max, isHidden

	if (option==0)
		option=ms0_ck_lastOption
	else
		ms0_ck_lastOption=option
	endif
	
	if (option==3)
		setaxis /a/e=1 left
		setaxis /z/a/e=1 right
	else
	
		l_log=str2num(stringbykey("log(x)",AxisInfo("", "left"), "=") )
		r_log=str2num(stringbykey("log(x)",AxisInfo("", "right"), "=") )
		getaxis/q bottom
		x_min=V_min
		x_max=v_max
			
			wavlist =tracenamelist("",";",1)
		num=itemsinlist(wavlist)
		
		for (idex=0;idex<num;idex+=1)
			wav=stringfromlist(idex,wavlist)
			wavinfo=traceinfo("",wav,0)
			wave xwav=$(stringbykey("XWAVEDF",wavinfo)+stringbykey("XWAVE",wavinfo))
			isHidden = numberbykey("hideTrace(x)",wavinfo, "=")
			if (isHidden>0)
				continue
			else
			
				if (waveexists(xwav))
					ptleft=ceil(binarysearchinterp(xwav,x_min))
					ptleft=numtype(ptleft)?(0):(ptleft)
					ptright=floor(binarysearchinterp(xwav,x_max))
					ptright=numtype(ptright)?(numpnts(xwav)-1):(ptright)
				else
					ptleft=ceil(x_min)
					ptright=floor(x_max)
				endif
				wave mywave = $wav
				wavestats /m=1/q/r=[ptLeft,ptRight] $wav
				if (stringmatch(stringbykey("YAXIS",wavinfo),"left"))
					l_top=max(v_max,l_top)
					if (l_log)
						l_bottom=min(l_bottom,sq_graph_minnonzero($wav,ptLeft,ptRight))
					else
						l_bottom=min(l_bottom,v_min)
					endif
				else
					r_top=max(v_max,r_top)
					if (r_log)
						r_bottom=min(r_bottom,sq_graph_minnonzero($wav,ptLeft,ptRight))
					else
						r_bottom=min(r_bottom,v_min)
					endif
				endif				
			endif
		endfor
	
		if (!numtype(l_bottom) && !numtype(l_top))
			switch (option)
				case 1:		//^ autoscale and scale 2 zero
					setaxis/z left 0,l_top
					break
				case 2:	//^ autoscale
					setaxis/z left l_bottom,l_top
					break		
			endswitch
		endif
		if (!numtype(r_bottom) && !numtype(r_top))
			switch (option)
				case 1:		//^ autoscale and scale 2 zero
					setaxis/z right 0,r_top
					break
				case 2:	//^ autoscale
					setaxis/z right r_bottom,r_top
					break		
			endswitch
		endif
	endif	

End



//& Return the minimum positive value of a wave
Function sq_graph_minNonZero(wav,p1,p2)
	wave wav
	variable p1,p2
	
	variable idex,minval=inf
	
	for (idex=p1;idex<=p2;idex+=1)
		if (wav[idex]>0)
			minval=min(minval,wav[idex])
		endif
	endfor
	return minval

End


//^ returns a list of all the traces on a specific axis
Function/S sq_graph_GetTracesThisYAxis(GraphNameStr, AxisNameStr)
	string GraphNameStr, AxisNameStr

	string returnTraceList, TraceList, traceStr
	variable idex, num
	
	TraceList = traceNameList(GraphNameStr,";",1)
	num = ItemsInList(TraceList)	
	returnTraceList = ""
		
	for(idex=0;idex<num;idex+=1)
		traceStr = stringFromList(idex, TraceList)
		if ( stringMatch(AxisNameStr, stringByKey("YAXIS",   traceInfo(GraphNameStr, traceStr, 0))  )  )
			returnTraceList +=traceStr+";"
		endif
	endfor
	
	return returnTraceList

End


/////////////////////////////////////////////////////////////////////////
///////////////// GENERAL USE FUNCTIONS ///////////
/////////////////////////////////////////////////////////////////////////


//1.56O
Function sq_smoothNans_acrossTime(target, twave, pnts)
	wave target, twave
	variable pnts
	
	if (numpnts(target)==0)
		Abort "Could not smooth wave "+nameofwave(target) +" because the wave had zero points."
	endif

	variable idex, kdex, endflag, start_n, end_n, av, al_op
	wave t_series = root:index:t_series

 	duplicate/o/FREE target targetDUP
 	duplicate/d/o/FREE twave twaveDUP
	gen_RemoveNaNsXY(twaveDUP, targetDUP)
 	target = interp(t_series[p], twaveDUP, targetDUP)

 	Smooth  pnts, target

End

//& Smooth a wave containing nan's
// updated in 1.46D - there was some old code that no longer applied
//& I want this function to be phased out. Simply put, it sucks.
Function sq_smooth_nans(target, pnts)
	wave target
	variable pnts
	
	if (numpnts(target)==0)
		Abort "Could not smooth wave "+nameofwave(target) +" because the wave had zero points."
	endif

	variable idex, kdex, endflag, start_n, end_n, av, al_op

	controlinfo /w=ams_anal misc_smooth;al_op=v_value
	idex=0
	endflag=0
	
	do
		if (numtype(target[idex])==0)
			start_n=idex
			do
				idex+=1
				if (idex==numpnts(target))
					endflag=1
					break
				elseif (numtype(target[idex])==2)
					break
				endif
			while(1)
			end_n=idex-1
			make /o /n=(1+end_n-start_n) smooth_temp
			smooth_temp=target[p+start_n]
			wavestats /q smooth_temp
			av=V_avg
			fastop smooth_temp=smooth_temp-(av)
			if (al_op==2)
				smooth /b/e=3 pnts, smooth_temp
			else
				smooth /e=3 pnts, smooth_temp
			endif
			fastop smooth_temp=smooth_temp+(av)
			for (kdex=start_n;kdex<=end_n;kdex+=1)
				target[kdex]=smooth_temp[kdex-start_n]
			endfor
		endif
		idex+=1
		if (idex==numpnts(target))
			endflag=1
		endif
	while (endflag==0)
	killwaves /z smooth_temp

// Here is another version of this function without the mean subtraction, and without the option for boxcar vs gaussian
//	variable idex, num, kdex, endflag, start_n, end_n
//
//	idex=0		// runs over all points in wave
//	endflag=0
//	num = numpnts(target)
//	
//	do
//		if (numtype(target[idex])==0)		// check to see if first point in wave has a real number
//			start_n=idex
//			do
//				idex+=1
//				if (idex==num)
//					endflag=1
//					break
//				elseif (numtype(target[idex])==2)		// contains a nan
//					break
//				endif
//			while(1) //  find if at end of wave or we now get a nan
//			end_n=idex-1
//			
//			duplicate/o/r=[start_n, 1+end_n] target smooth_temp  // wave has original values
//			smooth /b/e=3 pnts, smooth_temp
//			for (kdex=start_n;kdex<=end_n;kdex+=1)
//				target[kdex]=smooth_temp[kdex-start_n]
//			endfor
//		endif
//		idex+=1
//		if (idex==num)
//			endflag=1
//		endif
//	while (endflag==0)
//	killwaves /z smooth_temp

End


// we are going to use the sq_smooth_nans,
// but first we are going to remove nans, then replace them at the end.
// not currently implemented, new in 1.46D
//Function sq_smoothAcrossNans(target, pnts)
//	wave target
//	variable pnts
//	
//	variable idex, kdex, numOrig, numNoNans
//	
//	if (numpnts(target)==0)
//		Abort "Could not smooth wave "+nameofwave(target) +" because the wave had zero points."
//	endif
//
//	duplicate/o target, targetNoNans	
//	sq_removeNans(targetNoNans)
//
//	numOrig = numpnts(target)
//	numNoNans = numpnts(targetNoNans)
//	
//	smooth /b/e=3 pnts, targetNoNans
//
//	// now put smoothed results in their original place
//	kdex=0
//	for (idex = 0;idex<numOrig;idex+=1)
//		if (numtype(target[idex])==0)	
//			target[idex] = targetNoNans[kdex]
//			kdex+=1
//		endif
//	endfor
//	
//	killwaves/z targetNoNans
//	
//End


// similar to sq_smoothAcrossnans except we don't smooth across points that are separated in time by maxTime
// kinda tricky to think about, when dealing with v and 2 mode switching
// not yet implemented, new in 1.46D
//Function sq_smoothMaxTime(target, pnts, maxTime)
//	wave target
//	variable pnts, maxTime
//	
//	wave t_series = root:index:t_series
//	variable idex, kdex, numOrig, numNoNans, start_p, stop_p
//	
//	if (numpnts(target)==0)
//		Abort "Could not smooth wave "+nameofwave(target) +" because the wave had zero points."
//	endif
//
//	duplicate/o t_series, t_seriesNoNans
//	duplicate/o target, targetNoNans	
//	sq_removeNansXY(t_seriesNoNans, targetNoNans)
//
//	duplicate/o t_seriesNoNans timeDelta
//	timeDelta = t_seriesNoNans[p] - t_seriesNoNans[p-1]
//	timeDelta[0] = timeDelta[1]
//	numOrig = numpnts(target)
//	numNoNans = numpnts(targetNoNans)
//	
//	for (idex=numNoNans-1;idex>=0;idex-=1)		// work backwards
//		if (timeDelta[idex]>maxTime)   // insert a blank value	
//			insertpoints idex, 1,  t_seriesNoNans, timeDelta, targetNoNans  // don't need to do this for timeDelta
//			 t_seriesNoNans[idex] = nan
//			 timeDelta[idex] = nan
//			 targetNoNans[idex] = nan
//		endif
//	endfor
//
//	sq_smooth_nans(targetNoNans, pnts)
//
//	// now remove nans again
//	sq_removeNansXY(t_seriesNoNans, targetNoNans)
//	
//	// now put smoothed results in their right place
//	 kdex=0
//	for (idex = 0;idex<numOrig;idex+=1)
//		if (numtype(target[idex])==0)	
//			target[idex] = targetNoNans[kdex]
//			kdex+=1
//		endif
//	endfor
//	
//	killwaves/z t_seriesNoNans, timeDelta, targetNoNans
//	
//End


//& Find a string match in a text wave
//& Method bits 0&1: 0=match part of source 1=exact match 2=match part of str, 4 = case sensitive	//1.52L
//& Igor 6 will make sushi out of this with the grep command
Function sq_findStr(source,str,method)
	wave /t source
	string str
	variable method
	
	variable num,idex,loc=-1,match
	
	num=numpnts(source)
	
	if (strlen(str) && num)
		for (idex=0;idex<num;idex+=1)
			switch (method&15)
				case 0:
					match=strsearch(upperstr(source[idex]),upperstr(str),0)>-1
					break
				case 1:
					match=stringmatch(upperstr(source[idex]),upperstr(str))
					break
				case 2:
					match=strsearch(upperstr(str),upperstr(source[idex]),0)>-1
					break
				case 4:
					match=cmpStr(str,source[idex],1)==0
					break
			endswitch				
			if (match)
				loc=idex
				break
			endif
		endfor
	endif
	return loc

End


//& A find value function that isn't spoofed by nan's
Function sq_findRun(srcwave,target)
	wave srcwave
	variable target
	
	variable wt=wavetype(srcwave)
	
	nvar lastfind=root:panel:lastfind
	
	if (numtype(lastfind) !=0)		//1.50C
		lastfind=0
	endif
	
	// Igor 6.02 modification
	if (numpnts(srcwave)==0 ) 			// change in 1.43B   || numpnts(srcwave)==lastfind)
		return -1
	elseif(lastfind>=numpnts(srcwave))		// change in 1.43B
		lastfind = 0
	endif
	
	if (lastfind<0)
		if (wt&6) // Float
			findvalue /v=(target) srcwave
		elseif (wt&0x20 && wt&0x40) // Unsigned long int
			findvalue /u=(target) srcwave
		else
			findvalue /i=(target) srcwave
		endif
	else
		if (wt&6) // Float
			findvalue /s=(lastfind)/v=(target) srcwave
			if (v_value<0)
				findvalue /v=(target) srcwave
			endif
		elseif (wt&0x20 && wt&0x40) // Unsigned long int
			findvalue /s=(lastfind)/u=(target) srcwave
			if (v_value<0)
				findvalue /u=(target) srcwave
			endif
		else
			findvalue /s=(lastfind)/i=(target) srcwave
			if (v_value<0)
				findvalue /i=(target) srcwave
			endif
		endif
	endif
	
	lastfind=v_value
		
	return lastfind

End


//^ returns 1 if all runs in todo wave have same mode - 0 else
Function sq_onlyOneModeInTodo(todo)
	wave todo
	
	wave rn_series = root:index:rn_series
	wave toftype = root:diagnostics:toftype
	
	variable returnVal, idex, num, thisRunP,thisModetype
	
	returnVal = 1
	thisModetype = nan
	num = numpnts(todo)
	
	for(idex=0;idex<num;idex+=1)
		thisRunP = sq_findrun(rn_series,todo[idex])
		thisModetype = (numtype(thisModetype) ==2) ?  toftype[thisRunP] :  thisModetype//^ gets set once		
		if( toftype[thisRunP] != thisModetype)
			returnVal = 0
			break
		endif
	endfor

	return returnVal

End


//^ makes mask wave of 1s and nans, where blacklisted runs become nan 
Function	sq_makeBlacklistMask(blacklistMask)
wave blacklistMask
	
	wave rn_series = root:index:rn_series
	wave/z blacklist = root:blacklist
	
	variable idex, pt, num
	
	if (waveExists(blacklist))		//1.52
		num = numpnts(blacklist)
		blacklistMask = rn_series/rn_series
	else
		num=0
		blacklistMask=1
	endif
	
	for(idex=0;idex<num;idex+=1)
		pt = sq_findRun(rn_series, blacklist[idex])
		blacklistMask[pt]=nan
	endfor

End


//> add function to graph marquee list
//& Revised and expanded
Menu "GraphMarquee", dynamic

	"-"
	submenu	"New todo wave"
		"Simple", /q, sq_Run2panel("Standard")
		"Combine with...", /q,sq_Run2panel("Other")
		sq_combineMenuTxt("V only","root:allV"), /q, sq_Run2panel("Vonly")
		sq_combineMenuTxt("W only","root:allW"), /q, sq_Run2panel("Wonly")
	end
	"Set airbeam reference", /q, sq_Run2panel("Airbeam")
	"Blacklist runs", /q, sq_Run2panel("Blacklist")

End


//& Enables menu text depending on the existence of a wave
Function /s sq_combineMenuTxt(menutxt,targetstr)
	string menutxt,targetstr
	
	if (waveexists($targetstr))
		return menutxt
	else
		return "("+menutxt
	endif
End


//> function for graph marquee list, sends run interval to AMS panel
//& Expanded to allow for the more complicated menu
// presumes bottom axis is time series
Function sq_run2panel(typestr)
	string typestr
	
	wave t_series=root:index:t_series
	wave rn_series=root:index:rn_series
	svar toDo_makeFromRuns_sv=root:panel:toDo_makeFromRuns_sv
	svar airbeam_refRuns_sv=root:panel:airbeam_refRuns_sv
	
	string destStr,logicstr,todostr,axList,thisAxis, run1Str, run2Str, TraceList
	variable idex, num, lft, rgt
	
	// find bottom axis
	axList=axisList("")

	TraceList = TraceNameList("",";",0)
	if (WhichListItem("bottom",axList)<0)	//1.59E
		abort "The graph must have the bottom axis be t_series.  Aborting from sq_run2panel"	
	endif
	wave/z BottomWave = XWaveRefFromTrace("",stringFromList(0,TraceList))
		
	if (Wavemin(BottomWave) < 0.9*Wavemin(t_series) || Wavemax(BottomWave) > 1.1*Wavemin(t_series))  //1.22a
		abort "You must use this marquee function within a time series graph.  Aborting from sq_run2panel"	
	endif

	// get marque values
	GetMarquee/K/Z bottom
	if(v_flag==0)
		abort "No marquee selected! - aborting from sq_run2panel"
	endif
	
	num=numpnts(t_series)-1
	lft = v_left>=t_series[0]?(ceil(binarysearchinterp(t_series,V_left))):(0)
	rgt=v_right<=t_series[num]?(binarysearch(t_series,V_right)):(numpnts(t_series)-1)
	
//1.59E  runs are never nan!
	// check to see if runs are NaNs or not
//	do
//		if(numtype(rn_series[lft])!=0)
//			lft+=1
//		else
//			break
//		endif
//	while(lft<=rgt)
//	do
//		if(numtype(rn_series[rgt])!=0)
//			rgt-=1
//		else
//			break
//		endif
//	while(rgt>lft)

	if (lft>rgt)
		lft=rgt
	endif

	sprintf run1Str, "%d", rn_series[lft]		// 1.42D fix
	sprintf run2Str, "%d", rn_series[rgt]		// 1.42D fix
	if (lft==rgt)	
		deststr=run1Str
	else
		deststr=run1Str+"-"+run2Str
	endif
	strswitch (typestr)
		case "standard":
			toDo_makeFromRuns_sv=deststr
			dowindow /f ams_panel
			setvariable ams_toDoName activate
		break
		case "Other":
			prompt logicstr,"Logic",popup,"and;or;and not;or not;"
			prompt todostr,"Todo",popup,removefromlist("all;new",SQ_getTODOwaves())
			doprompt /help="" ("Combine "+deststr+" with existing todo wave"),logicstr,todostr
			if (!v_flag)
				toDo_makeFromRuns_sv=deststr+" "+logicstr+" "+todostr
				dowindow /f ams_panel
				setvariable ams_toDoName activate
			endif
		break
		case "Vonly":
			toDo_makeFromRuns_sv=deststr+" and allV"
			dowindow /f ams_panel
			setvariable ams_toDoName activate
		break
		case "Wonly":
			toDo_makeFromRuns_sv=deststr+" and allW"
			dowindow /f ams_panel
			setvariable ams_toDoName activate
		break
		case "Airbeam":
			airbeam_refruns_sv=deststr
		break
		case "Blacklist":
			toDo_makeFromRuns_sv=deststr
			sq_butt_addtoblacklist("")
		break
	endswitch

End


//& Return custom time base wave name based on panel settings
Function /s sq_tbase()
	
	variable t1,dt, num
	string target

	nvar ams_time_saved=root:panel:ams_time_saved
	nvar ams_time_interval=root:panel:ams_time_interval
	nvar ams_time_int_val=root:panel:ams_time_int_val
	nvar ams_time_custom=root:panel:ams_time_custom
	svar ams_time_cus_val=root:panel:ams_time_cus_val
	wave imt_series=root:index:imt_series
	
	if (ams_time_saved)
		target=""
	elseif (ams_time_interval)
		if (ams_time_int_val<=0)		//1.44B
			abort "You cannot choose a time base interval where the number of minutes is <=0.  aborting from sq_tbase()"
		endif
		dt=ams_time_int_val*60
		t1=floor(imt_series[0]/dt)*dt
		target="tmin_"+num2str(ams_time_int_val)		//1.41
		target = replacestring(".", target, "_")
		num=numpnts(imt_series)-1
		make /d/o/n=(ceil((imt_series[num]-imt_series[0])/dt)+1) $target=t1+(dt*p)
		setscale d,0,0,"dat" $target
	else
		wave /z custom=$ams_time_cus_val
		if (waveexists(custom))
			make/FREE/n=(numpnts(custom)) time_temp		// sanity check added in 1.44B
			time_temp = custom[p] - custom[p-1]
			time_temp[0] = time_temp[1]
			WaveStats/q/m=1 time_temp
			if (V_min <=0 || V_numNans>0)
				killwaves/z time_temp
				abort "The chosen custom time wave "+ams_time_cus_val+" is not monotonically increasing - aborting from sq_tbase"
			endif
			target=ams_time_cus_val			
		else
			target=""
		endif
	endif
	return target
	
End


//& Return the name of the custom diameter base wave based on panel settings
//^ Also does a bit of sanity checking.
Function /s sq_dbase()

	string target, MinStr, MaxStr

	nvar tof0_d_saved=root:panel:tof0_d_saved
	nvar tof0_d_reg=root:panel:tof0_d_reg
	nvar tof0_d_reg_min=root:panel:tof0_d_reg_min
	nvar tof0_d_reg_max=root:panel:tof0_d_reg_max
	nvar tof0_d_reg_n=root:panel:tof0_d_reg_n
	nvar tof0_d_custom=root:panel:tof0_d_custom
	svar tof0_d_cus_val=root:panel:tof0_d_cus_val
	
	if (tof0_d_saved)
		target=""
	elseif (tof0_d_reg)		//^ set interval option
		if (tof0_d_reg_min>=tof0_d_reg_max)
			Abort "The minimum is >= maximum diameter. Values don't make sense. - Aborting from sq_dbase()"
		endif
		if (tof0_d_reg_n==0)
			Abort "Choose the number of bins (size intervals) to be greater than 0.  - Aborting from sq_dbase()"
		endif
		sprintf MinStr, "%d", tof0_d_reg_min		//^ 1.36E, for big numbers
		sprintf MaxStr, "%d", tof0_d_reg_max
		target="d_base_"+MinStr+MaxStr+num2str(tof0_d_reg_n)
		target = replacestring(".", target, "_")
		make /o/n=(tof0_d_reg_n+1) $target=tof0_d_reg_min*((tof0_d_reg_max/tof0_d_reg_min)^(p/tof0_d_reg_n))
	else
		wave /z custom=$"root:"+tof0_d_cus_val
		if (waveexists(custom))
			if (Wavemin(custom)<=0)		//1.60T  check that e don't have negative DVa
				string CustomStr = UniqueName(tof0_d_cus_val, 1,0)
				DoAlert 1, "In the wave "+tof0_d_cus_val+" your minimum Dva size in nm is <= 0. Make a new wave, called "+CustomStr+" with values<=0 removed and continue?"
				if (V_flag)
					tof0_d_cus_val = CustomStr
					duplicate/o custom, $"root:"+tof0_d_cus_val/wave= newDva
					newDva =  custom[p]<=0? nan : custom[p]
					WaveTransform zapNans newDva
					wave custom=$tof0_d_cus_val
				endif	
			endif
			
			// check that we don't have non-monotonic Dva wave
			make/FREE/n=(numpnts(custom)) temp_custom
			temp_custom[1,]=custom[p] - custom[p-1]; temp_custom[0] =temp_custom[1]			// 1.19E
			if (WaveMin(temp_custom)<=0)		// check for monotonicity	
				Abort "The custom wave you entered, "+tof0_d_cus_val+" is not monotonic - Aborting from sq_dbase()"
			else
				target=tof0_d_cus_val
			endif
		else
			Abort "The custom wave you entered, "+tof0_d_cus_val+", doesn't exist. - Aborting from sq_dbase()"
		endif
	endif

	return target

End


//> Function controlling the diameter base radio buttons
//^renamed from sq_diambase_check
Function sq_ck_diamBase(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked
	
	nvar tof0_d_saved=root:panel:tof0_d_saved
	nvar tof0_d_reg=root:panel:tof0_d_reg
	nvar tof0_d_custom=root:panel:tof0_d_custom
	nvar tof0_d_reg_min=root:panel:tof0_d_reg_min		//^
	nvar tof0_d_reg_max=root:panel:tof0_d_reg_max		//^
	nvar tof0_d_reg_n=root:panel:tof0_d_reg_n			//^
	tof0_d_saved=(stringmatch("tof0_diam_saved",ctrlname))
	tof0_d_reg=(stringmatch("tof0_diam_interval",ctrlname))
	tof0_d_custom=(stringmatch("tof0_diam_custom",ctrlname))

	if (tof0_d_reg)
		SetVariable tof0_diam_reg_min noedit=0
		SetVariable tof0_diam_reg_max noedit=0
		SetVariable tof0_diam_reg_num noedit=0
	else												//^ disable if Set Interval is not checked.
		SetVariable tof0_diam_reg_min noedit=1
		SetVariable tof0_diam_reg_max noedit=1
		SetVariable tof0_diam_reg_num noedit=1
	endif

End


//& Function controlling the m/z base radio buttons
Function sq_ck_mzBase(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked
	
	nvar ms0_mz_saved=root:panel:ms0_mz_saved
	nvar ms0_mz_reg=root:panel:ms0_mz_reg
	nvar ms0_mz_custom=root:panel:ms0_mz_custom
	nvar ms0_mz_reg_min=root:panel:ms0_mz_reg_min
	nvar ms0_mz_reg_max=root:panel:ms0_mz_reg_max
	nvar ms0_mz_reg_dm=root:panel:ms0_mz_reg_dm
	nvar ms0_AvGraphType=root:panel:ms0_AvGraphType
	if (ms0_AvGraphType==1 || ms0_AvGraphType ==4)		// sticks or itof
		GroupBox ms0_mzbox disable=2
		CheckBox ms0_mz_saved disable=2
		CheckBox ms0_mz_custom disable=2
		CheckBox ms0_mz_area disable=2
		CheckBox ms0_mz_reg disable=2
		SetVariable ms0_mz_reg_min disable=2
		SetVariable ms0_mz_reg_max disable=2
		SetVariable ms0_mz_reg_dm disable=2	
		CheckBox ms0_mz_saved_regrid disable=2
		SetVariable ms0_mz_custstr disable=2
		checkbox ms0_mz_refit disable=2
	else 	//  raw vs mz
		GroupBox ms0_mzbox disable=0
		CheckBox ms0_mz_saved disable=0
		CheckBox ms0_mz_custom disable=0
		CheckBox ms0_mz_area disable=0
		CheckBox ms0_mz_reg disable=0
		checkbox ms0_mz_refit disable=0
		if (strlen(ctrlname)>0)
			ms0_mz_saved=(stringmatch("ms0_mz_saved",ctrlname))
			ms0_mz_reg=(stringmatch("ms0_mz_reg",ctrlname))
			ms0_mz_custom=(stringmatch("ms0_mz_custom",ctrlname))
		endif
	
		SetVariable ms0_mz_reg_min disable=2*(!ms0_mz_reg)
		SetVariable ms0_mz_reg_max disable=2*(!ms0_mz_reg)
		SetVariable ms0_mz_reg_dm disable=2*(!ms0_mz_reg)
	
		CheckBox ms0_mz_saved_regrid disable=2*(!ms0_mz_saved)
		SetVariable ms0_mz_custstr disable=2*(!ms0_mz_custom)
	endif
	
End


//@ function which adds prefix and suffix to all points in a spec list
Function	sq_dataDestStr(dataStr,prefix,suffix,species,uniqueFlag)
	string &dataStr,prefix,suffix,&species
	variable uniqueFlag
	
	variable idex,num=itemsinlist(species,",")
	string spec=""

	species=replacestring(" ",species,"")
	num=itemsinlist(species,",")

	for(idex=0;idex<num;idex+=1)
		spec=Prefix+stringfromlist(idex,species,",")+suffix
		spec = CleanupName(spec, 0 )
//^		spec=uniquename(spec,1,0)
		dataStr+=spec+"/"
	endfor

End


//@ function to extract frag info for all species in a spec list
Function sq_getParamStr(param,speclist,msflag, waves2PlotFacList)
	string &param,&speclist,&waves2PlotFacList   //@param will take the get the final data, speclist is modified to remove spaces
	variable msflag		// when MSflag is 0, use the species RIE, CE
	
	wave/z/t frag_list=root:frag:frag_list
	wave/z/t spec_list=root:frag:spec_list
	wave/z/t specname_list=root:frag:specname_list
	wave/z IEfac_list=root:frag:IEfac_list
	wave/z CEfac_list=root:frag:CEfac_list

	wave /z/t speccorr_list=root:frag:speccorr_list
	if (!WaveExists(speccorr_list))
		make/o/t/n=(numpnts(frag_list)) root:Frag:speccorr_list/wave=speccorr_list
		speccorr_list=""
	endif

	wave /z/t CEWave_list=root:frag:CEWave_list
	if (!WaveExists(CEWave_list))
		make/o/t/n=(numpnts(frag_list)) root:Frag:CEWave_List/wave=CEWave_list
		CEWave_list=""
	endif
	
	variable idex, numInList, loc
	string fragStr, RIEStr, CEStr, SpecStr, specCorrStr, specItem, CECorrStr
	
	fragStr="fraglist:"
	RIEStr="rie_list:"
	CEStr="ce_list:"
	specStr="speclist:"
	specCorrStr="spec_corr:"
	CECorrStr="CE_corr:"
	waves2PlotFacList=""		//1.47I change
//	specCorrStr=""		//1.48B error ??

	numInList=itemsinlist(speclist,",")
	if ( !waveexists(frag_list) || !waveexists(spec_list) || !waveexists(specname_list) || !waveexists(IEfac_list) || !waveexists(CEfac_list) || !waveexists(speccorr_list) )
		abort "ALERT!! At least one of these waves do not exist in the frag folder:frag_list, spec_list, specname_list, IEfac_list, CEfac_list, speccorr_list - aborting from sq_getParamStr"
	endif
		

	if (numInList>0)		//^ not sure what the default behavior should be if the list is empty
		for(idex=0;idex<numInList;idex+=1)
			specItem=stringfromlist(idex,speclist,",")	// look in spec_list (NO3)
			loc=sq_findstr(spec_list,specItem,1)
			if(loc==-1)		
				loc=sq_findstr(specname_list,specItem,1) // look in specName_list  (nitrate)
			endif
			if (loc==-1)		// not a species
				if(numtype(str2num(specItem))==0)		// integer, i.e. 43
					specStr+="mz"+specItem+"/"
					fragStr+=specItem+"/"
					RIEStr+="1/"
					CEStr+="1/"
					CECorrStr+=" /"		// 1.53N
					if (msflag)
						waves2PlotFacList+="1/"
					endif
				elseif (cmpstr(specItem,"all")==0)		// all
					specStr+="all/"
					fragStr+="all/"
					RIEStr+="1/"
					CEStr+="1/"
					CECorrStr+=" /"		// 1.53N
					if (msflag)
						waves2PlotFacList+="1/"
					endif
				endif
			else		// it is a species we know about
				specStr+=specItem+"/"
				fragStr+=frag_list[loc]+"/"
				if(msflag)		// mass spec, want nitrate equivalent
					RIEStr+="1/"
					CEStr+="1/"
					CECorrStr+=" /"		// 1.53N
					waves2PlotFacList+=num2str(IEfac_list[loc]*CEfac_list[loc])+"/"
				else
					//1.57F
					if (stringMatch(specItem, "Total"))		//1.57F
						RIEStr+="1/"
						CEStr+="1/"
						waves2PlotFacList+="1/"
						specCorrStr+=" /"
//						CECorrStr+=" /"  // 1.60Y
						IEfac_list[loc]=1
						CEfac_list[loc]=1
						specCorrStr[loc]=""
//						CECorrStr[loc]=""
						CECorrStr+=CEWave_List[loc]+"/"  // 1.60Y
					else
						RIEStr+=num2str(IEfac_list[loc])+"/"
						CEStr+=num2str(CEfac_list[loc])+"/"
						waves2PlotFacList+=num2str(IEfac_list[loc]*CEfac_list[loc])+"/"
						specCorrStr+=speccorr_list[loc]+"/"
						CECorrStr+=CEWave_List[loc]+"/"
					endif
				endif
			endif
		endfor
		param+=specStr+";"+fragStr+";"+RIEStr+";"+CEStr+";"+specCorrStr+";"+CECorrStr+";"
	endif
	
End


//^ returns list of textwave entries
Function/S sq_textwave2List(textwave)
	wave/t textwave
	
	variable idex, num = numpnts(textwave)
	string returnList=""
	
	for(idex=0;idex<num;idex+=1)
		returnList +=textwave[idex]+";"
	endfor
	
	return returnList

End


//^ returns list with any empty strings removed
Function/S sq_removeEmptyStringsFromList(myList, separStr)
	string myList, separStr

	variable idex, num
	string str, returnList
	
	returnList = ""
	num = ItemsInList(myList)
	
	for (idex=0;idex<num;idex+=1)
		str = StringFromList(idex, myList)
		if (strlen(str)>0)
			returnList +=str + separStr
		endif
	endfor
	
	return returnList

End


//^ a workaround for removing missing proc files that are generated every time the panel is recreated on experiment startup
Function sq_killMissingProcPics()
	
	variable idex,nlim=100		// limit just in case the kill fails (we don't want an infinite loop)
	
	for(idex=0;idex<nlim;idex+=1)
		if( strlen(PICTList("missing proc pict",";","")) == 0 )
			break
		endif
		KillPICTs/Z 'missing proc pict'
	endfor

End


//^ Duplicates the last non-nan value in a wave  to the last point in a wave
// if there is no last non nan value the function returns 0
// Useful for waves which indicatee state (zero, measure) but may not have a reading, non-nan value every seccond
// All nan values preceeding the first nan value remain nan.
Function sq_repeatLastNonNan(wav)
	wave wav

	variable idex, num, temp
	
	 idex=sq_FindFirst(wav, 0)
	 num=numpnts(wav)
	 temp = wav[idex]
	 
	 if (idex == num)
		return 0		// the entire wave is nans
	endif
	
	do
		if(numtype(wav[idex])==2)
			wav[idex]=temp
		else
			temp = wav[idex]
		endif 	
		idex+=1
	while(idex<num)

	return 1
	
End


//^ Duplicates the last non-nan value in a wave  to the last point in a wave
// if there is no last non nan value the function returns 0
// Useful for waves which indicatee state (zero, measure) but may not have a reading, non-nan value every seccond
// All nan values preceeding the first nan value remain nan.
Function sq_repeatLastNonNanRepeatFirst(wav)
	wave wav

	variable idex
	
	sq_RepeatLastNonNan(wav)
	idex=sq_FindFirst(wav, 0)
	
	if (idex>0)
		wav[0,idex]=wav[idex]
	endif

End



//^ Performs a linear interpolation on wave originalWave.
// The interpolation built into igor can change wave scaling, so be careful if you use that.
// This is mostly obsolete with new Igor code that handles interpolation better.  
// This intepolates to the first and last points if original values are nans.
//& Rehashed and made multidimensional 1.47g
Function sq_interpolateWave(resultWave, originalWave, kill)		// JDA 1.47G, added a kill parameter	
	wave resultWave, originalWave
	variable kill

	variable idex, jdex, nOrig, nCol, mat_flag, i
	string cmd, waveInterpolatedStr, wave2interpStr, iStr
	
	nOrig=dimsize(originalWave,0)
	nCol=dimsize(originalWave,1)

	if  (norig != dimsize(resultwave,0) || ncol != dimsize(resultwave,1))
		Abort "The number of points in both input waves should be the same - Aborting from InterpolateWave"
	endif
	
	mat_flag=ncol>0
	ncol=max(ncol,1)
	
//	nResult = numpnts(resultWave)  // JDA 1.47G
		
//	iStr= UniqueName("i", 1, 0)				// get wave names that aren't being used
//	waveInterpolatedStr = UniqueName("w_i", 1, 0)		// get wave names that aren't being used
//	wave2interpStr = UniqueName("w_2i", 1, 0)
	
//	Make/d/o/n=(nOrig) $iStr, $waveInterpolatedStr,   $wave2interpStr
//	wave iwave = $iStr
//	wave w_i = $waveInterpolatedStr
//	wave w_2i = $wave2interpStr
//	iwave = p
//	w_2i = originalWave
	make /o/n=(norig) sq_interp_tmp1,sq_interp_tmp2
	for (i=0;i<ncol;i+=1)
		matrixop /o sq_interp_tmp1=col(originalwave,i)
		wavestats /q/m=1 sq_interp_tmp1
		if (v_npnts>0)
			if (numtype(sq_interp_tmp1[0])) // Tweaked the behaviour of the end padding - interpolate2 doesn't work like you'd think it should
				idex=sq_findfirst(sq_interp_tmp1,0)
				sq_interp_tmp1[idex-1]=sq_interp_tmp1[idex]
			endif
			if (numtype(sq_interp_tmp1[norig-1]))
				idex=sq_findlast(sq_interp_tmp1,norig-1)
				sq_interp_tmp1[idex+1]=sq_interp_tmp1[idex]
			endif
			interpolate2 /t=1/i=3/y=sq_interp_tmp2 sq_interp_tmp1
			if (mat_flag)
				imagetransform  /d=sq_interp_tmp2 /g=(i) putcol resultwave
			else
				fastop resultwave=sq_interp_tmp2
			endif
		else
			resultwave[][i]=nan
		endif
	endfor
	
//	WaveStats /Q w_2i   // JDA 1.47G
//	if (V_numNans!=nOrig)
//		idex=sq_FindFirst(w_2i,0)
//		jdex=sq_FindLast(w_2i,nOrig-1)
//		w_2i[0]=w_2i[idex]
//		w_2i[nOrig-1]=w_2i[jdex]
////		cmd="interpolate /T=1/N="+num2str(nOrig)+"/y="+waveInterpolatedStr+", "+wave2interpStr + " /X="+iStr
////		print cmd
////		Execute cmd
//		interpolate2 /t=1/n=(norig) /y=$waveInterpolatedStr iwave, w_2i // Much faster...
//		resultWave=w_i
//	else
//		Print "// Interpolation is a problem for wave "+Nameofwave(w)
//		resultWave = nan
//	endif
//	if (kill)
		Killwaves /z sq_interp_tmp1,sq_interp_tmp2
//	endif

End


//^ Returns the last non-nan value before (or including) endPt in a wave.
// If the entire wave is nans, FindLast will return -1.
// It steps through the wave backwards; in decreasing point number.
Function sq_findLast(wav, endPt)		
	wave wav
	variable endPt

	variable idex, num
	
	idex=endPt
	num=numpnts(wav)		// 1.47G

	if (idex >= num)
		return num
	endif

	if (idex < 0)
		return -1
	endif

	if (numtype(wav[idex])==0)// is the w[endPt] a number?
		return idex		
	endif

	do
		idex-=1
	while  ( (numtype(wav[idex])!=0) && (idex >=0 )  )
	
	return idex

End


//^ Returns the first non-nan value after and including beginPt in a wave.
// If all values after beginPt are nans, Findfirst will return number of points.
Function sq_findFirst(wav, beginPt)
	wave wav
	variable beginPt

	variable idex, num
	
	idex=beginPt
	num=numpnts(wav)

	if (idex >= num)
		return num
	endif

	if (idex < 0)
		return -1
	endif
		
	if (numtype(wav[idex])== 0 )	// is w[beginPt] a number?
		return idex	
	endif

	do
		idex+=1
	while  ( (idex <num) && (numtype(wav[idex])!=0) )		// 1.58G  important that (idex <num) is first
	
	return idex

End


//^  A simple fetch function for dumping  PToF data into a destination wave.
//^  Is intended for only one run, but in theory could be used for many runs.
Function sq_getThisRawPToF_viaFetch(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn 
	variable n_acorns

	wave source=$stringbykey("acorn_0",paramstr)
	variable thisRun=numberbykey("thisRun",paramstr)
	string destStr = stringbykey("dest",paramstr)
	destStr = ReplaceString( "/", destStr,":")
 
	if (dimsize(source, 0)>1)		// more than one run
		duplicate/o source $destStr 		
	else
		make/o/n=(dimsize(source, 1), dimsize(source, 2) )$destStr 	
		wave dest = $destStr
		dest = source[0][p][q]
	endif
	wave dest = $destStr
	string str1
	sprintf str1, "%d" , thisRun		// small bug, things can go wrong with run numbers > 1e6
	note  dest, str1

End


//^ A function similar to sq_GetThisRawMS
//^ Currently not used in any processing but is available for the user in general debugging. 
//^ Although the function has the word "Raw" in its name, it could be used for raw or stick PToF data.
//^ A sample useage would be:
// sq_GetThisRawPToF(13335, "stickPToF", "PToF_13335", "PToF_stick_p")
// where "stickPToF" is an existing data folder, the run number 13335 is desired, the wave containing the raw PToF data
// will be called PToF_13335 and the data source is PToF_stick_p.
Function sq_getThisRawPToF(runNumber, dataFolderStr, RawSpectraNameStr, sourceStr)
	variable runNumber
	string RawSpectraNameStr, dataFolderStr, SourceStr
	
	if (sq_doesPToFDataExist(runNumber)!=1)
		Abort "Either the run number doesn't exist or there is no PToF data for this run..  Aborting from sq_GetThisRawPToF"
	endif	

	string destStr, str1
		
	destStr = "dest:"
	destStr+= ReplaceString(":", "root:"+dataFolderStr+":"+RawSpectraNameStr, "/")
	
	if (!DataFolderExists(dataFolderStr ))
		print "// Could not find data folder "+dataFolderStr+" and so could not extract wave "+RawSpectraNameStr
		return 0	
	endif
	
	sq_makeOneRunToDo(RunNumber)
	wave/u/i MyOneRunToDoWave = root:MyOneRunToDoWave

	sprintf str1, "%d" , runNumber		// small bug, things can go wrong with run numbers > 1e6

	squirrel_fetch(MyOneRunToDoWave,sq_GetThisRawPToF_viaFetch,"thisRun:"+str1+";"+destStr, SourceStr)		

	killwaves/z MyOneRunToDoWave
	
End


//& Combine two todo waves using AND logic
Function sq_todo_AND(todo1,todo2,deststr)
	wave /i todo1,todo2
	string deststr
	
	variable idex,n1,n2,np=0,num, placeVar
	
	n1=numpnts(todo1)
	n2=numpnts(todo2)
	num=min(n1,n2)
	make /o/i/n=(num) $(deststr+"_tmp")
	wave dest=$(deststr+"_tmp")
	
	if (n1<n2)
		for (idex=0;idex<num;idex+=1)
		placeVar = sq_findrun(todo2, todo1[idex])
			if (todo1[idex]>0 && sq_findrun(todo2, todo1[idex]) > -1)
				dest[np]=todo1[idex]
				np+=1
			endif
		endfor
	else
		for (idex=0;idex<num;idex+=1)
			if (todo2[idex]>0 && sq_findrun(todo1, todo2[idex]) > -1)
				dest[np]=todo2[idex]
				np+=1
			endif
		endfor
	endif	
	if (np<num)
		deletepoints np,num-np,dest
	endif
	
	sort dest,dest
	duplicate /o dest,$deststr
	killwaves /z dest

End


//& Combine two todo waves using OR logic
Function sq_todo_OR(todo1,todo2,deststr)
	wave /i todo1,todo2
	string deststr
	
	variable idex,n1,n2,np=0
	
	n1=numpnts(todo1)
	n2=numpnts(todo2)
	make /o/i/n=(n1+n2) $(deststr+"_tmp")
	wave dest=$(deststr+"_tmp")

	for (idex=0;idex<n1;idex+=1)
		if (todo1[idex]>0)
			dest[np]=todo1[idex]
			np+=1
		endif
	endfor
	for (idex=0;idex<n2;idex+=1)
		if (todo2[idex]>0 && sq_findrun(todo1, todo2[idex]) == -1)
			dest[np]=todo2[idex]
			np+=1
		endif
	endfor
	if (np<n1+n2)
		deletepoints np,n1+n2-np,dest
	endif

	sort dest,dest
	duplicate /o dest,$deststr
	killwaves /z dest

End


//& Get the NOT of the todo wave
Function sq_todo_NOT(todo,deststr)
	wave /i todo
	string deststr
	
	wave /i all=root:all
	
	variable idex,n1,n2,np
	
	n1=numpnts(all)
	n2=numpnts(todo)	
	make /o/i/n=(n1) $(deststr+"_tmp")
	wave dest=$(deststr+"_tmp")

	for (idex=0;idex<n1;idex+=1)
		if (sq_findrun(todo, all[idex]) == -1)
			dest[np]=all[idex]
			np+=1
		endif
	endfor
	if (np<n1)
		deletepoints np,n1-np,dest
	endif
	sort dest,dest
	duplicate /o dest,$deststr
	killwaves /z dest

End


//^ A simple bit of code that makes a todo wave called MyOneRunToDoWave
//^ This todo wave is used in the m/z cal and background panels when one wants to look at one run.
Function sq_makeOneRunToDo(RunNumber)
	variable runNumber

	killwaves/z root:MyOneRunToDoWave //1.44B prevents things from going bad if not in root folder.
//	make/i/u/o/n=1 root:MyOneRunToDoWave
//	wave/u/i MyOneRunToDoWave = root:MyOneRunToDoWave
//	Note MyOneRunToDoWave, "TYPE:todo;"
//	MyOneRunToDoWave = runNumber
	wave/z blacklist = root:blacklist		//1.53D
	if ( WaveExists(blacklist) && sq_findRun(blacklist,RunNumber)>=0 )
		abort "This run has been blacklisted - aborting from sq_makeOneRunToDo"	
	endif
	string todostr		//1.57G
	sprintf  todostr, "%d", RunNumber
	sq_create_todo(todostr,"MyOneRunToDoWave")

End


//& New function to create to do waves
Function sq_create_todo(todostr,deststr)
	string todostr,deststr
	
	wave rn_series=root:index:rn_series
	wave all=root:all

	variable idex,numItems,andflag,notflag,jdex,num,np,p1,p2
	string todoitem

	todostr = sq_parsePandDinTodoCreation(todostr)		//1.52M

	make /o/i/n=0 todo_tmp1

	numItems=itemsinlist(todostr," ")
	for (idex=0;idex<numItems;idex+=1)
		todoitem=stringfromlist(idex,todostr," ")
		if (cmpstr(todoitem,"not")==0)
			notflag=1
		elseif (cmpstr(todoitem,"and")==0)
			andflag=1
		elseif (cmpstr(todoitem,"or")!=0)
			wave /z todo_test=$todoitem
			if (waveexists(todo_test))
				num=numpnts(todo_test)
				make /o/i/n=(num) todo_tmp2
				if (cmpstr(stringbykey("TYPE",note(todo_test)),"todo")==0 || cmpstr(todoitem,"blacklist")==0 )	
					if (num>0)	// num>0 added 1.58G
						todo_tmp2=todo_test
					endif
				else		// wave exists but is not a todo wave
					np=0
					if (num==numpnts(rn_series))
						for (jdex=0;jdex<num;jdex+=1)
							if (todo_test[jdex])		// this is the case for using a key wave.
								todo_tmp2[np]=rn_series[jdex]
								np+=1
							endif
						endfor
						if (np<num)
							deletepoints np,num-np,todo_tmp2
						endif
						sq_todo_AND(todo_tmp2,all,"todo_tmp2")
					else
						killwaves /z  todo_tmp2
					endif
				endif
			else		// string item is not a todo wave
				if (strsearch(todoitem, ",", 0)>0 && itemsinlist(todoitem,",")>0)			//1.40D
					num=itemsinlist(todoitem,",")
					make /o/i/n=(num) todo_tmp2
					for (jdex=0;jdex<num;jdex+=1)
						todo_tmp2[jdex] = str2num(StringFromList(jdex,todoitem, ","))					
					endfor
				else
					if (itemsinlist(todoitem,"-")==2)
						p1=round(str2num(stringfromlist(0,todoitem,"-")))
						p2=round(str2num(stringfromlist(1,todoitem,"-")))
					else
						p1=round(str2num(todoitem))
						p2=p1
					endif
					if (!numtype(p1) && !numtype(p2) && p2>=p1)
						make /o/i/n=(p2+1-p1) todo_tmp2=p1+p
						sq_todo_AND(todo_tmp2,all,"todo_tmp2")
					else
						killwaves /z  todo_tmp2
					endif
				endif
			endif
		endif
		if (waveexists (todo_tmp2))
			if (notflag)
				sq_todo_NOT(todo_tmp2,"todo_tmp2")
				notflag=0
			endif
			if (andflag)
				sq_todo_AND(todo_tmp1,todo_tmp2,"todo_tmp1")
				andflag=0
			else
				sq_todo_OR(todo_tmp1,todo_tmp2,"todo_tmp1")
			endif
			killwaves /z todo_tmp2
		endif
	endfor
	string deststr1=CleanupName(deststr,0)
	duplicate /o todo_tmp1,$"root:"+deststr1 //1.59F		//1.44B prevents things from going bad if not in root folder.
	if (cmpstr(deststr1,"blacklist")!=0)
		note $"root:"+ deststr1, "TYPE:todo;"
	endif
	killwaves /z todo_tmp1,todo_tmp2

End


//  makes a simple mask wave of nans and 1s corresponding to whether a run is in the todo wave
Function sq_makeMaskFromTodofindRun(maskwave,todowave [oppositeFlag])
wave maskwave,todowave
variable oppositeFlag

	wave rn_series = root:index:rn_series
	variable pos, idex, num
	
	num=numpnts(todowave)
	
	redimension/n=(numpnts(rn_series)) maskwave			// sanity check in 1.44B
	maskwave=nan
	for(idex=0;idex<num;idex+=1)
		pos =sq_findRun(rn_series, todowave[idex])
		if (pos>=0)
			maskwave[pos]=1
		endif	
	endfor

	if (!ParamIsDefault(oppositeFlag))		//1.52
		maskwave = selectnumber(numtype(maskwave[p])==0, 1, nan)
	endif

End


// changed in 1.49E
// returns either the biggest or smallest value in the todo wave for the mFinish or the mStart values.
// print sq_findMaxMinMz(all, 1, 0) prints the smallest mzFinish value 560
// print sq_findMaxMinMz(all, 1, 1)  prints the largest mzfinish value
// print sq_findMaxMinMz(all, 0, 1) prints the largest mzStart value
// print sq_findMaxMinMz(all, 0, 0) prints the smallest mzStart value
Function sq_findMaxMinMz(todo, MzFinishFlag, MaxFlag)
wave todo
variable MzFinishFlag, MaxFlag

	variable returnVal
	wave mFinish = root:diagnostics:mFinish
	wave mStart = root:diagnostics:mStart
	make/Free/o/n=(numpnts(mFinish)) tempMask	
	sq_makeMaskFromTodofindRun(tempMask,todo)
	if (MzFinishFlag)
		tempMask*=mFinish
	else
		tempMask*=mStart
	endif
	if (MaxFlag)
		returnVal = WaveMax(tempMask)
	else
		returnVal = WaveMin(tempMask)
	endif
 
	killwaves/z tempMask
	return returnVal

End


//1.49E
// usage: sq_findMaxMinSQIndex(all, "MSSDiff", 4, 1)
// gets the max or min value of the dimensions of a data set.
// returns nan if data set does not exist
Function sq_findMaxMinSQIndex(todo, IndexLabel, SqCol, MaxFlag)
wave todo
string IndexLabel
variable SqCol, MaxFlag

	variable idex, kdex, returnVal, n
	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index
	
	kdex = FindDimLabel(squirrel_index,2,IndexLabel)
	if (kdex<0 || SqCol> 8 || SqCol<0)
		returnVal = nan
	else
		ImageTransform/g=(SqCol)/P=(kdex) getCol squirrel_index
		wave W_ExtractedCol
		n=numpnts(W_ExtractedCol)
		make/o/free/n=(n) myCol		// 1.60K		 
		for (idex=0;idex<n;idex+=1)
			myCol[series_index[idex]] = W_ExtractedCol[idex]
		endfor			
		make/Free/o/n=(numpnts(W_ExtractedCol)) tempMask
		sq_makeMaskFromTodofindRun(tempMask,todo)
		tempMask*=myCol
		tempMask = tempMask[p]==0 ? nan : tempMask[p] 		// 1.52H for pedros data we have  PToF only runs... we need to make sure this max mz does not return 0
		if(MaxFlag)
			returnVal = WaveMax(tempMask)
		else
			returnVal = WaveMin(tempMask)
		endif	
	endif
	
	killwaves/z W_ExtractedCol, tempMask
	return returnVal
	
End


// Generate ModifySITable table
Function sq_butt_modifySI(ctrlName) : ButtonControl
	string ctrlName
	
	if (!DataFolderExists("root:index:"))		// sanity check in 1.43I
		Abort "You must first press 'Get Index' before you can check the single ion - aborting from  sq_butt_modifySI"
	endif
	wave /z ionSingleStr=root:diagnostics:ionSingleStr
	if (!waveexists(ionSingleStr) || numpnts(ionSingleStr)==0)
		duplicate /o root:diagnostics:ionSingleStr_logged, root:diagnostics:ionSingleStr
	endif
	wave/z ionizationType = root:diagnostics:ionizationType
	DoWindow/F ModifySITable
	if (V_flag!=1)		// 1.44B preventing things from going bad if not in root folder, added ionization type
		Edit/W=(4.8,42.2,510,216.8)/N=ModifySITable as "ModifySITable"
		AppendToTable/W=ModifySITable root:index:t_series,root:index:rn_series root:diagnostics:ionSingleStr
		if (waveexists(ionizationType) )
			nvar/z VWSwitching = root:diagnostics:VWSwitching
			if ( NVAR_Exists(VWSwitching) && VWSwitching) 
				AppendToTable/W=ModifySITable root:diagnostics:ToFTypeVKey, root:diagnostics:ToFTypeWKey
			endif
			AppendToTable/W=ModifySITable root:diagnostics:toftype,  root:diagnostics:toftype, root:diagnostics:ionizationtype
			ModifyTable/W=ModifySITable title(root:diagnostics:ionizationType)="ionization type: 0=EI, 1=sEI, 2=VUV, 3=Li, 4=Neg, 5 = MAB, 6=SP2"
			ModifyTable/W=ModifySITable width(root:diagnostics:ionizationType)=140
		else
		endif

		ModifyTable/W=ModifySITable format[1]=8,width[1]=100,title[1]="Save Time",title[2]="Run Number"
		ModifyTable/W=ModifySITable title(root:diagnostics:toftype)="ToF type: 0=c,1=v,2=w"	
		ModifyTable/W=ModifySITable rgb(root:diagnostics:ionSingleStr)=(65280,0,0)
		ModifyTable/W=ModifySITable width(Point)=41, width(root:index:rn_series)=60, width(root:diagnostics:ionSingleStr)=60
	endif
	
End


//& Check for bad file locations and correct
Function sq_butt_checkfiles(ctrlname) : ButtonControl
	string ctrlname
	
	sq_GetIndexNotDoneYet()
	sq_ams_stat_upd("Checking files...")

	wave /t file_index=root:index:file_index

	variable idex,num,counter,kdex,foundflag,numSub
	string fullpath,filestr,subdirs

	num=numpnts(file_index)
	make /t/o/n=(0) checkfiles_tmp
	counter=0
	
	for (idex=0;idex<num;idex+=1)	// big loop through all file names
		foundflag=0
		kdex=-1
		filestr=stringfromlist(itemsinlist(file_index[idex],":")-1,file_index[idex],":")
		do
			if (kdex==-1)
				fullpath=file_index[idex]
			else
				fullpath=checkfiles_tmp[kdex]+filestr
			endif
			getfilefolderinfo /q/z fullpath
			if (v_flag==0)
				if (kdex>-1)
					file_index[idex]=fullpath
				endif
				foundflag=1
			else
				kdex+=1
			endif
		while (!foundflag && kdex<counter)
		if (!foundflag)
			do
				newpath /q/o/m=("Specifiy folder containing "+filestr) checkfile_path
				if (v_flag==0)
					pathinfo checkfile_path
					subdirs=s_path+";"
					sq_harvest_files(s_path,subdirs,"dir")
					numSub=itemsinlist(subdirs)
					for (kdex=0;kdex<numSub;kdex+=1)
						checkfiles_tmp[counter]={stringfromlist(kdex,subdirs)}
						if (!foundflag)
							getfilefolderinfo /q/z (checkfiles_tmp[counter]+filestr)
							if (v_flag==0)
								file_index[idex]=checkfiles_tmp[counter]+filestr
								foundflag=1
							endif
						endif
						counter+=1
					endfor
				else
					doalert 1,"Continue checking?"
					if (v_flag==1)
						foundflag=1 // Cancel pressed, but carry on
					else
						foundflag=2
					endif
				endif
			while (!foundflag)
		endif
		if (foundflag==2)
			break
		endif
		sq_ams_prog_upd(100*(idex+1)/num)
	endfor
	sq_ams_stat_upd("Done.")
	
	killwaves /z checkfiles_tmp
	killpath /z checkfile_path
	
	print "// Finished checking files at "+date() + " "+time()

End


//^  squirrel fetch function which extracts one run's raw data and puts it in the dest, which is created or overwritten.  Used in sq_GetThisRawMS.
//^  presumes that the todo wave had only one run in it, so the data is in row 0 of source
//^  Not intended for PToF data!		1.49B//
Function sq_getThisRawMS_viaFetch(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn 
	variable n_acorns

	string str1
	variable PToFflag = numberbykey("PToF",paramstr)
	wave source=$stringbykey("acorn_0",paramstr)
	variable SinglePToFBin=numberbykey("SinglePToFBin",paramstr)
	variable thisRun=numberbykey("thisRun",paramstr)
	string dest = stringbykey("dest",paramstr)
	dest = ReplaceString( "/", dest,":")
	
	if (dimsize(source, 0)>1 )
	 	print "// Something is wrong with the dimension of the source when we were looking for this run "+paramstr
	endif
	
	if (!PToFflag)
		make/o/n=(dimsize(source, 1)) $dest/wave=myRawSpectra			// dest should have data folder info in the string.  
		myRawSpectra = source[0][p]
	elseif(SinglePToFBin>=0)
		make/o/n=(dimsize(source, 2)) $dest/wave=myRawSpectra					// dest should have data folder info in the string.  
		myRawSpectra = source[0][0][p]
	else
		make/o/n=(dimsize(source, 1),dimsize(source, 2)) $dest/wave=myRawSpectra					// dest should have data folder info in the string.  
		myRawSpectra = source[0][p][q]
	endif
	sprintf str1, "%d" , thisRun		// small bug, things can go wrong with run numbers > 1e6
	note  myRawSpectra, "RunNumber:"+str1	// not necessary but nice if there is ever any question about where this raw spec came from
End


//^ checks the run number existence, creates a 1 run todo wave, then calls sq_GetThisRawMS_viaFetch to extract raw data.
Function sq_getThisRawMS(runNumber, dataFolderStr, RawSpectraNameStr, sourceStr, [PToFflag, PToFbin])
	variable runNumber, PToFflag, PToFbin
	string RawSpectraNameStr, dataFolderStr, SourceStr
	
	wave rn_series = root:index:rn_series
	
	if ( sq_findrun(rn_series, runNumber)<0)
		Abort "Cannot find run number in run series wave.  Aborting from sq_GetThisRawMS"
	endif

	string destStr, ClosedOpenStr, str1, str2
	variable isClosed
		
	destStr = "dest:"
	destStr+= ReplaceString(":", "root:"+dataFolderStr+":"+RawSpectraNameStr, "/")
	
	if (!DataFolderExists(dataFolderStr ))
		print "//Could not find data folder "+dataFolderStr+" and so could not extract wave "+RawSpectraNameStr
		return 0	
	endif
	
	sq_makeOneRunToDo(RunNumber)
	wave/u/i MyOneRunToDoWave = root:MyOneRunToDoWave
	sprintf str1, "%d" , runNumber		// small bug, things can go wrong with run numbers > 1e6

	str2 = selectString(Paramisdefault(PToFflag) && PToFflag, "PToF:1;", "")
	
	if (!ParamIsDefault(PToFbin))
		str2+="SinglePToFBin:"+num2istr(PToFbin)+";"
		str2+="min_cl:"+num2istr(PToFbin)+";"
		str2+="max_cl:"+num2istr(PToFbin)+";"
	endif
	
	squirrel_fetch(MyOneRunToDoWave,sq_GetThisRawMS_viaFetch,str2+"thisRun:"+str1+";"+destStr, SourceStr)		

	killwaves/z MyOneRunToDoWave
	
End


//^ handles interpolation between mode switching
Function sq_interpolateWaveSameMode(resultWave, originalWave,kill)		// JDA 1.47G, added a kill parameter
	wave resultWave, originalWave
	variable kill

	wave ToFTypeVKey = root:diagnostics:ToFTypeVKey
	wave ToFTypeWKey = root:diagnostics:ToFTypeWKey
	
	duplicate/o/free originalWave originalWaveV, originalWaveW  //1.61E
	variable isV, isW
	
	wavestats/q/m=1 ToFTypeVKey
	isV = v_max		// should be 0 or 1
	if (isV)	//^  we have v type
		originalWaveV*=(ToFTypeVKey/ToFTypeVKey)		//^ make nans when not in v mode
		sq_InterpolateWave(originalWaveV, originalWaveV, kill)	
		originalWaveV*=ToFTypeVKey//		 make 0s where not in v mode
	else
		originalWaveV=0		//^ never in V mode
	endif
	
	wavestats/q/m=1 ToFTypeWKey
	isW = v_max		// should be 0 or 1
	if (isW==1)	//^  we have v type
		originalWaveW*=(ToFTypeWKey/ToFTypeWKey)		//^ make nans when not in v mode
		sq_InterpolateWave(originalWaveW, originalWaveW,kill)	
		originalWaveW*=ToFTypeWKey//		 make 0s where not in v mode
	else
		originalWaveW=0	//^ never in W mode
	endif
	
	if (isV==0 && isW==0)
		sq_InterpolateWave(resultWave, originalWave,kill)
	else	
		resultWave = nan			// slightly modified in 1.43B
		resultWave = SelectNumber(ToFTypeVKey[p]==1, resultWave[p], originalWaveV[p])
		resultWave = SelectNumber(ToFTypeWKey[p]==1, resultWave[p], originalWaveW[p])
	endif
	if (kill)
		killwaves/z originalWaveV, originalWaveW
	endif

End


//^ handles 'interpolation' between mode switching
Function sq_repeatLastNonNanSameMode(originalWave,kill)			//JDA 1.47G  added a kill parameter
	wave originalWave
	variable kill

	wave ToFTypeVKey = root:diagnostics:ToFTypeVKey
	wave ToFTypeWKey = root:diagnostics:ToFTypeWKey
	
	duplicate/o originalWave originalWaveV, originalWaveW
	variable isV, isW
	
	wavestats/q/m=1 ToFTypeVKey
	isV = v_max		// should be 0 or 1
	if (isV)	//^  we have v type
		originalWaveV*=(ToFTypeVKey/ToFTypeVKey)		//^ make nans when not in v mode
		sq_RepeatLastNonNanRepeatFirst(originalWaveV)	
		originalWaveV*=ToFTypeVKey//		 make 0s where not in v mode
	else
		originalWaveV=0		//^ never in V mode
	endif
	
	wavestats/q/m=1 ToFTypeWKey
	isW = v_max		// should be 0 or 1
	if (isW)	//^  we have v type
		originalWaveW*=(ToFTypeWKey/ToFTypeWKey)		//^ make nans when not in v mode
		sq_RepeatLastNonNanRepeatFirst(originalWaveW)	
		originalWaveW*=ToFTypeWKey//		 make 0s where not in v mode
	else
		originalWaveW=0	//^ never in W mode
	endif
	
	if (isV==0 && isW==0)
		sq_RepeatLastNonNanRepeatFirst(originalWave)	
	else	
		originalWave = nan			// slightly modified in 1.43B
		originalWave = SelectNumber(ToFTypeVKey[p]==1, originalWave[p], originalWaveV[p])
		originalWave = SelectNumber(ToFTypeWKey[p]==1, originalWave[p], originalWaveW[p])
	endif
	if (kill)			//JDA 1.47G  added a kill parameter
		killwaves/z originalWaveV, originalWaveW
	endif

End


//^ when you want to average across several runs
// sample uses include findAvgStd(MSSClosedBaseL_p_d, "ClosedBkAvg", "ClosedBkStd")
Function sq_findAvgStdMatrix(wav, avgStr, sDevStr)
	wave wav
	string avgStr, sDevStr

	variable idex, num, mz
	
	mz= dimsize(wav, 1)
	make/o/n=(mz) $avgStr, $sDevStr
	
	num = dimsize(wav,0)
	make/n=(num) temp
	wave avg = $avgStr
	wave sDev = $sDevStr

	for (idex=0;idex<mz;idex+=1)
		temp = wav[p][idex]
		wavestats/q temp
		avg[idex] = V_avg
		sDev[idex] = V_SDev	
	endfor
	
	killwaves temp

End


// sample usage  sq_FindStrInTextWave(root:index:InfoText, "esolution")		// find infoVals containing the words resolution or Resolution
//^ added for general diagnostics & trouble shooting, is not called in any other function
//Function sq_findStrInTextWave(wav, str)
//	wave/t wav
//	string str
//	
//	variable idex,num
//	 
//	num=numpnts(wav)
//	
//	for(idex=0;idex<num;idex+=1)
//		if (strsearch(wav[idex], str, 0) >=0)
//			print idex, wav[idex]
//		endif
//	endfor
//
//End


// Copied from the Wavemetrics remove points ipf
Function sq_removeNaNsXY(theXWave, theYWave)
	Wave theXWave
	Wave theYWave

	Variable idex, numPoints, numNaNs
	Variable xval, yval
	
	numNaNs = 0
	idex = 0											// the loop index
	numPoints = numpnts(theXWave)			// number of times to loop

	do
		xval = theXWave[idex]
		yval = theYWave[idex]
		if ((numtype(xval)==2) %| (numtype(yval)==2))		// either is NaN?
			numNaNs += 1
		else										// if not an outlier
			theXWave[idex - numNaNs] = xval		// copy to input wave
			theYWave[idex - numNaNs] = yval		// copy to input wave
		endif
		idex += 1
	while (idex < numPoints)
	
	// Truncate the wave
	DeletePoints numPoints-numNaNs, numNaNs, theXWave, theYWave
	
	return(numNaNs)
	
End

// RemoveNaNs(theWave)
//	Removes all points in the wave with the value NaN.
//	A NaN represents a blank or missing value.
//	Returns the number of points removed.
Function sq_RemoveNaNs(theWave)
	Wave theWave

	Variable p, numPoints, numNaNs
	Variable val
	
	numNaNs = 0
	p = 0											// the loop index
	numPoints = numpnts(theWave)				// number of times to loop

	do
		val = theWave[p]
		if (numtype(val)==2)					// is this NaN?
			numNaNs += 1
		else										// if not NaN
			theWave[p - numNaNs] = val			// copy to input wave
		endif
		p += 1
	while (p < numPoints)
	
	// Truncate the wave
	DeletePoints numPoints-numNaNs, numNaNs, theWave
	
	return(numNaNs)
End


//////////////////////////////////////////////////////////////////////////////////
/////////////////// PICTURES FOR LOGOS /////////////////////////
//////////////////////////////////////////////////////////////////////////////////

// PNG: width= 177, height= 55
Picture manchesterlogo
ASCII85Begin
M,6r;%14!\!!!!.8Ou6I!!!#(!!!!X#Qk&,!-B8d1&q:V!)Q?g7J=/?bfS4jNKBE>Y5%eeZ*LdfP=F
`skcJ]3Bdf$Q,aGm1aMGI.in3FA7\#?/I&;P.f%&G[)2[nNo'G`1AKcqtR%/PPJTE`2JqJiSV5N2,h
sT^so()Bg/!'`1s*+PXzz!'g`%!&XKa!7_J:G;$bkG>L/'!-hQ]!-hQ]!84g@GBa-%!-eMXz!-hQ]!
'g`%!-hQ]!9b4\!$M(M!$hOE!/rE&G5qUV!([P4!$hOEz!;Q=%!!!'#!!!!4!75Bq!-eMX!9O7]!!C
7=GKIf$GMpF;G5qUCz!4[)@!3g)P!0Ch0!,Q9az!$hOGzzz!/UF`!'k'2!!XqJG5qUV!'"L*!1`it!
*EkM!!XqJG5qUV!)R;E!*EkM!-eMX!-eMX!&46^!*(-9G<c?G!<<*!s$6Dn!$92YGM!-6!*EkM!,Q9
a!*EkM!!*'"z!;Q@&!*(-9G:4d4GQ7^Crs8H6!&.IKG>qW<GE;k(G<&_!GHb]r!0Ch0!,Q9a!!(sUI
fKHKz!-eMX!-eMX!-eMX!-eMX!!!!4!!`K(z!,Q9a!*EkM!!*'"!!1dg!"]//GHCTQ!.anY!.anY!*
(-9G:4d4GQ7^Cs,d'i!$#-DHiO-[z!!*'"!/AhYG5qUC!!*'"!!(sUIn0Q.!.Fo&!*EkMz!'C8^!*&
e-!"8i-!3lJ9!(7o6HtXR&I/j6Hs8W-!s(kFt!*EkM!!!!4!9O7]!4ZYX!3g)P!,)BH!!$kK'dNbZ!
,udf'`^\A!<<*"!75Bq!,VKE!-eMX!3g)P!4ZYX!$D:B!!*'"!/q-q!/q-q!&XQc!*(-9G8MY$GQ7^
Cs$Z_s!1f6RHiO-[!!iQ=!#P_:!/AhYG5qUCzzz!;+,r!!?mN!6!(r!!d0R!!dU:!<<*!s0u\X!+*Q
2!!?mN!#+]?`rH)>$#iF<ErZ1M_Z0ZH_Z@erW+5l."uSt?5u`*!m?qaNlR30r'2^&\!kBlq+&_n6s)
MHc884um*N_/nN\o>OKG*<-0ufTPcGs9=h&l0rb9-9Kb9-9Kb9-9Kb9-9KbHE6nOS4uT3grO5e7^7+
U<_WDYF`gVOF%^iZGDUU2r`b##jn`*culdt&pdP6!rpX<hMGfHKMu3^*U'J;PJ9'IS2cR=JI5Zc#qW
e7<mL@7DU/,/fR5Ra\%T;3:1Y``+2Zo)X9LVrS*U8eA(N#["a6sZWnKjF%UIZq/D]gNaieemLLo/@>
Gc2i@;rNQGjt=La3)"e]"!(@0.E<kb\a!#ij4e=Bm4-MG=b'=0:15Z,_eKWT'S">Uj#mTld0c0HWUb
g7RIlFJn@m6H]2M`#;J9SR:OF6>L@eQgr==np/ITaid._6]Ju36k&F^4NatNIEk'!DGdkE2SQEL).d
T`sAk%5N20;aZ&04*e5tX-B*TooiPbsF?2U!,!>)\J**6Ht>7SE);;o(_2Viu@oPV!GQm,CQa<$sD*
HEBqt:Y0h]*&;LZinOW6fuY+_1;k.[3F4TTf5Pf9''%s8\8u[Xm+q)GRJl@H`=r^&?,]9^/3XR';Vi
]5:NoPFiH&Hr`/HTbmUh<K5eoec*Rm[)^-.<I'<7,3@ZR=O.1`f_lrIUV`gHnH%epooM<g^Ijj(p:O
Vi@/&)Bor/SA<'&L3jg=G]$U[D_r8+,_@uCB9nOE*:HsEPsY]Yt)_><`k?;2t>gY9YBmfoUBTO8`Zs
1jbmrC[@*D[J"ff0TE."2rcJ*/ianoEUAJmaGr!FSfRp(AEHS8mPBDag-=.bQN/8o\j][KG8HSW1*4
d<W](InuQ:KRH0iju=UO/7Vr'I_#O27T',t:AoCJHpV__i+.fY`e`@e5PgT;l-kik3JH#Zu@CG#<`3
*dP]3&dRbgb@nck*mtZ'P:"+RZQ6<F":#Lpi>>.0c6JaEp6W,jT7+A%,d(#'T0ri,GbtV[_9Bj1%A$
G%QqY.31EC0GgE#cH0if36DISRXh%Tj)hE0OZZ!3%S+p[*Ta)Q-D?MH'Q+Lb4WNpLBN8=Z$Q.k?[(l
TSU?f05c[6:E00D2"9B&o``W6-8G,4akQ5O\>n_];4#T;P.R1=s5&[Fkh,Ko),Ib<h;ecJUpn5U7Y$
XM175*8Af[+/]YH];AqWRo/;UI"'bQSP]KUpcgu-V6o5G#HlT20?MBtV9T.[=YD+hK@])-Ri:1n3kF
!8Djd!dQ!&)i(;el.>@YGi61uR.*`60aEI6_[#+j1BC%15c]#r^2\7[2j!3[RVF0RaVEo"cS8XXfX9
.h?Dko'.ILi@uhQHJM!XCMp8ql==dg?0XefE[M+WG]fncS2gUGSCKcCSDZYaB#(19YS?bjSksM?9%9
^PS-pBKA5:8cDPnIAfm2^`g*/2S/3BA]Ej7_tOo8;0]"0u$ch,d`Uu[N.F_=`jf*Qk[PEun1<inf/D
f0W6o+($/EV'GN!$4[LAK@e3\LiS+k*`]B@Gj;;DomP+f\U/tDnQa*$/r-fq9kd!b-kI)F5SQ4iD_4
Plg5C[b)&I\5Xu$C>UnmjTc$3i\$B79U*+A5NsU*IGm*0ak!:hRO$<Q8EoU!hR.iqPAi7gf>YFo`1L
H4c3_QM-dm_TnP".%HE^"pJlL=OAIYJ^:"m(Fd&]FIC>Zr6l1GVtQ?ha,P&5sT(:^&\?8fk)pL:VFN
CV1OiRYMbE7cqt7&*c&PRsFIqr$L<]36kBF9T7FLJ]a&b+e4ZP=3YYQ$lk-3gA'U\@496KM(o&-rJ4
r,k'Cm+-(,L?@j?8'@N:fH/1q/-HjQb0UjcZ[pfL!HIP<P?$m]Mg2k]L:ZuB4F8KUmJ+HNhC3@7S;+
\\i[pq!;o,?Ake;ZsOCpfg[kVE3pHM01,1*GpD7"u_a;D]'9n,9V*h?OQZB#$u(CQ</=CQ%pQtP;?5
[l6-"u.R)&RY/L6Z&9\T\'c(F/29R3>YV=8pX5-mf4BCQIId-"LlK_=FbQ"d1QcL9=pWG38Y!8ET)Y
k3;oZ:6s]BQd)!!!!j78?7R6=>B
ASCII85End
End

// PNG: width= 103, height= 95
Picture MPIlogo
ASCII85Begin
M,6r;%14!\!!!!.8Ou6I!!!!n!!!!h#Qau+!6t"=JH,ZM$#iF<ErZ1J&c_n>&cpG:If'0G+94u$5u`
*!Xh/4e>hPD`aPSfr-=S;YC7,?AHM$&mCXc86lZuQA'ru#*hLGaf#S;_E"@.P=6$R;R&DfLcHga7FP
DSqohRrQl2'4Hd,-.Yk4Y:5U+M^N9nuR33fmE+/f"Q[\?31Z<"5*G<k9"Y^#0+Fr0m/$4\o)q*R\g'
5'*a(<?imVF)W2Du!rRRQYQ3SbG;8*0n:LN<5MuS:K)5^Q!"'8EC'juTTK9$k21U9uBI5-_8K]tt,7
k%^Kj]Lb$ZPXh.fZL"L#:pthAjE/"sF*P"$_8C/i\Q8&44o)K2IU_*A@IX+YjT1!e?3W/[r?7CojkO
Z*:bnmsSL$gG^cXMTS!6?<3AYFg^rrc0n2P+5dr?"&-Mg0SIfhrD]YeN#OHF0Fge^k7ET)&]%1\$Gg
]lnm?q=$d>6V3'Vn;>em"?TW0U]B7L<0&2J2sN%MfBH[5Tj?1mlg;;^6BI4Zom-L55hBlS#rmCWAS\
q.ThWJU2kp6Y6JOt2FYAYf5M1@-))hnPSBOASq2ZF+R/oi"f^0jTP<L5GM7YH-C18g'MZ9Q:!W`:m>
QIR;4<ru<ft"QR(r;[Adg$/>X:ZSE>(q"FS4&$No?Q#sM00$V_7*:=%0%Vc1J(F&rG"p2T&)@?PDTF
UHKaZFg]gU8r.?<_D(r8H`bO4$W.(A>0<9\$p9E)k8HWIKAQXS$PXX`41#A%a"6HPF5>IsQtdJjS\Z
'"AHG#!@KRGYZFC>HZ"94@i0pl"E6.'a\i!l=*-c]\jD6!:6R(!.5=f>uL`iBh7DWe2kAd_%bh&_i\
/#EB>@,/2"MFBOK`d#luO6d8^jQefk8WAW/>R_#Se1\GeP70=$W5$;LsSJM74j"UP6RR!XQehUh:=e
>"BE;gT<nCo/BY114Z306dJ9130&1;b)1?963hf,OYj5HKJgcB;YQ<B3(%RNb'X>8:ZI.):/C):k;!
;pK^SXUQi^/M6SWG_`i&*;[n=^qahZ8bfZ8?E.38Qr[2Z*@3&#CkWjq[+#@b%mo`l-r[]BI/U>H]/-
0Wt8q:8fVkJ&+4@<m77I?*/;A6cmFQX_eh7iGBp/]3)HS8=XMt8-!B0K!a$@e1a2a6Zmn4-P(_IHn`
<crU]DJpO""$T>Zo]q-K$eDpHIlehA8UB+ceqQQD,YiK4!gF#6fi`##?_46H0i#_SK_;-0O:aG!?WC
,((`rBgT[*jOe((diEOL7:QsNsD/LoapFN!e1[ga!<@g?3IZ_La%CkJsC4!AX6hg</P&-j@ma`]eOq
m#i^hm9dP=/)9kNK,E#C=n^O:;M<C&9*1@WM/[IWf-W?2@g8nQl,tW!M+9Upt5`Es"mJ[:]M18W2]m
nQoVYQnQ'a"lJ&cqOqcj0a-i-[:.Dg,V]V][r=nc]VnTTfB$q1m!KUUh+JZ#Ke)tnHT@1f>(BFfVi'
G-`'QpjEltn`_4*^eG[=kj&5<l^qQ']t5^3mfC@O))XT:A#98;MVXZ#Y5b!%M@V+l*,@(`6bT&H3>V
0DpP>#U+0\N"ArfPu7\i#WfITp\hd0'qMHb=dFaI!Ihjd:2LRrdsm7">VjmEic,qT8lg)rJK,("?:#
@!Y.K$qkG',\JR_i/=^:<+bX\W@*#iWnIE_diO$R$d;S\RPff\T/A[OGo[tf0j8d`6u\2>jG&d(,_G
Z++h4@je,GeEKVVU*a@^cB3V[e+X2?\Ngb;hG"6*XH]cP7%`]J6Pre\iOcJ6r!)sF:743Q[fOS1VKO
T9%9(&k(XOJP5ko.$e@L">1(pdB?\LK/VA\(Za2q?#TWX;S\q3P&/:4ViUsUAN]%^3!tJ$W]t0qfID
lB6H0dIg&kY2g]nDc'7_$`O!"sP45gP_:7hZurrLANX'`b(;`9fc$_\Y;NVtVRe7fX3!+Z/+_GK6Nb
pBHp"4V62%8%.";-H/2&b+CiLHe7.:\\7)0XBK'l[.lT5G#NT?Ei=\P%BXVdUo^WWGu;DYWlh.8]WC
Cuo$39KUP"tu_sr@b0Als_#C7m*H@s#)(5a\i)j?WUK9/'ZFWpf[V^gY36ONqV*A)bbq;U>LX9!uJP
C79ec\ThaDus8MAs!K/5qNEJkeO/I2\-As*<'XLj/*pf5TFO4]#!5ROcSc3H;:l0$LB_l=iJA'#7"S
T,iFLBr?'YKoX*GuIdoA3r:#48r0RHUi5RF<anKj`hL1rD-gSahgfN*7,lQW0Y5Go4Qi:smQg"!lU7
pG$OT?ErN[dP2^P[9,Bd]nh@/qVjKQ>)K!"*C)5g[p/V=/=#19nRQ-\cMmiU8\o/,T,K-P;k6R-/TC
+R$b`l?@Gj&$@NhgM#VZ<F>L^n-:3(b9$21b)1oO^%B`^)_i\#p>\aQrbM;B^U\M:]Xk=\EMDE"UYi
=@,J+cb^l7V$pXpnrNd8n,H*gSd0jcgtH7/aC^Ua?]V8SaSR^*b&eIOE5G(Q:s+:G&4aI:BXX@,FD:
^GGLT;fTolb3rK^3Y+,!9Cf"r!u`n=)mN`Z=&,V(68*k6pCIOZK)8Gi4H#]WikLXoCrLd6#L3"T&TK
rH[oUDS3dYNDEQ4hqKG/2]_V+ee_K4R^t$$*OYtL2o6&%`EDbVJ5Q!_9nb(u<bOI<:s7kG85)Zq<*.
,:O.r2)im:^R48oFpGrYThEhd<q$)YA9b/p#JA'M^'L;kiOqkM4EX!!_IETE#^tm5G^=55JPGVcLt=
6j^W"LFetRJj\`5174Dr%\c+6*ri[BecXk7Nega/U%ao+Qj)6,PEDGjl%FYYZ%FViKFQ#iD>UrL>F1
Q6lBeBG][!&8p@%%90?$C.<g>Vf9FPjB/K>jMq`KXk]IsMVh2\b8^#&/LZAHDrWhOFkT)A.?m7-f-H
[2fXlY@Jj"9b-dK$2pX0hMJh)/tle9p62T!PI?qGr[=Mq%BSdVaPJJ39?*>pA;`6hu[>O0a8+W\-i"
^>r@^@<>+mQr@erT!cFZFI,sFrVc14^?>p(0J=V3D\$_o@H1#G0o05CLSNkQ7W;)t9PlLR,rP[]IiU
o&M+9N87(K:Vb8i4O]J,h&A"!6A7r"pWg[]4Ue^::qeIq/);OB&J?!-gd-JkCOo&-:'B9a1X<KPD,%
:k3]Wl1N\bL62KC63VJH"E_clj_)p$Z[KO&!(n[W'Np\$-UcS_r6<0XlV<oXfKj0:LHgNK[>^/=J4D
<&@46X:(dHmS-8Op@#uO(8_s2r4n"R]u/'E\!f6j*D">iAP65<`1%i?Gs5rl93)$L]T-R!D4)XF:Jh
Tnl4CO0`<c,1>8n&NH=gKX50>BZ7hprCWRa(^ViKb3&_i37/-^^rgJ/-,6LFmaG4e(NbeO!$32#r$l
b_:W[1dgKC\!&ka++p]00m;?)o@7QLapqTu0Y.JC><BXW!mB)p8;oaW-;4.q:fDa%65K?e=:3]O.9&
BQ1Q8#\P@3`>b(k?-p;o%<F\Zj_pab=2k'F:'q:l&,,4eoHcCoHf2G34D6Pu:PGgYV2uQJAX%qO4qR
]PenJ]+lD,QCOb#hPh?NC'4Ts_dM7&A?a;#P(^Ja.k+[!Bpb+rp:Ii2>QCWm9gAp>Nt:)@I!S*n-T@
PLF'BU#1/cqucKspTO,YEM'N>V;GAf,6^\;WYl"Zg`g;=<(mq/H@SfYEG$NW$CP%GU@!h]rK@>7&JQ
s;&0l$sTBLhL?AH56VN]`-4GJt0?nip>7Y9gu3()m'trBV(di_poj8S*IH[T',ofGMR-Wcm]'P0KIU
]Fi4:DPUN3j:>8Q?*mX4kb7L]3$6`d$]GC]Y'#jpdTcY\6.o2drDQUL'klmC/Va!Y+:ET$UJ./s'N^
<LP[f.oG<_PruW:TM6K]n)H,!/I):]N"^XI!?4(.*!(Wke[<M#!fuMP7b.F5r6!o5fd:Z6K<d:.A2S
hS[q_%pu/O"FY@bj05oOZ0b7-0R(%!>?C,K$j/J!Glln(Kru<o#bra)-@06!HV?nt7opGA$*6XE%e`
#20*jg#M$^+G9n1cIe:[gT9:-cVYa9(W9m*A,Vjco2bR\NZTqBdII`b3K;`m!GV8S\]Y6S>S:^o+3+
I"\!WC\3t#U+jt8e'$U'OF5_o6DjAqhmpiDn^M%7&APId_+Q,KogLQ#ulrqXp;Tq-\l]P3@je:9/j0
r>%r',ine"W4GS5X9aP6uTAc"X:,Mc9AGFs2L'jUV-5YgB\G_*0$M4nf!t.arm$aDcR>)-WbtVJl(;
6J7mdhEFb`1tlk5YA?:606RV56)Ekfj,78O*R:&.AOULB'7>Vi202!6,%jOA7(HbIZEZ<.E0`jMfX$
YgPI!j8JpH*ujAjb<GR"q-8PVCLJ*[gHhHSdOZ^'-kIeBC-(jo'Z!L/A*ajl1:]*T-).GjO->1,RTH
=S5t3\]Sp)NriY8n1<F-Q1gu#[Y*PUWT."IMM:Z#b#FLRP.G2?"ibc\%GlL#YIh>Ao:DnR3*CYiCo2
E#s6FlX14!_*41(q<tBERmMXWbG9pK*W@%^9bFaDPjqIo)LV\X5Si@\8Pgu8!U`8nht8oB@A<noYGE
MDYCC5e,s-Y#?FQ^J`WZEbi/])agQ4&&Kh-)V%h:l,Yh?IC3/d_HafQ'X?^G1#33J;BsCeg2dTIKjL
hO5;H!VISYt@/]!j#3:I/8o8"n<)a/uT4bWAr\[^c0.FBHT;S/X9j7aG6u#0qp2J.a#m8kfs)JHc6o
)]]eu?HR2))*6P%)<m3_/m4E%#K#\2?"fk!n:H_)Y=3'93)W*b_!8.hF5_?!jlg&TG[4VSWBsL5![\
^EAHnnV\CGEjR/-)K7e:$&"t6"(hsVon'SpVJF#PCoAq/F,XC^e$8S*Ur+@.+MG_$$Rm9bA;:!;6W7
T4/%<QVB^:]O-i"f!bGQmMqp9q?kTJ->-kjIu7C`lZU3O5kM.g$?)d\B<gMJGZ)gQ1f;VN=;f%T$%k
8RCVQAPlM&V"8pMFB5NDac1SPE&q5cLs3pY5Y!bKtF#*s_!!+XjbF#N`0FF`iZ=(Ap'@0ur3-E1?bh
pMH(JMWjf\lVKO-,KO&.3BPaEJ;h9cWME!=shoE'ct,c+]g8534o;'HKBG]kQ"gP;>ZV(^&ro"Q2[e
O![NX-Ut%M@B+ccGX_23Y:X@o2VcSKGudrW?_!J?goqUe#DLg9fj<eW3#0EOLf;Y&U=N&!6l5#m:3u
cG2h+S<XEc`\qGVe6MjdO*;6Bk\M_gn7$t'-A0L18P3-?,(%sMro*ZsTr.emq%l@=rDP)e+Hr7h9?&
=D2-^)A#sYD5l@H)QC>jl!]_ps8\Q<_a,@p3"C9^34Rt!eq8F0ea)\-IO^>O<?%2+PQ^T_:4@*bkJN
W9Rg5Ppp.HEH[WGSICZl$jWNIlE:,)!YGu>JC!"EKM6;"Rc!?6ga_\%![dDVjO8hFgY(l%N4Y8>.m;
1(H.<C,T!!.cJ";5*T$5NeU7V.C&EA9W*'/G4J_1%#8(;__L>gD[/WJLV.$rlk@5(/pV4u;lCVE1op
5,\BcB']=Y4h<d(\UTKtl'e/D!L],B0B1oK1L^]#K$.OLRbTVZ[HOuA0$PbDPbbsm/0!h8#!"B%cC(
XB$hGuVpG5k"n:"nreITkE+2m<Tq;^"trcI2cfZF-fl+t("oWk`QFY.P8iW<Fc'\O2B8u1#Y#T,*2-
lBFLU]pt<o%m@_2:PdB/,RTe$is[(Y=:^Dgto@%8+`:PlJ_`-;nH>e*P/rsn0YfO]U0btZ+#023rCZ
W):kPd-nt]3E$ct6$\:n]HW$MVCrF=bBm4c)<FpJ^eY:[C\N$'_s))R]6Nofl]<8;sW<jY#ZF=s$3B
jUQTRCtAO#O7K8W:>&)d+sPYbOcR^_5"?k,,^;a$P`R>]9_h_9[s!jilFSMqPS#%7b!,aaj(F:(@P7
:k66Ps/3nGX/@i^E1+_R\EK'g/ICo%k%2aGr5\]d99ps^I-=8(.$al3lu[2Ul4=B^$s\R,BN!=#LOt
i3NeQ/79e0oCaDYoi.*;pEO]:2b-3FnD3\\+U>1M$g"<ZFV\sAZ7[^CJ_?9I$;3&bXBj+[foC$5n3<
u&2QW5(q#8Tf*<?e7-SLk,;hih:spV-b>J9Q"eHo_:]P9`7+L&,=r=rk3tt*_O(uS:orF,9P7a&$7>
a"^#f9rZ>4VCHPi4/';RtSHo6GV#i?,Bl0`m$j.[V5/"T$@;Yi%];i<Ml'C"j`1iu['AL[/XaP5sD0
3]hL^l!&m_5fQGA+#"62/(ZoT$WX:$?F59=H[JcT."K&/*nUc*#IAp7\1GJH7tYDC%+n1%%n*$6^a(
#baO$B-KKO!#Nu_5:>1dpRcA2pN,nj\@'.dS""[#ijjg_)R/Ti]bMX$,P_Fl6e;NDQDSL(s7YT9XbZ
5/ihL.Ip8q:`.2@A)M92.lKYSn,\@q!W),519l#kNP$f>jD!?3Dm454o6h/:,l!!ah?KmC"Bql1FEp
+j0mF)bOZhT8BJcHk1+^",@u*q/hUc>7bG?I6O-3L_2r"<F#'p1gU';a9@d`A!"b"9AN7+:*.h935U
JG!/TH?9d+gJ[o_,?8^7(/FR]m>_/9sft&%?1NU'-daXYOPMJ2\=O>mt%rmX8h1rb@-I1uH;SXsp!1
KTc)*Z!,bLEE`FugFP:P;k7fR*YKMn8/Xp>u+OqV'?IPuCiZEFq#6L5F='oq`[r1"F8Cqo+'[+naNt
Z/KVJ>((p.:mmg=LV#)1UE`-t4ktmDqmrT20aJg%ReqGuGIGcfcAQZBB:ZMS1I<[fbHr2p0oPoj`jp
2#4VnB/3.daV>+bE#g']BM]!/Xar@5-lH!tlGf.XWUW#4gs+YBj6J*g-MjLuV@^;:3^SIuB*",^;$8
ig-'%sJP`p<3&?.FmP5/Ib^4rQWe)$4u-##5VC:o@mJE^rn*\rp]Dh9MNVN_f#F7&H/K$aT\E/jV#.
EHBS60o$+eH(F97VLV%Gu>=Z'+Z,&Q7F9&_[D1_iH*/&>>KE)7uh3@[Fo/$6RFRgqW(Q_m!R+GRZJF
JtQlgT\>SC^M%I1W<R/cc\/HGW9pL:tXb`e<g'JInTHF!eE=R3@sAc%5\YJX-&jp6Nq6WmmL.Z4B+A
IeQIM;a3IOi354t&Hlp)Q;q:uX[r%ia-F#bZK^=jY$QUCd^Qi;kJ_KIe%O9#Wq(qeZ)8IR%0O:RCWe
A(Mg!kc$!\5sa@KH^h6,S20h)1rEPnTffr^o=(^21(#KVN68So])k';=K.o&#kC/o9!qe?XT#\Y;#M
TsER!`g@_EE^rNFo?GTkL&FaUE8g&Oo^r7KQPJ]k-e*jI<*h,e`subYa9(#"5O2U5GCX-e9KHl\BF^
]Y`eGJdJ]-HTTKCrdMcnF6!?2`0.4e8fFMH^ZBoE`+`J+If\N*$>A`ZkH/IF\f@b$LqK5%*FC968Vk
pjm2@MqYNDPP4>Q*1:3:EakIN@UF)(OofIT9Hp9!o3a]<h/e-gO<)]F`,P;VU)u;H`R=;KUO\etp<P
<PM0e;m[]&_ej-EHQO3H5.JE!g7':,??WM*j`e+E^8mj5+!2?"?-kr;D3u.h+6YoL`mDQq`MX;`]%"
I)**o!lIX3\Z57G_+Fm+\`BT/o;n`uVn\9/K;KSn]Fi'Gi5.ka!WH4;$>at+QhSkH[rgn)BqT+X@Fp
U.MRK>&EJ81;XRJ9e(JZ*AU6.=PV7odqh-<ED)>NP$2Lr%9_(o4[a-`9<&Ar=HJJR$J"5]Y*a2^:J0
!l@>h0I@[R2lZ8N\)lL`6]@uCCO*s8^Io#IqLSTgeVRaePTB#h4a'mX=$N]G.S;^&&d10"pAgTHs%p
B+Z@,/mQeA=nY%YP\,8r-/4f?iHse._olb8N[6!7#J7cL]DbKUAUlD1eDT(Oj=@"Bm.,+/V8HJP!YK
ci%oqq"sU?[uL%g[Ne#@)>*p_/)POjXFHQN1OQ\aSX8RMqf1fc`8JX5HuWKinm#.#p=.4`XtK0WEd;
$DXst0n1c8')]Up5q+7@<eWIL$&,,M_1[Noci$SM:HG4:H7Pu$:LSS5;[Qm%+_#[mcg(q8(/!d;?)"
;K-T^o+0B77@P,efUFTnULTJ+:,EZ9@ob!flK/%c3fJ0&Kl$9!4H?$\eZB18<k=UV#$.5*e%3q[L;'
u,[_kTq7eQ\\c6b1XS>N-_PDr"!sij0ZG&B(]!N5l5C)iM4QkgrbB>)RFhbPqZYf?p`e*TVW3`ULA8
m;Pc&:%,Y*5L;UA@*W4Y=mcKA&Wc%-bAoGK2nM8a!IMo<X1p.Z=cAW9Wm5A;F*>QkD,JTPo("qs_sq
&ZrQ+P8=5.WNGt9s*4!%#lH24A\m`5Hn"XFK'V%sB%',Vigu0HXZO<\&2$^j%em\_EkcF:.(-0@Y-M
.2!eNIh;:O1`!LE\eSG'sUZGMJ04di^CBk>6gWpBt:QfcJ;]<^;.Er\@-/*jJoTd9[$R#&]?r;"gZ;
j]2!qp1mO],d4382U\R:'II6!+eJSM9G(SS=`%9HBu$)c>Td+3#s5B;`;*h,Lkf6r6?<0(BtEP`qD<
?M@<G0@hmuZS>tK[pihee%W8KH+hXI>q/7d03\At7MZ"g$[OT#(nFl1T525M%`0_Remg#<$8$X%J[r
luDmu/^<IG<.S4kNgp2"8.#cXpj.n:?RapQHhISLo$SZ4B*F7]9g*-F^6<X/>eqCfLGoD"DUQ>2^E'
OH:S#OlTJlK6%U@#iuJV<,HG`Ao_U*Cghe_j4<(dIIH5bA'A?9b-[IoaC&6f>QL:k8"[Ff<Bb1^J&Q
,B&H[IO,,oR.`"/OANPgAZ;kMeJ=`iB'W[an?G3UDErmT\=Z\nMBMo=$ANsiCkb/)p^DdEn>DnbUQI
FVT30)HWYCq-%Lo<UrE)us$QcEu;_VRaeda733O^Sf1+0J@)NHtm^S2=F72I>pmbJlJ(Ye`*=ATRr^
`mNuA"@B,RgF`$1.TXDO1U-rTmkF?st>Z/_H#ZitnK"ZV?SR#SK;=YHl>X3ukl>03DchE"p^fF6J5D
;>U%!kjpMl1d.S^^mP\GmN`<kCJb1XH_<Pa>QVFsKVrr)?X(DJX%'51bk+Z"uWRCM@+]SQO/5U=493
5,N+*WFp?fA7s'u[=VdI?sSQ0e1`#HI%tG2Pu"@##[u<4/bTieo]+'`nEc*WY+)@:i;u>r;djC!'Mp
as!PcQC[nMc0Jm1:r(H;G/&B!7<5<OA\&uH'sWVJM*V6m.1ro>a5&HM0L4KBn.j`T:]qtSpe7rcND#
9]4JgOhF<PA;\S>3aS;bDTSnG27$N:]QuY2,B9'k%A%IqIJ0+gb_2UJ%4rY1rtKsW!V[X;S_?e2%>`
^!4loI%2@)@e3f0u7sB)o\$E9TUFIaH#q1OBiB21=0OY$_i(dSRmrtq\g\)(l[ss="_[p9=jL^]l1U
48p[G(9qqB)T4=Ee'YYcgU*PJ_lkm8CjA6<[mdS]k%<0^X)Fp3.e3Pi[%r%W&5tG'>V,lie8jJKm%:
dp.CaH0h<]Qat?M:.Ce/*oPh:Rl+YYQS)0,[N#n1AdX`C.KlC]VI^a/LhU^<9j<N[$!G[_&SL3Y&M=
n;LX*G(8_:mopo?4j<POQX&PdlWOBbiUWk-F!bogu,.6kj@9HWU*+@8?ln;!<`l0tE+5J9Ti#^Pn%^
>*76bJn"#D>E8WOWEdVf;dReS8q.6n/LN*r*2Y0Mt`D[4%:V\/$j#?G1h=BgYJ\m=R>\/'o6Rq;)H)
h!?j]W[ks`kY@mIjE5uBo4kQfPDtP'\._*d+Y)lis1oGp*)W3K[\<lFh,6K]o=tW;Glc0l=&.AX0'4
]Y[\e=gP>Okl[_h=bsSGHEu@/FsuV5/'3Q,\mZs)d^!l1ArJgh?\#hrDSD7DI:XiLje"BBRdeWX_":
_90@#U?\c'P9U5jes)!Gf2774J%5JVG$U)-HRYWR-3P1EenT<_Zok4?8Kja]'EP.aqFl#ri9HmP+'t
D&37T-F_AM5S_NK^'jWVDI5/4T*_nFfJ-"-!"B6adG(VTqeXJ\ShYG"BrVU^b"+.B2?QoR1:)#eL)F
]q$-Tt8"Z$%<5Qh;7emDu]`aHRZ&kc/1arh`*\p5;nb`;#ep\=-s72o[N1iYhOT"O@<W=,_&p>jqcQ
$-U]meNV4sLHO5gjBs@_7"Z;]jbQOSRjATh6PU.!i+RE8cmT#!s)HJCkj[Y[X7"E-"/-JL/ApJBB;8
+T;!F[\Y8aH.O:Z,1X!=GbjoB>,mN8tXaGQAUKE`l7O<I*EI^aV'F&4]EDgXCK79u]+`;1D/rrn!M:
;UF7.l?2q(9.ZD9ZO!#]aU)tL#JZCi\4+sCb+a`VrMK+Iq@EO2C'9BmZ1IH"TI(<\S,sZQ_UK#%&Rq
U=Ft@p>g09/:Q=Z8"&;+/;+;bsRj35L,GB[tcXY'dFTn/c(35<CGh#NjnbikYEIK0,LVQ$h!:`%'1'
"f')^L_#o%lb^jQ,'_`_?E1c_:JYe$FEAm5uc,/+7EP53AnNgB)F;X*_u+k"9BU@ML]m$A;Gc0.tS^
j$l!o0FDn:A+7Bqd[Wm=k^7MY(B"K7d&?=[>2>c)"1P_qH&7FMA_&R"*Y1**A]JRPE!HcIX_T99^C7
*KN]Stu3^/'3I,D#.lWhA\ehq)i4P_D)\^tU5,D`iq=2FEc4US>O#An'PhWS0XN*67k<D$Q`#ihPe9
7h<-bH+4f_SMe-qB'j5eEm#YF.H7AcIUW^:04d)lq1.s9kmgJd5j.K%;I7Y7_kmG86WXP%J8Pp<:<I
-B2$>]XJlFu*3o?/9l^Unh\h(0cM]maAbRjQ8e+&bd[l-uW<'UQ;(h%qda]EGM-Dfo(Sr](kbgcQVH
AhM<;a%BF5I%TR'WeO:]mFgG7IkgJq.N_#q#C_'3Bg'Wc(3VCdK#[hj'5:f0l$B!qgO#u;3B\aZYQV
>pNCA-jo_+.hM?K?nmPtX&X'4>.8rP69@:*&+_JmHkT(Z^St,`>5dXXE._'WO)$EURIf6:J<!)f^\k
EQ#Yk(N(06%%9KNWFE8BcUWI1%i4+s3pHN_bJj#8Wl=X3[N`qR_X^3[\bLK3N-C@Nmtn1>l_#_"m'V
C/S)u7%"B19LpL1q-!/%iZ^p=Ggc1^7B(*?*EcORY/\0!h"/)6<**Ur'[H/a#Jp@jqD_CR*=*5$DlO
#[nDnh6H'uS72@6_bTLPk'KHdo-"Mb5-k,pfRgNC,>_(<>-"Umj,UL2p^/hi23=uHr;/8n[*>>mq9b
)$^NJ[p?jh9DR`7[/>bZ%5Rjls>U,r+'K*!1OV4rZlmYpt/JX"-e+Rh5.,!J\]"O]<K'M-n.^h>).i
9LPCCIaFYiP$:I/+9nt=,]K#3,MqZ"=J^pUM_k#JOXd/kPrlNRCd\;bnDNE+ZFYK[a"^ma>F<CiQGH
c/O=j5h%][&DD5_C`ndjZH!i]$c1Bb'(V!=oX$3;$20?:&IW;k9In*XE;'3^<<9PD:sf_sL:YAn'Q,
hsCY2J-S%je]UhKZaRb'a]Hm=q(sHL[CG^O6/M3b]_fg-5=UAd:6,.#Ni@l@VPXnI1MWFm/0,"HboQ
0uQfM`/<P<7KYO65-DJ^A]T6?!A#,<LkQKMTT+l0B>7#(2N&srPP\KKMM=GR>"_Do.J'c`O#nOoC<?
-Jb%Y_]+[+Uba=EScM.kaIu'jgl-''_MA!nE$#b?#,@Be!'*p7sCrt!qq;=g&18YdaKGfOd"Vpon?E
!];8/Ugt4>JHVE2Vq@UY#kk!6>mb-hIA#eGq0MHf<^U]]!<P9D2DL0,$?m/>[0Yn2fX`^(c=V7\8$A
@0`EiR:"e"31H+^#)96\@)=6(Zj0IM92B1Vjr=S=fTs/DI;FC#A:,[HR+BO/kGM5B&rRG9d(D4MDJ-
r\ja]nJ9VKk]rpds6AlnJ,B$'o@DX"dPpn-ZS&+;]q"f_EQO]KZFn,1b*9&`eF(>4o";^J]03O+.U.
mg6*+`6J-gI"V6%5D%sS3`187-<3-@hAB3`6`<\XR`YU`W+kg5Cbmqb#O.\MU(!?WN2`WFFG-3'5@=
ah$"UTIrE+bV-lW=UgQbLk27Qm^qKldj&K.G%djVn\)"s1a!Ra23\i;8;KOWDA#f9)@;`4#,!FIu(\
*f^\Cs7,NL(GI@$]A'Aj!YK6TB[kGcY=!]b+a->\Pp2jEdcfB[U/f6"uP_nMHc)RY\d((OZ!_KJ1B2
iBb!$k0'i#\We9MaH#M4E>ROp.$e2)m.17)Z8b<+!IeQEl5>1iXdo+G*fmRfHRVq!cgi7hZurXXefY
`6c?_[?T<.4hRB7<cc%N<GZ/6qEW42[*,YF[iDLB48(9Ra6nNIK=tW]qlb"#f4")teBO":IeghgXo^
)Lm(?(I@!m.+W4FIsL#jgF[ud.\!<WUYX$@6/B6rS.K=g/Zb>rdd9k#eQ#0+JDKD=&;1'&^QR]eF]T
V_ec_:p>-Y<R<^5!%a[2*Za5e-7/,Zgi?fr;2c$mh2B.S#UYIr_(c>6-"H7lKlj=cZY_*$>f"uj8A8
"P.0oC-Z13M^E4?#**!1S1_#-pfe?*-l/PfbeuKp'18BR89Q1"d_,\qiRCXTP$95$aWk.P#FSLal8E
/.".TTRroIDnN4eJ?cr]8L!l(`=]dfB<9"Md>hs6S7#YktiqX^4B$15?Z^`FD+9qlmPT2*#QoGPZB$
>hdEVaMIRoNuf8[RKPSf4YcVgb4;/L_ZuJDA`-NdIE[qk/N:#SBb5+$m0H@4[cMV0!!+MHokMCE+tc
ee.F,Ph'K^I,0`[mK'Tcl0*/oKsZch5Z%EH4FT>0A"BBBDgq6YhV"<$aoRL\[E:7nC/5C]*3ZF^bO%
t]/E]\m+(_.?7j/bk+u\+3]A2nZ<^mbR,pRd^\.""rENY,ph**tN=.Gs+sa^o8e*8cF.Qa%^Y/kc(P
9V*&[e(^g<ec4%N_5c(=fY(7,0ceaS<aXA[n&,H1^.\I'M;[.aar^dP^F.iGG^AS]-(En4POoSU0fO
.Z'VTB^0:eehP8\#RI2kqSSp\+gl2lBsf$#g4""1il+<8,_>S+H41rS'8?,1;AVoA<OqAS5?\%kDFo
0<'G&;ZEnmVWpouo]*m.Yf)3q&`L3.A"KKoAQG'\9MbUI-IN9H_6$,`+hCTRMAti`5.F\Gg$Ue@M%W
g-*?\CB&H(.b]"^/-o08`][*70mF"<+JE6_J4O9M--g:[G:mQjafnFG"Y*-?8N)QT&&+./Oe2Eg,1L
/!f=h$stCIE^1AVlk7Rbo3rL$-C5&a<R).e7T<c#$.(k#Q'E?gQ&8l"$GLsMVL<THoiZ1.48oWEGCo
u$ur/6I6J\I^B!HMp2g4Ik(d*.1141Zb4_,?&W`^9;u:1)*4d<p2Eg+)PlWOO!$VF%AYs%io2<ImkU
*l0EFip%$/>V([-Z>%\04V(nZKY$cEl..n]s8:7m+@t8S@+jH(rVt;19&Hru]N^JSsGRr[@hIE5/)N
DS&h-fKM@g3%=jlj+l`u9bSW#*CR4J-5j%:Z&m-o!($`<!RVE[1POD%Nt9m0V4k<IXQmrdp[?,9ba_
d>o9a+q>_V\5g*^+^=mc*6k2rjAkkl0cT3e.>KlnVR![1$E8ef*!^nld3VT(Db$?&=ehi<Ui0.lO^T
/or(?80_$gBZ[<F+Lm<mF:V+5/:cD7r"uLDC-h4mD\sHmlZNQXf7oKh"5Y3E@S<d!C=p%0#0G1O4)o
=n"2l8fB7Fof]7,*RDh'919@%m]D)Q#5MXM`.LSmDr:.m]998Pt9RQ[jrHVF2F\_P?gt)>'L>)!k\s
Mlc*iGpmLl8h9nG\]/n;#='X*_F$4DpL"KRa%[oj:i66FpTG@@1#AM<_.bq\S8il9jPB-7)\5[q<u4
@N'auiFA`l:d;GpFOb5t3;D.42ZJ5PXLPGiZ+MKsjaC<L7<2CBj^<#eoN;.io%<Zu:;H%%`#>ce11m
'"n5c2c$Kr;gB`?!Gq*,tars,3:%\<o&M>$uM!!#SZ:.26O@"J
ASCII85End
End

// PNG: width= 149, height= 89
Picture ARIlogo
ASCII85Begin
M,6r;%14!\!!!!.8Ou6I!!!"a!!!"%#Qk&,!!$&cZ2ak,!)Q?g7=]o=YQ+Y5Du]m%^]9;$!/\#^L9L
Z1WrR[J!.CUBH(G"ZRK.An!-")$DN=d5MuWhX%;u4UD?(,^!!##O!&d=I4\u,H=9)!'!*!h9?$ZfM!
!u3s#tP%%7K<]_!!l'p#XeXu6N@BY!!kgi#<r1o5l_-R!!bXe#<Mnj3WKCI!!bLa#<2\f2ZO%?!!Y:
\!(pZ"8RMNi?N<W'!(U;p7U--S!!#Jm!(C)l79T[Z=TCfk"YKcY0)u21!!Y.X"u6/Y6<4(Q<s:)S"Y
9WW/H>c7;?/pZ!'aB^5Z@_L<<XfO"Y'KP4&#];:B3RU!)-o'9k=<$BE1nE#tb0t3(X*19)q"H!'<pU
4\l&PA,oA:!)m_7=)e4BEsYP@#u:O.:]LJkB)khF!*!e8<H%q>EWB6a!*aXI?$QEWHiRQ'#tt=*:&k
W!!")X)$<7'5<WE+n@fT>>!**q;>'9mNGQ;-"!+LHY@tF\lKE,Y>!,78s<r`V2!"2s1$X<Z3:1jQ8I
fNu0!+^]^Aqg;!L]D1I!,n##EKgi:!"3*5$t'&D@/p:+C]I[_!,[bsDik$AQiM8s!-an@@K6gH!"<B
<$tTD=?@)ZcM#_U`!-OY/Gb"h]T`BP;!.UmHJZ&uh!"<K?%;5_AB86J'N<!p]!.:L@J#33sW;qOM!/
.ERKrk?0Y751G%;GkPCB+?jYlKK\!/IcYKWP6&U]>_6!0Y(sHCk1dV#Y_0!,dkuClSL-K`H:c!-=G5
;#gTY^&VD`$WmB:>6#"0!"3-6!,@DlMR<FeFT>H]%;c(FNk#.N])[r*!0"AeLp@#>[K)2l!0+MhNk,
4Q]`=&%s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s
8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s#a*
gI/j6J!-D+6;ucmts8W-!s8W-!s8W-!rrE*!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8
W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!
s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W
-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s
8W-!s8W-!s8W-!s8W-!s&4`d;ZHdt$#iF<ErZ1M_Z0ZH_Z@erW+5l.#,=aX5u`*!mG%)J&pG/mE"7Q
R=PFn=[b)CB1a1:+Ula$KelTH$7C*e@Ha,.K8t]aPK`pe9EuW6riJ.&ceg=QOXd2e+[!Uc)7IeE=91
hi<d7WYqZgSpTEQ9*Oqo.)%548i3mjI#]_t-"G;,tqt(oi2mYf6^Cp0%*aMZ9[]U=sh=O"1-E*e6lU
@B*j`M9NeK7E&7hc;/^#09jm7IOHLB.QmL>[*9<=>-1dSc9L&'4AcHd+Gf]!#!u`5l_@.+U8f!-K2o
1K+'YlsW8`k9<5nPRqkm=PPlR%hWoioj$Yl`BWg&C'<%>$TUl^HcdlG"6;C^8*>:qP3$H7Yn3.(I3I
hW:D<-hY6NP#si9I`166:6gRQ3g('Tu'M4($T22ko@aAP$tP%1)MS?*!N)+I?L[`\PsIV40$8i<C]V
\l0BP$RMDY2ZVsb%,RFV>AjMN]^biGcO_%OUMIL$r!E@+e9qEb*WL'?RTeI5qoiFXrGLquU:lJ.$5t
*`;W$(<gj3Hbh,DWb<;9Vce?Ib!Lc?BQBAs2]G(WhrEWeS^H_edhs<Vg<k>2>-@][PCO0B@<!A-:i4
F8DM<<K*JHdnS3HCQC@enRQ70N+-pf'@g>;`2YdoH%9(fl2E\k]0j&_''0gp>+q<.Tf<bXr*\eR6(*
ECf44(?HF?_R93^j!bD/ucMO@EtAY5WLqjZ!*IedVN8"s0$q48?D8srM/$6qj?]4+\Eno?X4W/NW2=
l(Kn<Of$T*=_]_GPWEEp9s:^+I;pGr))HQ/1==^ERXj/=D8bJ6H)o]S-?/c9-32U'!#IV6-sYRjDZ%
IQU8ZfmJ8enR8t-`^V=OOLKsG03#+<DH6df"DV(ZrEJEnYo[KcLceaPuI_EYNe5/Go_cq/7mGU6:.P
?i320`TpH"S=ID0%m.bBGS'9Idtol8Mr7NW=+][phs*R]qc$L7FB_=#Umq.rT[$A5O4=B(NgRJCtOE
m_=$+eMo[=USdub,b!pZS?8HK*mK\-W#EH\jRgND\_i5<DG5\1g8:=CNC&_"?%la&(Y*3?[CArjZMb
Ff^A7nhDneO:fdU^hB^ki&FFn3u%M`pYI9s,G$C5B$HAgp:&u?Ki_e++>rk4VXLMkO30X4D[`9[%/P
tT$f78*nc0-51UF&S4nEdW&haU2/E%F]u\_qUiM;fr%u'!Ee7,+2--04n7W^>Jai>Qk@#2;Q/Da1]4
6oMTFnr3FDm,Yn"JO$+&>h/XCX'+MHK;5XH:?pO4i6Y8Q4P;lS0H;Het8'-kn9,\90_$p,NA"W:EG@
UJUMX3F7pN\i#)O<XhKP:NC(f-S/G^n;n5*?E`\(dlKkoR3*eh8E!GI#!@<,71AD4_U,'+s(OLf%/q
ae70`]^K8$Pb(_HF7[T,!Wc^ZEJ9r)]g#2Z6(%L`-Mg+b]b(R8!Wr*g,,d?\ZIhn]fds!6#Uo6;Yd;
eTL7F>AkrX'.l5&tP8:+>0d8@NpC)\'/[TQk,?KW&NM?3N@.2/CJi+1Yp=F;\J9I2[4X2V""/t>'f4
>^_q3D*5R?JN@fgN4+i2&K&bn[[c7L[Y&R^Gsb_/V^?8LF5%nl]0ju/nVCn0[X(Fn^N?U^W@/T.]d;
6/6BLG<Rj.hjf)p>1Hq"Mr*Vsk`S(gL=m@=:S%QsTF+4lFAh.En.'_Z-PB]2oJ!.q<hJMX[LrKNnq>
/2V@pg'/RuTRC(:.r&NTmI&W`gLG@"#95.&n]F+B\p<;:#irBr1Ndp8b3P5)>@I#WXVR)$8Q'5W5hq
IN-fC7#AW)_qkM^`.H%D^1t"._8I<Ci[(1@OV4Z8@Y<$BUC0Cb2!Ao3/Jdhe-N_<$<Gd-i'o9_+U2)
//@[Aa.NEWFWn2I2#`/Wgkh:>o#*;9T1A5WRomdO6BT[iH?9V`cD?H[&,hGj(\PiA]_\'$O?)mWVam
a=Ka%S58?]3$APQis-/?#Lf+3HO0'KsN#AKD%l40X;QlY%?H1!qd2.&'P/L8-,!WlM:#+q(nXMFo</
9>`[2nH]Z^>,Z4f(fI<foECM=r"4>&h)6c[nmG;`K2TWdNim*)DpQ^!Lli-8IT;u+rj]&3%dKNTZhH
'4G_(F#VfL3-l&r2Y/?7NPm:FrnW*(lO/i@Ra-R#I2(e\WWd,ie>2j<O?=rehK4Sm$O>*u"YD5El2/
*t^*Ih>dNU!(fUS7'8jaJc
ASCII85End
End

// PNG: width= 101, height= 68
//Picture CUlogo
ASCII85Begin
M,6r;%14!\!!!!.8Ou6I!!!"j!!!"6#Qau+!5dfH,6.]D$#iF<ErZ1V&HDeI&HU$$o033T(F)L>5u`
*!ls3b4)on9DH=+4dU*rm5@X2M)M=&BP>W^OFI"ON&$jLc-^`\,7#.T.krlR@a&*3+ih@a?dEg,-A&
p_Y[;.Nge,[6L(E=n]+R>6Y]N'pP!ACI7fIlK,qW4V>:I=8+j<Lm%tmQ$:VE7>4Wa0>''g1-'(e/hg
VVtSd&3OQmCc`'(939J_b"2SBl1edt,6pd%^5nF#-;70T04i.'o49/NM,tS.l0ej7IK`HeDiH.*i^u
t:qJoK5#jTrU/C1h-j%)W(<lZtIY-)*`"nEA8p6D75Zf;Sk1Mi3imKnr?t;QWt-#(uW=&IsQsLn\RO
k#"@/,922J-RU9C<`\Fn\:4B;a)Rh%Z@?`jdckj#P@<$97-/H7D/G:2rqY`L!@3k#i7VeNB1#=Icnl
13ch"72!T`it,21]%GkgbO&bWu_bficD40c6&`_>(SpB+5lQ+[huGa^oQME:Eiq>'ikYq])i)%Dj'A
T`-<@:<SlI%1Y0OsIRiP7>q?:7aR^>B?ReYRR._b/8Io!ATHm%0F07M<Ns<MZ?YS<&>Ks?l0*oo6h;
Y^becXcc>YTgt^]1c;(36alRO^)]P?=`2I)YF`IQ<BEUV/G*C0_n)(le//F*+.4@GL]=Y[CUaQRk[M
;6QB!Y:,C57%gWF_j\[;4@s6"mZ0CfoNIg7"V)IL<Ibf\+qd2%ibG*)7alM*th*<BJ5W9^UWjSDF-m
n\l<L==b!h0^Euk[>UcH8u4R32>4Hf]5$MR<iKZ5c-;_:)7B07qK2X8?.YJH`I7g>f[qU=b9Jn.NfY
_c!'o#?M2;N=NCIE'Gr_A=ZGtF;rFcpmr:huY^%gTF;c?V)@q/$-bV(Fd[0#chlZt)tS!]SqhVMkaa
ulXJT3V6krb+,\7.#0paH^0nH4=+F&;9lTq,42&=dICs@uY.Tq&Z5=Ck\::rM<EV3OQ#P8gS8\*GSf
V:AdE?@Nlut_QF"c1u/j7Gt8k)C:/FQNt/+g3i'?5iu+UM)"b9V'TC9$$82C:#QaA3LRH9*bj_^VkO
T9_X]ArE#(saeEgr[UC7@UjqnHb-nh,L7^KEpp"BX$EP6Tso;FAmZmZtWco#j9@^uf,oWp:3jNhf^b
!.p:DMC#a@rhnDm''VgJ=$f<=o.M=$*sW$i:h@OC<<;%.='m8JcT_47^o:813r<QuB?W7OLUo_FCeu
(3a2@n,$uAtaM'Sfphpb[Ja%O#e\uYmOs-P3J&3Oh57\OBr[L_9k-Wubg<,L9JoWph83&*8pU9mo)2
*&kFgLRS%JsBmYM+!]eHik?FLgDt@>E`NcIB0EL`F<h8IGNbb@/nL7o9V(8!c\/:Gn6t4X3'jg*ZVs
7\hC,f_C?(jREbF();Qs8%mfiN%oDd/DZBha/hjX;!J#lX"X7]h>)_Uu[r:0:Gr(j^L-d%\'Q#p,-B
m:cl:EGBJr-]r0`MKgWY:@Mg'o^7XZVUWq1pYqS4;9u`kh;[B=>XH.CQT-bHe!Ze'lct+EVMl1IGe0
*hH=lda\+%^C#IK1a9Y?a'dcQ?7D.9gXXG8Kdc=%&b@:l&$%PffF'5]'SM&#Gtlb:pu)J$ZKh*DgYk
("Dqqq!TpCBWnN:a1-*[[bLVrX5J2a,E2DOmI4G[U*UAKd][R#T6!f2(kZ7AjHBXP2LR(eYQ!0ZZ-H
4N;0Q=XoMD6]?`__@sbV?SL=Lo+DtD_ZSOL2]+G73]<M/ll:Bq(G-caV@*B=$C51G@n>Fe4-Jr&Fll
'pV3jaKBRnIH'E^o>IXIs]C2+o*=N-.RERo"HDR#[aKj#:Fo]8Vrqg<6H2$`4,21o1hJ%JoW&9Dqhe
[k"X4L57mLNZ_"d)Bn^pk%<OTEj`b"d.qgN=(t;=c38'a,ZqMm;B(7\`7;d:dW`!ftQ?!F30U`V(/7
ofC-5I_Qu;`$7V`WtK)I+W@]P?-&,Vd*+;-!Q:MLl1fc-q$dla#FT_HMD0e!LYi3FY",6a<E0c&@?/
lgKC2[7QHdtu2E*R]QBj`1jHGFWM9apOE0,VT8R7maeQ"FE+\m'[2IsaRaZj,;dI_;ie`r`hI7-@cL
:([P(-Kou_dO;dc+K-%$@/Z$8s0ks"ueFu()Icg<`V8Jh`;J:7BKQ[+GrkP/[n_I!!cF,0#*.]"k5,
<Pc84WF.lF_^RjO,:R,)`bY;cY>4u'VhaTEpVRBGX3!k",5UA#_!>#hFE^d&mO@P_mWMq=nRj"-Aos
]/+4gcj)f62[=e*NUHZ'EkKhgYHqQa&KWNSR/@5$8XYS:C\4"mD??+TfN#<<Z^<b;XEPpX/6jb*6JR
QI=)XeW&$T>S2PZ98Fi(.5i$Y$Rn;Zg@NnM"'&?(_O95OcL:Fng.3Ju(e-9KA0IK3^ABOS,XU>#H^A
;9Z"4aFD`<@i;(DWsoOAL+C+lQ(N`-mb:rk9hnl;bRaHRTVP$gq^JX$J.5@-]2U(X<%IRp`g$A\a%B
"VuorA\rbPTAB=[TiHSdt<IBQBmmCca[NU\k>[hCMR\c,*</Wo5)+7RmN.6Q%_3<U!tt2RF10rWKGL
4#^9s,9u\\[TU<KO-pk^"&?Z1bnJ3"M2W).!Fp6Fe5K9F!]ktHcmE(gh^%^B9b@&tr:b0^E>;]uS\t
UUY/6-<i3MMglaMDPOgm`qB'358t-6;Bto4",,d)nh57#?;kHUllrCCkidk+K_&IG=G\fBn)nk>cb#
XXqZ>;ON+$\t2G<p:J.((&D34bIkp$Z*B:JN?0O%Gd=YK7!J(SE><*I^"&.(Nt]pSHhZk=Jn8m\9IB
f<:j_NZX]hj8\@<B46k5rW]`DckS70.T;7]U_Ek0u->ITEE\]:[K9%,V0$9=h]OWlPmM9`R\-uZE+-
G!GX+Sqjj/qa!$eOr;O<'O*AC0G9m5]*1pWr_EZ>E8s4Yeq)U`ZKR#CUKVK&dj?0daHQ7:b,*M$b9k
WK<@"a*)UMB-\:4CeGrI0.(3@P&U!\nRQQ_in+\W2@W=mh2e0ff8ehmXZr=mT71I9Hc%\p(CTZ-%[b
pCM0jo?THR,QWS9+j@s)k3#,AM?p!0^S+YFS%3bZ6;ih3OK_B7,ga6oa!Cdj)LY$!G+qY9Dfeh@gH/
1'*eAAGiLG@RX.)>q=)1m:/<^TMhbJ"LUpA:"+p>Ni[H%OL)4c#uh4B!`?<nlMg,J#XABFi325m!+L
hbK#`>F0@MXIjJt5OGK?3]i.U6);%1787uo^K.KDG(g;K2F6l.^A^XO!7Y;hllYoaIh]4"Y($caDW'
VL$30/gJ>eh@O//]PiOH(GOhXJHob/>GQa>8[7qK+EdZ1em*X4&]h&e-8=B=&:GC<SQ;XZ/I:BCb**
QDXZhLS^15)Lfsep@$$u@2N:IeSDpeP`oC&q;q`nuAY)i4[C*tsEYqo'S#`f;<2^N75nF1BZJ=<hRp
)Pnl3BB*,)=["K<"]+BE8jY17Dc]=3g/A#H*kB-d2(PY*_XS\8IUB:[Q&TB[Z]Ulp^etVpn>#&IPN4
ndDcnW9i>t*u;8X:rkh"bf5V]2dA;bZ);bV&Oa_jrO73g;ecIa!7;l?$ah;kML2ahon6L?P#bXcp[H
=GX'I[-EM+(ZaG3qL>X-$.R/HF9s1ol'+flmb@)l@'%<[YWdZ`TCc>cZhIeJ&Q%LZ1DeaU^rp[FWtk
8um8fJg4]bKDMUEEe2coM)IH=(E@&lfc'ooL)a35U9HSoNmM,Q9]PTa<6pgdNN1J95S;A>:3[$:Gu`
dDDW8=J,QeH>=OWV8QPeQ>d+/pV:^]Yga6bt;ae`N*UPmX,e)N6qq+QDl8VpZW/664X(P5d/[[^e.u
NoVLECh//HD)smG\njFZ<HV/UP(Cd0+Q%Z62aQWC.C)0B@F+gWOLH75NY#>7F@T5HGG4()@rRGeeQP
s8D]F)!n\6<)kLa$6qrU+'u\*SH9<3P8s?aFlLFf&5<S&g3O.egf6@t[ajkXX:5:6O[t.:EFgmC8Wr
H$>.;askKY)[n]l%j0"%j:I0LRH+9=1WTQL#M2N(/$_kLZG('C`B=\)kBaR%tu)_<6X(_$*S=%l"D4
$2K_j3DT5L0?Z%$U?2,1(8f+%dn^/ZFb-<3:K=MU*.hdm<V?:rg/(9m-KLEGeQ>fB+"\>@^-bSf8I]
00(/C)"$;qa^pi3M917$:Z]E`0\&B7*->-qq\N*ELUi&!?rh]O9]ufX6ir5rJK\A[60KD/heQ6+_hU
p@$m>Z.0H57)UIf/ui:Hp^2PBB0D'Iu]S%ll%X&iPZiSHG%[qNZkff:`3#ia>6/=ocNN0qZd!\8X`2
'N]poB3#Dub*=Ir)]Qb*&O8/k*W0._^DN%d#8=n0F"`)Xc9l=UUk+G#TOVkheY>J`3sn>TeUo'T&%p
L-%2+N9Rr?$/bN0d.HIUibXZ(bQLIjph+4GSTVrRK!:]j,br>`Hg3B7kqWKcr=/J?&[o?c-VUSX9a@
6U<uET;dXa8"7Q][DPtH)<tX'QW<V3<Gj%$4tg2s'ENUU9b::eSYCE\cssM`!`fQk@CN3qTr/RNneA
^B4k@n.Y)U'cLk%d2p/DT'\4#>j)NDI<ek&!*2G1lo0Gm9c8@0&]2@l!3"_n3H-9p:+UX"$lPqLad:
foCDHiD1+IPpsGKQ[n@kF0pGuC(]o\TDC2^:L(i!kHsF)iHa9MT5qABb^C#PmGuTJi:a-5$W.KQjcU
A4,)o"aWXTX]Bf7/_=^?K;1B57-Q9252#2bS.h<?Ml7aj&d^t?"3t'e$FS+PA1^A@oCMPuOVRoD7j#
9I]_2\f;*.Jd+rWCJ3YBo\GPBI_U>=ge4#gnXG=^4%L/B?5f%8O,&l:P-55_i1"V,Q/>7li_,4m/&B
9:R<K)iZ(@^cK?Brr^`.\at7'naTm')qlSP\Tu-0a%NST'-T#m2H%3Iei)A2QLQG47BiBFq:6IaTLD
G1="O\7PGZAr!'?5L+nthpSr@U[g"%?81cneEQFDE.]?Gl\o&W2$)I[O.r#rh5:juu+5`LO?Lf3tZZ
H^%@NWcQ'!!%F)LLkZ=&$f'c%>.YW<?s]Gpo17br1CW938Dq^^DiE.\*CL*=PA6dcpDkgUHRLj%*:S
]lR7-Q^J6.qteU!$aLkSWj9s#%&/BF/6/K%9`d2^7STbgHtZ3-,:T20jZmq]D]euo1&rU5oAIE0Fq=
sI[9Ci:EeB^h#6RiHEdijYCMO:f!iFYPp[$S>m#a?T\EI-%5nNBn.2cb#1<NV(gE6R*"],!R/IOtu_
''F`bECgU5KkYZ^o^hM/B_cb)M=Be#D73@X=(Q#l&q684SBi#cWLk-`ufdn34/`S;.Su<\d9k6%_YE
8E4_*1POkM!5""t>J;BnS!==995[&$&g)S/h]6B<a*N8;W%tdp1LJA8TC$,#4<urB?gf,!,rXLAE1`
BpE8+u,RlqqC+fW:`E%>I3C:b%asi1gr55fC-P+>W[^[Dm-&J]K6>:b77?^Kp&D)3Ie=@Il\^p@2L8
!BB![3(6[GJH4$f[M9k;HJF^cR:<G2]tM+`YV7=]V&sGp?"^DbPtIlNWAsY9^A6n1johusLhnu]^:q
l&0d3:Eg"B-/fEf%nSSs%UBle?:GOOCrF(ofAGM-PkM%%crY<2e^E3D)TC?e2Cm@$?U.HaR^mWR9$@
XSE6_OhqQd!TI".;%aI8486);JeY>o($h%eRDmk2@O(@XO]'6^Y^]%imk)2R>Eo$QAAXLQYh5R)aAE
+N,?E)EUL)69\fsIVeWW^%_;E"Vk8G9n],shDDt]P(lZFCQS/6qAF(t\M%]1jU(C2'nB::ms0m2p4i
npGGbEEL.LSddd8fp0+n8;!"tqf[l'9pDm%;oINJZ$ehZ\Td?m8G!8l4I4`KQm17'TZS?^<(r=PD&g
3V.6:k*^:H&k'k@gFg[Dr(g(Dhj04d?pOU*<,oI.7cWk%//J+,%Q\JSU-bPmH[C[#0o4r@huS9r/b[
hRaL:Jd1Wal-]j>nQ/HI\&_^JIuAUSutLu+[im0AC1]2r^8`WKLP$Al"^27]iC`4Nc\5S-)Es8L2j.
fQ_!oW[!IIC]Bd-1)3dr`&^Wm3`>X$AH91CU`'Ecd,tHr'5sEb%`i(KjMf^3^d/ZO[p`9NTThXQ>a!
BnS9fq`)[*;aTLr90e=6&`oHUg;2\3-0/'i4Bu9DCG`8%Gi,).).[<UB(Dj$I>A`dlLEIg[Df8]Y=%
J*-9^,l;P^^E9;R#8I80eDG3b276lqYGPPWnk['RZfeZ2_*kIL4:GYe.LTFWu^elKTiW2q]20RAO(;
U0gYHWKU-.+ug9dG7VDP+JW,!Xl\YUNa;)XLHP;Y[X1uq^7kRDQ^=&pDV)0F2XJieIf/tlJdR3`AQd
Pu'b,lcpf&`.9I>NDh5cXc%leFeZ#sSW4!qc+AQ`%lS+W[_\,SuY"Od:0_ArmdJIpi<pCFc8'7b06e
*/\ja\r5HU"Wa(\$rh:7#:?mK=:j'\=tD1E0uHaYHJ=f!qbd7I<1TqKb/$8CQk08q]T6[//A>9r9$t
[@2KhQMP:N8M)YLPM$AlCQfW6j#a%e-Og<hl)m2]+;-hc__tZ,piXaq.Y2S^4X)6T(iA;Q;4ZtZl9n
YTlQZH9I@PK&f3&m"J&2Pe\/XU?)PtEZq$cm_g9a/t^_4MP5>VWSkgPWjhYf>&l!k?.EHN\Q;>-3N=
,L'hA!m(q-LU;#tBbD!tINBR;#(m2OFE2CWXVT#jZ`R9O8("#,#`C4G@#uIuiI)]URj<BQ]SF&]jaN
;-i*\m`p_Z'0!t1q!$,^T_6*Fc5D]Fj>/Z@aebpZ"XYg.7@2if+_7gmE)h(XS^VJ3JB/ansq.JOdg[
9B]]l$0"%ZLpLOnT]G.H[@6eAD=O,ZW@F[l#_`[<%<0cU1Oa]</[E<4McKVjLfO]9tfT)1[;[UnW63
W3t6.^!L692LuA3bg"F3\9I=h&FQ>)4bN'i&go@ApT]8]mKBDse]rhh9B!Z3?k,bNtZ3>lsF?0k<Q+
J:3qWbeTXRE,fC.abQK25!I5+d=PHo)8lZd4-[m#>t#rE3(db0#TM(`XGN*"LTdFWrk04gf-r=VH[e
BUT]n6sqaB?IPp.'`8VXCtf0Km5*9"+`;18?=$sXF>?c%+-,(Sa?Sb($YAn*AQeDD>?+\[nDDsjR`S
sKn@;o,Wp9-EZ"]ZWC3=%H^VDF/>bJD:;7kY=h=TB`4>FY%5XaFG(QNjP9/0>tFMR$tS'HVXi([`UY
p/&`8'44D_/,e9o5f+UR3,?Y(-usSc;rP=>@_MbM\je<qg6471em"5=4_RG+1eUbU?2^:)X[3Dqtp8
3X'4ALe9.<VAc<EV-SBjhdLW:V$<)#AP03lh^bXiIKn1bq)2>gFpOg&[K5uZOoXRu()]K_8S:B\jn;
ttQOHWE-B5*(1`)'1#a^hVY7R[#*+JQK[]7@e5?)Vq((oli:=P2EaCc!%i'@?(<*ZcAU_aRSU=igsH
5K(W<`?U#[JAef&9Gf!Q/K6-sH$De4)BIa$KQ)rfN8p;C!jYo:YIVV=[<%7[C?HB4!`IC(-O!2&_>j
Q9!(fUS7'8jaJc
ASCII85End
End

// PNG: width= 109, height= 136
Picture Redsquirrel
ASCII85Begin
M,6r;%14!\!!!!.8Ou6I!!!"#!!!"8#Qk&,!%=o)0E;(T!)Q?g7J?,^qX2)qla6?GZhisu^qdb^lG!
8_](4jlrT(*LgTCJ?^>mJ5o$Ej)k.]QbR)uCbiimmPS9D3"EnuOTWG+oND*aXh28E6JLd3Du67/3X*
dT1PA/>kS$jnot"TSN&zzzzzzzzzzzzzzz!&4'Y!$hOE!":FUG5qUW!([P5!$hOE!"`ZX!!r61!!!'
#!;Q7#!+^QUG=XI`GQ7^Crs8?3!#;[7G=W/Wzz!%@[Vzzzzzzzzz!,$"X!;,ps!"L%FG5qX2495E^!
!3-#!7:BO!20#u!%`Bqz!!rc.!'h:e4:),jz!5L>W4NO<!!.Z?_49,?]!!*'"!6FgGz!&X?]!''Zbz
!+^QUGK?Q\!<<*!rr<Vu4G`YC!3lJ9!'p5j!+^QUG@20\GQ7^Cs%rD%!*L<;G5qX24MW]>4>caEz!(
dc*HiO074MW]>4>caEz!20#u!%`Bqz!5L>W4:hJm!!rW*!2T<$!<)ru!,2'=!2m`pGPl;K!<)ru!.a
bU!%)mX4;%Voz!<)ruz!0m0i!;sapG5qUC!%)mX4:(uf!2T<$!!rW*z!"*U7!3uYs!,d)s!!%<Z!6_
]8!!!#e4=57?4T'%e!<3$!!!!!5!%`Bq!;p\)!<3$!!,d)s!!)a+!$hOE!%`Bq!!%<Zz!&;7h!4*,:
Hu8oa!,_c:!"`ZX!$D:B!%KU6C$Yp)!:0dj!(?Po!+^QUG>K(MGQ7^Cs&A_*!1f6RHiO-\!!iQ=!#P
_:!!%<Zzzzz!(>O/!+07R!:7fC!+TOV!.4PT!<<*!rt&]X!1qn4!+07R!-?LT!"`ZX!'!]WmJm4f!-
D+6;ucmts8N*!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!
s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W
-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s
8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-!s8W-
!s8W-!s8W-!rs*ar[f?C.$#iF<ErZ1M_Z0ZH_Z@erW+5l.$Zem-5u`*!X]gQj.QJ-b"P?CM=QmY>]7
'>Os5cj&2b+K9AF`D(?:'<KV)msl0>!j[Ib=$_ID=b4f*AL)q(_/]n(_f"INWBTr_p<skG.@UMs%S@
ft$iAL$P6^0#m,$^%6^*rup1(-YA=j"#[[hdHc7;3s[VU(U2:MP4saA4ih5aQJqocg`m\cL3j'D%*V
t_nGVkM#B2Ul7oV[<=u)=]h8:'/!*@kUE[d:3i9MH!p]n;]a$RKTfX8X7ikq_n!;CV4\:BA?23-N8I
ZM,**4T&/(+LJQ2o!B"OCjTJejY7C>@SYeq1IjL?^Y0LkUs_!hhT>I1bK1@kE>6W+o(T0][,SL)&HT
jE^ep%pDZ1VL[1H\1kR'X^]F1Ld<QB!(lN4ROFcjeTlZ+joLmubRgP(q>NlLW`GbG:1Lm;$/XO8<ht
&ue?H(?Z7\e$U&&75<='[3e5_7B/k25Lj@4[;Y;RRuo/.h6=5CQ4[W+mq<>Q\'%H[B!?T"s0R>nj;J
B@nJ7L>fBMcg\ol&8U<1CST.-o=1*9O8D!!_GXE9EODH,NgN`D4morVLf,#L;D0LE<JKPO<qHO_hBV
a%`G6dD[j]P@7hS&J1F?3]\eeFY.?P\uh,AG$[C8'XCZLd";)bQ^+9)f<ETg[WX*5M+Ytc)Uq4<??@
o!%[mLa"*@*I37BK;E[k9T`ca%n;eT5jnr,EneRCS_L>aD)DHi1fuAO$3+Qs.U68+mB,`:j"1!GB+\
R5)/MD>RZ_AWaiT,\6@'/))F0Dd.)UhmM>[;57G*2b&Gm?Z%BVVLBNIe@E`onc.$L<f:O%sQtV8RS7
iP:[*9=?X&OU,J8\+)giqpTpK.+>&7`50@q3.#FdQRU7pU00e%9Q0lR7,"./LJ@p!tXrBsECh`&Xka
@UJS=KlAc%4&#f?G9rk:F)Pm<<SUV)l8i3OFJ\?4]BtV#(Yl^u@@G!aF's%ea6DG(0>+_ZOb:shEO@
,=3@!ho#eXJ\dh`c>rQl8f\T%@7NGWIMh^%4%EX-I=d$>lmoH.E=Ie<e%%P3;k`0`6?hGr+$ce>U7D
6Si"+`LRYTqHF&_1(g"kdn#`?>rmNED7V-m&CT6q\9is`c,73(*m!lK^s@3='Vhn\OgfD[\1d(k238
.DCP/_Pf8FEqVuS)57OiXf,b)fnMqCSJQn\K=+@H(81Z\K)(rG]RN+f+`$l;70o>DBPjuQ[JI3&gC2
h?6DlPt421@Oof=:4ta;76%NFOHe'Z(iKRS1<S*9T^mh+C_1UaC(]6M20[l#6Lh$M1(1lBK3IniVUd
#4I._P#$N2h:ZK4D#dmQ&!+"pQ]!<`eOhK\:mpIcgSKQ8\q4miERc6-!6>-H!"G-MD/?*-#N',F'q2
9$h:iZ'Jh<ZHF9V(Fr%odO@UhRIeAU;rM:5'0RG(8Lb->&qXr?<G=2(6&B$L\GK)i'Z3"YfA%-I0JJ
JoX6hT,hCH)7'N#uLjt50e@5cq#UdqIc4H>Snjp0hl2;2Z`<!2!=buG`bA+o4;Nl[D1]B2;>-]cs8h
uf8PXle4aXK$GMX5J/ajk9Mo2T"AL3lTS#=M#K+N=ZM[o_,*0K1RC]8`J5RRfP,-UskRTF'We$+p\6
6-2bjn,X[i==M7K(fS$+>]1$Hr_4&fF!)I)NW^=3"D;(,8sPqda'"[Htrn2,h/\#^Y7li$u`do#ND9
"';*dGf#(s$OD;4@.Hqufmuq>.r@g[]Z>3ag,j7M!pho+R[(8p!`pHjOIg_,pa:[u"XS/Sj"0F]]X1
Stk$W1M;(dJ=-GM*LA9&5o(-42r^h@G:A%[[.Yg"u+$8MKglQha6o=*Zg=hTmD?#VqOGERMtP&k$\K
&10A/L"ZQ_9!1Ip5/*i]U%N[k-H5qE$_ED=XhB2..4/ik(l8okVAj7ePabpfU&!XT"<eNm47L17^[f
^lT!kW'n$0S?8*TP/uq'uc/*j6/tbs"B=3m<*4i;JcVu\u5_\jj";e:;P3%D$+fdZhi62PR8fsZK[U
PZ,[_).SDP,1c.(pX;#'$OqE(tC`$o9,Oj;X"<1A<L3S72$5_jenq3eK<VQ#@Z,O_PBojU1]uSr>?D
Tpf\4e$eri)WY6P$Ga"3Ee&q`XR3eDoiaR?P'#.uGgesE5cmj'/dYQg-rft^c7LPW\Mg0Y$2eT^DN@
bKHFe>6'e\NYklJK\!4Tb[bRS5V6("EI*u7+6`&W237F$"jreq##S?*](":pf:8NFiSRG@%;"qf'XQ
HNCc>r*BtK;kNS;Y>5L9CNYQ!)$j49%4[\N1r&)<\tJJP1:Xe3JaQ+=d'b2k(bYk;RdtA\Sk$FfaKR
>YZHo74t!DOi3.sYB<jp.VcL<;BRIc5/u,2=&bRNMdBEO\itTCAcF.*TA@%+O0hQ4M4CrYP53jSk4*
ijM67n<=?fX/bjepdNZA9j2[#7PgFoT;*82IjRnMj"iJZrY4Xo\l3At*KaN.W^XXUmc*k-@gi*DeGN
Z]4?hNoC?d]\bcgM@3l,N<Pgl;P"#mIqP/qCJJ[<TcH'^]1HD?"+Ic@Q=5b#($9`BG\Ni(>KSITd_`
%,Zbj*j5%05kFZr1C.I-/VFo,,N-]S^&#U<pro&Y4$,`OM$]T.`I\pDZ>hj8V$4'AeIY,j.Jp]^_/f
,Ve:\O2@>8Zm6%>@f=.?3MpOSOg,9$\#*RbKG"Qg3X*KYp;F)]aLUWd%Z7U_21*jUhCbh4_MI5,M[0
1[@3#NEW<=kn+pH4*@Ydbl+7G8b\jjPAi6WL.U09_?cpehc?XcUI0XY]jJ)0V@r[*a^qT9LF&1T<N1
0qi3A/Jfgj4co\aJcfgsD!M?KCn=)dLUT'F\eD\$m&P!.sVDLpRV,RF<0(P06V#q6sn8kk><37h&3\
:E;p&6u/;Q(1`ga=t(e.9T?Z2gfKk!+dkRMV0a_HeW@S*)k4MeRk?a;Vil]Q2)WD>;1:SSkXL5:g3m
4@OMn!0RX7#*d0d=iMWc,t59AA9S,71ak7?%$#]JJbp?dhe>hKr)]o/5EQ"7qDZifIuRi-MGn?4KaD
q9*\('dWG<.>sD&S#F]+\S`6lCD\9gjO2JI<uUr,q`U"LVr@q3(.(Y'&gZ25%$%<<aQWPJFR*@f$8.
,:UgD]+&6H"8%Wha*e^SGafdbOaEC)caZk6afD4?PB=g0o6#d_]lUdS8A2&nA)dBV:gnhj(h]3ZliA
+Mof64VLmU/[XVq*-"QW\*ff?RcE]-lhQ?f>lUU!hZ`0=ZWE!GiNCFrrKn/J@08Na]:hqL\1%5_i9B
#<k!_)R/U$\?V/4[-TK:LKla$h$[riG>Fn/FbQY+g=r;KYj/[Q8;!2FOZV=D\D-uH*p;R@9>+G#45P
-:UU2J0A*NCpmNqQ;QWk5#I$mTZDJJnJ/9G5@Ktj!T^I0#?(dtjeKW8?'lF%.t\F.Pp3A2>/n-,c":
2;;o)*Nk\)'ZQee(A:t\4Q=u5CF;5UJ\6a:97mHe8pZO\hQ[eL=>2[oD?iXODEShj'h+)9]Vm3a1V,
de)?e.]FSs%Mt(JAY!_A1]C\HiIDG^Ien3D*nC_;3G2r+754lm>fnJ9P!53\?C[cOl2B2(m<N_Vs]m
W+]Y!1b2R5Wulk#*nF9\nmd$D2<B%NhifbWOa#[Pu"V:!X<f`eeF'd=50lJ@i-;VIH=>]!L5LjlMtI
ZhKZ^GBL3V8_2!ZMuWMT]sW>VJPWf5Y.c!=:K%-'mSDI7!W<O>StFOT$31&+!(fUS7'8jaJc
ASCII85End
End

//^New one has white background, approx same size as original
// PNG: width= 99, height= 68
Picture CUlogoNew
	ASCII85Begin
	M,6r;%14!\!!!!.8Ou6I!!!!p!!!!W#Qau+!""!NfDkmO$#iF<ErZ1M_Z0ZH_Z@erW+5l.(i`,85u`
	*!m@&<BSCNbcX1Q..hYSn<8Fjb=5B_(ebTmTg30T\K800$0)+'j$j5$"Pac\3uQ5@Z_$T9^bKI%n!"
	EFbKN:A*kpJkr[/[[.OP/1YDL4KnT%![W2`@Z4^9>*R$-/0Qs5fh.k06QQ@mZu/3p\3M@<Rn3$^b8H
	)6k*!\eBottaShPF<?9I,1!K_$#>@g*30M;2#bDpRU$RQ9VD0r[R5ABm5gr+X&WLk]*1P2<e.=Dq2U
	SE6p]p3LVp25eNZsLBWfd6oA-@[CcN<<E*9u.`&_'9j^R,5&;Po$-3KHeUc1,dWm=1(<9X:0knhd5l
	30M8n%8eoYf?h`*&*"r#-Vumbq?\/@!71QHchms%5=#/MC)Z@Te5P&@A>3[rK4KoBIg5^XBoTA\4bk
	qnHM1^i!Q5L)BD*^i[4T,8`eLe/VkVkVXKeHMX0)B_c,!D9D^(c<1P7$C-L,jLW-j!4cQ[il=u9+*1
	_[:'kM%sNEb8ZKbKlUYeK'eLRsZ0f]@ZCoY5I5`I^ih2\"A(`nZu"Cp=Ij5r0pkVePYeXf%@Ep+13>
	bb.YB]A,\(Gqk@d:cRo]+Lo4)L5jRmfqYOG_Rp%"9M:d\TGP,GbB0.P5"Ipr$'HfLt'Q>In8mn"%`E
	DoI\2"\#)Jq%uql:>/S/FG,kTbgGJnUOKIWiSJG5Gb>`S9J/WA@5d'Bu2L>/Qh6JnnSBCKn^Ns7V;[
	?^_B5#)WBo-b(F)&4?niGXWpCEKkHpBQ:UoR@>`-I-GBjqKF`jU$?l9e'YYi&I/mQ&N*k?S43AuUeN
	(oN7eY=)u-Wr&c#.BTQ^2g-/5%@\a_/0!4_BZR$)BO7E+M!P+CX4+A.lt2NHEL,)DE"=TAN%MT\9m7
	'M./hnH`^qQOnYgp[d&]lggo;*2D!s#maO\J'sN0lY&NcnJrRAk(4)rLOg+ltbDSU[R'TCqskKa)&s
	,.U`Z1$KG,uE=gtm":)?f'oQh9W-/PN_'V]@i[C(Zkb+ZO9%JTA#Y0Bl)L/>@nCY@VqD%T(M400e@I
	-eM8J<m,)S2o9W0oZ<Ug_i(I6k50egm9R(ecd60ML!E-CQ0Ire'USMAMo_cDEJVgf/X`VV4*Rh"ZNH
	lgEJIs7`k2Fo;iZY.J=^mCc_>mk%m%rN]"6fd,L#!8o7?.?u;Y#U))9ln5O*J`k#6Sema6G-=X?[1<
	jl'6OsEqH3o4)JJ9!F$W%g&)'ZL0"r22'sic%@bO5Fs7!bc3[;i-ofqf&/Ehp)pI6[=g>OXK$C9g21
	92r%PFh8l4e[/79dSUi2;LtaO)CG&(P,GD;Mc%:jd^"l#^3hN8V0;4LBs`_^RC*G(@Y9N)BV(hi7ZW
	MG\6FS1f'j.6JXo_5X";qa*j^I&$;E`lW4NOpG&Ed@LDYDi6as0\#Ru"?_Ut@dT`1401Z<0ISsD+$^
	/4MY==k%H"QLQc0=^6G5)FiHWJDdr_5/%m+tX7;PI'`:b(.DcH^J@%Q:N([k5%o0i6L:/8>M-[5Mme
	BRUAL6`;(qr@$q5BVP2(d\;Rf2B"M34[">8!#brqrJ9p3kuZV,>Il%04+m.Y)A[Pnf!]hS[Wki6BsW
	.d<kFimCp&+=^9dZ$BR+7.XPRnnDn)ab>P6`X/s$rI8h$$GbZ(<9+uVo,bUM3KJ:%YK$VXN-H-%'-s
	+YL^rg81&GMA>;D,2@iNG+[q0\;q\(/<;d1u^7.59G5*G3lnE1B)N&o<6ts2E!F/k_mu5#7B5@KcP_
	%:'">nXC`!=6Nk"(:'so:oE8oTK1e8\F$&/u'E49)(#P<+:b#?mdW7gakGe/;X%cQL/:pk'U=a!(c$
	)2,L2/fqY4[dGFcDu8c+]0NS@XepqE2+hRYVmAi5+7d6M5-R^8e]H.M8]Up#?FoFaJ[SJ_8/hgZoY7
	H"K#2McBqJ9L#MlK-\@b';7@rBs4]okpoI($6qX!II/@YVH-;Xb4p#m3%JrKC:DBL;\bf\i&Qfr>Uf
	`u;sXpcD#V[jo5@BWf'-fWUH.nupXV_Q;`\YSC79liqCse)TpEQH@FU$l^CtCBY1W>danP57id5lT_
	-'&8^`a9p%o)_.Sc4cfs+6:#(7WC8QVDI+2?a4+7'N_tUk1D[_TQ2U9>0YObM,?0$#`72?"Hr?AQ)u
	rBE=%4Mj1QKe1U?M_E49N4jQP6bpoP&,>r^&#nmVF#SS*;AKo8br9?+?UOO$Da&#,j7mo_fN/V%A/k
	0UpW9IfYbTY2XTVW-lnJ\;!*W<14TfprT^EH02-o+Y1,4Kl2.P<$^J3p??Yes\0#SfMs6qNun!B'os
	9Uhp730jF5[J#*\flGQL+;/(V3pXgnJ,]36gb5b^n]\!Rc`HunUC/G07BjZ$kuU[\qW2pKrJE[ST5s
	h\-EH\sB0->l'g^gcUK#I8@QnFULq!;$E]]_Y@2OfhBkX,r2Jo1[7Pk@t*'F4,UbTA;*j+8)X""`fl
	E4LXhRRZa6R<jp<X38[Lia8<eB+60Xs*?3`Hq\[g&f5nMne?biKbGAQ5a7No7j'EVS.FYB:u=V[XnU
	#aHt#%(H@fG&/5-Z!?;_G<:,PP3b)/]Is"P#rSC@^>@d-G=*$.YABKm!93d/?7"VK@G=^"+s8<tsc,
	0X566&9IA""a)3f]-Hi^qWU3-5:YN[2:'qq>(8]Qs@+)e[d*^%3$Nc(B:c'0qhMM\eB[jG:]?,Z"eO
	39.(:@MR^M-&GI;[r.b(0>kF?=3[4S<El-+a&h!D:mBW2UX$Z&QXo'WMI"Ki78=D*8eal3L%--JJIP
	q"=jYPMX2huNc1@./YOG.!AAZNC+-/=P0Th<35-s?F]+4ac(3d2MNHbfT1nGB:?C^^Ve.GK+KVq%LF
	$Hlf](1@.$C<ii8Hf,SLZG71,)d=K&7c>O:n1S+>CWu]E,T,UBDoK7f(BLSGq+)QbNt"mb`6t7[_%H
	EK1gPXoCg2HSJ!n^OUrYb+u5(q$5P-?19gl@ER5Y3fGU42gK:&+Q,^]\-7GD"nH-ahU?H\[78^EqXW
	5AUR51V?F>[19-A&9`Fqr)m/Ut&>giX!nJf>;_ABgC-99oI.G"`;R%=Kf,*(51Le\AaU<k<S$*8V$s
	#_F<7.T,2u`5.+SJUk[)L]?>/HhP1.q=-_P6@k7L<#JXQaqoOfl)X+?QFH`,a+LE\%^)3,ael13hqH
	BFi^C.#&ZrVCRQOo^gc&_@I.te/d%Zn?cI@^/Pk.9eX/`2"WhLmWMa\211M=uUiZjLH_Ba\g11A\P^
	rCmq<g?Tg.Pq;Y%e"l_N>*;agdq]I]=>UMBp_M$3e_8W&[DB/`:*PMjU-N2&W&aVP#&%!.*!a60]36
	k%V!%.luh4;kFE]:YEl0<!dPCZM869,(NhVMG;h'DH=sY^QSF'+GK0:^DoJcniWIU.gZG']k+/Q1+N
	WWqO++4;DLKBM:IfZl'F'oWYN5p!7&qG6>qVK"DU30S@>LXK)%]Z=1f$q5:dC,X`?s=G2#5;g2?+Z(
	JLmpX,:7"TmVdm-(eYGO+oYP5oRVFa[13O[oU8+GPVWi7;]+SrclQ<h8us:82tQ2Cr()scOTu3oKg;
	\_c+_!;^A<Q.3u0/Q2(m$7rV5`TB@5]#ZJMI(&^U$(B/sT*6%jK%=c[bmQZ#0*TI+"HLROQrDeG"_7
	L1.;\MYHjG-%@0J2(G"U8!QBM,9&,TJ2j.@4d%1Xo;%^*ZV!s1i_a=Zl5CD'H3]s`WpM0KC,8\Fpak
	KNKd=p_(@U.T#N?&hShX/q:jL!qt/X6htXeT_s^k%_s^hDY@$-$R#uW=p>1OEp[b`jj4cMJGEqlU([
	pr2F[jP:p$4a5lR(^l7>A=%FcUIl?=.-IpHaW9+iLO^KFgJ+/B\#I3&mjN>&eQPPUTOA_D=M-;$^/-
	<<U0s4E(;FJMkR56^U&#HBO%W9O/j.1,5'+a6JJuAoldHg:c$[2Ei_=_i23GD%1;Q1b:Wu/St.q2:k
	htFtX<;<#Kq[1;9Zj-Tn<]=4CQk34AG!HXf;+DCdm]?'MEp)VMgjRA['WH)d=BK$t5"5]r-+<mk'^k
	IK-C$j%"ENe^KRcd+NY@sE6ckBR&h7>Xm(1-W=ZN"h(+aEKsLT_aZHc_5MsFMgR#n_T^j-Dkgg<8,:
	7E-&oMgO76t6u."H2@KHFOeSYd]#VE*\`_h8S[4c.bii^glt@g&+"cgJc#);n\#jOCG@5$p^UPM9:W
	omYqnlY<pggpC!Pnh9-;7AV2#C?rq.FpHb#VMi=-ftOXE%>\cgs9F.uGNB&gG'_em"=b:!1Z&A"nlY
	O\.m+8=6@&WuVU\gbUtWXWBIYMFP@CgY5BSj>5MoBcri^1c)'Nq<QG4DeF?jVc(&*XmF,-<$GM^s3d
	pCB3C:>;3uLS/"r\=@nU-f/_TGo&DmE82UD<(d,P#/U<[FtHZW<`V)a$MUtePXY#;l(D.*=/0?]41M
	QXbmAp;q1dj.5d&?:Q!^^+L^S4T-1:FW+qA1nHU9UOmoQX6'BD5\Hr3/BP-lGf`Z/i:d[-5S[#qB,'
	!hI"%(B_/gIj9s>g6tYJ]'CrZ4PG,teZ\5eGiEP%MWbnl1hc`6/kpu+Y<UOWRm-kgG[kIFB>S6Ros*
	W9+(]^<N0+_G4/m0cos0$:RASpiqM*Q3t'5W>c'c4P;/L:m!.?u$FUQqdH01!ZbdamtGi[I$=3h*Fc
	1p)do3;D@(^jCh<rnZ*Xs)Db('0&Y9+HIaTYprKRAXk#t9*U^i/etN?J/=iGq;O1d'>BWQGNo+HH#;
	EtWVO>45`pS9TJ394TH'4W.d*etfj?='GfuTBkI$"Z)$<0:,'-@#\M1-PWC.WMR$BD,.`3c`Ii#7pS
	f'_4?4l[i[fY&V+7>-cCZ>>^p@(FJll^oDY[9hU1+o\E632$f0+`oV7@>^L7$PfH!_6a2CL^mjgf)T
	t?d]\c8S<9ZJ]s$oJk3^m"0gihProT`#XkB5<55<J=-i>.MRlk].e&V>'>$Ta"_js'NNj?'`dgsCH.
	O$!r&isERV8/d3OHg+Dm\]h_Mtn0*"u,;peLCjcG8Gb^g`"LKfO"5,4UmQN\I%:8L?Q0<m%M.=UF+Y
	YFt&--UOSX9;?u0j7`<GIIm2'QF$k=Q7i#@b=fTJ\b)2Fnh4&qrCYVgDcJ@$X^^7+[?]4(Z%_"bq\"
	If:]7:uQ@Mi(&OdJc;-K)9ShN?DJH\MgM,L2`J7T+,>IO%0mZr!O+(d+o-fngE.5YCGhU^,Z[&%316
	9n?fSA_D$SOu.X@$I!HKi'Qt.k&1]0,+1:SMHW!Cj`Urn^5'i`G;_=qgs%$"_Y2rk-b)QZj.ASL?H"
	"kI-)%>5^mlrh?RZr)WQ_D0>Sp2E`aDmVPo-_K_5<a"a1J3-2#Y'dVW;AOX)J_i*O5788=?e1lS)F1
	frha(WM\Z]]#3/T5CVd+#9cTjT#Z?3+2J:ngi[)&6^[@A4un.j.f&7/<WV)cW.tY:c7"jf(l?R2LMM
	SqOSW0=&%<?/=PCm.Qe6%?r+VQLss=p%Xkr2_7\k>+"rJPqKSsAck?YGY&O86E$,Ce)]p?3Mhst"VP
	#rl^o*5$i?+]pEf:Kbe&UaqY16^nZ7tXB+U&]Q9m^uY:JJ6lDGS%rDY,<+Rt&"AYQ3/X"Klh-)D`)^
	][JiX:Ud*:*qt,<@CcL;0'5p&?:OSAld!^6,!dpc`QX*Y1OPnC3>m0O0(SW/8ol\G)q,ELMpU&W2RU
	<eDW"EnWicmX4lAK6i]doM<(*ZH)dr*3L`I#<Cp5.*)Vt`_8[aO8KoO&YbCp]c?N(%]+g%X`o4B]NJ
	JGm[7fVF9ghCuba)TlLoE0PF@QH!3"'[@TN'.4]I4LplJSc5r:>gbg^A;><-?[_jJM5LB*GmL<$s((
	YR/)Y&1H06&8b6Bq9>ANDg"W0[!7m*4j.'HCKeE:8^G&P?tj\1BhuCM271"B=P4=gC_*[?1t9g_qc9
	U=MnHsl]Rj"G".47!_1Xpn6CqomX!4MEJ<O(@5^D<!'!W1.n0W57aB1UD6o8n&ga7aHC!@W77diheN
	:,IthupYZZ9'<t[M#T<iA)U0,/TV/+;S.HCp&UOXD`qZe.R2N?!m9JD*KXUpm(=*1#Y@bS9")S;d]A
	g<Nop'Y$Hrh)HX:&Y1W?_Jg54&5^XNq59[c*fj;8U%oq4eDGruC8DoTG+bNDlQ%MYOJVgBX:Z+6*H'
	k["BB5b#2`dkmk]Eht&mt]@(Vn&Un+J&Vd2K"'o_Z2aJ;GUb9Z.>3g3fD+&J;FXG.N1erN<p<=%qUB
	8JWUT:k4H!e93E@5S;p9hmfu2[gf`Tpt'`eg4%r2p3U/aP.8-&1Jk>0\t[GTP44]ZprX5@dR<_arkJ
	+!s.pNkPGk;i;)="#oUEtRLLgfF<M<k&@kO>Z4;4Y]#ZWDU6rZPu9>kl46q@G>G5-q.NK5G*+2<7SV
	[*j9h\p4-D@KZh\!5k@1"6XW1RQDiVbo6)F.ko3N0`af>ka88\hSfVdJn$0Wl_`=n/t@6=`P(R&E:d
	.]^.OfcFm:L_\JP)1bskSLdQtIe;oY!roqq;f2!K<"#EFZO!C5]*'.j@ZX"qJs1qbYST_>)6uXV*'+
	/u"*b,j#Rm<C4;TU8:6ma^OS-$@uFAZ8LWi']619rYQ=W,jlin[bCkG8os+4u&%=?GO>fkW$sef7E&
	gh@i(^&93.U5$\"8b[sqB9P]k#oj[>8uO4M9d18BGh:*\>9^=]eAfdmTq=QPBoZ3"[Biok5YNE^a`q
	V>YlPI(N2iUC'h'=2,F"tI.OeCjSPD7O0c?_b>(>Anmag8>*^0)jN[(arLt&PCO).,B%E&bhLH]ba;
	/RDL/SCjW>^oAUfD]UBCdoi!.m1!@9]BVYOKCq1A?c(0n[l]$;Uc:5Pq?[@q_WHo/GltP2Mg&J*V2.
	QaHD1sP=.tXA.U"/&eG@[)(;bH5Uss\%0^B56KJILp0]q6)+<j+C8VV-7/RVFa3dFfAm@"\&)&aAD<
	s(r"r`jiP;."nnOV<G0jM1Zj8l=^<Y-8Y`rn^TRCX@rM#"&Tj4b,&`0&H@`\3+:Lo-$+M'`]U%\eel
	qQ6EgOse&u/Y]!/]T[:e=d3Go&co`HJ,ZDnYk$*F4K&d"Au'WXB7":h(Jej?)jiO(6fH)Xo?cbl[]2
	Q$U_-D8rp&q6^`#cI?F99t's(Hdjg826O"#;.3[raln_jD;L`$l6d9/+rS'rP!+Z.O_Gr+M3T9:k[<
	E\>K17'A?<O.0dK7CY,FsLfHmRktc9OT8r`l,WH>B\%#9s5R$o\/7k"+t5Ul*<UkaCjg[bdQWpBJn"
	GT[MP.IH9dUn-Wn6c=Z$O(0B?\YX!aAY*fF7^s<r_24/YJCOnrZ3A3rcJsa@_C8jSFNKjt]>W8)-n[
	5>\qY#'NZiA_Unk/Ao/#2MImBP2/a7a/kA.sK^Ni=tor6H0cf`'b)n%ADo4!piR,H9(q[EhQ_S>A(t
	USe_$hqA$#eWP7nU+/P7i*?i9oRA@sm9/93Y'Kd"F-ntR$d`o[N,\mPYs_/1]>Dd[6]kbR_RmND]Xk
	/C1_H//)P3K*/l)V:G6WMQW=Mir*A]-$:Ca+:i6\-OQpSJ.omV>!5Nd(2gu+eG(!g'_F*;!aW+]icC
	'iJHi6&gNQ%,?Nq3UXqhH1ce<q`.JLuuKu?*kDpJ'M8[W?YmP_:KX#iEu!@h=8kt/H_o_&H@]6%.P/
	Q_qDN`lnceD4P%Yq6!sJfBJ9'L"64qIJ`kVhSmVAu=$b>A(A*n6Gpf$A4P0(/<4)6LP)+o=Lo1e[,+
	^Q05W8pB9UhoNCNB:k?nNlEV+othY<3nC-k/)!G/T_olUh]&k/D.hnN$-WV<!#-'2;CaE>UFbIXHUN
	p"rn)7[lu=W1Q9#pW!AaJ)&ZS7/r*-`"=Sb15p&&qbtYXBufW_J*YfQ]3IIFIM-cC%>.H8Y5-!r55*
	IH34'KER"*/SnG`L(I^kFcJ0)l6!!!!j78?7R6=>B
	ASCII85End
End


//^New one has white background, is about 1.7 times bigger (it gets too pixelated beyond this size
/// PNG: width= 259, height= 159
Picture ARILogoNew
	ASCII85Begin
	M,6r;%14!\!!!!.8Ou6I!!!"i!!!",#Qau+!/O2/7K<Dg$#iF<ErZ1J3WK-f3WWc@<t,-0(/@Fh5u`
	*!m$r9)PZPH:^D(>;).l@AWIB$BPg.7e(,so^/AYXX";+Ks"XKh8ZiL<r$B.r>2DiB>m'/r-,(^Lp;
	6LmJ&edp^g3.CD@UDiG$29J]64aiC7Td=pq`K?:_jomPkBoMW][-JfB8.n2Sk%2^!>tK'AE<T7b/j8
	OP`]a>lJ]X9"U,&]d#jH+M^fqrj1!opCOqM)>['t(=0Ff1l;Yt!A`VQ3\pF$a;GpDNF_Bdh6IKO(GO
	OC*Z0mQU>=+f<Dba&&DTNrZ>bAQ%SN7K-+5ar+)S&%Q,pXaPhRpCQ4#M&,[aJhGdF$>nhli1.1K870
	DId;=[;4At^2"tFB;H]"r)':gX]i-4<I-TE24,FJHBb%oT3%eTR$bh1`7>:8aOO\0E8cCPXU_C/6q"
	ti9:,9p]6sEp*Ej>k)H^-F=Xo[d/1f!fl&o5ProKJRFD,@KC3Z:0F!`e->^ntPBk`>4*R_'lOm=gNQ
	VdA@YPNK7:/4PW9@LG^OfRG@$$S".eAjq&H?sCDX?I\a>Rde*^3pArHVGRmWMuk:EH-;Z@H;/orG1T
	AEqGgKjQ,C#W2SI[DsJ9tOfQ=ji5U`YnCtj93dXCj92hfhkKfdP58YVH_s#^!pC>!XX=To*Uo(#DKn
	XC!\BuGh(qCPS`NQsUf"6.T5C`"MXh'!/-RX\'Kl,YWePPcQ\Jd`0]m>sXo1lW\`5fp=`5G&37)[*b
	/mZ&1ac[rI;,IN[dUqR?YJ-!Qd32RPHhM8dA7TQ);?$d/Sr?qIdY"#J/)]8[5O$Pge>ZAD;,Lb1@Bm
	)B2fIP0Cg]`8]'G\5<t<,D#7ftaiS+_V<nQ)RJ*)[jUXJH-&_C0^'tlLG-)6W^8ld!EjcSG;q*?bcL
	[@'`E;\.l?QM&O@3qFEWUpM]TV^aOJV!ZBBM?`:=2u%6ME**I+BM0,4$q*(-Wt1E)3qCB3q89#5<mh
	<Th':Ld8?OO.L-CW.O[h0&+t&5hS%XpcRmauh>!mQWPr"W$9q)YlmZ1TD>D!XCQ<3lo0\/UGFP!8FR
	5r%GU;j%E3MMIlK[ZbX(o'=f/c\GSjT[8O)L>>+J8To;6<FPpEuf=WEa5*n#BmH9@)2^?R,pQq@sB2
	iCh(*^Y?59?ajoY]f2QBY2,jZP6]Sb>.n8@+f2Pk>cXucX=q<"EOVsJW_b6!1c*T@]Upia4p4q;.L\
	)bqtKQWV56'ESY,)#X32DO`S<q=#1W"WWKfMah+,UO2P/2QDc\+g3_+G\Rr8eS*CH'@X/`2BbKCP4'
	@342fAM.N'<Wrjiu>p>CN:_5ELLM._mT4.M-TXqq-[ES?FL2904'#GmU!Drs'X0D3u8PDoAie=S*,+
	bcIEE@AksOQb>mMZ_@MQdT$>?JWhFm(B4em4e<JGi(9KNbg[(]1-TjKuot)L$.Pik:+sJ3W-0<5jCY
	N)IhmcWEj)#3>/Qs`3dSD]bW2>N]?g][(c.>9f]UkcQI$W`XGko@oRi#]+b:a[#Qo'##=0>fUBJaAe
	PUpirF5u9><%:mS?J\VM[r&;J'l)S>U@hQ(;n8dmn$M`910E2(5=m.PdR$soQU#42bOR=BHHJD=rG1
	$UV:&jsFug'!b*=JMQS+8RLkq"Kbfe2Y<ZDbc&l,&_h3@&=QtqHgZXuM*?F'PSd[RHOY<4l!B%h-if
	@,nmHkrk2-l&A!r"9=\,^]u>q.(PWGe;?jT\#5Gh%.Qmm<'K.Y$JYS*t3gXLTb$t]'4(d.bDeC*L[@
	9b>hY(N7<_46T*DYAgq%7KW2kZM9]`$C6Zj8W:<Yqc71$HZ>;Hk`G!E4R15bj4VJiA!n[/7f5m<o[<
	frX,r%,/#F\eLDNe>'AiV`8W$6ccrj7Rl-M>`LTWU7b3A%lLMVsJe<#0=YFuhg%]]2g81Nt^VD7*3J
	(Z7$[:=]fVUiY]3\:3LprZf+'rqn.hcI]7,Df3J$a7[9D#BfK6Rh!t*3VQ,>3N3a@r5H7-YNEZU%PO
	M.@,>YrPF*5?B,(?%bZf^746hFTTkZ1>@/3$*BOe[Ip"*bOC7s)NUq_D5Y--J"f0N".XTMPN:H#pV&
	$tijr4`amKtT1]3=+/9Au@F8QK]k]U[V&kIMS&-Lu1Qtn`(\7<un9?Wqnn@])_PKmr"4q((.oE.k@0
	[[kY$iNc!./$(J[-C<\jfZ2p]C&'8=%f62DD#dRm@XM&;pH9t]mQb\QV9FJlsR_TUQXsZ9"pd1-:)G
	.5pUcQ$PL&K7Vima@092%GTs3U6/.,#M>7;0"\Wss,UH0")NS95iZc%g,f#Eo@QBAkoLipht9=q&lH
	0f+RB%$k]R2OB(@OrLAPYPES5$_7X_HUAc!/:$d)I@WF`n#%aW%GKqhpXb+7H[eRN:.cBAQ)sa&b8E
	q\5YJHq6FqW]_KF([AQlJ:\C"c$M8TaZ0eiV@<8169P#O&3"e*Ia,Gi'0%;t>4*u@0k.)J3:[Hj2DU
	H9P>Ii'f@>\T;1C,9+uh#9SOXQ*bi"@*5"F`.&Jrji>T+<-2HfjD<%ZCI>f\1YeC?PnGM&r@XW$!=]
	HU<4*#nWk]E$:!p;0BTOEeX;c$N:eQn]Cjhd>GMUh9:;,XZ!`Q/6[Ne8:*J]-Du]%H*CEP&S)NYA`O
	!*OV6_nG6Ph[js27+R"ket>71e)8%25Rm),$AQ#H&-\YZHK$#ZaJ9OA<W$)R<Mer>r"9qEi2'A/ou4
	cDguN#M]PE&sG]($@Ln(ME^cEZYrB0qYF70f:emmSZXlg[<GlbVa>5BJ9`R&?q`q-(sYU%h2hlpO:?
	K>(L6f=Rs@K^[ZH>sN)S`o.iS,e0ER(O;C=#m,4e.h6g]V8cWL,AW`NNQK:O?d08*rC?nDBt]V:dr_
	CN'Ed^H$6kl+@Bm=cbe#<pZ%S'+UYe%%ZPG3s`og[-*^pJl-<okMu_o#AElZef1F'L38sXML;6AWS(
	5Q]2A/,&mt,_&L!(N1DOA?mZ:N@U$P9b,.,19XQ4=bs6W5TboZqTIq@33SqrH(4et8hJiZOB3BZscZ
	YYhrd(!k*j@l3VfUZ)]@qjJs3Yj0*ss-`1Y?,"'N5rTCcrX&JaElcLBtdk,dp5k@c;p_"5-B/ILRr/
	=TG")Z<fg,li[.s]3mO,$D*Bi0?,4<+#S+?U"Vt6nPeWBq[FJoTVQ@)6f;`Z:ZkpXfTc?T=q2655"*
	&66PhcnJ>%eq,PhC;Dm8cKD?^aUE/t]-kUrE^Kc:fVCPXlncpETB*#?95DCC1RXtU6_'2f(RUD8.jN
	b9V0%1Cb;<\8^mSS`0is8C2$H_:f8?b'WBL^iS4>g"8Q5M/S:RjjtsA,B=3GJW?-Y_8^&)<#1>q6$Y
	TU>C_',('YkZVB6<R!;+lVmNf*#ask>G$VWkMZE*u;[.RkZT[\?696!@,EgF[UCbGPa#B-kRnOU$,5
	P4N$IP*$ZEMmB#4?Y`IJE='dA'@nS!c()!Q537FKW(_+26UcV@$YVV+89]B%cP\]"L[r2rS]%"-]=D
	IaH?XEX5$<)*40ocAZj"+4<eE!+?.b2%k8C$WQ8KbR7S6R?9o<m=JL5(<*KcG+6jp*O-R3#tXCoX:[
	p9]pVNj^ErV>2N.:cOS3roS[lDi"J1U2.tV&Gp[[EY"0hm7NI9AN\WFP#lBmQFn+YOYa1S<Xp>5*DR
	)iZJL,i]0L@'(&HuKG0Fb0A,_3/e/-R,*T;\l;_!7Oa[^.epp5sDr"#9HD`+rO<He/$.cUm&'NL<L%
	9J$l!';cBlu_tDEPd]Qm!iD`?=$dVr0i6'\T%G3Xi*;gZ:bBSN,K5mBA7lW;7nOk-P3HNf>c3]h_+S
	/"hKb-;TYm%/PFZXlRi9fet\emmH_:0L),8+46;$b`D7O)n<lAW\]A2B<ofC;\(l`/:<0j"#9^DDbZ
	/6Z]+>,Bj5M?$A!;ef-D?`+I"7VF.?Z<4c%n1@&r+=;lRI,al-o;mX72C=8@Un:W]f#K3GK)#h\B=3
	=sYS2o0m<t@^`"@h8Jec-nKMb:[enj@faC`u[_\IWCcIT'YGr@@\$jts&F&"\3GfEpfj(=.XI%ki9[
	j\@i'9be"*m8^?^P@Id').Pg6?4ND1/c8qMn3Umjo4YS(o2_=JpDhigB>Z6Ep5neG=%[KF=`#$_?bh
	RB^6CrnOTQciIT4RiGDiY#H7r2F55&`IK:.uM=KV1H,a$sq^-&Dj``!<X`$cW,aFHj9X9snkoUsj5A
	o_XTh0RHRq8->W)JK*$gO&i3RQ+^@3jj+L^,.58$GHD%L_[#e.]B2_l8s=+1#?;#>Hb(CtL$%n?X8J
	$1"S!_0&N7G>1+afJ(TCepc:p?<54<4j*(i0QLSD\FkB/['N4a"S!VQ!tf;V`V)inZ#E4qM9NTjX0P
	uekoBO[Z4F6L2tW^V6?Gt<cW4%G>N*0\gE0#Ah[Gg=7p'bUUf3A?lb)U_H0HDd(OI:84muO*4i1UF!
	t]s<GQ?`S#U9msOZHq0L29<]QdT%n$Xqs1$>NVSn,#ISZ3b(t?EN__i/apUE36.?@dR6u4PHa9r_*o
	h/W8L"f\b8lT?SE*HE8#b!aEXlJUb^N'P>5p>9`?fkQ=6OWeo:jTmLgRfIR0_G:A2MaG0@'*Q=^&;/
	2I1M<fOok-jt_<E225CMC7qV9jsu_(+t-."c(arHZe_hr:CW9FML,8(8@&#Di4!rXeU-KTUDW(>?''
	6^L\b+O%h!Dni2RA`387pp`+i.5(42T$?=mQcr60P$_^6P\W_&I]ZrFe\SUC2':C?(!="3aX./K*6]
	6q7SgqEQ'&5DhDG[_3._U&EC_J-WEL]Ip`W_-e0SiN6D&7nGH<.&'2$'R4#eH&L"SFI-7Ej@_IXcpd
	=F<C/]k1N29rUJhc?rZ51T4t'T-:N8-o2f([LgNRZI2QJeCR<`cttSb(qJTT>^4j=Lho4&`WqH_$F(
	4`ZfQ.flCjL\17E</#B$`QN_T9/O)ts6XH>E\JV4;"=GJGLkd1_`+5r2cEioSNdh[72X0np["_MS>]
	6/qg$3/-HIeqea=cojWG=0[[:/,17_19i;Dl5JP8HKoqG$:TN1Pd;(QSJg%V8f\4rUDaeAC=PZD'Rh
	5T+:.8JV_5pgP/aS*m)b9&50$"K&p9'+g3mXNe1)0cBG4lTAdu&X#`((=I@*D&C0jc/_T!<E66T]/.
	8%%q]P%^p+;gA>g.d-=c(rSL7p\R1R0p&DS$T?,`m)!]5RBZ>_DS>=<PgA2BADes(?C."!aDgd]:to
	D.jBKee**Kln00[]J]d2N1'eZmL(dO/`'\gqrQ<Ap+B:2@uF=HI)*JH6$9IT\:%1D21<q_4,F.Fj(X
	l5:-Rg.0R*`G_G)lNGgpO%3[6h[t[<jLtG&TNp;3q6BUN<NHNPt8`gO,isSad%_#l+ljj=QEaXY/DI
	$X,_SDW$\Z`!C<?GJ3i"a5tF;Cu+C'X%[,jltdidBcn_eNVf-*C6J<J:?YHY461jUm:<T,bJ5X("41
	5A3`#C27TZ8QDuuMh9rk;XgW:Em&k:JtO<\6&t%j(-)L3;/$?./#"#XTR[9L[O,k?->d4QZq];NBk+
	/gqdGh&QVp7h?$>>OI,CLh[kg,;bk%I9>fRqH.V*<LYmTJ@8?=#7QBYnGD'84*)5kPRP2/NDZeCU@\
	P\6Reo@lb_@S*/6H-u'R:jD!4#Q\L>#]si--.1K9UDTc82SBXU3VRP`o:809Hg9dUfu1bOXnPcTSaM
	GYC+4!q#:jB(tZ;'g=3S#J5NE0&$%,@>p-n9r77R4`NlP/F\gcFO?R/lK;mNaXnfCCC+O@n")A_2OW
	^)G(>0q<7l1bH6GuXaCn$D3A=O_agA_bMT73j0a"nh?j4\YM<sm]ib[E)Q=>_<&bp'=YZ]ls\I<J[`
	->5a)Wn%B6Ak:g0<?PM]WX.(mDi3ln]nP)>nN5s1'a(]ML)f=5RZ7J/o_iTJA7/XG6*RL57THag'1F
	9K2^]mnR2K@/0Oo82SCO'E<IRBYKGS!<$RQu%f.!F?PK#0J@(A3KS'2XB;f-J*V-(9<XYG]5[UKAlm
	gCW5.0!f\%9C:V\UO5+T2b#\LKE,'=Z>G*P]j>3Wq6(SbiuGD>M6H9Z9R0KC?M8s&mh"OfsHC)FP`(
	t/HfbfY.hFB+Uu4=PRZA@f.L&DU"ag#^3pCB*O_XW)@+E"qeV.3.\e@5)Hh\m(m=2U#Rir1`LcG$8S
	aib=<6ZL%<7Ja36E.5c'80=e"DAgC8S,>YZbu6KPq3eGHiJmm6IfC@AP'O/\$SB+V*C?6F2JJOORt(
	De$L+K\T37FDDu>gI.)kdAQT:Wk/#H?R*LK(sih!%4*_+:H)C^TKNAn5sB;R;FfCkB.nXUZR-=<(0l
	8jiN:,13g_d%GU;:_LThb-($qkBobcp@O=SFg,JV2Cn"`A3r^UE4s70QrMTaNpBt:%e&6oYm0WZ.Vk
	Fic^+EmU_"cb?p>;.#VO9OY/Mp!H;]l<LNKb%(2gd5*b_rdKmm3=BYD.W(6A^:UWT0Rj+]pp]gUTiQ
	"Va_W*q7ad5dk=/WZ]A@<p<88dTuO.(h,shoobNjKbsbdq-6`o7eW5uE3.%rIUY8OLk)%8n<r1hl_R
	cjo-/b+^8/BTACp,+pNkGm4S0GR:SY"63E%U=>BV!UTa%d[ST[^YoUj[-uX_//\Qnl<sdiaX6q67r2
	Kr\ACcB>SMMdPbqH_IOqMH;#$WJ&FkXi*T&ert9IbgYi2<.<$;"j82N,[n8SFV1#%enLek?Jh[LY!5
	SacW(O08Y4<\pI5pS7lVIIn4k/]NNaC38k:p,;QW!UR!BU\An\V:+q.In;4Qoc)i5gI8[O=8Ngd7N4
	oHEBE=:\j1'Xn5+@O_g&=uO:+`V)[4@o#Tp3t)s'4d[X]8=3"C%d\B2P",f(F?bZIV'O1-;iUtPjC\
	Mf=],XqX3dHAL(La6+HL1O6!d5E=07>SEBf2[T-<co0f_:1oJb[ZG4+3*%GkI]^q].4$"o1%p)%.mb
	NBNFSZL/4\rmloDa-]4=smIFHT$H2M*C.D>N\XA&tUYC1L7k*C]-i5j_R,a<Qhc^L15I;tn6aqX2hm
	aZ-g<JoL%RhoF>RVlZBINlU9cgguo;+I7dCeCIq(rgpj9ng#toXt&8>rugjSQg,CL$jUanAL`#*]H5
	Su<%hM-]8W8\[Z5h96g=!MG#^\K'jYtt?.=6iFW].^U66"uMCuN0C\r&-4nnWqqYlr`NLhAtc]pu1)
	Q-'8)Q-'8)Q-'8)Q-'8)Q-'8)Q-'8)Q3Q=W7GbRC,a3"z8OZBBY!QNJ
	ASCII85End
End

//////////////////////////////////////////////////////////////////////////////////
/////////////////// Misc Functions - Not Necessary for squirrel  /////////////////////////
//////////////////////////////////////////////////////////////////////////////////


// Sample correction function for v w switching
Function sq_sampleCorrectionFunction()

	wave ToFTypeVKey = root:diagnostics:ToFTypeVKey
	wave ToFTypeWKey = root:diagnostics:ToFTypeWKey
	
	variable n=numpnts(TofTypeVKey)
	
	wave corr_fact_user = root:diagnostics:corr_fact_user		
		// there is currently only one non-airbeam correction factor.  It is segregated into v and w segments as necessary.
		// note that corr_fact is the airbeam correction factor		
	
	if (waveExists(corr_fact_user)==0)
		make/n=(n) root:diagnostics:corr_fact_user
		wave corr_fact_user = root:diagnostics:corr_fact_user		
	endif
	
	make/o/n=(n) corr_fact_V, corr_fact_W
	corr_fact_V = 0.9* TofTypeVKey		// supposing we want to multiply v modes by 0.9   
	corr_fact_W = 1.05* TofTypeWKey   	// supposing we want to multiply v modes by 1.05  
	
	corr_fact_user = corr_fact_V + corr_fact_W
	
	killwaves/z corr_fact_V, corr_fact_W

End


//^ not used in any code & is not intended to do so.
//^ Sample Usage:
//^ sq_RoughAvgRawSpec(14850, 14852, "myRawDataFolder", 1, 1)
//^ does a simple raw spectra average and also calculates an estimate of the m/z wave using the m/z cal fit parameters for the first run number.
Function sq_roughAvgRawSpec(ToDoWave, DataFolderName, saveIndividualRaw)
wave ToDoWave
variable saveIndividualRaw
string DataFolderName

	variable idex, num, slope, intercept, power, firstRunIndex, RunNum
	string str1
	
	//^  get the parameters needed for the m/z axis
	wave/z mz_FitSlope = root:mzFitting:mz_FitSlope        //^ use root:diagnostics:mzSlope for logged version
	wave/z mz_FitIntercept= root:mzFitting:mz_FitIntercept    //^ use root:diagnostics:mzIntercept for logged version
	wave/z mz_FitPower = root:mzFitting:mz_FitPower        //^ use root:diagnostics:mzPower for logged version
	wave/z rn_series = root:index:rn_series
 
	if (waveExists(mz_FitSlope)==0)
		wave/z mz_FitSlope = root:diagnostics:mzSlope     
		wave/z mz_FitIntercept = root:diagnostics:mzInt   
		duplicate/o mz_FitIntercept root:diagnostics:mzPower
		wave/z mz_FitPower = root:diagnostics:mzPower 
		mz_FitPower=.5
	endif
 
 	num = numpnts(ToDoWave)
 
	firstRunIndex =sq_findRun(rn_series,ToDoWave[0])
 
	slope = mz_FitSlope[firstRunIndex]
	intercept = mz_FitIntercept[firstRunIndex]
	power = mz_FitPower[firstRunIndex]
 
	//^ next average the spectra

	NewDataFolder/o $"root:"+DataFolderName

	for (idex = 0; idex< num; idex+=1)
		RunNum = ToDoWave[idex]
		sprintf str1, "%d" , RunNum		// small bug, things can go wrong with run numbers > 1e6
		sq_GetThisRawMS(RunNum, DataFolderName, "Open_"+str1, "MSOpen_p")
		sq_GetThisRawMS(RunNum, DataFolderName, "Closed_"+str1, "MSClosed_p")
		wave myOpen = $"root:"+DataFolderName+":Open_"+str1
		wave myClosed = $"root:"+DataFolderName+":Closed_"+str1
		duplicate/o myOpen  $"root:"+DataFolderName+":Diff_"+str1
		wave myDiff = $"root:"+DataFolderName+":Diff_"+str1
		myDiff = myOpen - myClosed
		if (idex == 0)
			duplicate/o myOpen $"root:"+DataFolderName+":AvgOpen"
			duplicate/o myClosed $"root:"+DataFolderName+":AvgClosed"
			duplicate/o myDiff $"root:"+DataFolderName+":AvgDiff"
			wave AvgOpen = $"root:"+DataFolderName+":AvgOpen"
			wave AvgClosed = $"root:"+DataFolderName+":AvgClosed"
			wave AvgDiff = $"root:"+DataFolderName+":AvgDiff"
			//^ find a m/z wave the first time out.  Note this wave may not be needed if you aren't creating a plot
			make/o/n=(numpnts(AvgDiff)) $"root:"+DataFolderName+":AvgMz"
			wave AvgMz = $"root:"+DataFolderName+":AvgMz"
			AvgMz = ((p-intercept)/slope)^(1/power)
		else
			wave AvgOpen = $"root:"+DataFolderName+":AvgOpen"
			wave AvgClosed = $"root:"+DataFolderName+":AvgClosed"
			wave AvgDiff = $"root:"+DataFolderName+":AvgDiff"
			AvgOpen +=myOpen
			AvgClosed +=myClosed
			AvgDiff+=myDiff                
		endif
		if (!saveIndividualRaw)
			killwaves/z myOpen, myClosed, myDiff
		endif

	endfor

	AvgOpen/=num
	AvgClosed/=num
	AvgDiff/=num

	Note/K AvgOpen, NameOfWave(ToDoWave)
	Note/K AvgClosed, NameOfWave(ToDoWave)
	Note/K AvgDiff, NameOfWave(ToDoWave)

End


Function sq_roughAvgRawSpecNonp(ToDoWave, DataFolderName, saveIndividualRaw)
wave ToDoWave
variable saveIndividualRaw
string DataFolderName

	variable idex, num, nOpen, nClosed, RunNum
	string str1
	
	NewDataFolder/o $"root:"+DataFolderName
	num = numpnts(ToDoWave)
	nOpen=0; nClosed=0
	
	for (idex = 0; idex< num; idex+=1)
		RunNum = ToDoWave[idex]
		sprintf str1, "%d", RunNum		//1.47I
		sq_GetThisRawMS(RunNum, DataFolderName, "Open_"+str1, "MSOpen")
		sq_GetThisRawMS(RunNum, DataFolderName, "Closed_"+str1, "MSClosed")
		wave myOpen = $"root:"+DataFolderName+":Open_"+str1
		wave myClosed = $"root:"+DataFolderName+":Closed_"+str1
		if (idex == 0)
			duplicate/o myOpen $"root:"+DataFolderName+":AvgOpen"
			duplicate/o myClosed $"root:"+DataFolderName+":AvgClosed"
			wave AvgOpen = $"root:"+DataFolderName+":AvgOpen"
			wave AvgClosed = $"root:"+DataFolderName+":AvgClosed"
			AvgOpen=0
			AvgClosed=0
		endif
		
		AvgOpen += myOpen
		nOpen+=1
		if (numtype(myClosed[0])==0)	
			AvgClosed += myClosed
			nClosed+=1
		endif
		
		if (!saveIndividualRaw)
			killwaves/z myOpen, myClosed
		endif

	endfor

	AvgOpen/=nOpen
	AvgClosed/=nClosed

	duplicate/o AvgOpen $"root:"+DataFolderName+":AvgDiff"
	wave AvgDiff = $"root:"+DataFolderName+":AvgDiff"
	AvgDiff = AvgOpen - AvgClosed

	Note/K AvgOpen, "FirstRunInAvg:"+str1+ ";NumSpectraInAvg:"+num2str(nOpen)
	Note/K AvgClosed, "FirstRunInAvg:"+str1+ ";NumSpectraInAvg:"+num2str(nClosed)
	Note/K AvgDiff, "FirstRunInAvg:"+str1+ ";NumSpectraInAvg:"+num2str(nClosed)

End


//^ Along with sq_CorrectPre138PToFSticksFetch, this function should be executed once, on all pre-1.38 versions of squirrel for which the user pre-processed the PToF sticks.
//^  See the release notes for squirrel 1.38 for more details.
//^ Note that this will correct all PToF sticks for the duty cycle correction, and will not mess up any dc marker correction that may already have been applied
//^ because the DC marker correction works on individual m/zs.  Yippee for the distributive law!
Function sq_correctPre138PToFSticks()
	string ControlName

	wave all=root:all		// We want to do this correction once, on all runs, regardless of what todo wave is selected.
	if (WaveExists(all)==0)
		Abort "The Get Index function must be executed before this function is called - Aborting from sq_CorrectPre138PToFSticks"
	endif
	
	nvar/z ver138_PToFCorr= root:diagnostics:ver138_PToFCorr
	if (NVar_Exists(ver138_PToFCorr)==1)	// if global variable exists
		Abort "It appears that this correction was alredy performed. - Aborting from sq_CorrectPre138PToFSticks"
	endif
	
	squirrel_fetch(all,sq_CorrectPre138PToFSticksFetch,"dest:PToF_stick_p","PToF_stick_p;")

	variable/g root:diagnostics:ver138_PToFCorr=DateTime  // sets variable to the time, in secs, when this correction was performed.	
	Print "//The duty cycle correction was applied to all pre-processed PToF sticks on "+date() +"  "+ time()+"."

End


//^ Fetch function to extract other waves from the info val or parval data sets.
//^  Initial list of extra values were created by Ken D to help with some error calculation issues.
//^ The list of values to extract is intended to be completely modifiable.  That is, no other squirrel functions (as of 1.37C) uses these newly created waves.
//^ Note that it creates two new, somewhat duplicated waves of diag_list_More and diag_loc_More.
Function sq_correctPre138PToFSticksFetch(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn
	variable n_acorns
	
	wave source=$stringbykey("acorn_0",paramstr)		//^ PToF_stick_p
	string dest=stringbykey("dest",paramstr)
      	
	sq_dutyCycleCorr(source, acorn==n_acorns-1)		//^ 2nd param indicates whether to kill some items set up for corrections.
	
	//1.14M  UMR
	squirrel_hdf_write(index_pos,source,dest)

End


Function sq_findNewFlowRate()
	
	nvar cor4_flowRateSlope = root:panel:cor4_flowRateSlope
	nvar cor4_flowRateIntercept = root:panel:cor4_flowRateIntercept
	nvar cor4_flowRatePlot_ck = root:panel:cor4_flowRatePlot_ck
	
	wave flowrate = root:diagnostics:flowrate
	wave/z flowrate_logged = root:diagnostics:flowrate_logged
	wave analogIn03 = root:diagnostics:analogIn03
	
	if (WaveExists(flowrate_logged)==0)		// we need to accomodate the situation where old versions did not create the _logged wave
		duplicate/o flowrate root:diagnostics:flowrate_logged			
		wave/z flowrate_logged = root:diagnostics:flowrate_logged
	endif
	
	if (numtype(cor4_flowRateIntercept)==0 &&  numtype(cor4_flowRateIntercept)==0)
		flowrate = cor4_flowRateIntercept + cor4_flowRateSlope*analogIn03
		if (cor4_flowRatePlot_ck)
			DoWindow/F FlowRateGr
			if (V_flag==0)
				Display/N=FlowRateGr/W=(100,100,500,350) 
				AppendToGraph root:diagnostics:flowrate vs root:index:t_series
				AppendToGraph root:diagnostics:flowrate_logged vs root:index:t_series
				ModifyGraph rgb(flowrate_logged)=(0,0,0)
				Legend/C/N=text0/F=0/A=MC
			endif
		endif
	else
		print "// The flow rate slope or the flow rate intercept do not make sense, and a new flow rate was not calculated."
	endif	

End


Function sq_findIE2ABratio()

	nvar cor5_IE2ABPlot_ck = root:panel:cor5_IE2ABPlot_ck

	wave/z IECalABVal = root:diagnostics:IECalABVal
	wave/z IECalIEVal = root:diagnostics:IECalIEVal
	wave/z IECalTime = root:diagnostics:IECalTime
	wave/z IECalRefFlag = root:diagnostics:IECalRefFlag
	wave/z IECalIE2ABRatio =  root:diagnostics:IECalIE2ABRatio
	wave/z ToFTypeVKey = root:diagnostics:ToFTypeVKey
	nvar/z VWSwitching =  root:diagnostics:VWSwitching
	
	wave/z IECalToFMode = root:diagnostics:IECalToFMode
	nvar/z VWSwitching = root:diagnostics:VWSwitching		// 1.42E fix

	wave t_series = root:index:t_series
	variable pt, temp1, sum1, temp2, sum2
	
	wave/z ioneff = root:diagnostics:ioneff
	if (waveExists(ioneff)==0)
		print "// You must first do the airbeam correction before you apply the IE2AB correction factor.  No IE/AB corrections were found or executed."
		return 0
	endif
	if (strsearch(Note(ioneff),  "IE2AB", 0 )>=0)
		print "// The IE2AB correction factor has already been applied to the ion efficiency wave.  You may need to recalculate your airbeam correction factor.  No IE/AB corrections were found or executed."
		return 0
	endif

//^	1.42F change.  Tim O pointed out that this formulation could be problematic.... To avoid complexities, this functionality will be essentially removed in 1.43
//^ 	When I get a more detailed tutorial put together, this will be reinserted.
//	make/o/n=(numpnts(t_series)) root:diagnostics:ioneff_to_ab_rel_ratio=1
//	wave ioneff_to_ab_rel_ratio =  root:diagnostics:ioneff_to_ab_rel_ratio
//	
//	if (!WaveExists(IECalIEVal) || numpnts(IECalIEVal)==0 || !WaveExists(IECalABVal) || numpnts(IECalABVal)==0 || !WaveExists(IECalTime) || numpnts(IECalTime)==0)
//		print "// Could not calculate IE/AB correction because no IE cal values exist"
//	else
//		redimension/n=(numpnts(IECalABVal)) IECalIE2ABRatio
//		IECalIE2ABRatio = IECalIEVal/IECalABVal
//		
//		ControlInfo/W=ams_panel cor5_popup_interptype  // value= #"\"Interpolate;Project Avg;Step function\""
//		switch(V_value)
//			case 1:		// interpolate
//				pt =BinarySearch(IECalRefFlag, 1)
//				if (pt>=0)
//					IECalIE2ABRatio/=IECalIEVal[pt]/IECalABVal[pt]
//					sq_mapTimeValueToTSeries(IECalTime,IECalIE2ABRatio, ioneff_to_ab_rel_ratio)
//					sq_InterpolateWave(ioneff_to_ab_rel_ratio, ioneff_to_ab_rel_ratio)
//				else
//					Abort "If you wish to interpolate your IE/AB values, you must select one cal as a reference cal - aborting from sq_findIE2ABratio"
//				endif
//				break
//			case 2:		// proj avg		// significantly redone in 1.42E
//				if (!NVar_Exists(VWSwitching) || VWSwitching==0)		// easy case
//					WaveStats/q IECalIE2ABRatio
//					ioneff_to_ab_rel_ratio = V_avg/ioneff
//				else		// we have v w switching 
//					WaveStats/q IECalToFMode					
//					if (V_sdev==0)		// we only have v-mode ion eff cals.  Keep the ioneff for w mode as set by the airbeam correction
//						// typically we do not have w mode ione eff calibrations
//						WaveStats/q IECalIEVal
//						ioneff_to_ab_rel_ratio = ToFTypeVKey[p]==1 ? V_avg/ioneff[p] : 1
//					else		// we have v and w mode ion eff calibrations
//						for(pt=0;pt<numpnts(IECalIEVal); pt+=1)
//							if (IECalToFMode[pt]==1)		// vmode
//								temp1+=IECalIEVal[pt]
//								sum1+=1
//							else
//								temp2+=IECalIEVal[pt]
//								sum2+=1
//							endif
//						endfor
//						// first do w mode						
//						ioneff_to_ab_rel_ratio = ToFTypeVKey[p]==0 ? (temp2/sum2 )/ioneff[p] : 1					
//						// next do v mode
//						ioneff_to_ab_rel_ratio = ToFTypeVKey[p]==1 ? (temp1/sum1)/ioneff[p] : ioneff_to_ab_rel_ratio[p]					
//					endif
//				endif
//				break
//			case 3:		// step function
//				pt =BinarySearch(IECalRefFlag, 1)
//				if (pt>=0)
//					IECalIE2ABRatio/=IECalIEVal[pt]/IECalABVal[pt]
//					sq_mapTimeValueToTSeries(IECalTime,IECalIE2ABRatio, ioneff_to_ab_rel_ratio)
//					sq_RepeatLastNonNanRepeatFirst(ioneff_to_ab_rel_ratio)
//				else
//					Abort "If you wish to use a step function to interpolate your IE/AB values, you must select one cal as a reference cal - aborting from sq_findIE2ABratio"
//				endif
//				break				
//		endswitch
//		
//		IECalIE2ABRatio = IECalIEVal/IECalABVal
//		
//	endif
	
	wave/z ioneff_to_ab_rel_ratio = root:diagnostics:ioneff_to_ab_rel_ratio
	if (!waveExists(ioneff_to_ab_rel_ratio) || numpnts(ioneff_to_ab_rel_ratio)!=numpnts(t_series) )
		print "// ALERT! The wave root:diagnostics:ioneff_to_ab_rel_ratio  either doesn't exist or has the wrong number of points.  The IE/AB correction was NOT applied."
		return 0
	else
		wavestats/q/m=1 ioneff_to_ab_rel_ratio
		if (V_numnans>0)
			print "// ALERT! The wave root:diagnostics:ioneff_to_ab_rel_ratio has nan values.  The IE/AB correction was NOT applied."
			return 0
		endif 
	endif
	
	if (cor5_IE2ABPlot_ck)
		DoWindow/F IE2ABGr
		if (V_flag==0)
			sq_IE2ABGr() 
		endif
	endif

	Note ioneff, "IE2AB applied on "+date() + " " + time()
	ioneff*=ioneff_to_ab_rel_ratio
	
	return 1
	
End


Function sq_IE2ABGr() 
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:diagnostics:
	wave ioneff_to_ab_rel_ratio, IECalIE2ABRatio, IECalTime
	Display/N=IE2ABGr /W=(3.6,42.8,403.2,293) IECalIE2ABRatio vs IECalTime
	AppendToGraph/R ioneff_to_ab_rel_ratio vs ::index:t_series
	SetDataFolder fldrSav0
	ModifyGraph margin(left)=54,margin(right)=54
	ModifyGraph mode(IECalIE2ABRatio)=3
	ModifyGraph marker(IECalIE2ABRatio)=43
	ModifyGraph rgb(ioneff_to_ab_rel_ratio)=(0,0,0)
	ModifyGraph axRGB(left)=(65280,0,0)
	ModifyGraph tlblRGB(left)=(65280,0,0)
	ModifyGraph alblRGB(left)=(65280,0,0)
	ModifyGraph dateInfo(bottom)={0,1,0}
	Label left "IE/AB at calibrations"
	Label bottom " "
	Label right "IE/AB correction factor (applied to ionEff wave)"
	Legend/C/N=text0/J "\\s(IECalIE2ABRatio) IECalIE2ABRatio\r\\s(ioneff_to_ab_rel_ratio) ioneff_to_ab_rel_ratio"
End



Function sq_mapTimeValueToTSeries(timeVal2Map,Val2Map, ValWave)
wave timeVal2Map,Val2Map, ValWave
	
	wave t_series = root:index:t_series
	variable idex, num, pt 
	
	num=numpnts(timeVal2Map)
	if(num==0)
		print "// There are zero points in the wave to map. - error from sq_mapTimeValueToTSeries"
		return 0
	endif
	
	ValWave=nan
	for (idex=0;idex<num;idex+=1)
		pt = round(binarysearch(t_series, timeVal2Map[idex]))
		if (pt>=0)
			ValWave[pt]=Val2Map[idex]
		elseif(pt==-1)		// comes before first time stamp
			ValWave[0]=Val2Map[idex]
		elseif(pt==-2) 		// comes after last time stamp
			ValWave[numpnts(t_series)-1]=Val2Map[idex]
		endif
		
	endfor

End


Function sq_butt_IECalTable(ctrlName) : ButtonControl
string ctrlName

	sq_GetIndexNotDoneYet()
	DoWindow/F IECalTable
	if (v_flag==0)
		wave/z IECalTime = root:diagnostics:IECalTime
		wave/z IECalABVal = root:diagnostics:IECalABVal
		wave/z IECalIEVal = root:diagnostics:IECalIEVal
		wave/z IECalIE2ABRatio = root:diagnostics:IECalIE2ABRatio
		wave/z IECalRefFlag = root:diagnostics:IECalRefFlag
		wave/z IECalFlowRate = root:diagnostics:IECalFlowRate
		wave/z IECalToFMode = root:diagnostics:IECalToFMode
		wave/z ioneff_to_ab_rel_ratio = root:diagnostics:ioneff_to_ab_rel_ratio
		if (!WaveExists(IECalTime)  || !WaveExists(IECalABVal)  ||  !WaveExists(IECalIEVal)   ||  !WaveExists(IECalIE2ABRatio)  ||  !WaveExists(IECalFlowRate)  ||  !WaveExists(IECalToFMode)   ||  !WaveExists(ioneff_to_ab_rel_ratio) )
			make/d/o/n=0 root:diagnostics:IECalIEVal, root:diagnostics:IECalABVal, root:diagnostics:IECalRefFlag
			make/d/o/n=0 root:diagnostics:IECalTime, root:diagnostics:IECalIE2ABRatio, root:diagnostics:IECalFlowRate		// not actually used in caculations
			make/d/o/n=0 root:diagnostics:IECalToFMode		// not actually used in caculations
			SetScale d 0,0,"dat",root:diagnostics:IECalTime
			wave t_series = root:index:t_series
			make/o/n=(numpnts(t_series)) root:diagnostics:ioneff_to_ab_rel_ratio=1
		endif
		
		edit/n=IECalTable/W=(10,60,620,240)
		AppendtoTable root:diagnostics:IECalTime
		AppendtoTable root:diagnostics:IECalIEVal
		AppendtoTable root:diagnostics:IECalABVal
		AppendtoTable root:diagnostics:IECalIE2ABRatio   //1.62 typo
		AppendtoTable root:diagnostics:IECalRefFlag
		AppendtoTable root:diagnostics:IECalFlowRate
		AppendtoTable root:diagnostics:IECalToFMode
		ModifyTable width(root:diagnostics:IECalTime)=110
		ModifyTable width(root:diagnostics:IECalRefFlag)=160
		ModifyTable width(Point)=0
		ModifyTable title(root:diagnostics:IECalRefFlag)="IE cal Ref Flag (1=Ref,0=not Ref)"
		ModifyTable title(root:diagnostics:IECalToFMode)="IE ToF Mode(0=C,1=V,2=W)"
		ModifyTable format(root:diagnostics:IECalTime)=8
	endif

End


//  A useful function for upgrading existing experiments.
// sq_KillProcs("1.40") would kill all functions with a"1.40" in their name.
//  There was a bug in Igor 6.02 whereby some procedure file names had a "T0" suffix, so sometimes this would not work.
//Function sq_KillProcs(ipfPrefix, verStr)
//string verStr, ipfPrefix
//
//	string ProcList = WinList(ipfPrefix+"*", ";", "WIN:128")		// all proc files
//	string ProcStr, thisProc
//	variable idex, numList
//	
//	thisProc=""
//	ProcStr = ""
//	numList=ItemsInList(ProcList)
//	for (idex=0;idex<numList;idex+=1)
//		ProcStr = StringFromList(idex, ProcList)
//		if ( strsearch(lowerStr(ProcStr), "panel",0)>=0)
//			thisProc =ProcStr
//		elseif (strsearch(ProcStr, verStr, 0)>0 )
//			Execute/P "CloseProc/Name=\""+ProcStr+"\""
//		endif
//	endfor
//	
//	if (strlen(ProcStr)>0)
//		Execute/P "CloseProc/Name=\""+thisProc+"\""		// kills this proc!!!!!
//	endif
//	
//End


// The button control for "pop" buttons.  It assumes that the calling button control is named appropriately.
Function sq_butt_popThis(ctrlName) : ButtonControl
	String ctrlName
	
	sq_WindowIsToBePopped(ctrlName[7, strlen(ctrlName)-1])	// the pop button controls MUST be named correctly, such as button_Mz_PpmGraph

End


// general all pupose function called from pop buttons in panels for creating or bringing to the front chosen window.
Function sq_windowIsToBePopped(NameOfPoppedWindow)
string NameOfPoppedWindow

	string WindowStr="", WindowPrefixStr="", FuncStr=""
	
	WindowPrefixStr=NameOfPoppedWindow[0,1]		// for example "mz"
	WindowStr=NameOfPoppedWindow[3, strlen(NameOfPoppedWindow)-1]
	
	DoWindow/F  $NameOfPoppedWindow
	
	if (V_flag==0)
		if (strsearch(lowerStr(NameOfPoppedWindow), "graph", 0)>=0)			
			Display/W=(50,50,450,450)/N=$NameOfPoppedWindow as NameOfPoppedWindow // a blank graph window
			ShowInfo			//1.51Q
		else
			Edit/W=(50,70,450,350)/N=$NameOfPoppedWindow as NameOfPoppedWindow	// a blank table window
		endif
		
		FuncStr =FunctionList(WindowPrefixStr+"_populate_"+WindowStr, ";", "")
		FuncStr=ReplaceString(";", FuncStr, "")
//		print FuncStr
		if (strlen(FuncStr)>0 && ItemsInList(FuncStr)==1)		
			Execute FuncStr+"()"	
		else
			print WindowPrefixStr+"_populate_"+WindowStr
			Abort "Could not find the function named "+WindowPrefixStr+"_populate_"+WindowStr+" to populate the new window - Aborting from sq_WindowIsToBePopped"
		endif
	endif

End


Function sq_updatePath(oldstr, newstr) // updatepath("H:/", "E:")
string oldstr, newstr

	wave/T localwave = root:index:file_index
	variable iPnt, position
	string tempstring

	for(iPnt=0; iPnt < numpnts(localwave); iPnt +=1)
		tempstring = localwave[iPnt]
		tempstring =  ReplaceString(oldstr, tempstring, newstr)
		localwave[iPnt] = tempstring
	endfor

End


// convert from the old, hard-coded file structure to the more versatile path
Function sq_butt_DVaTable(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()

	DoWindow/f  DVa_Table		//1.59E
	if (V_flag==1)
		return 0
	endif
	
	variable idex
	string str
	
	Edit/N=DVa_table /W=(100,100,600,350)  as "DVa_table"
	AppendToTable/W=DVa_table root:index:rn_series		//1.44B added rn series
	ModifyTable/W=DVa_table width(root:index:rn_series)=60

	wave/z allPToF = root:allPToF		// is created in the Get index step, is killed if all runs have PToF data
	if (WaveExists(allPToF) )	
		make/o/n=0 root:diagnostics:PToFKey	
		sq_makeMaskFromTodofindRun(root:diagnostics:PToFKey,allPToF)
		AppendToTable/W=DVa_table root:diagnostics:PToFKey		//1.44B added PToFKey
		ModifyTable/W=DVa_table width(root:diagnostics:PToFKey)=40	
	endif
	
	for(idex=0;idex<4;idex+=1)
		str = StringFromList(idex, "vl;vg;dx;b")
		wave/z ptofwave =  $"root:diagnostics:ptof_"+str
		if (WaveExists(ptofwave))	
			AppendToTable/W=DVa_table $"root:diagnostics:ptof_"+str
			ModifyTable/W=DVa_table rgb($"root:diagnostics:ptof_"+str)=(58880,9728,0), width($"root:diagnostics:ptof_"+str)=60
		else
//			abort "Had problems finding the parameter root:diagnostics:ptof_"+str +" - aborting from sq_butt_DVaTable"		//1.48F  not necessary, just make the table
		endif
		wave/z logged =  $"root:diagnostics:ptof_"+str+"_logged"
		if (WaveExists(logged))	
			AppendToTable/W=DVa_table $"root:diagnostics:ptof_"+str+"_logged"
			ModifyTable/W=DVa_table width($"root:diagnostics:ptof_"+str+"_logged")=60
		endif
	endfor

	AppendToTable/W=DVa_table root:diagnostics:ptof_t0
	AppendToTable/W=DVa_table root:diagnostics:ptof_step
	AppendToTable/W=DVa_table root:diagnostics:ptof_delay_us
	AppendToTable/W=DVa_table root:diagnostics:ePToF_enabled
	AppendToTable/W=DVa_table root:diagnostics:ChopperFreq
	AppendToTable/W=DVa_table root:diagnostics:ptofCoAdd
	AppendToTable/W=DVa_table root:diagnostics:ptofNumSpectraPerChop
	AppendToTable/W=DVa_table root:diagnostics:ptofNumTimesThrough
	if (Exists("root:diagnostics:ePToF_oversampling")>0)
		AppendToTable/W=DVa_table root:diagnostics:ePToF_oversampling
	endif
End


// for use in the Misc tab, Export Batch or Export Frags
Function sq_butt_exportAsItx(ctrlName) : ButtonControl
	String ctrlName

	string savelist=""
	if (strsearch(ctrlName, "Batch", 0)>0)		// batch
		savelist = "root:frag:spec_list;root:frag:frag_list;root:frag:speccorr_list;root:frag:specname_list;root:frag:calfac_list;root:frag:IEfac_list;root:frag:CEfac_list"
		Save/T/B savelist  as "BatchWaves.itx"
	elseif (strsearch(ctrlName, "Frag", 0)>0)
		wave mz = root:frag:mz
		if (numpnts(mz) !=1000)		// older versions of the template only went up to m/z 300.    Unnecessary, but nice.
			redimension/n=(1000) mz
			mz = p+1
		endif
		// note that mz is numeric while the other frags are text, so the igor text file is split into many parts
		// the list of waves is too long; so we have to do it in many parts.  First part is air-like frags
		savelist ="root:frag:mz;root:frag:frag_air;root:frag:frag_RH;root:frag:frag_O16;root:frag:frag_CO2;root:frag:frag_water;root:frag:frag_Delta02;" 
		savelist +="root:frag:frag_NH4;root:frag:frag_NH4_17;root:frag:frag_nitrate;root:frag:frag_sulphate;root:frag:frag_H2SO4;root:frag:frag_SO3;"
		savelist +="root:frag:frag_K;root:frag:frag_chloride;root:frag:frag_HCl;root:frag:frag_Cl;root:frag:frag_organic;root:frag:frag_PAH"
		Save/T/B savelist  as "FragWaves.itx"
	else
		print "// The button control name "+ctrlName+" did not include the words Frag or Batch and so nothing was performed." 
	endif

End


////////////////////////////////////////////////////////////////////////////////////
//		Frag Panel stuff
////////////////////////////////////////////////////////////////////////////////////

Function sq_fragPanel_butt_pop(ctrlName) : ButtonControl
	String ctrlName

	string info, colinfo, colWave, colStr
	variable numCol, iCol
	
	info =TableInfo ("FragPanel#FragTable", -2)
  	numCol = str2num(StringByKey("COLUMNS", info))
  	
	DoWIndow/F FragTable
	
	if (V_flag==0)
		Edit/N=FragTable/W=(10,10,400,400)  root:frag:mz as "FragTable"
		
		  for(iCol =0;iCol<numCol-1;iCol+=1)
	  		colinfo = TableInfo ("FragPanel#FragTable", iCol)
			colWave = StringByKey("WAVE", colinfo)
			colStr = StringFromList(ItemsInList(colWave, ":")-1, colWave,  ":")
			AppendtoTable/W=FragTable $colWave
			ModifyTable/W=FragTable size($colWave) =str2num(StringByKey("SIZE", colinfo) )
			ModifyTable/W=FragTable width($colWave) =str2num(StringByKey("WIDTH", colinfo) )
			info=StringByKey("RGB", colinfo)
			ModifyTable/W=FragTable rgb($colWave) =( str2num(StringFromList(0, info, ",")), str2num(StringFromList(1, info,",")), str2num(StringFromList(2, info, ","))  )
	  	 endfor
	endif
	
End


Function sq_fragPanel_setVar_fontSize(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	ModifyTable/W=FragPanel#FragTable size = varNum

End


Function sq_fragPanel_setVar_colWidth(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	ModifyTable/W=FragPanel#FragTable width =varNum
	ModifyTable/W=FragPanel#FragTable width(Point)=0
	ModifyTable/W=FragPanel#FragTable width(root:frag:mz)=40

End


Function sq_fragPanel_check_bold(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			Variable checked = cba.checked
			ModifyTable/W=FragPanel#FragTable style=checked
			break
	endswitch

	return 0

End


Function sq_fragPanel_check_Display(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	variable check_tmp
	string FragStr, FragList,topTableStr
	
	FragStr = ctrlName[11, strlen(ctrlName)-1]		// "check_frag_" has 11 characters
		
	if (!stringmatch(WinName(0, 64), "FragPanel"))		//1.22A
		return 0
	endif
	
	ControlInfo/W=FragPanel checkBold
	check_tmp = V_Value
//	string topTableStr = WinName(0,66)
//	if (stringmatch(topTableStr, "Fragpanel"))
		topTableStr = "FragPanel#FragTable"
//	elseif(stringmatch(topTableStr, "HROrgCheck_Panel") )		//1.59E
//		ControlInfo/W=HROrgCheck_Panel HRCheckTab
//		if (V_Value==0)
//			topTableStr = "HROrgCheck_Panel#j15NNUMRFragTable"
//		else	
//			topTableStr = "HROrgCheck_Panel#air44UMRFragTable"
//		endif
//	elseif(strsearch(topTableStr, "frag", 0)>=0 )
//		return 0
//	endif
	wave/z fragWave =  $("root:frag:frag_"+FragStr)
	if (!WaveExists(fragWave) )
		print "// The frag wave frag_"+FragStr+" either doesn't exists or doesn't live in the frag folder."
	else
		ControlInfo $("check_frag_"+FragStr)
		if (!stringmatch(topTableStr[0,3], "Frag") || (V_value==1 && V_flag==2) )  //1.21G   was  || V_flag==0  ??
			sq_appendFragWave(fragWave, FragStr, check_tmp, panelFlag=1)
		else
			RemoveFromTable/Z/W=$topTableStr $"root:frag:frag_"+FragStr				//1.59D  FragPanel#FragTable
		endif	
	endif		

End


//1.59E
Function sq_appendFragWave(fragWave, FragStr, boldFlag, [panelFlag])
string FragStr
variable boldFlag, panelFlag
wave/t fragWave

	wave Col_R = root:frag:Col_R		// These should always be a part of every squirrel experiment.  
	wave Col_G = root:frag:Col_G
	wave Col_B = root:frag:Col_B
	wave col_names= root:frag:col_names		// contains the names of all items that are automatically colored
	
	nvar fragTableFont =root:frag:fragTableFont		// created in sq_butt_reviewFrags
	nvar fragTableWidth = root:frag:fragTableWidth	// created in sq_butt_reviewFrags

//	string win = SelectString(!ParamisDefault(panelFlag) && panelFlag, WinName(0,2), "FragPanel#FragTable") 
	string win = WinName(0,66)
	if (stringmatch(win, "FragPanel") )
		win= "FragPanel#FragTable"
	elseif(stringmatch(win, "HROrgCheck_Panel") )
		GetWindow/Z HROrgCheck_Panel activeSW  //1.22A
		win= S_Value
	endif
	
	
	variable pt
	appendtotable/W=$win fragWave		// appends at end			1.56O  changed to not refer to frag panel table but any table
	ModifyTable/W=$win width($"root:frag:frag_"+FragStr) =fragTableWidth
	ModifyTable/W=$win  size($"root:frag:frag_"+FragStr) =fragTableFont
	ModifyTable/W=$win style($"root:frag:frag_"+FragStr)=boldFlag
	pt=sq_findstr(col_names,FragStr,2)
	if (pt>=0)
		ModifyTable/W=$win  rgb($"root:frag:frag_"+FragStr)=(Col_R[pt],Col_G[pt],Col_B[pt])
	endif			
End



Function sq_fragPanel_butt_compareFrags(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	string DataFolder1, DataFolder2, DataFolderList, baseDataFolderStr
	
	baseDataFolderStr = "root:"
	DataFolderList=gen_dataFolderList(baseDataFolderStr)
	
	switch( ba.eventCode )
		case 2: // mouse up
//		prompt Data
//		Do Prompt "Please select two data folders in the current experiment that have frag waves.  The results will be displayed in a notebook."
		Prompt DataFolder1,"data folder #1:",popup,DataFolderList
		Prompt DataFolder2,"data folder #2:",popup,DataFolderList
		DoPrompt "Select the two data folder that have the frag waves you wish to compare",	DataFolder1, DataFolder2
		if (V_flag==0 && !stringmatch(DataFolder1, DataFolder2)	)	// continue clicked and we have different folders
			sq_FragPanel_compareFrags(baseDataFolderStr, DataFolder1, DataFolder2)
		endif
		break
	endswitch

	return 0
	
End


Function sq_fragPanel_compareFrags(baseDataFolderStr, DataFolder1, DataFolder2)
string baseDataFolderStr, DataFolder1, DataFolder2

	string FragWaveList1, FragWaveList2, tempDataFolderStr, fragStr, resultStr
	variable idex, num1, num2

	tempDataFolderStr = GetDataFolder(1)

	SetDataFolder $baseDataFolderStr+DataFolder1+":"
	FragWaveList1 = WaveList("frag_*", ";", "")
	FragWaveList1 = RemoveFromList("frag_list", FragWaveList1)
	num1 = ItemsInList(FragWaveList1)
	
	SetDataFolder $baseDataFolderStr+DataFolder2+":"
	FragWaveList2 = WaveList("frag_*", ";", "")
	FragWaveList2 = RemoveFromList("frag_list", FragWaveList2)
	num2 = ItemsInList(FragWaveList2)
	
	SetDataFolder $tempDataFolderStr
	print "// Comparison results of frag waves in "+DataFolder1+" and "+DataFolder2+"\r"
	print "// In the text below, add one to the row number to get the corresponding m/z value\r"
	
	for(idex=0;idex<num1;idex+=1)
		resultStr=""		// bug fixed in 1.47B
		fragStr = StringFromList(idex, FragWaveList1)
		if (WaveExists($baseDataFolderStr+DataFolder2+":"+fragStr)	)	// we have a match, so compare 2 text waves
			wave/t fragWave1 = $baseDataFolderStr+DataFolder1+":"+fragStr
			wave/t fragWave2 = $baseDataFolderStr+DataFolder2+":"+fragStr
			resultStr+="\r // Results for "	+fragStr	+"\r"
			resultStr+=gen_Compare2TextWaves(fragWave1, fragWave2)			
			print resultStr
		endif
	endfor
	
	print "// The frag comparison has finished.\r"
	
End


// Returns a sorted list of all data folders in given data folder
Function/S gen_dataFolderList(FullDFPathStr)
string FullDFPathStr		// such as root:
	
	string tempDataFolderStr, existingDFName, existingDFList=""
	variable idex

	if (!DataFolderExists(FullDFPathStr))
		return ""
	endif

	tempDataFolderStr=GetDataFolder(1)
	setDataFolder  $FullDFPathStr

	existingDFList=""
	idex=0
	do
		existingDFName = GetIndexedObjName("root:", 4, idex)
		if (strlen(existingDFName) >0)
			existingDFList+=existingDFName+";"
		endif
		idex += 1
	while(strlen(existingDFName) > 0)

	// put the list in alphabetical order, 4 = case insensitive
	existingDFList = sortlist(existingDFList, ";", 4)
	
	return(existingDFList)
	
End


Function/S gen_compare2TextWaves(fragWave1, fragWave2)
wave/t fragWave1, fragWave2

	variable idex, num1, num2 
	string resultsStr, str1, str2
	
	resultsStr=""
	num1 = numpnts(fragWave1)
	num2 = numpnts(fragWave2)
	if (num1!=num2)
		resultsStr+= "The number of points in the waves do not agree!  One has "+num2str(num2)+" and the other has "+num2str(num2)+"\r"
		num1=min(num1, num2)
	endif
	
	for (idex=0;idex<num1; idex+=1)
		if (!stringmatch(fragWave1[idex],fragWave2[idex]) 	)	// try to keep it fast
			str1 = UpperStr(ReplaceString(" ", fragWave1[idex], ""))
			str2 = UpperStr(ReplaceString(" ", fragWave2[idex], ""))		
			if ( !stringmatch(str1, str2) )
				if (strlen(resultsStr)==0)
					resultsStr += "These rows show text differences:"+num2str(idex)+","
				else
					resultsStr+=num2str(idex)+","
				endif
			endif
		endif
	endfor
	
	return resultsStr
End


Function sq_fragPanel_butt_saveItx(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	string saveFolderStr, saveList
	
	saveFolderStr=GetDataFolder(1)
	SetDataFolder root:frag
	
	saveList = WaveList("frag_*", ";", "WIN:FragPanel#FragTable")
	switch( ba.eventCode )
		case 2: // mouse up
			// click code here
			if ( strlen(savelist)>0 )
				Save/T/B savelist  as "FragWaves.itx"
			endif
			break
	endswitch

	setDataFolder $saveFolderStr
	return 0

End


Function sq_fragPanel_make() 

	sq_makeFragListWave()
	
	PauseUpdate; Silent 1		// building window...
	NewPanel/N=FragPanel /W=(110,108,1059,676) as "FragPanel"
	SetDrawEnv linethick= 0,fillfgc= (56576,56576,56576)
	SetDrawLayer UserBack
	SetDrawEnv linethick= 0,fillfgc= (56576,56576,56576)
	DrawRect 25,58,105,113
	SetDrawEnv linethick= 0,fillfgc= (0,49152,49152)
	DrawRect 25,118,105,158
	SetDrawEnv linethick= 0,fillfgc= (0,52224,0)
	DrawRect 25,163,105,223
	SetDrawEnv linethick= 0,fillfgc= (65280,0,0)
	DrawRect 25,228,105,283
	SetDrawEnv linethick= 0,fillfgc= (65280,0,52224)
	DrawRect 25,288,105,343
	SetDrawEnv linethick= 0,fillfgc= (0,0,65280)
	DrawRect 25,388,105,408
	SetDrawEnv linethick= 0,fillfgc= (44032,29440,58880)
	DrawRect 25,413,105,433
	SetDrawEnv linethick= 0,fillfgc= (65280,43520,0)
	DrawRect 25,348,105,383
	SetDrawEnv fillpat= 0
	DrawRect 148,4,315,46
	SetDrawEnv fillpat= 0
	DrawRect 3,5,144,437
	SetDrawEnv fillpat= 0
	DrawRect 4,443,143,571
	DrawText 5,21,"Use the radio buttons to"
	DrawText 6,37,"add or remove a wave to"
	DrawText 6,53,"the table."
	DrawText 8,462,"Use the listbox & buttons"
	DrawText 9,478,"to add or remove a wave"
	DrawText 9,494,"to the table."
	
	CheckBox check_frag_air,pos={30,63},size={29,14},proc=sq_fragPanel_check_display,title="air"
	CheckBox check_frag_air,value= 1
	CheckBox check_frag_CO2,pos={30,79},size={39,14},proc=sq_fragPanel_check_display,title="CO2"
	CheckBox check_frag_CO2,value= 1
	CheckBox check_frag_O16,pos={30,95},size={38,14},proc=sq_fragPanel_check_display,title="O16"
	CheckBox check_frag_O16,value= 1
	CheckBox check_frag_water,pos={30,123},size={44,14},proc=sq_fragPanel_check_display,title="water"
	CheckBox check_frag_water,value=1
	CheckBox check_frag_RH,pos={30,139},size={34,14},proc=sq_fragPanel_check_display,title="RH"
	CheckBox check_frag_RH,value=1
	CheckBox check_frag_organic,pos={30,169},size={53,14},proc=sq_fragPanel_check_display,title="organic"
	CheckBox check_frag_organic,value=1
	CheckBox check_frag_PAH,pos={30,185},size={40,14},proc=sq_fragPanel_check_display,title="PAH"
	CheckBox check_frag_PAH,value=1
	CheckBox check_frag_Delta02,pos={30,201},size={53,14},proc=sq_fragPanel_check_display,title="delta02"
	CheckBox check_frag_Delta02,value=1
	CheckBox check_frag_sulphate,pos={30,232},size={58,14},proc=sq_fragPanel_check_display,title="sulphate"
	CheckBox check_frag_sulphate,value=1
	CheckBox check_frag_SO3,pos={30,248},size={39,14},proc=sq_fragPanel_check_display,title="SO3"
	CheckBox check_frag_SO3,value=1
	CheckBox check_frag_H2SO4,pos={30,264},size={53,14},proc=sq_fragPanel_check_display,title="H2SO4"
	CheckBox check_frag_H2SO4,value=1
	CheckBox check_frag_chloride,pos={30,291},size={55,14},proc=sq_fragPanel_check_display,title="chloride"
	CheckBox check_frag_chloride,value=1
	CheckBox check_frag_Cl,pos={30,305},size={27,14},proc=sq_fragPanel_check_display,title="Cl"
	CheckBox check_frag_Cl,value=1
	CheckBox check_frag_HCl,pos={30,321},size={35,14},proc=sq_fragPanel_check_display,title="HCl"
	CheckBox check_frag_HCl,value=1
	CheckBox check_frag_NH4,pos={30,351},size={40,14},proc=sq_fragPanel_check_display,title="NH4"
	CheckBox check_frag_NH4,value=1
	CheckBox check_frag_NH4_17,pos={30,366},size={58,14},proc=sq_fragPanel_check_display,title="NH4_17"
	CheckBox check_frag_NH4_17,value=1
	CheckBox check_frag_nitrate,pos={30,391},size={47,14},proc=sq_fragPanel_check_display,title="nitrate"
	CheckBox check_frag_nitrate,value=1
	CheckBox check_frag_K,pos={30,416},size={25,14},proc=sq_fragPanel_check_display,title="K"
	CheckBox check_frag_K,value= 1
		
	Button buttonSanity,pos={508,3},size={190,40},proc=sq_fragPanel_butt_CheckRecurs,title="Simple recursion/nonphysical check,\rresults in history window"
	Button buttonSanity,fSize=10
	Button buttonPop,pos={898,15},size={40,30},proc=sq_FragPanel_butt_pop,title="Pop\rTable"
	Button buttonPop,fSize=10
	Button buttonExportFrags,pos={323,5},size={180,18},proc=sq_FragPanel_butt_saveItx,title="Export frag waves in table as .itx"
	Button buttonExportFrags,fSize=10
	Button buttonCompareFrags,pos={323,26},size={180,18},proc=sq_FragPanel_butt_compareFrags,title="Compare frag waves in two folders"
	Button buttonCompareFrags,fSize=10

	CheckBox check_OrgPlusPAH,pos={702,9},size={187,14},proc=SQ_ChangeOrgLessPAH,title="Define Org to include PAHs (typical)"
	CheckBox check_OrgPlusPAH,fSize=10,value= 1,mode=1
	CheckBox check_OrgLessPAH,pos={702,28},size={193,14},proc=SQ_ChangeOrgLessPAH,title="Define Org and PAH separately (rare)"
	CheckBox check_OrgLessPAH,fSize=10,value= 0,mode=1
	wave/t frag_organic = root:frag:frag_organic
	if (stringmatch(frag_organic[200], "201") )
		CheckBox check_OrgPlusPAH, value=1
		CheckBox check_OrgLessPAH, value=0	
	else
		CheckBox check_OrgPlusPAH, value=0
		CheckBox check_OrgLessPAH, value=1	
	endif
	
	
	SetVariable setvarFontSize,pos={153,8},size={80,16},fsize=10,proc=sq_FragPanel_setVar_fontSize,title="font size"
	SetVariable setvarFontSize,value= root:frag:fragTableFont
	SetVariable setvarColWidth,pos={150,27},size={110,16},fsize=10,proc=sq_FragPanel_setVar_colWidth,title="column width"
	SetVariable setvarColWidth,limits={0,1000,5},value= root:frag:fragTableWidth
	CheckBox checkBold,pos={247,8},size={59,14},fsize=10,proc=sq_fragPanel_check_bold,title="font bold"
	CheckBox checkBold,value= 0

	ListBox frag_listbox_moreFragWaves,pos={14,501},size={120,44},fsize=10  //  ,proc=sq_frag_ListBoxProc  1.21G
	ListBox frag_listbox_moreFragWaves,listWave=root:panel:FragListWave,mode= 1
	ListBox frag_listbox_moreFragWaves,selRow= 0
	Button buttonAddRemove,pos={8,549},size={130,18},fsize=10,proc=sq_fragPanel_butt_addRemove,title="Add/Remove Frag Wave"
	Button buttonUpdateList,pos={76,478},size={60,18},fsize=10,proc=sq_fragPanel_butt_updateList,title="Update list"

	Edit/W=(150,50,940,575)/HOST=# 
	RenameWindow #,FragTable		//1.59D
	sq_populateFragTable()	
	SetActiveSubwindow ##
End


// Used to populate the Frag table in the Frag panel or in the popped window
Function sq_populateFragTable()

	nvar fragTableFont =root:frag:fragTableFont		// created in sq_butt_reviewFrags
	nvar fragTableWidth = root:frag:fragTableWidth	// created in sq_butt_reviewFrags

	variable iFrag, nFrag
	string FragList, FragStr, NoFragExist = ""
	
	FragList = "air;CO2;O16;water;RH;organic;PAH;delta02;sulphate;SO3;H2SO4;chloride;Cl;HCl;NH4;nitrate;K"		// spelling, order in which they appear
	nFrag = ItemsInList(FragList)
	
	wave mz = root:frag:mz
	//  There isn't a good place within squirrel to check this, so do it here
	if ( numpnts(mz)<1000 )
		redimension/n=1000 mz
		mz = p+1
	endif
		
//	AppendtoTable/W=FragPanel#FragTable mz
//	ModifyTable/W=FragPanel#FragTable width(root:frag:mz)=40
//	ModifyTable/W=FragPanel#FragTable format(Point)=1,width(Point)=0
	
	AppendtoTable mz
	ModifyTable width(root:frag:mz)=40
	ModifyTable format(Point)=1,width(Point)=0

	for(iFrag=0;iFrag < nFrag;ifrag+=1)
		FragStr =StringFromList(iFrag, FragList)
		wave fragWave = $"root:frag:frag_"+FragStr
		if (WaveExists(fragWave))
			sq_appendFragWave(fragWave, FragStr, 0)
			sq_fragPanel_check_display("check_frag_"+FragStr, nan)
		else
			NoFragExist+=FragStr+";"
		endif	
	endfor	

	if (strlen(NoFragExist)>0 )
		print "// The frag wave(s) for "+FragStr+" either doesn't exists or doesn't live in the frag folder."
	endif

End


//  from misc tab, a button that shows which traces get colored what
Function sq_butt_speciesColorTable(ctrlName) : ButtonControl
string ctrlName
	
	DoWindow/F AMSColorTable
	if (V_flag==0)
		Edit/N=SpeciesColorTable/W=(48,86.75,540,605.75) root:frag:Col_names, root:frag:Col_R,root:frag:Col_G,root:frag:Col_B as "AMSColorTable"
	endif

End



// creates or updates  root:panel:FragListWave which is used in the list box in the FragPanel
Function sq_makeFragListWave()

	string fragStr, fragList, tempStr
	string saveFolderStr
	
	saveFolderStr = GetDataFolder(1) 
	SetDataFolder root:frag:	
	fragList = WaveList("frag_*", ";", "")
	SetDataFolder $saveFolderStr

	tempStr = ReplaceString(";", "frag_"+FRAG_PANEL_LIST, ";frag_")
	fragList = RemoveFromList(tempStr, fragList)
	
	fragList = RemoveFromList("frag_list", fragList)		// frag_list is a wave used in the creation of the batch table

	make/o/t/n=(ItemsInList(fragList)) root:panel:FragListWave
	wave/t FragListWave = root:panel:FragListWave
	FragListWave = StringFromList(p,fraglist)
	
End


//  adds or removes selected wave to the table
Function sq_fragPanel_butt_addRemove(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	nvar fragTableFont =root:frag:fragTableFont		// created in sq_butt_reviewFrags
	nvar fragTableWidth = root:frag:fragTableWidth	// created in sq_butt_reviewFrags
	wave/t FragListWave = root:panel:FragListWave
	string FragStr, tempStr, saveFolderStr
	
	switch( ba.eventCode )
		case 2: // mouse up
		ControlInfo frag_listbox_moreFragWaves
		if (V_Value>=0)	
			FragStr = FragListWave[V_Value]
			wave fragWave =  $("root:frag:"+FragStr)
			saveFolderStr = GetDataFolder(1)
			SetDataFolder root:frag
			tempStr= WaveList(FragStr+"*", ";", "WIN:FragPanel#FragTable" )
			SetDataFolder $saveFolderStr
			if (strlen(tempStr)==0)	// add
				AppendToTable/W=FragPanel#FragTable fragWave		// appends at end
				ModifyTable/W=FragPanel#FragTable width($"root:frag:"+FragStr) =fragTableWidth
				ModifyTable/W=FragPanel#FragTable size($"root:frag:"+FragStr) =fragTableFont			
			else	// remove
				RemoveFromTable/W=FragPanel#FragTable fragWave
			endif
		endif
		break
	endswitch

	return 0
	
End


Function sq_fragPanel_butt_updateList(ctrlName) : ButtonControl
	String ctrlName

	sq_makeFragListWave()

End


//  For use when we want to remove traces but not kill window
Function sq_gen_removeAllTraces(PlotName)	
string PlotName

	string plotTraceList
	variable idex, ndex
	
	plotTraceList = TraceNameList("",";",1)
	ndex = ItemsinList(plotTraceList)
	
	for(idex=0;idex<ndex;idex+=1)
		RemoveFromGraph/Z/W=$PlotName $StringFromList(idex, plotTraceList)
	endfor

End


//& Convert a frag wave to a matrix
//& Method bit 0: Not used
//& Method bit 1: 2=Filter negative contributions
//  JDA change in 1.41
// for one species, makes the species_mat and species_vec waves that are used in the big ms_conc function 
// Note that this function is also called from the master sq_MS_concentration function in the conc.ipf
// added frag_excludeStr = 1.43A
// JDA - v1.46A switched to sparse matrices for matrix and dependencies
Function sq_frag_matrix(fragwave,destname,method) //& 1.43D removed frag_excludestr
	wave /t fragwave
	string destname//, frag_excludeStr // 1.43D
	variable method		// note that the method parameter is no longer used beginning in 1.47
	
	variable idex, jdex, kdex, num1, num2
	variable numFragWave, fact, mz, v_facitem, tempSum, tempSumNeg
	string listItemStr,facitem,facStr,depStr, tempStr, sparseStr
	
	numFragWave=numpnts(fragWave)
	make /o/n=(numFragWave,numFragWave) fragMatrix_tmp
	
	fastop fragMatrix_tmp=0
	depStr=""
	sparseStr=""
	
	for (idex=0;idex<numFragWave;idex+=1)
		
		num1=itemsinlist(fragWave[idex],",")		// number of , separated items in frag wave row
		for (jdex=0;jdex<num1;jdex+=1)
			// we build up the matrix fm_tmp by adding factors
			listItemStr=stringfromlist(jdex,fragWave[idex],",")	// get the next , separated item in fragWave[idex] 
			num2=itemsinlist(listItemStr,"*")		// number of * separated items
			mz=str2num(stringfromlist(num2-1,listItemStr,"*"))	// the last value in list separated by *
			if (numtype(mz)==0)
				fact=1		// the value that will eventually go in the fm_tmp wave
				facstr=""
				// go through all values separated by *
				for (kdex=0;kdex<num2-1;kdex+=1)
					facitem=stringfromlist(kdex,listItemStr,"*")
					if (stringmatch(facitem[0],"-"))		//^ not clear why we need to fuss with this... why not just let the str2num handle negatives? //& It's so you can put negatives in front of time-dependent operators
						fact*=-1
						facitem[0,0]=""
					endif
					v_facitem=str2num(facitem)
					if (!numtype(v_facitem))
						fact*=v_facitem
					else
						facStr+=facitem+"*"
					endif
				endfor
				if (strlen(facstr)==0)
					fragMatrix_tmp[idex][mz-1]+=fact
					sparsestr+=num2str(mz-1)+","+num2str(idex)+","+num2str(fact)+";"		//1.46A
				else
					depstr+=num2str(mz-1)+","+num2str(idex)+","+facstr+num2str(fact)+";"
				endif
			endif	// end if the last list item is a real mz number
			
		endfor		// end for every comma separated entry in FragWave[idex]
		
	endfor		// end for every row, idex, in FragWave

//& Filter m/z channels from the matrix that do not contain a positive contribuition and make vector and matrix
//& Not valid if a time-dependent matrix is generated

//& Removed 1.46A becuase of the time dependency issue - they should behave the same with or without the dependency

//	if (method&2 && strlen(depstr)==0)			//^ added some checking in 1.42B
//
//		matrixop /o fragWave_Key=greater(greater(fragMatrix_tmp,0) x fragWave_tmp,0)		// greater is a matrixop function that returns truth of a>b
//
//		//^ begin added some checking in 1.42B
//		duplicate/o fragMatrix_tmp fragMatrix_tmpNeg
//		fragMatrix_tmpNeg*=-1
//		matrixop /o fragWave_NegKey=greater(greater(fragMatrix_tmpNeg,0) x fragWave_tmp,0)	
//		
//		tempSumNeg = sum(fragWave_NegKey, -inf, inf)
//		tempSum = sum(fragWave_Key, -inf, inf)
//		tempStr = destname[13,strlen(destname)-1]		// root:ms_mats:
////		if (tempSum==0 && !stringmatch("frag_air",  lowerstr(frag_excludeStr) ))		// 1.43B
//		if (tempSum==0)		// 1.43D
//			print "// There was a problem with frag non-negativity (non-physicality) for "+tempStr+" because entries result in a zero matrix"
////		elseif (tempSumNeg!=0)
////			findlevel/Q/P fragWave_NegKey, 1
////			print "**** There was a problem with frag non-negativity (non-physicality) for "+tempStr+" at "+num2str( V_LevelX+1)
//		endif		
//		//^ end added some checking in 1.42B
//	
//		fragMatrix_tmp*=fragWave_Key[p]	// multiply rows of 2d wave by varying constants
//
//	endif
	
	matrixop /o $(destname+"_mat")=fragMatrix_tmp^t		// makes the species_mat wave
	imagetransform sumAllCols fragMatrix_tmp
	wave w_sumcols
	duplicate /o W_sumcols,$(destname+"_vec")	// makes the species_vec wave
	note /k $(destname+"_mat"),depstr // Legacy
	note /k $(destname+"_vec"),depstr // Legacy

//1.46A
// Generate sparse matrix operator
	num1=itemsinlist(sparsestr)
	make /o/n=(num1,3) $(destname+"_sparse")
	wave sparse=$(destname+"_sparse")
	for (idex=0;idex<num1;idex+=1)
		listitemstr=stringfromlist(idex,sparsestr)
		sparse[idex][]=str2num(stringfromlist(q,listitemstr,","))
	endfor
	
//1.46A
// Generate time dependency operator
	num1=itemsinlist(depstr)
	if (num1>0)
		make /o/n=(num1,2) $(destname+"_dep")
		make /o/n=(num1)/t $(destname+"_depstr")
		wave wdep=$(destname+"_dep")
		wave /t wdepstr=$(destname+"_depstr")
		for (idex=0;idex<num1;idex+=1)
			listitemstr=stringfromlist(idex,depstr)
			wdep[idex][]=str2num(stringfromlist(q,listitemstr,","))
			wdepstr[idex]=stringfromlist(2,listitemstr,",")
		endfor
	else
		killwaves /z $(destname+"_dep"),$(destname+"_depstr")
	endif
	
	// clean up
	killwaves /z fragMatrix_tmp, fragWave_tmp, fragWave_Key, fragMatrix_tmpNeg, fragWave_NegKey w_sumcols

End



//& Convert a frag wave to a matrix
//& Method bit 0: Not used
//& Method bit 1: 2=Filter negative contributions
//  JDA change in 1.41
// for one species, makes the species_mat and species_vec waves that are used in the big ms_conc function 
// Note that this function is also called from the master sq_MS_concentration function in the conc.ipf
// added frag_excludeStr = 1.43A
//*******************************************************************
//**  This function is no longer called from anywhere, as of 1.46E, but parts may be included some time in the future
// when we want to export the 2D matrix for use in QuickView, for example.
Function sq_frag_matrix2D(fragwave,destname,method) //& 1.43D removed frag_excludestr
	wave /t fragwave
	string destname//, frag_excludeStr // 1.43D
	variable method
	
	variable idex, jdex, kdex, num1, num2
	variable numFragWave, fact, mz, v_facitem, tempSum, tempSumNeg
	string listItemStr,facitem,facStr,depStr, tempStr
	
	numFragWave=numpnts(fragWave)
	make /o/n=(numFragWave,numFragWave) fragMatrix_tmp
	make /o/n=(numFragWave) fragWave_tmp
	
	fragMatrix_tmp=0
	fragWave_tmp=1
	depStr=""
	
	for (idex=0;idex<numFragWave;idex+=1)
		
		num1=itemsinlist(fragWave[idex],",")		// number of , separated items in frag wave row
		for (jdex=0;jdex<num1;jdex+=1)
			// we build up the matrix fm_tmp by adding factors
			listItemStr=stringfromlist(jdex,fragWave[idex],",")	// get the next , separated item in fragWave[idex] 
			num2=itemsinlist(listItemStr,"*")		// number of * separated items
			mz=str2num(stringfromlist(num2-1,listItemStr,"*"))	// the last value in list separated by *
			if (numtype(mz)==0)
				fact=1		// the value that will eventually go in the fm_tmp wave
				facstr=""
				// go through all values separated by *
				for (kdex=0;kdex<num2-1;kdex+=1)
					facitem=stringfromlist(kdex,listItemStr,"*")
					if (stringmatch(facitem[0],"-"))		//^ not clear why we need to fuss with this... why not just let the str2num handle negatives? //& It's so you can put negatives in front of time-dependent operators
						fact*=-1
						facitem[0,0]=""
					endif
					v_facitem=str2num(facitem)
					if (!numtype(v_facitem))
						fact*=v_facitem
					else
						facStr+=facitem+"*"
					endif
				endfor
				if (strlen(facstr)==0)
					fragMatrix_tmp[idex][mz-1]+=fact
				else
					depstr+=num2str(mz-1)+","+num2str(idex)+","+facstr+num2str(fact)+";"
				endif
			endif	// end if the last list item is a real mz number
			
		endfor		// end for every comma separated entry in FragWave[idex]
		
	endfor		// end for every row, idex, in FragWave

//& Filter m/z channels from the matrix that do not contain a positive contribuition and make vector and matrix
//& Not valid if a time-dependent matrix is generated
	if (method&2 && strlen(depstr)==0)			//^ added some checking in 1.42B

		matrixop /o fragWave_Key=greater(greater(fragMatrix_tmp,0) x fragWave_tmp,0)		// greater is a matrixop function that returns truth of a>b

		//^ begin added some checking in 1.42B
		duplicate/o fragMatrix_tmp fragMatrix_tmpNeg
		fragMatrix_tmpNeg*=-1
		matrixop /o fragWave_NegKey=greater(greater(fragMatrix_tmpNeg,0) x fragWave_tmp,0)	
		
		tempSumNeg = sum(fragWave_NegKey, -inf, inf)
		tempSum = sum(fragWave_Key, -inf, inf)
		tempStr = destname[13,strlen(destname)-1]		// root:ms_mats:
//		if (tempSum==0 && !stringmatch("frag_air",  lowerstr(frag_excludeStr) ))		// 1.43B
		if (tempSum==0)		// 1.43D
			print "// There was a problem with frag non-negativity (non-physicality) for "+tempStr+" because entries result in a zero matrix"
//		elseif (tempSumNeg!=0)
//			findlevel/Q/P fragWave_NegKey, 1
//			print "**** There was a problem with frag non-negativity (non-physicality) for "+tempStr+" at "+num2str( V_LevelX+1)
		endif		
		//^ end added some checking in 1.42B
	
		fragMatrix_tmp*=fragWave_Key[p]	// multiply rows of 2d wave by varying constants

	endif

	matrixop /o $(destname+"_mat")=fragMatrix_tmp^t		// makes the species_mat wave
	imagetransform sumAllCols fragMatrix_tmp
	wave w_sumcols
	duplicate /o W_sumcols,$(destname+"_vec")	// makes the species_vec wave
	note /k $(destname+"_mat"),depstr
	note /k $(destname+"_vec"),depstr
	
	// clean up
	killwaves /z fragMatrix_tmp, fragWave_tmp, fragWave_Key, fragMatrix_tmpNeg, fragWave_NegKey w_sumcols

End


//& Evaluates a frag list item, and assigns it to a mz bin
// JDA fix for 1.41, added an exclude parameter
Function /t sq_fragList_pass(itemStr,length,excludeStr)
	string itemStr,excludeStr
	variable length
	
	wave /t spec_list=root:frag:spec_list
	wave /t frag_list=root:frag:frag_list
	wave calfac_list=root:frag:calfac_list

	string prefix,dest,subItemStr
	variable num1, num2, kw, jdex, mz, kdex, flag,b1,b2,mz1,mz2,bailout=0

	mz=0
	dest=""
	flag=0

	num1=itemsinlist(itemStr,"*")
	if (num1>1)
		prefix=removelistitem(num1-1,itemStr,"*")
		itemStr=stringfromlist(num1-1,itemStr,"*")
	else
		prefix=""
	endif
	if (stringmatch(itemStr[0],"-"))
		prefix+="-1*"
		itemStr[0,0]=""
	endif

	num1=itemsinlist(prefix,"*")
	//& Bailout if a zero is found
	for (jdex=0;jdex<num1;jdex+=1)
		if (str2num(stringfromlist(jdex,prefix,"*"))==0)
			bailout=1
			break
		endif
	endfor	
	
	//& Bailout if the item contains the exclude string
	if (strlen(excludeStr)>0 && strsearch(itemStr,excludeStr,0,2)>-1)
		bailout=1
	endif

	if (bailout)
		flag=1
		dest=""
	else
		if (stringmatch(upperstr(itemStr),"ALL"))		//& The 'all' keyword
			itemStr=num2str(MZ_START_VALUE)+"-"+num2str(length)
		endif
		
		num1=strlen(itemStr)
		kw=0
		for(jdex=0;jdex<num1;jdex+=1)		//& Search for illegal characters
			if (strsearch(FRAG_CHARS,itemStr[jdex],0)==-1)
				kw=1
				break
			endif
		endfor
		
		if (kw==1)
			if (stringmatch(upperstr(itemStr[0,4]),"FRAG_"))		//& Reference to fragment wave
				b1=strsearch(itemStr,"[",0)
				b2=strsearch(itemStr,"]",0)
				if (b1>5 && b2>b1+1)
					wave /t/z fragwave=root:frag:$(itemStr[0,b1-1])
					if (waveexists(fragwave))
						subItemStr=itemStr[b1+1,b2-1]
						if (itemsinlist(subitemStr,"-")==1)		// single entry liek frag_organic[43]
							mz=str2num(subItemStr)
							if (mz<=numpnts(fragwave))
								num1=itemsinlist(fragwave[mz-1],",")
								dest=""
								for (jdex=0;jdex<num1;jdex+=1)
									dest+=prefix+stringfromlist(jdex,fragwave[mz-1],",")+","
								endfor
							endif
						else		// multiple entries like frag_organic[43-55]
							mz1=str2num(stringfromlist(0,subItemStr,"-"))
							mz2=str2num(stringfromlist(1,subItemStr,"-"))
							if (mz1>0 && mz2>=mz1)
								for (jdex=mz1;jdex<=mz2;jdex+=1)
	//								dest+=prefix+itemStr[0,b1]+num2str(jdex+1)+"],"
									dest+=prefix+itemStr[0,b1]+num2str(jdex)+"],"		//1.50C bug fix
								endfor
							endif
						endif
					endif
				else		// the entire frag wave
					wave /t/z fragwave=root:frag:$itemStr
					if (waveexists(fragwave))
						num1=numpnts(fragwave)
						for (jdex=0;jdex<num1;jdex+=1)
							if (strlen(fragwave[jdex])>0)
								dest+=prefix+itemStr+"["+num2str(jdex+1)+"],"
							endif
						endfor
					endif
				endif
			else			//& Reference to other species
				if (stringmatch(itemStr[0],"$"))
					kw=2	// determines whether or not we use the RIE values or not
					itemStr[0,0]=""
				endif
				num1=numpnts(spec_list)
				for (jdex=0;jdex<num1;jdex+=1)
					if (stringmatch(upperstr(itemStr),upperstr(spec_list[jdex])))
						num2=itemsinlist(frag_list[jdex],",")
						for (kdex=0;kdex<num2;kdex+=1)
							if (kw==2)		// determines whether or not we use the RIE values or not
								dest+=prefix+num2str(calfac_list[jdex])+"*"+stringfromlist(kdex,frag_list[jdex],",")+","
							else		// don't use RIE
								dest+=prefix+stringfromlist(kdex,frag_list[jdex],",")+","
							endif
						endfor
						break
					endif
				endfor
			endif
			
		elseif (itemsinlist(itemStr,"-")>1)		//& Range of m/z's
			mz1=str2num(stringfromlist(0,itemStr,"-"))
			mz2=str2num(stringfromlist(1,itemStr,"-"))
			if (mz1<=mz2)
				for (jdex=mz1;jdex<=mz2;jdex+=1)
					dest+=prefix+num2str(jdex)+","
				endfor
			endif
		
		else		//& Legal entry
			mz1=str2num(itemStr)
			if (numtype(mz1)==0)
				mz=mz1
				dest=prefix+num2str(mz1)+","
				flag=1
			endif
		endif
	endif		// if bailout
	
	return num2str(mz)+";"+dest+";"+num2str(flag)

End


//^ check to see if frags have been changed since vector creation
//  not currently used
Function sq_checkFragMod(speclist)
	string speclist

	wave/t frag_list=root:frag:frag_list
	wave/t spec_list=root:frag:spec_list
	wave/t specname_list=root:frag:specname_list

	variable idex, num, vecmodtime, matmodtime, fragmodtime,returnval,loc	
	string specstr, vecinfo, matmodinfo, fragmodinfo

	returnval=0
	num=ItemsInList(speclist,",")
	
	for(idex=0;idex<num;idex+=1)
		specstr = StringFromList(idex, speclist,",")
		loc=sq_findstr(spec_list,specstr,1)
		if(loc==-1)
			loc=sq_findstr(specname_list,specstr,1)
		endif
		if(loc==-1 || numtype(str2num(specstr))==0)
			returnval = 1
		else
			wave/z vecwave = $("root:ms_mats:"+spec_list[loc]+"_vec")
			wave/z matwave = $("root:ms_mats:"+spec_list[loc]+"_mat")
			wave/z/t fragwave = $("root:frag:"+frag_list[loc])
			if (WaveExists(vecwave) && WaveExists(matwave)  && WaveExists(fragwave))
				vecinfo = WaveInfo(vecwave,0)
				vecmodtime = NumberByKey("MODTIME", vecinfo)	
				matmodinfo = WaveInfo(matwave,0)
				matmodtime = NumberByKey("MODTIME", matmodinfo)	
				fragmodinfo = WaveInfo(fragwave,0)
				fragmodtime = NumberByKey("MODTIME", fragmodinfo)		
				if   ( (fragmodtime>matmodtime) || (fragmodtime>vecmodtime)  )
					returnval = 0
					break //^ get out of loop.. we know that things have been modified for at least one species	
				else
					returnval = 1		
				endif
			else
				returnval = 0
				break  //^ get out of loop.. we know that things have been modified for at least one species
			endif		
		endif
	endfor
	return returnval

End


//& Evaluates all keywords in a fragment list - squirrel version
//^ added comments and made it easier to read
// for individual sticks, like 44, fragList = "44", for species like Org, fragList = "frag_org", a real text wave
Function sq_fragList_convert(fragList,destWaveStr,length,excludeStr)
	string fragList, destWaveStr,excludeStr	
	variable length
	
	variable idex,numInterimList,flag,mz, jdex, simpleRecursionCount, simpleRecursionMax, maxUserDefined, userDefIndex, UserDefPos
	string interimList,dest,passStr, UserDefStr 
	
	simpleRecursionMax=300	// arbitrary
	
	make /o/t/n=(length+maxUserDefined) $destWaveStr	// 1.51K 
	wave /t destWav=$destWaveStr
	destWav=""

	interimList=replacestring(" ",fragList,"")

// first create destWave
	do
		dest=""
		numInterimList=itemsinlist(interimList,",")
// iterate until the first entry returned from sq_fraglist_pass is non zero
		for (idex=0;idex<numInterimList;idex+=1)
			passStr=sq_fraglist_pass(stringfromlist(idex,interimList,","),length,excludeStr)		//1.41 change
//			print idex, passStr
// i.e. frag_NH4		// sq_fraglist_convert("frag_NH4","vec_tmp",700,"")
//  0  0;frag_NH4[15],frag_NH4[16],frag_NH4[17],;0
//  0  15;0.1*frag_NH4[16],;0
//  1  16;16,-frag_water[16],-frag_air[16],-frag_sulphate[16],-frag_organic[16],;0
//  2  17;0*1.1*frag_NH4[16],1*frag_NH4_17[17],;0
// i.e. frag_NH4[16]			// sq_fraglist_convert("frag_NH4[16]","vec_tmp",700,"")
//  0  16;16,-frag_water[16],-frag_air[16],-frag_sulphate[16],-frag_organic[16],;0
// sq_fraglist_convert("frag_NH4[16-17]","vec_tmp",700,"")
//  0  0;frag_NH4[16],frag_NH4[17],;0
//  0  16;16,-frag_water[16],-frag_air[16],-frag_sulphate[16],-frag_organic[16],;0
//  1  17;0*1.1*frag_NH4[16],1*frag_NH4_17[17],;0
//  i.e. Over			sq_fraglist_convert("Over","vec_tmp",700,"")
//  0  0;-Others,;0
//  0  0;-1*-Water,-1*-NH4,-1*-NO3,-1*-SO4,-1*-Org,-1*-Chl,-1*-PAH,-1*-Air,-1*all,;0
//  0  0;-1*-1*frag_water,;0
//  1  0;-1*-1*frag_NH4,;0 etc
			
			mz=str2num(stringfromlist(0,passStr))
			if (mz==0)
				dest+=stringfromlist(1,passStr)
			elseif (mz<=length+maxUserDefined)		// 1.51K modification
				destwav[mz-1]+=stringfromlist(1,passStr)
			endif
		endfor
		interimList=dest
	while (strlen(dest)>0)
	
	for (jdex=0;jdex<length;jdex+=1)
		interimList=destwav[jdex]
		if (strlen(interimList)>0)
			simpleRecursionCount=0
			do
				simpleRecursionCount+=1
				dest=""
				flag=1
				numInterimList=itemsinlist(interimList,",")
// iterate until the last entry returned from sq_fraglist_pass is non zero
				for (idex=0;idex<numInterimList;idex+=1)
					passStr=sq_fraglist_pass(stringfromlist(idex,interimList,","),length,excludeStr)

					mz=str2num(stringfromlist(0,passStr))
//					print jdex, passStr
//sq_fraglist_convert("frag_nitrate[30]","vec_tmp",700,"")
//  29  30;30,;1
//  29  30;-1*0.0000136*frag_air[28],;0
//  29  30;-1*0.022*frag_organic[29],;0
//  29  30;30,;1
//  29  28;-1*0.0000136*28,;0
//  29  29;-1*0.022*29,-1*0.022*-frag_air[29],;0
//  29  30;30,;1
//  29  28;-1*0.0000136*28,;1
//  29  29;-1*0.022*29,;1
//  29  29;-1*0.022*-1*0.00736*frag_air[28],;0
//  29  30;30,;1
//  29  28;-1*0.0000136*28,;1
//  29  29;-1*0.022*29,;1
//  29  28;-1*0.022*-1*0.00736*28,;0
//  29  30;30,;1
//  29  28;-1*0.0000136*28,;1
//  29  29;-1*0.022*29,;1
//  29  28;-1*0.022*-1*0.00736*28,;1
					if (mz<=length+maxUserDefined)		// 1.51K modification
						dest+=stringfromlist(1,passStr)
						flag*=str2num(stringfromlist(2,passStr))
					endif
				endfor
				interimList=dest
				if (simpleRecursionCount>simpleRecursionMax || numInterimList>simpleRecursionMax)
					abort "// Recursion found for "+fragList+"!!"	
				endif
				
			while (flag==0 && simpleRecursionCount<simpleRecursionMax && numInterimList <simpleRecursionMax )
			if (simpleRecursionCount<simpleRecursionMax)
				destWav[jdex]=interimList
			else
				abort "// Recursion found for "+fragList+"!!"	
				break		
			endif
		endif
	endfor
	
End


// Added in 1.51K
// Used within sq_fragList_convert within sq_msconcs
// Given a list, check if any item has a prefix.  If it does, check the textwave to see if it exists and replace the list item with the entry.
// print SubItemsInListToTextwave("0;frag_NH4[15],UserDefinedHz_test1,frag_NH4[17],;0", textwave1, "UserDefinedHz_", 400)
//   0;frag_NH4[15],400,frag_NH4[17],;0
Function/s sq_SubItemsInListToTextwave(passStr, textwave, prefix, mzmax)
wave/t textwave
string passStr, prefix
variable mzmax

	string str, returnStr, UserDefList
	variable idex, num, numInWave
	
	returnStr= passStr
	numInWave = numpnts(textWave)

	UserDefList = GrepList(ReplaceString(",", stringfromList(1,passStr), ";"), "UserDefinedHz_")		// goes from "0;frag_NH4[15],UserDefinedHz_test1,frag_NH4[17],;0" to UserDefinedHz_test1 
	num = itemsInList(UserDefList)	// presumes list is ";" seperated.

	for (idex=0;idex<num;idex+=1)		// go through all the user defined waves thus far to see if it already is included in the list of waves
		str = stringfromlist(idex, UserDefList)			// "UserDefinedHz_blah"
		str = GrepList(ReplaceString("*", str, ";"), "UserDefinedHz_")			// if entry is something like -1*0.00368*-1*0.04*-1*0.022*UserDefinedHz_29 the coeffs need to be stripped off
		str = stringFromList(0, str)
		FindValue/Text=(str) textwave
		if (V_value <0) 		// item not found, add it
			InsertPOints numInWave, 1, textwave
			textwave[numInWave]=str
			returnStr = ReplaceString(textwave[numInWave], returnStr, num2str(mzmax+1+numInWave))
			numInWave+=1
		else
			returnStr = ReplaceString(textwave[numInWave], returnStr, num2str(mzmax+1+V_value))
		endif
	endfor
	
	return returnStr

End



Function sq_fragPanel_butt_CheckRecurs(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	string tableFragList, paramstr, specStr, fragStr
	variable idex, num, length
	
	switch( ba.eventCode )
	case 2: // mouse up
		SetDataFolder root:frag:
		tableFragList = WaveList("frag_*", ";", "WIN:FragPanel#FragTable" )
		setDataFolder root:
		print "// At "+time()+" began checking for very simple recursion and non-physicality errors."
		num = ItemsInList(tableFragList)
		for(idex=0;idex<num;idex+=1)
			fragStr=stringfromlist(idex,tableFragList,";")
			wave fragwave = $"root:frag:"+fragStr
			specStr = fragStr[5,strlen(fragStr)-1]
			sq_fraglist_convert(fragStr,"vec_tmp",numpnts(fragwave)-1,"")
			sq_frag_matrix($"vec_tmp","root:ms_mats:"+specStr,2)		// last parameter, 2 filters for negatives //1.43D
		endfor
		wave vec_tmp
		killwaves/z vec_tmp
		print "// All ok! At "+time()+" finished checking frag waves displayed in the table " +tableFragList+ " were checked for very simple recursion and non-physicality errors."
	break
	endswitch

	return 0

End


// generic button control function for killing panel/window
Function sq_butt_End(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			DoWIndow/k $(ba.win)
			break
	endswitch

	return 0
End


// added in 1.42E 
Function gen_joinWaves(wave1, wave2, joinedWaveStr)
wave wave1, wave2
string joinedWaveStr

	if (numpnts(wave1) !=numpnts(wave2) )
		print "// Cannot join waves "+NameofWave(wave1) + " and "+ NameofWave(wave2) + " because they have different lengths."
	endif
	
	duplicate/o wave1 $joinedWaveStr
	wave joinedWave = $joinedWaveStr
	
	joinedWave = numtype(wave1[p])==0 ? wave1[p] :wave2[p] 
	
End


// main panel function to use when the raw and intermediate hdfs are in a different location
Function sq_butt_changeHDFPath(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	wave/t file_index = root:index:file_index
	svar/z processed_path = root:processed_path		//1.57M

	variable iDir, numDir, idex, num	
	string str, oldStr, newStr, allDirList, DirStr, fileStr, fileList
	
	num=numpnts(file_index)
		
	// first get a list of all directories
	allDirList=""
	fileList=""
	numDir=0
	for (idex=0;idex<num;idex+=1)
		str = file_index[idex]
		DirStr = str[0, strsearch(str, ":", strlen(str), 1)]
		fileStr = str[strsearch(str, ":", strlen(str), 1)+1, strlen(str)-1]
		if (WhichListItem(DirStr,allDirList)<0)	// not found
	 		allDirList+= DirStr + ";"
			fileList += fileStr + ";"		// just do this for the first one.
	 		numDir+=1
	 	endif 
 	endfor

	str ="You may want to save the experiment before you perform this operation. Your hdf files are located in "+num2str(numDir) + " directories. If you wish to change the place where squirrel looks for these files (a sensitive operation) select yes." 
	DoAlert 1, str[0, min(254,strlen(str)-1)]	// Puneet's error when the directory structure gets long.  1.51I
 	if (V_flag!=1)//yes
		return 0 		// do nothing.
	endif 		
	
	// first check to see if
	for (iDir=0;iDir<numDir;iDir+=1)
		DirStr=StringFromList(iDir, allDirList, ";")
		fileStr = StringFromList(iDir, fileList, ";")
	 	NewPath/q/o/m="Select a directory where the hdf file "+fileStr+" and its siblings now live" tempPath  //1.57E
	 	if (V_flag==0)
	 		
	 		PathInfo tempPath
	 		newstr=S_path
	 		str = "Select Yes if you want to overwrite the location of files such as "+fileStr+" from\r"+DirStr+" to\r"+ S_path
	 		DoAlert 1,str[0, min(254,strlen(str)-1)]
	 		if (V_flag==1)//yes
	 			sq_updatePath(DirStr, S_path) 
				print "// The location of the hdf files such as "+fileStr+" in root:index:file_index was changed from \r//  "+DirStr + " to\r//  "+S_path
				if (!SVar_Exists(processed_path) )
					string/g root:processed_path
					svar processed_path = root:processed_path
				endif				
				if (stringmatch(DirStr, processed_path))	// the place for intermediate files.
					processed_path=S_path
				endif
			endif 		
 		else	// user aborted
 		 	DoAlert 0, "You did not choose a new directory for this file .  Continuing on the "+num2str(iDir)+"th directory...."
			print "// The location of the hdf files such as "+fileStr+" was not changed from "+DirStr
  		endif	
		KillPath/z tempPath
 	endfor

	DoAlert 1, "It is recommended that you check for the existence of all hdf files in their new directory path.  Select yes to perform this check."
	 if (V_flag==1)//yes
	 	sq_butt_checkFiles("")
	endif 		
	
End


// updates waves that will be displayed in sq_Journal_Table
Function sq_updateSquirrelJournalWaves()

	wave/t squirrel_journal = root:index:squirrel_journal
	
	variable numEntries, idex, p1,p2
	string Entry
	
	numEntries= numpnts(squirrel_journal)
	
	make/o/d/n=(numEntries) root:panel:sq_journalStart, root:panel:sq_journalFinish
	make/o/t/n=(numEntries) root:panel:sq_journalOperation, root:panel:sq_journalOperationParams
	
	wave sq_journalStart = root:panel:sq_journalStart 
	wave sq_journalFinish = root:panel:sq_journalFinish
	
	wave/t sq_journalOperation = root:panel:sq_journalOperation 
	wave/t sq_journalOperationParams = root:panel:sq_journalOperationParams

	sq_journalStart=numberByKey("T_Start",squirrel_journal[p])
	sq_journalFinish =numberByKey("T_Finish",squirrel_journal[p])
	sq_journalOperation =stringByKey("Operation",squirrel_journal[p])
	
	sq_journalOperationParams=""
	for(idex=0;idex<numEntries;idex+=1)
		Entry = squirrel_journal[idex]
		p1 = strsearch(Entry, "T_Start:", 0)
		if (p1<0)
			continue
		endif
		p1 = strsearch(Entry, ";", p1)
		if (p1<0)
			continue
		endif
		p2 = strsearch(Entry, "T_Finish:", p1)		
		if (p1+1<p2-2)
			sq_journalOperationParams[idex] = Entry[p1+1,p2-2]
		endif		
	endfor

End


// main panel function for displaying sq_journal_table
//Function sq_butt_reviewJournal(ba) : ButtonControl
//	STRUCT WMButtonAction &ba
//
//	switch( ba.eventCode )
//		case 2: // mouse up
//			sq_updateSquirrelJournalWaves()
//			
//			DoWIndow/F Sq_Journal_table
//			if (V_flag==1)
//				return 0
//			endif
//					
//			edit/n=Sq_Journal_Table root:panel:Sq_journalStart,root:panel:Sq_journalFinish,root:panel:Sq_journalOperation,root:panel:Sq_journalOperationParams as "Sq_Journal_Table"
//			// 1.44B preventing things from going bad if not in root folder
//			ModifyTable format(root:panel:sq_journalStart)=8, format(root:panel:sq_journalFinish)=8
//			ModifyTable width(root:panel:sq_journalStart)=100, width(root:panel:sq_journalFinish)=100
//			break
//	endswitch
//
//	return 0
//End


// for squirrel 
// sq_butt_UpdateIpfs("sq", "ams_panel", "sq_getAMSwin()")
// Kills old ipfs and main panel, loads new ones ipfs, creates new main panel
//Function sq_updateIpfs(packagePrefix, packagePanelWinList, packageCreationFuncList)
//string packagePrefix, packagePanelWinList, packageCreationFuncList
//
//	string currentVerStr, newVerStr, itemStr, ipfPrefix
//	variable idex, numList
//		
//	if (NumberByKey("IGORVERS", IgorInfo(0)) < 6.10)
//		Abort "This feature is not available for Igor versions less than 6.10"
//	endif
// 
//	currentVerStr = sq_CurrentProcsVersion(packagePrefix)		// Eventually this will use info in the pragma version variable.	
//	newVerStr = sq_newProcsLocation(packagePrefix)
//
//	DoAlert 1,  "You are about to kill procedures of version "+CurrentVerStr+" and load procedures of version "+NewVerStr+". It is recommended that you save the experiment before you proceed. Press yes to continue, no to quit."	
//	if (V_flag==2)		// user wants to abort
//		return 0
//	endif
//	
//	// should add something to the squirrel journal
//	print "// Began updating procedure files at", time()
//
//	sq_LoadProcs(NewVerStr, packagePrefix)
//	sq_KillProcs(packagePrefix, CurrentVerStr)
//	
//	numList = itemsInList(PackagePanelWinList)
//	for (idex=0;idex<numList;idex+=1)
//		Execute/P "DoWIndow/K "+StringFromList(idex, PackagePanelWinList)
//	endfor
//		
//	numList = itemsInList(PackageCreationFuncList)
//	for (idex=0;idex<numList;idex+=1)
//		itemStr = StringFromList(idex, PackageCreationFuncList)
//		Execute/P itemStr
//	endfor
//
//	print "// Finished updating procedure files at", time()
//	
//	// DoWindow/F SQ_Backbone_1_57K.ipf  It would be nice if this worked....  //1.57K
//	// DoIgorMenu "File", "Adopt Window"
//
//End
//
//
//// loads squirrel ipfs of version NewVersionStr.  ipfPrefix must be a 3-character string
//Function sq_loadProcs(newVersionStr, ipfPrefix)
//string newVersionStr, ipfPrefix
//
//	string myList, myStr, myPathStr
//	variable idex, num
//	
//	PathInfo UpgradeIPfsPath
//	myPathStr = S_path
//	
//	myList =IndexedFile(UpgradeIPfsPath,-1,".ipf")
//	num = itemsinList(mylist)
//	for (idex=0;idex<num;idex+=1)
//		myStr = StringFromList(idex, myList)
//		if (stringmatch(lowerstr(myStr[0,1]), lowerstr(ipfPrefix)) )
////			myStr = myStr[0, strlen(mystr)-5]
////			print myPathStr+myStr
//			Execute/P/Z "INSERTINCLUDE \"" + myPathStr  + ParseFilePath(3, myStr, ":", 0, 0)+"\""
////			Execute/P "LOADFILE "+ myPathStr  + myStr
//		endif
//	endfor
//
//	Execute/P/Q/Z "COMPILEPROCEDURES "
//
//End
//
//
//// Returns the new version number of the new squirrel ipfs
//Function/S sq_newProcsLocation(ipfPrefix)
//string ipfPrefix
//
//	string myStr, ReturnStr, myList
//	variable idex, num
//	
//	NewPath/q/o/m="Where is the folder that contains the new igor procedure files that you would like to load?" UpgradeIPfsPath
//	if (V_flag!=0)	// there was an error
//		Abort "The user chose to cancel"
//	endif
//	
//	ReturnStr=""
//	// Now check to see if this location has any ips that match the package type
//	myList =IndexedFile(UpgradeIPfsPath,-1,".ipf")
//	num = itemsInList(myList)
//	for (idex=0;idex<num;idex+=1)
//		myStr = StringFromList(idex, myList)
//		if (stringmatch(lowerstr(myStr[0,1]), lowerstr(ipfPrefix)) )
//			ReturnStr = myStr[strlen(mystr)-8, strlen(mystr)-5]
//			break
//		endif
//	endfor
//
//	return ReturnStr
//		
//End
//
//
////  returns the squirrel version number as a string, such as "1_43"
//Function/S sq_currentProcsVersion(packagePrefix)	
//string packagePrefix
//
//	string ReturnStr, ProcList, ProcStr, thisProc
//	variable idex, numList, len
//	
//	ReturnStr=""
//	ProcList = WinList("*", ";", "WIN:128")
//	numList=ItemsInList(ProcList)
//	for (idex=0;idex<numList;idex+=1)
//		ProcStr = StringFromList(idex, ProcList)
//		if ( strsearch(lowerStr(ProcStr[0,1]), lowerstr(packagePrefix),0)>=0)		// presume it is a squirrel ipf
//			len = strlen(ProcStr)
//			ReturnStr = ProcStr[len-8, len-5]
//			break
//		endif
//	endfor
//	
//	return returnStr
//	
//End	
//	
//
// main panel function for initiating an upgrade to a new version of squirrel
// Function sq_butt_UpdateIpfs(ba) : ButtonControl
// 	STRUCT WMButtonAction &ba
// 
// 	switch( ba.eventCode )
// 		case 2: // mouse up
// 			sq_updateIpfs("sq", "ams_panel", "sq_getAMSwin()")
// 			break
// 	endswitch
// 
// 	return 0
// End



//  These next two function are to be used when the run numbers for consequtive runs go backwards in time
// as in the case of a nasty power failure and the daq files were not backed up.
// (Squirrel cannot handle the case where run numbers jump backwards relative to time.)
//
// This function will create new 'raw' daq hdf files, with the *only* thing different in the raw files is the
// artificial increase in run number, based on the time stamp of the time of the run numbers going back in time.
// This function needs to be modified *by hand* before usage, as it will not automatically detect where
// run numbers went backwards relative to time.  The increase in run numbers is given as a convenient
// multiple of powers of 10, so one doesn't have to do cumbersome addition to run numbers when checking
// field notebooks for matching of times/run numbers with noted events.
//
// The original daq files are never overwritten.
// This presumes the text in the attributes are the same for all files (there was not an upgrade in the daq software).
//
// Usage is as follows:
// The user opens up a new squirrel template experiment and presses the get index button.
// The user selects the folder with all the original, raw daq hdf files.
// The user changes variables in sq_ChangeRunNumbers to match the breaks (pointes where run numbers go backwards).
// The user selects the folder where the new raw daq files (with modified run number) will be located.
// The user can close and save this experiment (for posterity sake)
//  The user opens a new squirrel template experiment and when the get index button is pressed the location of the new
// raw daq files are chosen.  Then everything proceeds as usual.

Function sq_changeRunNumbers()
	
	wave/t file_index = root:index:file_index

	string fileName, fullFileName
	string groupList, groupStr
	string tempStr
	variable idex, num, jdex, num2,  fileID, groupidex, groupnum
	variable/d firstTimeStampInFile, offset
	variable FirstBreakPoint, SecondBreakPoint, ThirdBreakPoint
	variable FirstBreakDeltaRun, SecondBreakDeltaRun, ThirdBreakDeltaRun
	
	FirstBreakDeltaRun = 3000		// add at lest 2610-number of runs, make it an even, arbitrary, 3000 
	SecondBreakDeltaRun = 1000		// add at least 304-number of runs, make it an even, arbitrary, 1000
	ThirdBreakDeltaRun = 1000		// add at least 624-number of runs, make it an even, arbitrary, 1000
	
	FirstBreakPoint = date2secs(2007,9,6) + 0*3600+0*60+0 - 1		// midnight, 00:00:00
	SecondBreakPoint = date2secs(2007,9,16) + 19*3600+32*60+40 - 1	// 19:32:40
	ThirdBreakPoint = date2secs(2007,9,17) + 0*3600+35*60+27 - 1	// 19:32:40
	
	PathInfo NewHdfPath
	if(V_flag==0)
		NewPath/o/m="Where do you want to put the new hdf files?" NewHdfPath
	endif
		
	STRUCT HDF5DataInfo di	// Defined in HDF5 Browser.ipf.
	InitHDF5DataInfo(di)	// Initialize structure.
	
	num = numpnts(file_index)

	make/t/o/n=0 RunInfo_att
	make/t/o/n=0 myTempText

	print "// The function setting new run numbers began at "+time()
	
	for (idex=0;idex<num;idex+=1)
		fullFileName=file_index[idex]
		fileName = ParseFilePath(0, fullFileName, ":", 1, 0)		
		HDF5OpenFile/r fileID as fullFileName
		
		// first deal with run info
		HDF5LoadData/q/o fileID, "RunInfo"
		wave RunInfo
		firstTimeStampInFile = date2secs(RunInfo[0][1],1,1) +(86400*RunInfo[0][2])+RunInfo[0][3]
		if(firstTimeStampInFile > FirstBreakPoint)
			if(firstTimeStampInFile > SecondBreakPoint)
				if(firstTimeStampInFile > ThirdBreakPoint)
					offset=FirstBreakDeltaRun + SecondBreakDeltaRun+ ThirdBreakDeltaRun
				else
					offset=FirstBreakDeltaRun + SecondBreakDeltaRun
				endif
			else
				offset=FirstBreakDeltaRun
			endif
		else		// just copy the old
			offset=0
		endif
		RunInfo[][0] += offset
		sq_LoadAttributesFromHDF(fullFileName, "RunInfo", RunInfo_att)

		// next deal with all other groups in  hdf file
		HDF5ListGroup/TYPE=2 fileID, "/"		// 1.55K  added /TYPE=2
		groupList = S_HDF5ListGroup
		groupList = RemoveFromList("RunInfo",groupList)		
		groupnum = ItemsInList(groupList)

		print "// added to run values "+num2str(offset)+" for "+num2str(idex) + " of "+ num2str(num) + " with file name "+fileName

		if (groupnum==0)		//1.55K
			HDF5CloseFile fileID
			abort "This hdf file "+fullFileName+" does not seem to have any other groups beyond RunInfo.  Aborting from sq_changeRunNumbers"
		endif

		for (groupidex=0;groupidex<groupnum;groupidex+=1)	
			groupStr = StringFromList(groupidex, groupList)
			make/t/o/n=(0) $groupStr+"_att"
			HDF5LoadData/q/o fileID, groupStr
			sq_LoadAttributesFromHDF(fullFileName, groupStr,  $groupStr+"_att")
		endfor
		
		HDF5CloseFile fileID

		// now write new file
		sprintf tempStr, "%d", runInfo[0][0]
		tempStr = "0000"+tempStr		// preprend some zeros if needed
		tempStr = tempStr[strlen(tempStr)-6, strlen(tempStr)-1]
		filename = filename[0,6] + tempStr + filename[13,18]
//		if (offset>0)
//			print TempStr, filename
//		endif
		HDF5CreateFile/o/P=NewHdfPath fileID as fileName
		HDF5SaveData RunInfo, fileID 
		for (groupidex=0;groupidex<groupnum;groupidex+=1)	
			groupStr = StringFromList(groupidex, groupList)
			wave mywave = $groupStr 
			wave/t mywave_att = $groupStr +"_att"
			HDF5SaveData mywave, fileID
			for(jdex=0;jdex<num2;jdex+=1)
				myTempText=mywave_att[jdex]
				HDF5SaveData/IGOR=0/A=(groupStr+"_"+num2str(jdex)) /Z myTempText, fileID, groupStr	// Save wave as dataset.
				if (V_flag != 0)
					print "HDF5SaveData failed for "+groupStr+"_att "+ mywave_att[jdex] // myTempText		//1.57J
					break
				endif
			endfor			
		endfor
		HDF5CloseFile fileID
		Killwaves/z RunInfo_att
	endfor	

	print "// The function setting new run numbers ended at "+time()

End


// Creates a text wave containing the attributes of a data set within an hdf file.  Sample usage:
// sq_LoadAttributesFromHDF("070710_000001663_fF.hdf", "FluxVals", FluxAtts)
// Creates root:F_index:FluxVals_atts.
Function sq_LoadAttributesFromHDF(hdfFile, dataSet, attWave)
string hdfFile, dataSet
wave/T attWave

	string att, savedDataFolder=GetDataFolder(1)	
	variable numInDataIndex, fileID, idex, numOfAttributes
	STRUCT HDF5DataInfo di	// Defined in HDF5 Browser.ipf.

	HDF5OpenFile/R fileID as hdfFile
	
	if (fileID<=0)
		abort "There was a problem opening file "+hdfFile
	endif

	HDF5ListAttributes/q fileID, dataSet
	if (V_flag!=0)
		abort "There was an error with getting the attributes to the "+dataSet+" data set in the hdf file:"+ParseFilePath(3, HDFfile, ":", 0, 0)+" Aborting from sq_LoadAttributesFromHDF"
	endif

	numOfAttributes=itemsinlist(S_HDF5ListAttributes)
	att=stringfromlist(0,S_HDF5ListAttributes)

	Redimension/n=(numOfAttributes) attWave

	for(idex=0;idex<numOfAttributes;idex+=1)
		att=stringfromlist(idex,S_HDF5ListAttributes)
		HDF5LoadData/A=att/Q/Z/N=attTmp/O fileID, dataSet
		wave/t source=$savedDataFolder+"attTmp"
		attWave[idex]=source[0]
	endfor

	HDF5CloseFile fileID

	killwaves/z source

End


// *************************************************
// Returns a string containing the common entries in the two lists.  (Sort of a list AND)  1.46E 
Function/s gen_IntersectLists(list1, list2)
	String list1, list2

	string str2, returnStr =""
	
	variable idex, num= ItemsInList(list1)
	for(idex=0; idex < num; idex+=1)	
		str2 = StringFromList(idex, list1,";")
		if (WhichListItem(str2 , list2, ";" )>=0)
			returnStr+=str2+";"
		endif					
	endfor										
	
	return returnStr
	
End


///////////////////////////////////////////////////////////////////////////////////////
// fBoxPlot - added in 1.44B
// renamed from fBoxPlot_graphAxNm
Function gen_fBoxPlot_graphAxNm(median, boxTop, boxBottom, whiskerTop, whiskerBottom, XWave, BoxWidth, ColoredBoxes, OUTY, OUTX, FillRed, FillGreen, FillBlue, DisplayLocation, AxNm)
	wave/Z median, boxTop, boxBottom, whiskerTop, whiskerBottom
	wave/Z XWave		// if null wave, use X scaling, which will be point scaling.
	variable BoxWidth	// width of the box part of the display, in X units of the X wave.
	variable ColoredBoxes // setting this to non-zero puts a colored rectangle behind each box. You can color them individually if you want.
	wave/Z OUTY, OUTX
	variable FillRed, FillGreen, FillBlue
	string DisplayLocation, AxNm
	
	string WName, WCompleteName, medianCompleteName, medianName
	string GraphNote=""
	
	GraphNote += "BOXWIDTH="+num2str(BoxWidth)+";"
	if (ColoredBoxes)
		GraphNote += "COLOREDBOXES=1;"
	else
		GraphNote += "COLOREDBOXES=0;"
	endif
	GraphNote += "FILLRED="+Num2str(FillRed)+";"
	GraphNote += "FILLGREEN="+Num2str(FillGreen)+";"
	GraphNote += "FILLBLUE="+Num2str(FillBlue)+";"
	
	if (!WaveExists(median))
		DoAlert 0, "The median wave does not exists"
		return -1
	endif
	if (!WaveExists(boxTop))
		DoAlert 0,  "The wave giving the tops of the boxes does not exist"
		return -1
	endif
	if (!WaveExists(boxBottom))
		DoAlert 0,  "The wave giving the bottoms of the boxes does not exist"
		return -1
	endif
	
	medianCompleteName = GetWavesDataFolder(median, 2)
	medianName = NameOfWave(median)
	variable nWavePnts=numpnts(median)
	string boxTopCompleteName = GetWavesDataFolder(boxTop, 2)
	string boxBottomCompleteName = GetWavesDataFolder(boxBottom, 2)
	
	GraphNote += "MEDIANwave="+medianCompleteName+";"
	GraphNote += "BOXTOPwave="+boxTopCompleteName+";"
	GraphNote += "BOXBOTTOMwave="+boxBottomCompleteName+";"
	
	if (!WaveExists(boxTop))
		DoAlert 0,  "The wave specifying the tops of the boxes does not exist"
		return -1
	endif
	if (numpnts(boxTop) != nWavePnts)
		DoAlert 0,  "The wave "+NameOfWave(boxTop)+" does not have the same number of points as "+NameOfWave(median)
		return -1
	endif
		
	if (!WaveExists(boxBottom))
		DoAlert 0,  "The wave specifying the bottoms of the boxes does not exist"
		return -1
	endif
	if (numpnts(boxBottom) != nWavePnts)
		DoAlert 0,  "The wave "+NameOfWave(boxBottom)+" does not have the same number of points as "+NameOfWave(median)
		return -1
	endif
		
	// make a dependency formula for the error bar wave for the box tops
	WName = NameOfWave(boxTop)
	WCompleteName = GetWavesDataFolder(boxTop,2)
	Duplicate/O boxTop, $(WName+"EB")
	Wave boxTopEB = $(WName+"EB")
	SetFormula boxTopEB, WCompleteName+"-"+medianCompleteName
	
	GraphNote += "BOXTOPEBwave="+GetWavesDataFolder(boxTopEB,2)+";"
	
	// make a dependency formula for the error bar wave for the box bottoms
	WName = NameOfWave(boxBottom)
	WCompleteName = GetWavesDataFolder(boxBottom,2)
	Duplicate/O boxBottom, $(WName+"EB")
	Wave boxBottomEB = $(WName+"EB")
	SetFormula boxBottomEB, medianCompleteName+"-"+WCompleteName
	
	GraphNote += "BOXBOTTOMEBwave="+GetWavesDataFolder(boxBottomEB,2)+";"
	
	if (WaveExists(whiskerTop))
		// make a dependency formula for the error bar wave for the whisker tops
		WName = NameOfWave(whiskerTop)
		WCompleteName = GetWavesDataFolder(whiskerTop,2)
		Duplicate/O whiskerTop, $(WName+"EB")
		Wave whiskerTopEB = $(WName+"EB")
		SetFormula whiskerTopEB, WCompleteName+"-"+boxTopCompleteName
	
		GraphNote += "WHISKERTOPEBwave="+GetWavesDataFolder(whiskerTopEB,2)+";"
	else
		GraphNote += "WHISKERTOPEBwave=_NONE_;"
	endif
	
	if (WaveExists(whiskerBottom))
		// make a dependency formula for the error bar wave for the whisker bottoms
		WName = NameOfWave(whiskerBottom)
		WCompleteName = GetWavesDataFolder(whiskerBottom,2)
		Duplicate/O whiskerBottom, $(WName+"EB")
		Wave whiskerBottomEB = $(WName+"EB")
		SetFormula whiskerBottomEB, boxBottomCompleteName+"-"+WCompleteName
	
		GraphNote += "WHISKERBOTTOMEBwave="+GetWavesDataFolder(whiskerBottomEB,2)+";"
	else
		GraphNote += "WHISKERBOTTOMEBwave=_NONE_;"
	endif
	
	// now make the graph
	if (WaveExists(XWave))
//		AppendToGraph/W=$DisplayLocation/L=$AxNm median vs XWave		// changed in 1.3J
		AppendToGraph/W=$DisplayLocation/L=$AxNm median vs XWave
		AppendToGraph/W=$DisplayLocation/L=$AxNm boxTop vs XWave
		AppendToGraph/W=$DisplayLocation/L=$AxNm boxBottom vs XWave
		GraphNote += "Xwave="+GetWavesDatafolder(XWave,2)+";"
	else
		AppendToGraph/W=$DisplayLocation/L=$AxNm median, median, boxTop, boxBottom
		GraphNote += "Xwave=_NONE_;"
	endif

	GraphNote += "BOXTRACE="+medianName+"#1;"
	GraphNote += "MEDIANLINETRACE="+medianName+";"

	ModifyGraph/W=$DisplayLocation mode($NameofWave(boxTop)) = 2, mode($NameofWave(boxBottom)) = 2
//	ErrorBars/W=$DisplayLocation/L=0 $(medianName+"#1") BOX,const=(BoxWidth),wave=(boxTopEB,boxBottomEB)
//	ErrorBars/W=$DisplayLocation/T=0 $(medianName) X,const=(BoxWidth)		// change in 1.3J
	ErrorBars/W=$DisplayLocation/L=0 $(medianName) BOX,const=(BoxWidth),wave=(boxTopEB,boxBottomEB)
	ModifyGraph/W=$DisplayLocation mode($(medianName))=3, marker=9

	if (WaveExists(whiskerBottom))
		ErrorBars/W=$DisplayLocation/T=0 $(NameOfWave(boxBottom)) Y,wave=(,whiskerBottomEB)
		GraphNote += "WHISKERBOTTOMTRACE="+NameOfWave(boxBottom)+";"
	else
		GraphNote += "WHISKERBOTTOMTRACE=_NONE_;"
	endif

	if (WaveExists(whiskerTop))
		ErrorBars/W=$DisplayLocation/T=0 $(NameOfWave(boxTop)) Y,wave=(whiskerTopEB,)
		GraphNote += "WHISKERTOPTRACE="+NameOfWave(boxTop)+";"
	else
		GraphNote += "WHISKERTOPTRACE=_NONE_;"
	endif

	if ( WaveExists(XWave) %& (WaveType(XWave) == 0) )
		ModifyGraph/W=$DisplayLocation toMode=-1
	endif

	if (WaveExists(OUTY) && WaveExists(OUTX))
		if (WaveExists(XWave))
			OUTX = XWave[OUTX[p]]
		endif
		if (WaveType(XWave) == 0)
			AppendToGraph/W=$DisplayLocation/L=$AxNm/T OUTY vs OUTX
		else
			AppendToGraph/W=$DisplayLocation/L=$AxNm OUTY vs OUTX
		endif
		ModifyGraph/W=$DisplayLocation mode($NameOfWave(OUTY))=3,marker($NameOfWave(OUTY))=8
		if (WaveType(XWave) == 0)
			SetAxis/W=$DisplayLocation top -(BoxWidth+.5), numpnts(XWave)-.5	// I have a bad feeling about this...
			ModifyGraph/W=$DisplayLocation noLabel(top)=2,axThick(top)=0
		endif
		GraphNote += "OUTLIERwaveY="+GetWavesDataFolder(OUTY, 2)+";"
		GraphNote += "OUTLIERwaveX="+GetWavesDataFolder(OUTX, 2)+";"
		GraphNote += "OUTLIERTRACE="+NameOfWave(OUTY)+";"
	else
		GraphNote += "OUTLIERwaveY=_NONE_;"
		GraphNote += "OUTLIERwaveX=_NONE_;"
		GraphNote += "OUTLIERTRACE=_NONE_;"
	endif

	SetWindow $DisplayLocation, note=GraphNote
	DoUpdate
	BoxPlotColorBoxes(DisplayLocation)

End


// new in 1.44B
Function sq_butt_plotABcorrFact(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	sq_ABsanity()
	sq_plot_corr()

End


//1.44B
// creates two sets of waves, both in m/z space
// one set is the start/stop of integration regions, and must have maxmz points
// the other set is a variable length set of stick compliment regions that defines baselines regions
// when using these waves in stick calcs, they need to be translated into point (ns) space
//  Once things are defined by the settings in the baseline panel, these waves never change.
Function sq_stickCalcGetRegions(maxMz)
variable maxMz

	nvar resolution_R0 = root:diagnostics:resolution_R0 	
	nvar resolution_dm = root:diagnostics:resolution_dm 	
	nvar resolution_m0 = root:diagnostics:resolution_m0 	

	nvar/z bk_UseMassDefect = root:baselineFitting:bk_UseMassDefect		//1.34
	nvar/z bk_ck_AdditionalStickComp = root:baselineFitting:bk_ck_AdditionalStickComp
	nvar/z bk_StickRegionMaxAmu = root:baselineFitting:bk_StickRegionMaxAmu
//	these 3 parameters below are dealt with when we actually fit the baselines
//	nvar bk_BKIsX_Open = root:baselineFitting:bk_BKIsX_Open
//	nvar bk_BKIsX_Closed = root:baselineFitting:bk_BKIsX_Closed
//	nvar bk_BKIsZeroBeyondThisMass = root:baselineFitting:bk_BKIsZeroBeyondThisMass

	wave/z sr_massDefect = root:StickRecalc:sr_massDefect
	wave/z bk_RemoveFromStickCompStart = root:baselineFitting:bk_RemoveFromStickCompStart
	wave/z bk_RemoveFromStickCompStop = root:baselineFitting:bk_RemoveFromStickCompStop
	wave/z bk_RemoveFromStickCompNMLFlag = root:baselineFitting:bk_RemoveFromStickCompNMLFlag
	
	variable peakIntegrationDelta
	if (NVar_Exists(bk_StickRegionMaxAmu))
		peakIntegrationDelta = bk_StickRegionMaxAmu/2
	else
		peakIntegrationDelta=.4		//default
	endif

	variable idex, num, mzA, mzB, ptA, ptB
	
	NewDataFolder/o root:baselineFitting
	make/o/n=(maxMz) root:baselineFitting:StickRegion_startmz
	make/o/n=(maxMz) root:baselineFitting:StickRegion_stopmz
	make/o/n=(maxMz) root:baselineFitting:StickIntegration_centerMz_temp
	make/o/n=(maxMz) root:baselineFitting:resolutionValues_temp
	
	wave StickRegion_startmz = root:baselineFitting:StickRegion_startmz
	wave StickRegion_stopmz = root:baselineFitting:StickRegion_stopmz
	wave StickIntegration_centerMz_temp = root:baselineFitting:StickIntegration_centerMz_temp
	wave resolutionValues_temp = root:baselineFitting:resolutionValues_temp
	
	// First do StickIntegration_ waves
	// get resolution values based on integers, peak centers not mass defect, it is cleaner
	StickIntegration_centerMz_temp = p+1
	resolutionValues_temp = resolution_R0-(resolution_R0/(1+exp((StickIntegration_centerMz_temp[p]-resolution_m0)/resolution_dm)) )

	if (bk_UseMassDefect)
		if (!WaveExists(sr_massDefect) )
			abort "The user chose a mass defect wave, but it doesn't exist - aborting from sq_stickCalcGetRegions"
		endif
		StickIntegration_centerMz_temp=sr_massDefect
	endif

	make/free/n=(maxMz) FormulaResolution= (p+1)/(2*resolutionValues_temp[min(maxMz-1,StickIntegration_centerMz_temp[min(p,maxMz-1)])])
	
	StickRegion_startmz[]=StickIntegration_centerMz_temp-min(peakIntegrationDelta,FormulaResolution[p])	// 1.58G
	StickRegion_stopmz[]=StickIntegration_centerMz_temp+min(peakIntegrationDelta,FormulaResolution[p])		// 1.58G

	make/o/n=((maxMz+1)*100) root:baselineFitting:StickRegion_key = nan
	wave StickRegion_key = root:baselineFitting:StickRegion_key
	SetScale/P x 0,0.01,"", StickRegion_key

	for (idex = 0; idex<MaxMz; idex+=1)
		StickRegion_key[StickRegion_startMz[idex]*100, StickRegion_stopMz[idex]*100] = 1
	endfor

	// set default stickComplement waves - we do this differently than stick integration region because 
	// between two integer m/z we may not have any baseline region
	// we basically create key waves, and then create the mz start/stop waves after all is taken care of
	make/o/n=((maxMz+1)*100) root:baselineFitting:BaselineRegion_Key = 1
	wave BaselineRegion_Key = root:baselineFitting:BaselineRegion_Key
	SetScale/P x 0,0.01,"", BaselineRegion_Key

	for (idex = 0; idex<MaxMz; idex+=1)
		BaselineRegion_Key[StickRegion_startMz[idex]*100, StickRegion_stopMz[idex]*100] = nan
	endfor
	
	if (bk_ck_AdditionalStickComp)
		
		num = numpnts(bk_RemoveFromStickCompStart)
	
		// recall flags for bk_RemoveFromStickCompNMLFlag (wave name no longer exactly matches its usage 		//1.44B
		// 0:  Remove this region from stick complement
		// 1:  Remove this region from stick complement *and* stick integration
		// 2:  Add this region to the stick complement (and remove from stick integration)
		// 3:  Add this region to the stick integration (and remove from stick complement)
		for(idex=0;idex<num;idex+=1)
			mzA = ceil(bk_RemoveFromStickCompStart[idex])
			mzB = floor(bk_RemoveFromStickCompStop[idex]) 
			if (bk_RemoveFromStickCompStart[idex] < bk_RemoveFromStickCompStop[idex])		// one final sanity check
				switch (bk_RemoveFromStickCompNMLFlag[idex])
				case 0:
					BaselineRegion_Key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] = nan
					break				
				case 1:
					BaselineRegion_Key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] = nan
					StickRegion_key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] = nan
					break
				case 2:			
					// we need to do 2 things.  Reinsert stick complement points, change start stop points.
					BaselineRegion_Key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] =1
					StickRegion_key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] = nan
					break
				case 3:			// added in 1.44B at James's request, 3 means we are identifying a wider stick integration region
					BaselineRegion_Key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] = nan
					StickRegion_key[bk_RemoveFromStickCompStart[idex]*100, bk_RemoveFromStickCompStop[idex]*100] = 1
					break				
				endswitch
			else
	
			endif
		endfor
	
		make/o/n=((maxMz+1)*100) root:baselineFitting:Overlap_key_temp
		wave Overlap_key_temp = root:baselineFitting:Overlap_key_temp
	
		Overlap_key_temp = BaselineRegion_Key + StickRegion_key
		wavestats/q/m=1 Overlap_key_temp
		if (V_max>=1)
			abort "There seems to be a problem with the definition of the stick and baseline regions near "+num2str(V_maxLoc/100) + " aborting from sq_stickCalcGetRegions"
		endif

 	endif

	make/o/n=0 root:baselineFitting:BaselineRegion_startmz
	make/o/n=0 root:baselineFitting:BaselineRegion_stopmz
	
	bk_makeStartStop(BaselineRegion_Key, root:baselineFitting:BaselineRegion_startmz, root:baselineFitting:BaselineRegion_stopmz)
	bk_makeStartStop(StickRegion_key, StickRegion_startMz,StickRegion_stopMz)
	  	
	//  Do another sanity check //1.52E in case stick integration regions overlap.
	duplicate/o/free StickRegion_startMz umrMzDiff
	umrMzDiff[0,numpnts(umrMzDiff)-2] = StickRegion_startMz[p+1] - StickRegion_startMz[p]		//1.58G
	umrMzDiff[numpnts(umrMzDiff)-1]=1
	if (WaveMax(umrMzDiff)>1.5)
		wavestats/q/m=1 umrMzDiff
		abort "The stick integration region at unit mass "+num2str(round(StickRegion_startMz[V_maxLoc]))+" overlaps its neighbor.  Change the user-modified stick integration region.  Aborting from sq_stickCalcGetRegions"
	endif
	umrMzDiff[0,numpnts(umrMzDiff)-2] = StickRegion_stopMz[p+1] - StickRegion_stopMz[p]
	umrMzDiff[numpnts(umrMzDiff)-1]=1
	if (WaveMax(umrMzDiff)>1.5)
		wavestats/q/m=1 umrMzDiff
		abort "The stick integration region at unit mass "+num2str(round(StickRegion_stopMz[V_maxLoc]))+" overlaps its neighbor.  Change the user-modified stick integration region.  Aborting from sq_stickCalcGetRegions"
	endif

	killwaves/z StickIntegration_centerMz_temp, resolutionValues_temp, Overlap_key_temp
	
End 


// new in 1.44D
//  given a run number returns the ionization type
Function/s sq_getToFIonizationStr(runNum)
variable runNum
 
	wave run_series = root:index:rn_series
	wave tofType = root:diagnostics:tofType
	wave/z ionizationType = root:diagnostics:ionizationType
	
	variable currentRunIndex = sq_findRun(run_series,runNum)
	string returnStr
	
	returnStr = ""
	if(currentRunIndex<0)
		return returnStr
	endif
	
	switch(tofType[currentRunIndex])
		case 1: 
			returnStr = "v"
		break
		case 2: 
			returnStr = "w"
		break
		case 3: 
			returnStr = "c"
		break
	endswitch
	
	if (waveExists(ionizationType))	// "EI;sEI;VUV;Li;Neg;MAB;SP2"
		switch(ionizationType[currentRunIndex])
			case 0: 
				returnStr += " EI"
			break
			case 1: 
				returnStr += " sEI"
			break
			case 2: 
				returnStr += " VUV"
			break
			case 3: 
				returnStr += " Li"
			break
			case 4: 
				returnStr += " Neg"
			break
			case 5: 
				returnStr += " MAB"
			break
			case 6: 
				returnStr += " SP2"
			break
		endswitch
	endif
	
	return returnStr
	
End


// generic sanity check for when using MS AB correction factor
Function sq_ABsanity()

	wave/z corr_fact = root:diagnostics:corr_fact
	if (waveExists(corr_fact)==0 )
		abort "The airbeam correction wave does not exist.  Please generate from the corrections tab. - Aborting from  sq_ABsanity"
	elseif(numpnts(corr_fact)!=numpnts(root:index:rn_series) )
		Abort "The airbeam correction factor wave does not have the same number of points as t_series! Recalculate it! - Aborting from  sq_ABsanity"
		Wavestats/q/m=1 corr_fact		//1.59E
		if (V_numNans>0)
			DoAlert 1, "There are nans lurking in the AB correction factor wave, root:diagnostics:corr_fact.  This may result in results generating nans.  Continue?" 
			if (V_flag == 1)		// user pressed yes, so abort
				Abort "The user chose to abort" 
			endif
		endif		
	endif

End


// for MS avg or MS time series get userr-selected suffix
Function/s sq_getWaveNameSuffix()

	string waveNameSuffix = ""
	
	svar/z WaveNameSuiffixStr = root:panel:WaveNameSuiffixStr			//1.51N
	if (!svar_exists(WaveNameSuiffixStr))
		string/g root:panel:WaveNameSuiffixStr=""
		svar WaveNameSuiffixStr = root:panel:WaveNameSuiffixStr			//1.51N
	endif
	
	waveNameSuffix = WaveNameSuiffixStr
	Prompt waveNameSuffix, "Enter the suffix you would like to append to the species name"		// Set prompt for y param
	DoPrompt "Enter wave name suffix - if you cancel default names will be used", waveNameSuffix
	//1.51m  Pedro wants the option for waveNameSuffix to be blank
	if (V_Flag)	// user cancelled
		abort "The user chose to cancel the operation.  Aborting from sq_getWaveNameSuffix"		//1.59D
		// waveNameSuffix=	""						// User canceled
	else
		waveNameSuffix =CleanupName(waveNameSuffix,0)
	endif

	WaveNameSuiffixStr = waveNameSuffix
	return waveNameSuffix

End


// Function checks the existence of nans within the waves in the list
// for only the runs in the todo wave.
//  THIS CODE IDENTICAL TO sq_check_NansInWaveList in Pika panel ipf!

Function sq_AreNansInWaveList(todoWave, wavList)
wave todoWave
string wavList
	
	wave rn_series = root:index:rn_series
	variable idex, numWaves, numOrigNans
	string str, str1
 	
	numOrigNans = numpnts(rn_series) - numpnts(todoWave)
 	make/o/n=(numpnts(rn_series))  tempWave
 	sq_makeMaskFromTodofindRun(tempWave,todoWave)
  	
 	tempwave = selectnumber(tempwave[p] ==1, 0, 1)		// make 1s and 0s instead of 1s and nans
 	numwaves = itemsinList(wavList)
 	
 	for (idex = 0; idex < numWaves; idex+=1)
 		str = stringfromList(idex, wavList)
 		wave/z  wav = $(stringfromList(idex, wavList))
 		if (!Waveexists(wav))
 			print "// Wave "+str+" doesn't exist - didn't check for nans in function sq_check_NansInWaveList"
 			continue
 		endif
 		tempwave *=wav
 		wavestats/q/m=1 tempWave
 		if (V_numNans>numOrigNans)
 			tempwave = selectnumber(numtype(tempwave[p]) ==0, p, nan)
 			wavestats/q/m=1 tempWave
			killwaves/z tempwave
			sprintf str1, "%d" , rn_series[V_minLoc]		// small bug, things can go wrong with run numbers > 1e6
 			abort "There is a nan at run "+str1+ " in wave "+str + " - aborting from sq_check_NansInWaveList"
 		endif
 	endfor
 	killwaves/z tempWave
 	
End


// ****************************  fast mode functions  *************************** 
// ***************************************************************************************

// creates a series of folders
Function gen_createFolders(pathStr)
string pathStr

	string PartialPath
	variable idex, num
	
	pathStr = RemoveEnding(pathStr, ":")

	partialpath=StringFromList(0, pathStr, ":") 	
	if (!stringmatch(partialpath, "root") )
		pathStr = "root:"+pathStr
	endif

	num = ItemsInList(pathStr, ":")
	partialpath = "root"
	
	for(idex=1;idex<num;idex+=1)
		partialpath+=":"+StringFromList(idex, pathStr, ":") 	
		NewDataFolder/o $partialpath		// unfortunately, there is no /z flage
	endfor
	
End


Function sq_butt_FastMSPanel(ctrlName) : ButtonControl
	String ctrlName

 	fm_initialise_FMS()
 
End


Function fm_initialise_FMS()	// - Set up globals and panel

	sq_GetIndexNotDoneYet()

	wave/z allFast = root:allFast
	if ( !WaveExists(allFast)  )
		abort "It doesn't appear that you have fast mode data.  Aborting from fm_initialise_FMS"
	endif

	NewDataFolder/o root:panel:fastMS
	
	sq_initializeGlobalNVar("root:panel:FastMS:doMzcalOnAvgs",1)
	sq_initializeGlobalNVar("root:panel:fastMS:DoAv", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:DoExtrap", 0)
//	sq_initializeGlobalNVar("root:panel:fastMS:DoNans", 1)			// 1.50D 
	sq_initializeGlobalNVar("root:panel:fastMS:NumCycles", 0)
	sq_initializeGlobalNVar("root:panel:fastMS:BslDiagsDisplayCycle", 0)
	sq_initializeGlobalNVar("root:panel:fastMS:BslDiagsDisplayType", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:MSSDiagsDisplayCycle", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:MSSDiagsDisplayType", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:MSSDiagsCODType", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:MSSDiagsLockFast", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:MSSDiagsLockSlowFast", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:MSSDiagsScale2mz", 44)
	sq_initializeGlobalNVar("root:panel:fastMS:NumFMSAvs", 2)
	sq_initializeGlobalNVar("root:panel:fastMS:NumSMSAvs", 2)

	sq_initializeGlobalNVar("root:panel:fastMS:UseFastModeSettings", 0)		// initialize to not use to prevent users who may
	// have accidentally or curiously pressed the fast mode panel button.

	sq_initializeGlobalNVar("root:panel:fastMS:Blacklist1Transitions", 0) //1.58c

	sq_initializeGlobalSVar("root:panel:fastMS:FastModeInfo", "")
	svar FastModeInfo = root:panel:fastMS:FastModeInfo
	FastModeInfo = ""
	FastModeInfo+="The FastModePreprocessPanel is only useful for DAQ data taken\r"
	FastModeInfo+="in fast mode, which is generally uncommon.\r"
	FastModeInfo+="\r"
	FastModeInfo+="This code was developed by Mike Cubison at CU and modified by\r"
	FastModeInfo+="Donna Sueper in Squirrel version 1.50.\r"
	FastModeInfo+="\r"
	FastModeInfo+="For data taken using DAQ fast mode, this panel helps users with\r"
	FastModeInfo+="examining and eliminating runs in the open/closed transition\r"
	FastModeInfo+="periods and between fast mode cycles. Users need to check the\r" 
	FastModeInfo+="'Use these settings..' box for these options to work in partnership\r"
	FastModeInfo+="with the regular Squirrel pre-process code.\r"

	//1.53D
	sq_initializeGlobalSVar("root:panel:FastMS:InfoStr" , "Steps 1 - 3 need only be done once.\rThey are always done on the all todo wave.")

	sq_initializeGlobalNVar("root:panel:fastMS:doCopy", 0)
//	nvar DoNans=root:panel:fastMS:DoNans; DoNans=0
//	nvar DoCopy=root:panel:fastMS:DoCopy; DoCopy=1

	DoWindow/F FastModePreprocessPanel
	if (V_flag==0)
		FM_Analysis_panel()
	endif

End


// Generates the fast mode panel  // revamped in 1.55J
Function fm_analysis_panel() 

	sq_initializeGlobalNVar("root:panel:fastMS:doMzCalOnAvgs", 1)
	sq_initializeGlobalNVar("root:panel:fastMS:doReplaceAllAvg", 0)
	sq_initializeGlobalNVar("root:panel:fastMS:Blacklist1Transitions", 0) //1.58c


	PauseUpdate; Silent 1		// building window...
	NewPanel/N=FastModePreprocessPanel /W=(598,97,848,581) as "FastModePreprocessPanel"
	ModifyPanel fixedSize=1  //1.57L

	SetDrawLayer UserBack
	SetDrawEnv fsize= 16,fstyle= 1
	DrawText 5,20,"Fast Mode Panel 1.5"
	SetDrawEnv fsize= 11
	DrawText 1,223,"4. Choose pre-processing option (Unchecked ="
	SetDrawEnv fsize= 11
	DrawText 11,236,"use DAQ closed sticks for fast open runs)"
	Button button_fastHelp,pos={182,2},size={50,20},proc=fm_butt_help,title="Help"


	Button butt_FMS_DoUsual,pos={4,24},size={230,35},proc=fm_butt_DoUsual,title="For all runs find fast mode cycles, make todos,\rblacklist first open and closed.  \"The Usual\""
	Button butt_FMS_DoUsual,fColor=(65280,43520,0), fsize=10
//	CheckBox check_USEinPreProcess,pos={4,94},size={214,14},title="Use usual settings in the pre-process step"
//	CheckBox check_USEinPreProcess,variable= root:panel:fastMS:UseFastModeSettings
	Button butt_FMS_MakeToDos,pos={5,146},size={180,20},proc=fm_butt_makeFirstFastToDos,title="2. Make ToDos of Fast Transitions", fsize=10
	Button butt_FMS_Blacklist,pos={5,184},size={135,20},proc=fm_butt_DoBlacklist,title="3. Blacklisting/Quarantine", fsize=10
	Button butt_FMS_MakeCycleWaves,pos={5,89},size={120,20},proc=fm_butt_DefineCycles,title="1. Find Fast MS Cycles", fsize=10
	Button butt_FMS_BslDiags,pos={139,184},size={105,20},proc=fm_butt_BaselineDiags,title="Opt. Baseline Diags", fsize=10
	SetVariable setvar_FMS_NumCycles,pos={130,89},size={97,16},bodyWidth=28,title="# FMS cycles"
	SetVariable setvar_FMS_NumCycles,limits={0,inf,0},value= root:panel:fastMS:NumCycles, fsize=10
	CheckBox check_USE,pos={3,241},size={210,14},title="Use these setting in the pre-process step"
	CheckBox check_USE,variable= root:panel:fastMS:UseFastModeSettings
	CheckBox check_FMSDoAv,pos={15,279},size={145,14},title="Average fast closed cycles"
	CheckBox check_FMSDoAv,variable= root:panel:fastMS:DoAv
	CheckBox check_FMSDoExtrap,pos={15,378},size={172,39},title="Extrapolate Slow/Fast transitions\r(if ending of fast cycle was in fast\ropen not closed, use slow MS)"
	CheckBox check_FMSDoExtrap,variable= root:panel:fastMS:DoExtrap
	CheckBox check_FmInterpolate,pos={15,441},size={203,14},proc=fms_interpolateOrCopy_CheckProc,title="Interpolate fast closed across fast open"
	CheckBox check_FmInterpolate,value= 0,mode=1
//	CheckBox check_FMSZeros,variable= root:panel:fastMS:DoNans,mode=1
	CheckBox check_FmCopy,pos={15,460},size={162,14},proc=fms_interpolateOrCopy_CheckProc,title="Copy last fast across fast open"
	CheckBox check_FmCopy,variable= root:panel:fastMS:doCopy,mode=1
	Button butt_FMS_SeriesTable,pos={5,110},size={60,35},proc=fm_butt_FastKeySeriesTable,title="Fast Series\rTable", fsize=10
	Button butt_FMS_FClosedTable,pos={154,110},size={80,35},proc=fm_butt_FastClosedTable,title="Fast Closed\rRegions Table", fsize=10
	Button butt_FMS_StartEndTable,pos={70,110},size={80,35},proc=fm_butt_FastStartEndTable,title="Start/End Fast\rCycle Table", fsize=10
//	CheckBox check_showHideFMdetails,pos={4,112},size={105,14},proc=fm_showHideDetailsCheckProc,title="Show/Hide details"
//	CheckBox check_showHideFMdetails,value= 1
	CheckBox check_FMSdomzCal,pos={15,341},size={217,26},title="Do mz cal on avg fast closed and then\rinterpolate mz params across all fast runs"
	CheckBox check_FMSdomzCal,variable= root:panel:fastMS:doMzCalOnAvgs
	TitleBox title0,pos={7,60},size={206,26},frame=0
	TitleBox title0,variable= root:panel:fastMS:InfoStr
	GroupBox group0,pos={6,424},size={239,56},title="How to calculate closed in fast open runs"
	GroupBox group1,pos={8,261},size={238,162},title="How to modify fast closed in fast closed runs"
//	CheckBox check_FMSReplaceLastAvg,pos={29,354},size={195,14},proc=fms_AllorLast_CheckProc,title="Replace last fast closed with average"
//	CheckBox check_FMSReplaceLastAvg,value= 1,mode=1
//	CheckBox check_FMSReplaceAllAvg,pos={29,333},size={189,14},title="Replace all fast closed with average"   // proc=fms_AllorLast_CheckProc,
//	CheckBox check_FMSReplaceAllAvg,variable= root:panel:fastMS:doReplaceAllAvg,mode=1
	CheckBox check_blacklistFastTransistions,pos={18.00,170.00},size={227.00,13.00},title="Automatically blacklist first runs in fast transitions"
	CheckBox check_blacklistFastTransistions,fSize=10
	CheckBox check_blacklistFastTransistions,variable= root:panel:fastMS:Blacklist1Transitions

	nvar doCopy = root:panel:fastMS:doCopy
	CheckBox check_FmInterpolate,value= !doCopy
	CheckBox check_FmCopy,variable= root:panel:fastMS:doCopy

	string/g root:panel:fastModeHelp = "To view the non-averaged closed values\rone can repreprocess without the fast mode\rsettings checked on todo of fast closed runs"
	TitleBox fastmodeAvgHelp pos={35,295}, variable=root:panel:fastModeHelp,frame=0, fsize=10		//1.16M

End


// 1.51N
// New checkbox function to show or hide details of fast mode analysis


// ******** DIAGS ONLY
// this bit of code is simply retained from Mike's ipf.  It is used for the case of
// when one wants to "start fresh"
// None of this code is accessible via the FastMode panel.
// squirrel_fetch(preproc,fm_mjc,"Dest:FMSb4;","MSSClosed")

Function fm_mjc(index_pos,paramstr,acorn,n_acorns)	
    wave index_pos
    string paramstr												
    variable acorn,n_acorns
    
    wave MSSClosed=$stringbykey("acorn_0",paramstr)
    Duplicate/o MSSClosed, $"root:"+stringbykey("Dest",paramstr)
 
End


Function fm_mjc_revert(index_pos,paramstr,acorn,n_acorns)	
    wave index_pos
    string paramstr												
    variable acorn,n_acorns
    
    wave MSSClosed=$stringbykey("acorn_0",paramstr)
    Wave Orig = root:sq_replaceClosed_origMSSClosed
    
	//1.14M  UMR
    squirrel_hdf_write(index_pos,orig,"MSSClosed_p")
    
End

// ************** END DIAGS ONLY


// *********** FAST-MS functions  ***************

// Pops up a simple panel with warnings and explanations.
Function fm_butt_help(ctrlName) : ButtonControl	
	String ctrlName
	
	NewPanel/N=FastModePanelHelp /W=(567,175,913,398) as "FastModePanelHelp"
	ShowTools/A
	TitleBox title0,pos={3,5},size={326,208},frame=0
	TitleBox title0,variable= root:panel:fastMS:FastModeInfo

End


// Button on main Fast mode panel.  Does calcs and brings to front fast mode baseline panel.
Function fm_butt_BaselineDiags(ctrlName) : ButtonControl	// MJC 3/9/2009 - for looking at potential influences on baseline during slow->fast transitions
	String ctrlName
	
	// function will run the SQ baseline fitting function for all the transitions to and from FMS mode.
	
	NVAR NumCycles = root:panel:fastMS:NumCycles // knowing the number of FMS cycles is a pre-req
	if (NumCycles==0)
		abort "There are no FMS cycles to process"
	elseif( NumCycles > 30)		// 30 is arbitrary
		abort "It is not recommended that you perform this action - there are too many fast mode cycles and many raw spectra waves are generated! - aborting from fm_butt_BaselineDiags"
	endif
		
	if (!wintype("sq_baseline_panel"))	// SQ baseline panel is a pre-req of this function
		sq_butt_CheckBk("")
	endif
	
	Variable n, k, Run, num, numFastOpen, numFastClosed, typeTemp
	
	// Define ToDo waves:
	Wave allFast = root:allFast
	Wave allFastClosed = root:allFastClosed
	Wave allFastOpen = root:allFastOpen
	Wave all = root:all
//	Wave rn_series = root:index:rn_series
	NVAR bk_run = root:baselineFitting:bk_currentRunNum
	
		// Define Cycle waves:
	Wave FMS_StartRuns = root:index:FMS_StartRuns		// when does FMS cycle start?
	Wave FMS_EndRuns = root:index:FMS_EndRuns		// 						end?
	Wave FMS_StartTypes = root:index:FMS_StartTypes		// starting run is open (1) or closed (0) ?
	Wave FMS_EndTypes = root:index:FMS_EndTypes		// ending
	Wave FMS_Before = root:index:FMS_SlowRunBefore
	Wave FMS_After = root:index:FMS_SlowRunAfter
		
	// Destination folder... keep tidy by using Squirrel quantifChecks folder
	String path = "root:quantifChecks:FMS_Baseline:"	// with colon on end

	String FirstType, SecondType
	
	// Waves to use in this analysis:
	String DestList = "OneRunRawSpectraMz;"
	DestList += "OneRunRawSpectraOpen;OneRunRawSpectraOpenBk;OneRunRawSpectraOpenBkFit;"
	DestList += "OneRunRawSpectraClosed;OneRunRawSpectraClosedBk;OneRunRawSpectraClosedBkFit;"
	DestList += "BaselineRegion_Key;StickRegion_key;"	// up to here are all the waves required to plot the baseline graph; the key waves get updated
													// when the button is pressed
	String OpenList = "OneRunRawSpectraMz;"
	OpenList += "OneRunRawSpectraOpen;OneRunRawSpectraOpenBk;OneRunRawSpectraOpenBkFit;"
	OpenList += "BaselineRegion_Key;StickRegion_key;"	
	String ClosedList = "OneRunRawSpectraMz;"
	ClosedList += "OneRunRawSpectraClosed;OneRunRawSpectraClosedBk;OneRunRawSpectraClosedBkFit;"
	ClosedList += "BaselineRegion_Key;StickRegion_key;"	

	//Step 2: Create mirrors of squirrel baseline waves for each entry in the SlowBefore and SlowAfter waves
	// Graph will be updated used the "allincdf" command, so generate a separate folder for each FMS cycle, then within that, put
	//	- SlowBefore, SlowAfter, FirstFMS, LastFMS
	
	String DestPath = path	// "root:quantifChecks:FMS_Baseline:"
	NewDataFolder/o root:quantifChecks
	NewDataFolder/o root:quantifChecks:FMS_Baseline
	
	numFastOpen = numpnts(allFastOpen)
	numFastClosed = numpnts(allFastClosed)
	
	make/o/n=0 dummyWave 	// a placeholder so that the FastModeBaselineGr will work for all cases of fast/slow, etc
	
	for (n=0;n<NumCycles;n+=1)
		DestPath = path+"Cycle"+num2str(n)+":"	// 0-based
		NewDataFolder/o $RemoveEnding(DestPath,":")
		NewDataFolder/o $DestPath+"SlowBefore"		
		NewDataFolder/o $DestPath+"SlowAfter"
		NewDataFolder/o $DestPath+"FirstFMS"
		NewDataFolder/o $DestPath+"FirstFMS:Open"
		NewDataFolder/o $DestPath+"FirstFMS:Closed"
		NewDataFolder/o $DestPath+"LastFMS"
		NewDataFolder/o $DestPath+"LastFMS:Open"				
		NewDataFolder/o $DestPath+"LastFMS:Closed"
		
		DoUPdate
		// SlowBefore
		if (FMS_Before[n]>=0)		// ie not nan, is a real run
			bk_Run = FMS_Before[n]			// set run # in baseline panel
			bk_butt_RawSpectraThisRun("")	// press Donna's baseline panel buttons.. assume all other parameters as set as the user wishes a priori
			bk_butt_CalcbkFit("")
			for (k=0;k<ItemsInList(DestList);k+=1)	// go through and copy all the waves over: raw open, closed, diff, etc
				Wave/z Source = $"root:BaselineFitting:"+StringFromList(k,DestList)
				if (WaveExists(Source)) //? should always exist
					Duplicate/o Source, $DestPath+"SlowBefore:"+nameofwave(Source)
				else
					print "// Could not find root:BaselineFitting:"+StringFromList(k,DestList)	
				endif
			endfor
		else // there is no slow before
			for (k=0;k<ItemsInList(DestList);k+=1)	// go through and copy all the waves over: raw open, closed, diff, etc
				Wave/z Source = $"root:BaselineFitting:"+StringFromList(k,DestList)
				Duplicate/o dummyWave, $DestPath+"SlowBefore:"+nameofwave(Source)
			endfor		
		endif

		// SlowAfter
		if (FMS_After[n]>=0)  // ie not nan
			bk_Run = FMS_After[n]			// set run # in baseline panel
			bk_butt_RawSpectraThisRun("")	// press Donna's baseline panel buttons.. assume all other parameters as set as the user wishes a priori
			bk_butt_CalcbkFit("")
			for (k=0;k<ItemsInList(DestList);k+=1)	// go through and copy all the waves over: raw open, closed, diff, etc
				Wave/z Source = $"root:BaselineFitting:"+StringFromList(k,DestList)
				if (WaveExists(Source))	//? should always exist
					Duplicate/o Source, $DestPath+"SlowAfter:"+nameofwave(Source)
				else
					print "// Could not find root:BaselineFitting:"+StringFromList(k,DestList)	
				endif
			endfor
		else  // there is no slow after
			for (k=0;k<ItemsInList(DestList);k+=1)	// go through and copy all the waves over: raw open, closed, diff, etc
				Wave/z Source = $"root:BaselineFitting:"+StringFromList(k,DestList)
				Duplicate/o dummyWave, $DestPath+"SlowAfter:"+nameofwave(Source)
			endfor		
		endif		
	
		// First FMS - need to find open and closed...
		typeTemp = FMS_StartTypes[n]
		if (typeTemp==0)	// first run is open
			FirstType = "Open"
			SecondType = "Closed"
		else
			FirstType = "Closed"
			SecondType = "Open"
		endif
		bk_Run = FMS_StartRuns[n]			// set run # in baseline panel
		bk_butt_RawSpectraThisRun("")	// press Donna's baseline panel buttons.. assume all other parameters as set as the user wishes a priori
		bk_butt_CalcbkFit("")		
		// transfer the waves from first FMS run: either the first run in fast is open or closed
		for (k=0;k<ItemsInList(OpenList);k+=1)	// go through and copy all the waves over - 
			Wave/z Source = $"root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),FirstType)
			if (WaveExists(Source)) //? should always exist
				Duplicate/o Source, $DestPath+"FirstFMS:"+FirstType+":"+ReplaceString("run",nameofwave(source),"FMSRun")
			else
				print "//Could not find root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),FirstType)
			endif
		endfor
					
		// look for first FMS run of type not equivalent to first run
		wave allFastX=$"allFast"+SecondType		// the opposite of open/closed that the first fast run is on.
		num = numpnts(allFastX)
		k=0
		do
			FindValue/I=(bk_Run+k) allFastX
			k+=1
		while (V_value<0 && k<num)
		// transfer
		bk_Run += (k-1)			// set run # in baseline panel
		bk_butt_RawSpectraThisRun("")	// press Donna's baseline panel buttons.. assume all other parameters as set as the user wishes a priori
		bk_butt_CalcbkFit("")
		for (k=0;k<ItemsInList(OpenList);k+=1)	// go through and copy all the waves over - 
			Wave/z Source = $"root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),SecondType)
			if (WaveExists(Source))   //? should always exist
				Duplicate/o Source, $DestPath+"FirstFMS:"+SecondType+":"+ReplaceString("run",nameofwave(source),"FMSRun")	
			else
				print "//Could not find root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),SecondType)
			endif
		endfor		

	// Last FMS - need to find open and closed...
		bk_Run = FMS_EndRuns[n]			// set run # in baseline panel
		bk_butt_RawSpectraThisRun("")	// press Donna's baseline panel buttons.. assume all other parameters as set as the user wishes a priori
		bk_butt_CalcbkFit("")
		typeTemp = FMS_EndTypes[n]
		if (typeTemp==0)	// final run is open
			FirstType = "Open"
			SecondType = "Closed"
		else
			FirstType = "Closed"
			SecondType = "Open"
		endif
		// transfer the waves from last FMS run
		for (k=0;k<ItemsInList(OpenList);k+=1)	// go through and copy all the waves over - 
			Wave/z Source = $"root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),FirstType)
			if (WaveExists(Source))   //? should always exist
				Duplicate/o Source, $DestPath+"LastFMS:"+FirstType+":"+ReplaceString("run",nameofwave(source),"FMSRun")
			else
				print "// Could not find root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),FirstType)
			endif
		endfor			
		// look for first FMS run of type not equivalent to first run
		wave allFastX=$"allFast"+SecondType		// the opposite of open/closed that the first fast run is on.
		num = numpnts(allFastX)
		k=0
		do
			FindValue/I=(bk_Run-k) allFastX	// and v.v.
			k+=1
		while (V_value<0 && k<num)
		// transfer
		bk_Run -= (k-1)			// set run # in baseline panel
		bk_butt_RawSpectraThisRun("")	// press Donna's baseline panel buttons.. assume all other parameters as set as the user wishes a priori
		bk_butt_CalcbkFit("")
		for (k=0;k<ItemsInList(OpenList);k+=1)	// go through and copy all the waves over - 
			Wave/z Source = $"root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),SecondType)
			if (WaveExists(Source))
				Duplicate/o Source, $DestPath+"LastFMS:"+SecondType+":"+ReplaceString("run",nameofwave(source),"FMSRun")	
			else
				print "// Could not find root:BaselineFitting:"+ReplaceString("Open",StringFromList(k,OpenList),SecondType)
			endif
		endfor	
			
	endfor

	DoWindow/F FastModeBaselineGr
	if (V_flag==0)
		fm_baselineDiagsGraph() 		// Donna added.
	endif
	
End


// creates FastModeBaselineGraph
Function fm_baselineDiagsGraph() 
	PauseUpdate; Silent 1		// building window...
	Display/N=FastModeBaselineGr /W=(100,60,700,440) as "FastModeBaselineGr"
	ShowTools/A
	ControlBar 30
	PopupMenu popup_BslDiags,pos={2,2},size={173,23},proc=fm_BslPopMenuProc,title="Display:"
	PopupMenu popup_BslDiags,mode=1,popvalue="Beginning of cycle",value= #"\"Beginning of cycle;End of cycle\""
	SetVariable setvar_BslDiags,pos={183,5},size={104,18},proc=fm_BslSetVarProc,title="FMS Cycle:"
	SetVariable setvar_BslDiags,value= root:panel:fastMS:BslDiagsDisplayCycle,bodyWidth= 40
	// always start with cycle 0 to make things easier
	nvar  BslDiagsDisplayCycle = root:panel:fastMS:BslDiagsDisplayCycle
	BslDiagsDisplayCycle=0
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:quantifChecks:FMS_Baseline:Cycle0:SlowBefore:
	wave StickRegion_key,BaselineRegion_Key
	wave OneRunRawSpectraOpen, OneRunRawSpectraOpenBk,OneRunRawSpectraOpenBkFit
	wave OneRunRawSpectraClosed,OneRunRawSpectraClosedBk,OneRunRawSpectraClosedBkFit,OneRunRawSpectraMz
	
	AppendToGraph/L=LClosed StickRegion_key,BaselineRegion_Key
	AppendToGraph/L=LOpen StickRegion_key,BaselineRegion_Key
	AppendToGraph/L=LOpen OneRunRawSpectraOpen vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed OneRunRawSpectraClosed vs OneRunRawSpectraMz
	AppendToGraph/L=LOpen OneRunRawSpectraOpenBk vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed OneRunRawSpectraClosedBk vs OneRunRawSpectraMz
	AppendToGraph/L=LOpen OneRunRawSpectraOpenBkFit vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed OneRunRawSpectraClosedBkFit vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed ::FirstFMS:Closed:OneFMSRunRawSpectraClosed vs ::FirstFMS:Closed:OneFMSRunRawSpectraMz
	AppendToGraph/L=LClosed ::FirstFMS:Closed:OneFMSRunRawSpectraClosedBk vs ::FirstFMS:Closed:OneFMSRunRawSpectraMz
	AppendToGraph/L=LClosed ::FirstFMS:Closed:OneFMSRunRawSpectraClosedBkFit vs ::FirstFMS:Closed:OneFMSRunRawSpectraMz
	AppendToGraph/L=LOpen ::FirstFMS:Open:OneFMSRunRawSpectraOpen vs ::FirstFMS:Open:OneFMSRunRawSpectraMz
	AppendToGraph/L=LOpen ::FirstFMS:Open:OneFMSRunRawSpectraOpenBk vs ::FirstFMS:Open:OneFMSRunRawSpectraMz
	AppendToGraph/L=LOpen ::FirstFMS:Open:OneFMSRunRawSpectraOpenBkFit vs ::FirstFMS:Open:OneFMSRunRawSpectraMz
	SetDataFolder fldrSav0
	ModifyGraph margin(left)=58,margin(bottom)=49,margin(top)=14,margin(right)=14
	ModifyGraph mode(StickRegion_key)=7,mode(BaselineRegion_Key)=7,mode(StickRegion_key#1)=7
	ModifyGraph mode(BaselineRegion_Key#1)=7,mode(OneRunRawSpectraOpenBk)=4,mode(OneRunRawSpectraClosedBk)=4
	ModifyGraph marker(OneRunRawSpectraOpenBk)=19,marker(OneRunRawSpectraClosedBk)=19
	ModifyGraph lSize(OneRunRawSpectraOpenBkFit)=2,lSize(OneRunRawSpectraClosedBkFit)=2
	ModifyGraph lSize(OneFMSRunRawSpectraClosedBk)=2,lSize(OneFMSRunRawSpectraClosedBkFit)=1.5
	ModifyGraph lSize(OneFMSRunRawSpectraOpenBk)=2,lSize(OneFMSRunRawSpectraOpenBkFit)=1.5
	ModifyGraph rgb(StickRegion_key)=(65280,57600,57600),rgb(BaselineRegion_Key)=(43520,43520,43520)
	ModifyGraph rgb(StickRegion_key#1)=(65280,48896,62208),rgb(BaselineRegion_Key#1)=(43520,43520,43520)
	ModifyGraph rgb(OneRunRawSpectraOpen)=(32768,40704,65280),rgb(OneRunRawSpectraClosed)=(32768,40704,65280)
	ModifyGraph rgb(OneRunRawSpectraOpenBk)=(0,0,0),rgb(OneRunRawSpectraClosedBk)=(0,0,0)
	ModifyGraph rgb(OneRunRawSpectraOpenBkFit)=(65280,0,0),rgb(OneRunRawSpectraClosedBkFit)=(65280,0,0)
	ModifyGraph rgb(OneFMSRunRawSpectraClosed)=(0,0,0),rgb(OneFMSRunRawSpectraClosedBk)=(39168,39168,39168)
	ModifyGraph rgb(OneFMSRunRawSpectraClosedBkFit)=(65280,43520,0),rgb(OneFMSRunRawSpectraOpen)=(0,0,0)
	ModifyGraph rgb(OneFMSRunRawSpectraOpenBk)=(39168,39168,39168),rgb(OneFMSRunRawSpectraOpenBkFit)=(65280,43520,0)
	ModifyGraph msize(OneRunRawSpectraOpenBk)=2,msize(OneRunRawSpectraClosedBk)=2
	ModifyGraph hbFill(StickRegion_key)=4,hbFill(BaselineRegion_Key)=4,hbFill(StickRegion_key#1)=4
	ModifyGraph hbFill(BaselineRegion_Key#1)=4
	ModifyGraph grid=2
	ModifyGraph zero(LOpen)=1,zero(LClosed)=1
	ModifyGraph mirror(LOpen)=2,mirror(LClosed)=2
	ModifyGraph nticks(bottom)=10
	ModifyGraph fSize(bottom)=16
	ModifyGraph fStyle(bottom)=1
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph lblPos(LOpen)=50,lblPos(LClosed)=50
	ModifyGraph lblLatPos(LOpen)=-8,lblLatPos(LClosed)=-8
	ModifyGraph freePos(LOpen)=1
	ModifyGraph freePos(LClosed)=1
	ModifyGraph axisEnab(LOpen)={0.51,1}
	ModifyGraph axisEnab(LClosed)={0,0.49}
	ModifyGraph manTick(bottom)={0,1,0,0},manMinor(bottom)={0,50}
	Label LOpen "Open"
	Label bottom "m/z"
	Label LClosed "Closed"
	SetAxis LOpen 1e-06,0.01
	SetAxis bottom 15,45
	SetAxis LClosed 1e-06,0.01
	Legend/C/N=text0/J/X=0.93/Y=2.23 "\\s(OneRunRawSpectraOpen) Slow mode raw spectrum\r\\s(OneRunRawSpectraOpenBk) Slow mode backgnd"
	AppendText "\\s(OneRunRawSpectraClosedBkFit) Slow mode backgnd fit\r\\s(OneFMSRunRawSpectraClosed) FMS raw spectrum"
	AppendText "\\s(OneFMSRunRawSpectraClosedBk) FMS background\r\\s(OneFMSRunRawSpectraClosedBkFit) FMS background fit"
End


// function on fast mode baseline panel... Not working?
Function fm_BslPopMenuProc(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum	// 1 = beginning, 2 = end
	String popStr

	nvar BslDiagsDisplayType = root:panel:fastMS:BslDiagsDisplayType
	nvar BslDiagsDisplayCycle = root:panel:fastMS:BslDiagsDisplayCycle
	
	String path = "root:quantifChecks:FMS_Baseline:Cycle"
	String savedDF = GetDataFolder(1)
	String FMSSubFolder
	String SlowSubFolder

	BslDiagsDisplayType = popNum

	if (BslDiagsDisplayType==1)	// display beginning
		FMSSubFolder = "FirstFMS"
		SlowSubFolder = "SlowBefore"
	else
		FMSSubFolder = "LastFMS"
		SlowSubFolder = "SlowAfter"	
	endif
	
//	print BslDiagsDisplayType, BslDiagsDisplayCycle, popNum, FMSSubFolder, SlowSubFolder
	
SetDataFolder path+num2str(BslDiagsDisplayCycle)+":"+FMSSubFolder+":Closed"
//	print path+num2str(BslDiagsDisplayCycle)+":"+FMSSubFolder+":Closed", GetDataFolder(1)
	ReplaceWave/W=FastModeBaselineGr allincdf
	DoUPdate
	
	SetDataFolder path+num2str(BslDiagsDisplayCycle)+":"+FMSSubFolder+":Open"
//	print path+num2str(BslDiagsDisplayCycle)+":"+FMSSubFolder+":Open", GetDataFolder(1)
	ReplaceWave/W=FastModeBaselineGr allincdf
	DoUPdate
	
	SetDataFolder path+num2str(BslDiagsDisplayCycle)+":"+SlowSubFolder
//	print  path+num2str(BslDiagsDisplayCycle)+":"+SlowSubFolder, GetDataFolder(1)
	ReplaceWave/W=FastModeBaselineGr allincdf
	DoUPdate

	SetDataFolder savedDF
End


// function on fast mode baseline panel...  fixed in 1.50F used only for FMS Cycle set variable
Function fm_BslSetVarProc(ctrlName,varNum,varStr,varName) : SetVariableControl		// name change 3/19/09
	String ctrlName
	Variable varNum
	String varStr
	String varName

	NVAR BslDiagsDisplayType = root:panel:fastMS:BslDiagsDisplayType
	nvar NumCycles = root:panel:fastMS:NumCycles
	
	if (varNum>=NumCycles || varnum<0)		// we count from 0
		abort "Out of range of fast mode cycles in this data set.  Aborting from fm_BslSetVarProc"
	endif

	fm_BslPopMenuProc("",BslDiagsDisplayType,"")

End


//Button on Past mode panel.  Does LOTS of calcs on raw and stick spectra for fast mode cycles.
Function fm_butt_MSSDiags(ctrlName) : ButtonControl	// MJC 3/9/2009 - for looking at potential influences on spectra during slow->fast transitions
	String ctrlName
	
	NVAR NumCycles = root:panel:fastMS:NumCycles // knowing the number of FMS cycles is a pre-req
	if (NumCycles==0)
		abort "There are no FMS cycles to process"
	endif

		// Declare squirrel panel globals	
	SVAR todo_makefromruns_sv = root:panel:todo_makefromruns_sv
	SVAR todo_makefromname_sv = root:panel:todo_makefromname_sv
	SVAR sq_toDoWvNm = root:panel:sq_toDoWvNm
	SVAR ms0_sv_speclist = root:panel:ms0_sv_speclist
	NVAR ms0_graphOutputType = root:panel:ms0_graphOutputType
	NVAR ms0_dataType = root:panel:ms0_dataType
	NVAR ms0_ion2mass = root:panel:ms0_ion2mass		// 1.48D fix was ms0_ck_convert2ug
//	NVAR plot = root:panel:ms0_ck_plotnew
	NVAR ms0_ck_trunc2zero = root:panel:ms0_ck_trunc2zero
	NVAR ms0_ck_findavgbaseline = root:panel:ms0_ck_findavgbaseline
	NVAR ms0_appendErrorBars = root:panel:ms0_appendErrorBars
	NVAR ms0_corr = root:panel:ms0_corr
	NVAR ms0_AvGraphType = root:panel:ms0_AvGraphType

		// Declare FMS panel globals
	NVAR NumFMSAvs = root:panel:fastMS:NumFMSAvs	
	NVAR NumSMSAvs = root:panel:fastMS:NumSMSAvs	
		
		// Declare ToDo waves:
	Wave allFast = root:allFast
	Wave allFastClosed = root:allFastClosed
	Wave allFastOpen = root:allFastOpen
	Wave all = root:all
	Wave rn_series = root:index:rn_series
	Wave/z allSlow = root:allSlow
	if (!WaveExists(allSlow))
		sq_create_todo( "all and not allFast","allSlow")
	endif
	
		// Declare FMS cycle waves:
	Wave FMS_StartRuns = root:index:FMS_StartRuns		// when does FMS cycle start?
	Wave FMS_EndRuns = root:index:FMS_EndRuns		// 						end?
	Wave FMS_StartTypes = root:index:FMS_StartTypes		// starting run is open (1) or closed (0) ?
	Wave FMS_EndTypes = root:index:FMS_EndTypes		// ending
	
		// Local variables
	Variable n, k, Run, Pnt
	String ExtendRunIntervalWave, destpath, DiffSlowPath, DiffFastPath, path, DestList
	Variable ly1, ly2, ly3, ly4
	String Layer2Type, Layer3Type, Layer4Type
	String Layer2Folders, Layer2RunSlowWaves, Layer3Folders, Layer4Folders, Layer4Abbr
	
	string str1, str2
	
	path = "root:quantifChecks:FMS_MSS:"	// with colon on end
	
	ms0_appendErrorBars = 0		// turn off error generation
	ms0_AvGraphType = 2
	
	if (ms0_corr)
		sq_ABsanity()
	endif
	
	gen_createFolders(path)
		
	// Waves to use in this analysis: use SQ default
	sq_butt_MSAveSpeciesDefault("")
	
	DestList = ReplaceString(",", ms0_sv_speclist, ";")
	//String/G $path+"SpecList" = DestList	// Save the spec list in a global string in the FMS_MSS folder
	sq_initializeGlobalSVar(path+"SpecList", DestList)			//

	// Step 1: Create waves that define if slow mode data before and/or after each FMS cycle.
	// Go through the "all" wave and find run number each side. Put "-1" if nothing
	// *** THIS IS A DIRECT CUT-and-PASTE FROM THE BASELINE FUNCTION
	Make/o/n=(NumCycles) root:index:FMS_SlowRunBefore, root:index:FMS_SlowRunAfter = NaN
	Wave FMS_Before = root:index:FMS_SlowRunBefore
	Wave FMS_After = root:index:FMS_SlowRunAfter
	
	// Fill in RunBefore:
	for (n=0;n<NumCycles;n+=1)
		FindValue/I=(FMS_StartRuns[n]) all	// Find point in all wave where the FMS cycles run starts
		if (V_Value)	// if FMS cycle doesn't start on first run
			for (k=V_Value-1;k>0;k-=1)	// work backwards from run before first one in FMS cycle
				Run = all[k]
				FindValue/I=(Run) allFast	// is this run a fast mode run?
				if (V_Value==-1)
					FMS_Before[n] = Run	// if not, put in slow-mode wave
					break
				else
					Print "// This shouldn't happen, right?"
				endif
			endfor
		else		// FMS cycle starts on first run. Cannot have slow mode beforehand, so put "-1"
			FMS_Before[n] = -1
		endif
	endfor

	// Fill in RunAfter:
	for (n=0;n<NumCycles;n+=1)
		FindValue/I=(FMS_EndRuns[n]) all	// Find point in all wave where the FMS cycles run starts
		if (V_Value<(numpnts(all)-1))	// if FMS cycle doesn't end on last run
			for (k=V_Value+1;k<numpnts(all);k+=1)	// work forwards from run after last one in FMS cycle
				Run = all[k]
				FindValue/I=(Run) allFast	// is this run a fast mode run?
				if (V_Value==-1)
					FMS_After[n] = Run	// if not, put in slow-mode wave
					break
				else
					Print "// This shouldn't happen, right?"
				endif
			endfor
		else		// FMS cycle ends on final run. Cannot have slow mode after this, so put "-1"
			FMS_After[n] = -1
		endif
	endfor

	//Step 2: Create mirrors of squirrel stick waves for:
		// Layer 1: Cycle#
		// Layer 2: Beginning/End of cycle
		// Layer 3: Slow/Fast
		// Layer 4: Closed/Open/Diff
	
		// for Layer 2
	Layer2Folders = "Start;End"
	Layer2RunSlowWaves = "Before;After"
		// for Layer 3
	Layer3Folders = "Slow;Fast"
		// for Layer 4
	Layer4Folders = "Diff;Open;Closed;'"
	Layer4Abbr = "D;O;C"  // "C;O;D"
//	String Layer4AvTypeSetting = "2;4;1"
	
	// SQ panel settings:
	todo_makefromname_sv = "FMSTestToDo" // will keep overwriting this one-run todo wave and acting on it...
	sq_toDoWvNm = "FMSTestToDo"
	ms0_graphOutputType = 2	// Sticks and raw
	ms0_ion2mass = 0 		// Hz
	ms0_graphOutputType = 4			// don't plot, "update"
	ms0_ck_trunc2zero = 0		// don't truncate
		
	for (ly1=0;ly1<NumCycles;ly1+=1)		// Layer 1 (Cycle number)
		for (ly2=0;ly2<2;ly2+=1)			// Layer 2 (beginning/end)
			Layer2Type = StringFromList(ly2,Layer2Folders)
			for (ly3=0;ly3<2;ly3+=1)		// Layer 3 (slow/fast)
				Layer3Type = StringFromList(ly3,Layer3Folders)
				if (ly3)	// if Fast
					Wave RunListWave = $"root:index:FMS_"+Layer2Type+"Runs"
					Wave RunTypeWave = $"root:index:FMS_"+Layer2Type+"Types"
				else
					Wave RunListWave = $"root:index:FMS_SlowRun"+StringFromList(ly2,Layer2RunSlowWaves)					
				endif
				Run = RunListWave[ly1]	// Preliminarily define Run# here
				for (ly4=0;ly4<3;ly4+=1)	// Layer 4 (open/closed/diff)
					Layer4Type = StringFromList(ly4,Layer4Folders)
					ms0_dataType = ly4+1 //str2num(StringFromList(ly4,Layer4Folders)) // Donna change from MJC Layer4AvTypeSetting))	// set C/O/D on panel
					DestPath = path+"Cycle"+num2str(ly1)+":"+Layer2Type+":"+Layer3Type+":"+Layer4Type+":"
					gen_createFolders(DestPath)
					if (ly3)	// if fast... have to take account of whether FastMS run is open or closed at this point.
						if ((ly4==0 && RunTypeWave[ly1]==0) || (ly4>=1 && RunTypeWave[ly1])==1)	// if calculating same spec type as first point in fast wave -> don't search
							Run = RunListWave[ly1]
							// do nothing... keep run# the same
						else	// need to hunt for appropriate run in FMS, a-r-g!
							k=0
							do
								k += ly2 ? -1 : 1	// increment if start of FMS, decrement if end of FMS
								if (RunTypeWave[ly1])	// first/last run is open
									FindValue/I=(Run+k) allFastClosed	// so look for closed
								else
									FindValue/I=(Run+k) allFastOpen	// and v.v.
								endif
							while (V_value<0)
							Run += k
						endif
					endif
					// 3/16/09 - Extend run interval from single run# to the number of averages required by the user from the panel SV's
					// use variable k as number of runs to extend interval
					if (ly3)	// if fast
						k = ly2 ? -NumFMSAvs : NumFMSAvs	//increment if start of FMS, decrement if end of FMS
						if (ly4==0)	// FastClosed
							ExtendRunIntervalWave = GetWavesDataFolder(allFastClosed,2)	
						else		// FastOpen (and diff, which operates only on the open anyway)
							ExtendRunIntervalWave = GetWavesDataFolder(allFastOpen,2)													
						endif
					else		// slow
						k = ly2 ? NumSMSAvs : -NumSMSAvs	//decrement if start of FMS, increment if end of FMS
						ExtendRunIntervalWave = GetWavesDataFolder(allSlow,2)
					endif
					Wave ToDoExtend = $ExtendRunIntervalWave
					FindValue/I=(Run) ToDoExtend // what pnt number are we at right now?
					
					sprintf str1, "%d" , run		// small bug, things can go wrong with run numbers > 1e6
					sprintf str2, "%d" , ToDoExtend[max(0,V_value + k)]	// small bug, things can go wrong with run numbers > 1e6
					if (k<0) // place new run number before current one
						todo_makefromruns_sv =str2+"-"+str1
					elseif (k>0)	// place after
						todo_makefromruns_sv = str1+"-"+str2				
					else	// no averaging
						todo_makefromruns_sv = str1
					endif
					todo_makefromruns_sv += " and "+nameofwave(todoextend)	// only want points from this todo wave in our averaging
				
					// *** ACT HERE
	//				String/G $DestPath+"ToDoInterval" = todo_makefromruns_sv
					sq_butt_todofromruns("")	// press the todo button
					// sq_butt_ms_avg("")	// make the MS and MSS waves
	
					sq_MSCalc_avgStick("FMSTestToDo")	// make the MSS waves
					sq_MSCalc_avgRaw("FMSTestToDo")	// make the MS waves

					// waves created by the ms_avg function:
					for (n=0; n<ItemsInList(DestList);n+=1)
						Wave/z MSS = $"root:MSS"+StringFromList(ly4,Layer4Abbr)+"_FMSTestToDo_"+StringFromList(n,DestList)
						if (WaveExists(MSS))
							Duplicate/o MSS $DestPath+"MSS"+StringFromList(ly4,Layer4Abbr)+"_"+StringFromList(n,DestList)
						else
							abort "Couldn't find "+"root:MSS"+StringFromList(ly4,Layer4Abbr)+"_FMSTestToDo_"+StringFromList(n,DestList)
						endif
					endfor
					Wave mzbase = root:mz_base_FMSTestToDo
					Duplicate/o mzbase, $DestPath+"mzbase"
//					print "root:MS"+StringFromList(ly4,Layer4Abbr)+"_FMSTestToDo_all"
					Wave/z MS = $"root:MS"+StringFromList(ly4,Layer4Abbr)+"_FMSTestToDo_all"		// slight change from MJC
					if (waveexists(MS))
						Duplicate/o MS, $DestPath+"MS"+StringFromList(ly4,Layer4Abbr)
					endif
					//abort // debug only
				endfor //ly 4 = C;O;D
				ms0_graphOutputType=0	// only need one graph of each type
			endfor //ly 3 // slow/fast
			
			// *** Calculate differences between slow and fast here
			// Slow has historically larger signals than fast, so duplicate the slow waves and subtract the fast (or do we prefer fast/slow ratio?)
			for (ly4=0;ly4<3;ly4+=1)	// loop again over C;O;D
				DestPath = path+"Cycle"+num2str(ly1)+":"+Layer2Type+":SlowLessFast:"+StringFromList(ly4,Layer4Folders)+":"
				gen_createFolders(DestPath)
				DiffSlowPath = path+"Cycle"+num2str(ly1)+":"+Layer2Type+":Slow:"+StringFromList(ly4,Layer4Folders)+":"
				DiffFastPath = path+"Cycle"+num2str(ly1)+":"+Layer2Type+":Fast:"+StringFromList(ly4,Layer4Folders)+":"
				gen_createFolders(DiffSlowPath)
				gen_createFolders(DiffFastPath)
					// mzbase - copy slow mzbase in only. we have assumed it is the same to take the slolw-fast difference so this should not matter
				Wave mzbase = $DiffSlowPath+"mzbase"
				Duplicate/o mzbase, $DestPath+"mzbase"					
					// Raw mass spec
				//print DiffSlowPath+"MS"+StringFromList(ly4,Layer4Abbr)
				Wave MSslow = $DiffSlowPath+"MS"+StringFromList(ly4,Layer4Abbr)
				Wave MSfast = $DiffFastPath+"MS"+StringFromList(ly4,Layer4Abbr)
				Duplicate/o MSslow, $DestPath+"MS"+StringFromList(ly4,Layer4Abbr)		//oh-o, no idiot checks, this had better work
				Wave MSslowLessFast = $DestPath+"MS"+StringFromList(ly4,Layer4Abbr)
				MSslowLessFast-=MSfast							// and they had better darn well be on the same mz scale... perhaps best in future to force this from the sQ panel options?
				Note MSslowLessFast GetWavesDataFolder(MSslow,2)+" minus "+GetWavesDataFolder(MSfast,2)
					// Sticks
				for (n=0; n<ItemsInList(DestList);n+=1)
					Wave MSSslow = $DiffSlowPath+"MSS"+StringFromList(ly4,Layer4Abbr)+"_"+StringFromList(n,DestList)
					Wave MSSfast = $DiffFastPath+"MSS"+StringFromList(ly4,Layer4Abbr)+"_"+StringFromList(n,DestList)
					if (WaveExists(MSSslow) && WaveExists(MSSfast))
						Duplicate/o MSSslow $DestPath+"MSS"+StringFromList(ly4,Layer4Abbr)+"_"+StringFromList(n,DestList)
						Wave MSSslowLessFast = $DestPath+"MSS"+StringFromList(ly4,Layer4Abbr)+"_"+StringFromList(n,DestList)
						MSSslowLessFast -= MSSfast
						Note MSSslowLessFast GetWavesDataFolder(MSSslow,2)+" minus "+GetWavesDataFolder(MSSfast,2)
					else
						Print "// Couldn't find wave creating difference sticks..."
					endif
				endfor				
			endfor
		endfor //ly 2	// beginning/end
	endfor //ly 1 //cycle number

End


//Button on main Fast mode panel for plotting the values found in previous MS diagnostics calculate button
Function fm_butt_plotMSSDiags(ctrlName) : ButtonControl	// MJC to go with function above, make pretty plots
	String ctrlName

	// ** get speclist from something passed to function, or save global string when creating all the waves??
	// ** just plot cycle0:start: and then call the function which executes the allinCDF commands
	
	SVAR SpecList = root:quantifChecks:FMS_MSS:SpecList	// list of stick species generated by last calculate command
	
	// root:quantifChecks:FMS_MSS:Cycle0:Start:SlowLessFast:Closed
	String DestPath = "root:quantifChecks:FMS_MSS:Cycle0:Start:"
	String FolderList = "Slow;Fast;SlowLessFast"
	String GraphName = "FMS_MSDiagsGr"
	
	Variable n, k
		
	if (WinType(GraphName))
		KillWindow $GraphName
	endif
	
	Display /W=(150,75,650,575)/N=$GraphName as GraphName
	Controlbar 50
	PopupMenu popup_MSSDiagsStEnd,pos={2,1},size={173,23},proc=fm_MSSPopMenuProc,title="Display:"
	PopupMenu popup_MSSDiagsStEnd,mode=1,popvalue="Beginning of cycle",value= #"\"Beginning of cycle;End of cycle\""
	PopupMenu popup_MSSDiagsCOD,pos={2,23},size={173,23},proc=fm_MSSPopMenuProc,title="Display:"
	PopupMenu popup_MSSDiagsCOD,mode=1,popvalue="Closed",value= #"\"Closed;Open;Diff\""
	SetVariable setvar_MSSDiags,pos={160,25},size={104,18},proc=fm_MSSSetVarProc,title="at this FMS Cycle:"
	SetVariable setvar_MSSDiags,value= root:panel:fastMS:MSSDiagsDisplayCycle, bodyWidth= 40
	CheckBox check_MSSDiags_LockFast, variable = root:panel:fastMS:MSSDiagsLockFast, pos={300,2}, title = "Lock Fast to Slow"
	CheckBox check_MSSDiags_LockFast, proc=fm_MSSCheckProc, disable = 2		// not working, ask MJC
	CheckBox check_MSSDiags_LockSlowFast, variable = root:panel:fastMS:MSSDiagsLockSlowFast, pos={300,18}, title = "Lock \"Slow - Fast\" to Slow"
	CheckBox check_MSSDiags_LockSlowFast, proc=fm_MSSCheckProc, disable = 2		// not working, ask MJC
 	SetVariable setvar_MSSDiags_Scale2mz, value = root:panel:fastMS:MSSDiagsScale2mz, pos={600,2}, title = "Set max to this m/z"
	SetVariable setvar_MSSDiags_Scale2mz, bodywidth=40, disable=2
	
	// hard-code the free axes; if folderlist changes this would fail
	NewFreeAxis L_Fast
	NewFreeAxis L_SlowLessFast
	NewFreeAxis/r R_Fast
	NewFreeAxis/r R_SlowLessFast
		
	for (n=0; n<ItemsInList(FolderList);n+=1)
			// append raw MS trace to right axis is can find it
		Wave/z MSC = $DestPath+StringFromList(n,FolderList)+":Closed:MSC"
		Wave/z mzbase = $DestPath+StringFromList(n,FolderList)+":Closed:mzbase"
		if (WaveExists(MSC) && WaveExists(mzbase))
			appendtograph/W=$GraphName/R=$"R_"+StringFromList(n,FolderList) MSC vs mzbase
		endif
			// append all the stick traces
		for (k=0; k<ItemsInList(SpecList);k+=1)
			Wave/z MSSC = $DestPath+StringFromList(n,FolderList)+":Closed:MSSC_"+StringFromList(k,SpecList)
			if (WaveExists(MSSC))
				appendtograph/W=$GraphName/L=$"L_"+StringFromList(n,FolderList) MSSC
			endif
		endfor
		
	endfor
	
	ModifyFreeAxis L_Fast master=L_slow
	ModifyFreeAxis R_Fast master=R_slow
	ModifyFreeAxis L_SlowLessFast master=L_slow
	ModifyFreeAxis R_SlowLessFast master=R_slow
	
	// steal Donna's code with minor mods for the colouring-in part
		kbcolorizetraces(.5,1,0)	// Igor 6.03 change
		wave /z/t col_names=root:frag:col_names
		String wavlist=tracenamelist(GraphName,";",1)
		if (waveexists(col_names))
			wave col_r=root:frag:col_r
			wave col_g=root:frag:col_g
			wave col_b=root:frag:col_b
			Variable idex, jdex, num=itemsinlist(wavlist)
			for (idex=0;idex<num;idex+=1)
				String listitem=upperstr(stringfromlist(idex,wavlist))
				jdex=sq_findstr(col_names,listitem,2-(0&1))
				if (jdex>-1 && StringMatch(ListItem, "MSSC*"))
					modifygraph rgb($listitem)=(col_r[jdex],col_g[jdex],col_b[jdex])
					ModifyGraph offset($listitem)={1,0}
				endif
			endfor
		endif
	// end colouring in
	
	ModifyGraph mode=1, tomode=3,lsize=3	// all sticks, allstack
	for (k=0;k<ItemsInList(wavlist);k+=1)	// set the raw waves how we'd like them
		listitem=upperstr(stringfromlist(k,wavlist))
		if (stringmatch(listitem, "MSC*"))
			ModifyGraph mode($listitem)=0
			ModifyGraph tomode($listitem)=0
			ModifyGraph lsize($listitem)=1
			ModifyGraph rgb($listitem)=(0,0,0)
		endif
	endfor
	ModifyGraph fSize=10
	ModifyGraph fStyle=1
	ModifyGraph freePos=0
	ModifyGraph axisEnab(R_Slow)={0.67,1}
	ModifyGraph axisEnab(R_Fast)={0.33,0.65}
	ModifyGraph axisEnab(R_SlowLessFast)={0,0.31}
	ModifyGraph axisEnab(L_Slow)={0.67,1}
	ModifyGraph axisEnab(L_Fast)={0.33,0.65}
	ModifyGraph axisEnab(L_SlowLessFast)={0,0.31}
	ModifyGraph margin(left)=70, margin(right)=70
	Label L_Slow "Slow mode signal [Hz]"
	Label L_Fast "Fast mode signal [Hz]"
	Label L_SlowLessFast "Slow - Fast"
	ModifyGraph lblPos(R_Slow)=60,lblPos(L_Slow)=60,lblPos(R_Fast)=60
	ModifyGraph lblPos(L_Fast)=60,lblPos(R_SlowLessFast)=60,lblPos(L_SlowLessFast)=60
	Label bottom "m/z"
	
	nvar MSSDiagsLockFast = root:panel:fastMS:MSSDiagsLockFast
	nvar MSSDiagsLockSlowFast = root:panel:fastMS:MSSDiagsLockSlowFast
	nvar MSSDiagsScale2mz = root:panel:fastMS:MSSDiagsScale2mz

	MSSDiagsLockFast = 1
	MSSDiagsLockSlowFast = 1
	MSSDiagsScale2mz = -1

End


// Checkbox control on Fast mode Diagnostic plot
Function fm_MSSCheckProc(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	if (stringmatch(ctrlName, "check_MSSDiags_LockFast"))
		if (checked)
			ModifyFreeAxis L_Fast master=L_Slow
			ModifyFreeAxis R_Fast master=R_Slow
		else
			ModifyFreeAxis L_Fast master=L_Fast
			ModifyFreeAxis R_Fast master=R_Fast
		endif
	elseif (stringmatch(ctrlName, "check_MSSDiags_LockSlowFast"))
		if (checked)
			ModifyFreeAxis L_SlowLessFast master=L_Slow
			ModifyFreeAxis R_SlowLessFast master=R_Slow
		else
			ModifyFreeAxis L_SlowLessFast master=L_SlowLessFast
			ModifyFreeAxis R_SlowLessFast master=R_SlowLessFast
		endif	
	endif

End


// Popup menu control on Fast mode Diagnostic plot
Function fm_MSSPopMenuProc(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum	// 1 = beginning, 2 = end.......... OR 1 = CLosed, 2 = Open, 3 = Diff
	String popStr

	NVAR MSSDiagsDisplayType = root:panel:fastMS:MSSDiagsDisplayType	// Start/End
	NVAR MSSDiagsCODType = root:panel:fastMS:MSSDiagsCODType		// C/O/D
	NVAR MSSDiagsDisplayCycle = root:panel:fastMS:MSSDiagsDisplayCycle	// cycle number

	if (stringmatch(ctrlName, "popup_MSSDiagsStEnd"))	// beginning or end of cycle
		MSSDiagsDisplayType = popNum
	elseif (stringmatch(ctrlName, "popup_MSSDiagsCOD"))	// closed-open-diff
		MSSDiagsCODType = popNum
	else // called by SV
		// don't alter either
	endif
	
//	root:quantifChecks:FMS_MSS:Cycle0:Start:Fast:Closed
//	** panel has 3 graphs... fast, slow and SlowLessFast. Have to change all of them... in the correct order, eck.
	String path = "root:quantifChecks:FMS_MSS:Cycle"
	String FolderList = "Slow;Fast;SlowLessFast"
	String GraphName = "FMS_MSDiagsGr"
	String TraceList = TraceNameList(GraphName,";",1)
	String StEndList = ";Start;End"
	String CODList = ";Closed;Open;Diff"
	String CODrawlist = ";MSC;MSO;MSD"
	String CODsticklist = ";MSSC;MSSO;MSSD"
	
	Variable n
	String WavePath, CycleStr, StEndStr, CODStr
	
	for (n=0;n<ItemsInList(TraceList);n+=1)
		Wave Source = TraceNameToWaveRef(GraphName, StringFromList(n,TraceList))
		WavePath = GetWavesDataFolder(Source,2)
		
		// Overwrite the wave path with the new one
			// Cycle number
		CycleStr = StringFromList(3,WavePath,":")
		WavePath = ReplaceString(CycleStr,WavePath,"Cycle"+num2str(MSSDiagsDisplayCycle))
			// Start/End
		StEndStr = StringFromList(4,WavePath,":")
		WavePath = ReplaceString(StEndStr,WavePath,StringFromList(MSSDiagsDisplayType,StEndList))
			// C/O/D
		CODStr = StringFromList(6,WavePath,":")
		WavePath = ReplaceString(CODStr,WavePath,StringFromList(MSSDiagsCODType,CODList))
		
			// New wave reference... HAVE TO CHSNGE MSC to MSD or MSO as appropriate first...
		WavePath = ReplaceString("MS"+CODStr[0], WavePath, StringFromList(MSSDiagsCODType,CODrawlist))
		WavePath = ReplaceString("MSS"+CODStr[0], WavePath, StringFromList(MSSDiagsCODType,CODsticklist))

		Wave/z Dest = $WavePath
		
		if (WaveExists(Dest))
			ReplaceWave trace=$StringFromList(n, TraceList) Dest
		endif	
			// update trace list...
		TraceList = TraceNameList(GraphName,";",1)
		
	endfor

End


// Set variable control on Fast mode Diagnostic plot
Function fm_MSSSetVarProc(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	fm_MSSPopMenuProc("",-1,"")

End


//Function fm_makeAllSlow()  // MJC 3/16/2009 - create the generic todo wave for slow runs, donna changed to be a regular function
//	String ctrlName
//	
//		// Declare squirrel panel globals	
//	SVAR interval = root:panel:todo_makefromruns_sv
//	SVAR name = root:panel:todo_makefromname_sv
//		
//	interval = "all and not allFast"
//	name = "allSlow"
//	
//	sq_butt_todofromruns("")	// press the todo button... clearly, this function overwrites your existing todo wave
//
//End


// Step 3 button on FastModePreProcessPanel, Find FMS cycles button
// creates many waves used in future fast mode functions
Function fm_butt_DefineCycles(ctrlName) : ButtonControl // MJC 3/9/2009 - Define start and end of FMS cycles
	String ctrlName
	
	wave fastKey = root:diagnostics:fastKey
	wave rn_series = root:index:rn_series
	wave allFastOpen = root:allFastOpen
	wave allFastClosed = root:allFastClosed
	wave/z fastMSTimeWithinCycle = root:diagnostics:fastMSTimeWithinCycle
	wave/z fastMSRunWithinCycle = root:diagnostics:fastMSRunWithinCycle

	wave all = root:all		//1.16M

	wave/z blacklist = root:blacklist		//1.53D
	
	nvar numCycles = root:panel:FastMS:numcycles
	Variable idex, num, NumCyclesTemp, NumCases, FirstClosed, kdex, currentfastModeNum, continueFlag
	
	// get fastMSTimeWithinCycle, fastMSRunWithinCycle
	if (!WaveExists(fastMSRunWithinCycle) || !WaveExists(fastMSTimeWithinCycle))
		duplicate/o all allTemp				// some runs may have been blacklisted.  We want every value from the hdfs.
		redimension/n=(numpnts(rn_series)) allTemp
		allTemp=rn_series
		squirrel_fetch(allTemp,sq_getNewDiagValuesList,"dataFolderStr:diagnostics;colList:111/112;destList:fastMSTimeWithinCycle/fastMSRunWithinCycle","InfoVal;")	
		wave fastMSTimeWithinCycle = root:diagnostics:fastMSTimeWithinCycle
		wave fastMSRunWithinCycle = root:diagnostics:fastMSRunWithinCycle
	elseif ( (WaveExists(blacklist) && numpnts(blacklist)>0) || numpnts(fastKey) != numpnts(rn_series) )
		duplicate/o all allTemp				// some runs may have been blacklisted.  We want every value from the hdfs.
		redimension/n=(numpnts(rn_series)) allTemp
		allTemp=rn_series
		squirrel_fetch(allTemp,sq_getNewDiagValuesList,"dataFolderStr:diagnostics;colList:71/111/112;destList:fastKey/fastMSTimeWithinCycle/fastMSRunWithinCycle","InfoVal;")	
	endif

	WaveStats/q fastMSTimeWithinCycle
	if (V_npnts==0)		// sanity check added in 1.50L
		wave/z FastModeAvgTimeSec = root:diagnostics:FastModeAvgTimeSec
		variable numClosedStart, numClosedStop
		Prompt numClosedStart, "Enter the number of fast mode closed runs at the beginning of a fast cycle "		
		Prompt numClosedStop, "Enter the number of fast mode closed runs at the end of a fast cycle "		
		DoPrompt "Enter number of closed runs at start and stop of cycle", numClosedStart, numClosedStop
		if (V_Flag)
			return -1								// User canceled
		endif
		sq_RecreateFastMSRunWithinCycle(FastKey, FastModeAvgTimeSec, fastMSRunWithinCycle, fastMSTimeWithinCycle, numClosedStart, numClosedStop)
	endif
	
	//  deal with root:index:FMS_ClosedCycles
	
	// fill in 2D FMS_ClosedCycles wave
	Make/i/o/n=1 root:index:FMS_ClosedCycles/Wave=FMS_ClosedCycles
	num=numpnts(FastKey)

//	do
//		do 
//			idex+=1
//		while (fastKey[idex]!=2 && idex < num && fastMSRunWithinCycle[idex]!=0)	// go through all start of fast closed
//		if (idex<num && fastKey[idex]==2)		// not at end of wave and we have a closed.  we are the start of a fast cycle
//			ReDimension/n=(NumCyclesTemp+1,4) FMS_ClosedCycles
//			FMS_ClosedCycles[NumCyclesTemp][0] = rn_series[idex]
//			FMS_ClosedCycles[NumCyclesTemp][1] = idex
//			do	// we are at the start of a fast mode cycle.  first run should be closed
//				idex+=1
//			while (idex < num &&  fastMSRunWithinCycle[idex]!=0 )  // fastKey[idex] ==2 && ) 		//  1.53M
//			idex-=1
//			FMS_ClosedCycles[NumCyclesTemp][2] = rn_series[idex]
//			FMS_ClosedCycles[NumCyclesTemp][3] = idex
//			NumCyclesTemp+=1
//		endif
//		idex+=1
////		if (idex<num && (fastMSRunWithinCycle[idex]==0 || fastKey[idex]==2)  )
//		if (idex<num && ( fastKey[idex]==2)  )		// change for TimO may 2013
//			idex-=1		// cuz we are gonna add 1 till it is checked again
//		endif
//	while (idex<num)
	
	idex=-1
	NumCyclesTemp = 0
	do
		//  first skip past any slow runs
		do 
			idex+=1
		while (idex < num && fastKey[idex]!=2 && fastMSRunWithinCycle[idex]!=0)	// go through all start of fast closed
		if (idex<num && fastKey[idex]==2)		// not at end of wave and we have a closed.  we are the start of a fast cycle
			ReDimension/n=(NumCyclesTemp+1,4) FMS_ClosedCycles
			FMS_ClosedCycles[NumCyclesTemp][0] = rn_series[idex]
			FMS_ClosedCycles[NumCyclesTemp][1] = idex
			do	// we are at the start of a fast mode cycle.  first run should be closed
				idex+=1
			while (idex < num &&  fastMSRunWithinCycle[idex-1]< fastMSRunWithinCycle[idex] &&  fastKey[idex] ==2 )  // fastKey[idex] ==2 && ) 		//  1.53M
			idex-=1
			FMS_ClosedCycles[NumCyclesTemp][2] = rn_series[idex]
			FMS_ClosedCycles[NumCyclesTemp][3] = idex
			NumCyclesTemp+=1
		endif
		idex+=1
//		if (idex<num && (fastMSRunWithinCycle[idex]==0 || fastKey[idex]==2)  )
		if (idex<num && ( fastKey[idex]==2)  )		// change for TimO may 2013
			idex-=1		// cuz we are gonna add 1 till it is checked again
		endif
	while (idex<num)


	//  deal with root:index:FMS_StartRuns, etc waves
	Make/o/n=1 root:index:FMS_StartRuns/Wave=FMS_StartRuns
	Make/o/n=1 root:index:FMS_EndRuns/Wave=FMS_EndRuns
	Make/o/n=1 root:index:FMS_StartTypes/Wave=FMS_StartTypes
	Make/o/n=1 root:index:FMS_EndTypes/Wave=FMS_EndTypes

	idex=-1
	NumCyclesTemp = 0

	do
		do 
			idex+=1
//1.53D if user represses the Get Index after we have blacklisted the first runs we need to be careful about redefining new fast cycles
// 
		while (idex < num && numtype(fastMSRunWithinCycle[idex])!=0 && fastKey[idex]!=0)		// 1.52A  before we looked for identically 0
//		while (numtype(fastMSRunWithinCycle[idex])!=0 && idex < num)		// 1.52A  before we looked for identically 0
		if (idex<num)		// start of new cycle
			ReDimension/n=(NumCyclesTemp+1,2) FMS_StartRuns, FMS_EndRuns
			ReDimension/n=(NumCyclesTemp+1) FMS_StartTypes, FMS_EndTypes
			FMS_StartRuns[NumCyclesTemp][0] = rn_series[idex]
			FMS_StartRuns[NumCyclesTemp][1] = idex
			FMS_StartTypes[NumCyclesTemp] = fastKey[idex]
			currentfastModeNum =  fastMSRunWithinCycle[idex]
			continueflag=1
			do
				idex+=1
				if(idex<num &&  fastKey[idex]==0 && fastMSRunWithinCycle[idex]==0) //  fast open and first in cycle.  Tim O's data
					currentfastModeNum  =  fastMSRunWithinCycle[idex]
					idex+=1
				endif
			while (idex<num && numtype(fastKey[idex])==0 && fastMSRunWithinCycle[idex]>currentfastModeNum)		// 30 is arbitrary
			idex-=1	// either out of fast mode, at the end of the wave, or our fast counting started at 0
			FMS_EndRuns[NumCyclesTemp][0] = rn_series[idex]
			FMS_EndRuns[NumCyclesTemp][1] = idex
			FMS_EndTypes[NumCyclesTemp] =fastKey[idex]
			NumCyclesTemp+=1
		endif
		if (FMS_EndRuns[NumCyclesTemp-1][1]==FMS_StartRuns[NumCyclesTemp-1][1] )		// we have a fast run of length 1.
			idex+=1			//1.60B	
		endif
//		idex+=1
		if (idex<num && fastMSRunWithinCycle[idex]==0)
			idex-=1		// cuz we are gonna add 1 till it is checked again
		endif
	while(idex<num)

	numCycles=NumCyclesTemp
	
	//  Does the fast mode cycle have an adjacent slow run?

	Make/o/n=(NumCycles) root:index:FMS_SlowRunBefore/Wave=FMS_SlowRunBefore
	Make/o/n=(NumCycles) root:index:FMS_SlowRunAfter/Wave=FMS_SlowRunAfter	
	FMS_SlowRunBefore= NaN
	FMS_SlowRunAfter= NaN
	
	for (idex=0; idex<NumCycles;idex+=1)
		
		kdex=FMS_StartRuns[idex][1]	// starting index
		do
			kdex-=1
			if (kdex>=0)
				findvalue /i=(round(rn_series[kdex])) all
			endif
		while(kdex>=0 && V_value == -1)
		if(kdex<0)
			FMS_SlowRunBefore[idex]=nan
		elseif (numtype(fastKey[kdex])!=0) 		// not in fast mode
			FMS_SlowRunBefore[idex]=rn_series[kdex]
		else
			FMS_SlowRunBefore[idex]=nan
		endif
		
		kdex=FMS_EndRuns[idex][1]	// starting index
		do
			kdex+=1
			if (kdex<num)
				findvalue /i=(round(rn_series[kdex])) all
			endif
		while(kdex<num && V_value == -1)
		if(kdex==num)
			FMS_SlowRunAfter[idex]=nan
		elseif (numtype(fastKey[kdex])!=0)		// not in fast mode 		
			FMS_SlowRunAfter[idex]=rn_series[kdex]
		else
			FMS_SlowRunAfter[idex]=nan
		endif

	endfor

	//  deal with root:index:FMS_Extrapolate for when fast mode starts (never) or ends on a fast open

	Make/o/i/n=0 root:index:FMS_Extrapolate/Wave=FMS_Extrapolate

	Make/free/u/i/n=0 badcycle		//1.60Y
	variable badCycleCount = 0			//1.57L
	
	NumCases=0
	// fill in 2d wave FMS_Extrapolate which contains run numbers
	// Go through all Fast mode cycles and check the start of the fast mode to see if open or closed
	for (idex=0; idex<numpnts(FMS_StartTypes);idex+=1)

		if (FMS_StartTypes[idex]!=2)	// Start of FMS cycle requires extrapolation of closed backwards from first closed cycle
		// I don't know how this can happen, it is left for historical purposes
			ReDimension/n=(NumCases+1,2) FMS_Extrapolate
			// Find a previous fast closed cycle. Assume first closed point is good for extrapolation (ie run this function AFTER averaging)
			FirstClosed =binarysearch(allFastClosed, FMS_StartRuns[idex])	// note that the run in FMS_StartRuns  // if data = {1, 2, 3.3, 4.9} then BinarySearch(data,3) is 1	
			if (FirstClosed == -1)	// Extrapolate back from first point // not within the range, but would numerically be placed before the first value in the wave.
				FirstClosed = 0
			elseif (FirstClosed == -2)  // -2 if not within the range, but would fall after the last value in the wave.
				//. this shouldn't happen...
//				print idex
				insertpoints numpnts(badcycle), 1, badcycle 	//1.57L
				badcycle[numpnts(badcycle)-1] = idex
				continue		//1.57L
//				abort "Something unexpected happened within fm_butt_DefineCycles"
			else
				FirstClosed += 1 // want the first closed after FMS_startRuns 
			endif
			FMS_Extrapolate[NumCases][0] = FMS_StartRuns[idex]
			FMS_Extrapolate[NumCases][1] = allFastClosed[FirstClosed]  // This is the first fast closed after FMS_StartRuns[n]
			NumCases += 1
		endif

		if (FMS_EndTypes[idex]!=2)	// last run in fast cycle is open	
		// End of FMS cycle requires extrapolation of closed forwards from last closed cycle
			ReDimension/n=(NumCases+1,2) FMS_Extrapolate
			// Find last closed cycle. Assume last closed point is good for extrapolation
			FirstClosed =binarysearch(allFastClosed, FMS_EndRuns[idex])  // if data = {1, 2, 3.3, 4.9} then BinarySearch(data,3) is 1	
			if (FirstClosed == -1)	// Extrapolate back from first point  // not within the range, but would numerically be placed before the first value in the wave.
				//. this shouldn't happen...
//				print idex
				FindValue/u=(idex) badcycle 
				if (V_value<0)
					insertpoints numpnts(badcycle), 1, badcycle 	//1.57L
					badcycle[numpnts(badcycle)-1] = idex
				endif
				continue		//1.57L
//				abort "Something unexpected happened within fm_butt_DefineCycles"
			elseif (FirstClosed == -2) // not within the range, but would fall after the last value in the wave.
				FirstClosed = numpnts(allFastClosed)-1		// use the very last fast closed that we have
			endif
			FMS_Extrapolate[NumCases][0] = FMS_EndRuns[idex]
			FMS_Extrapolate[NumCases][1] = allFastClosed[FirstClosed]		// note that this if the first fast closd after the last point in a fast cycle, which is open in this case 
			NumCases += 1
		endif
	endfor
	
	if (numpnts(badcycle)>0 )
		for (idex=numpnts(badCycle) -1; idex>=0; idex-=1)
			deletepoints/m=0 badcycle[idex], 1,  FMS_Extrapolate, FMS_StartRuns, FMS_EndRuns,FMS_StartTypes,FMS_EndTypes,FMS_SlowRunBefore,FMS_SlowRunAfter,FMS_Extrapolate			
		endfor
	endif
	
	killwaves/z tdiff, allTemp  //1.60M1
  
//	idex = SQ_montonicityFastMSRuns()
//	if (idex>=0)
//		fm_butt_FastKeySeriesTable("")
//		abort "The wave root:diagnostics:fastMSRunWithinCycle was not monotonic at row "+num2str(idex)+". Perhaps you want to investigate root:diagnostics:fastCycleDelta further."
//	endif

End



// Step 2 button on FastModePreProcessPanel, blacklisting button
Function fm_butt_DoBlacklist(ctrlName) : ButtonControl	// MJC 3/6/2009 - easy creation of FMS todos.
	String ctrlName

	String ToDoStr, Type
	Variable BlacklistOrQuarantine, ClosedOrOpen, OneOrTwo

	Prompt BlacklistOrQuarantine, "Blacklist or duplicate fast todos and remove?", popup, "Blacklist;Duplicate and remove (eg allFastOpenNotFirst)"
	Prompt ClosedOrOpen, "Closed or Open?" popup, "Closed;Open"
	Prompt OneOrTwo "Act on first run in fast cycle, or first AND second?", popup, "The first run in each fast mode transition;Both the first and the second"
	DoPrompt "Choices, choices", BlacklistOrQuarantine,ClosedOrOpen,OneOrTwo
	
	if (V_flag==1)
		abort "The user chose to cancel"
	endif
	
	BlacklistOrQuarantine -=1	// 0 = blacklist, 1 = quarantine
	ClosedOrOpen -=1		// 0 = Closed, 1 = Open
	
	if (ClosedOrOpen)
		Type = "Open"
	else
		Type = "Closed"
	endif
		
	// idiot checks
	if (!BlacklistOrQuarantine && ClosedOrOpen)
		DoAlert 1, "Are you sure you want to blacklist the first "+num2str(OneOrTwo) +" runs in the fast mode transition to "+Type+" ??!"
		if (V_Flag==2)
			abort  "The user chose to cancel"
		endif
	elseif (OneOrTwo==2)
		DoAlert 1, "Are you sure you want to operate on the second run in an FMS cycle?"
		if (V_Flag==2)
			abort "The user chose to cancel"
		endif	
	endif
			
	ToDoStr = "First"+num2str(OneOrTwo)+Type	// for use in panel
	Wave ToDo = $"root:"+ToDoStr

	if (!WaveExists(ToDo))
		abort "Could not find ToDo wave named "+todoStr
	endif
	
	if (BlacklistOrQuarantine)		// operate on ToDo wave
		sq_create_todo("allFast"+Type+" and not "+ToDoStr,"allFast"+Type+"X"+ToDoStr )
		print "// Created  allFast"+Type+"X"+ToDoStr +" from the formula allFast"+Type+" and not "+ToDoStr
	else					// blacklist
		sq_BlacklistWave(ToDo) // point of no return
	endif

End


// Step 2 button on FastModePreProcessPanel, Make FMS todos button
Function fm_butt_makeFirstFastToDos(ctrlName) : ButtonControl	// MJC 3/6/2009 - Calls Donna's function below to generate "FirstFast" todo waves
	String ctrlName	
	
	wave rn_series = root:index:rn_series
	wave fastKey = root:diagnostics:fastKey
	wave FMS_ClosedCycles = root:index:FMS_ClosedCycles		//1.53H
  
  	variable idex, run
  	string runStr="", AlertStr=""
  	
	duplicate/o rn_series First1OpenTemp, First2OpenTemp, First1ClosedTemp, First2ClosedTemp	// make it a todo wave
    
	duplicate/o fastKey diff1_temp, diff2_temp
	diff1_temp[1,] = fastKey[p] - fastKey[p-1]	// when these values are not zero we have a transition
	diff2_temp[2,] = fastKey[p] - fastKey[p-2]	// when these values are not zero we have a transition
	diff1_temp[0]=1
	diff2_temp[0,1]=1

	First1OpenTemp = (fastKey[p]==0 && diff1_temp[p]!=0) ?  First1OpenTemp[p] : nan
	First2OpenTemp = (fastKey[p]==0 && (diff1_temp[p]!=0 || diff2_temp[p]!=0)) ?  First2OpenTemp[p] : nan
			
	First1ClosedTemp = (fastKey[p]==2 && diff1_temp[p]!=0) ? First1ClosedTemp[p] : nan
	First2ClosedTemp = (fastKey[p]==2 && (diff1_temp[p]!=0 || diff2_temp[p]!=0)) ?   First2ClosedTemp[p] : nan
	
	sq_RemoveNaNs(First1OpenTemp)
	sq_RemoveNaNs(First2OpenTemp)
	sq_RemoveNaNs(First1ClosedTemp)
	sq_RemoveNaNs(First2ClosedTemp)
	
	redimension/i First1OpenTemp, First2OpenTemp, First1ClosedTemp, First2ClosedTemp
	Note First1OpenTemp "TYPE:todo;"
	Note First2OpenTemp "TYPE:todo;"
	Note First1ClosedTemp "TYPE:todo;"
	Note First2ClosedTemp "TYPE:todo;"
	
	sq_create_todo("First1OpenTemp and allFastOpen", "First1Open")
	sq_create_todo("First2OpenTemp and allFastOpen", "First2Open")
	sq_create_todo("First1ClosedTemp and allFastClosed", "First1Closed")
	sq_create_todo("First2ClosedTemp and allFastClosed", "First2Closed")
		
	Killwaves/z diff1_temp, diff2_temp
	Killwaves/z First1OpenTemp, First2OpenTemp, First1ClosedTemp, First2ClosedTemp
		
	make/free/i/o/n=(dimsize(FMS_ClosedCycles,0)) ClosedDelta =  FMS_ClosedCycles[p][2] - FMS_ClosedCycles[p][0]
		
	string RunList = ""//1.53H we could have some fast closed cycles that are only one point large.... Alert the user 
	if (WaveMin(ClosedDelta)<=0)		// at least one fast closed segment is only one run big.
		WaveStats/q/m=1 ClosedDelta		
		DoAlert, 2, "There are closed cycles of length one at run "+num2istr(FMS_ClosedCycles[V_minloc][0])+ "; if you blacklist them, you may have problems interpolating between fast closed sections.  Select yes to remove there runs from First1Closed todo. Select No to abort and print a problem run."
		if (V_flag==1)		// yes clicked
			idex=0
			do
				FindValue/I=0 /S=(idex) ClosedDelta
				if (V_Value>=0)
					run=FMS_ClosedCycles[V_Value][0]
					sprintf runStr, "%d", run 
					sq_create_todo("First1Closed and not "+runStr, "First1Closed")
					idex=V_Value+1
					RunList+=runStr+";"
				else
					break
				endif
			while(V_Value>=0 && idex < numpnts(ClosedDelta))
			print "// The list of runs removed from todo First1Closed are "+RunList[0, min(200, strlen(RunList))-1]
		else		// user set no, do NOT remove single closed runs from First1Closed
			WaveStats/q/m=1 ClosedDelta		
			sprintf runStr, "%d", FMS_ClosedCycles[V_minloc][0] 
			print "// The user chose to not remove single fast closed run such as "+runStr+" from First1Closed"
		endif	// DoAlert option
	endif	// at least one fast closed segment is of length 1
	
End


// Very important function that alters the MSClosed_p data set
// for individual runs, inserts closed spectra... NOT fill spectra
Function fm_ExtrapolateClosed(index_pos,paramstr,acorn,n_acorns)	// MJC 2/27/2009 in Montseny
    wave index_pos	// point nos in rn_series to act on			
    string paramstr	
    variable acorn,n_acorns

	// REQUIRES a two-row ToDo wave... will take first row in MSC and overwrite second row with it
	if (numpnts(index_pos)!=2)
		return 0
	endif

	wave MSClosed=$stringbykey("acorn_0",paramstr)
	String ClosedType = stringbykey("FMS",paramstr)
	Variable IsSticks, DoIt, ReadFrom, WriteTo, verbose
		
	if (stringmatch(ClosedType, "MSSClosed_p"))	// Sticks
		IsSticks = 1
		Make/o/n=(dimsize(MSClosed,1)) root:FMSTemp = nan
		Wave FMSTemp = root:FMSTemp
	elseif (stringmatch(ClosedType, "MSClosed_p"))	// Raw
		IsSticks = 0
	else
		return 0
	endif

	if (stringmatch(stringbykey("Direction",paramstr),"forward"))					// overwrite
		ReadFrom = 0
		WriteTo = 1
	elseif (stringmatch(stringbykey("Direction",paramstr),"backward"))
		ReadFrom = 1
		WriteTo = 0	
	endif
	
	if (IsSticks)
		FMSTemp = MSClosed[WriteTo][p]
		DoIt = sum(FMSTemp) == 0 ? 1 : 0			// overwrite if stick wave is row of zeros
		DoIt = numtype(MSClosed[WriteTo][0])==2 ? 1 : DoIt	// or stick wave first point is NaN
	else
		DoIt = numtype(MSClosed[WriteTo][0])==2 ? 1 : 0	// overwrite if raw wave first point is a NaN
	endif
	
	verbose=1
	if (!DoIt) // Don't do it!
		if (verbose)
			Print "// In FMS_Extrapolate_Closed function, tried to overwrite a non-NaN/zero spectrum at position "+num2str(index_pos[WriteTo])+" with that at position "+num2str(index_pos[ReadFrom])+" in wave "+ClosedType
			Duplicate/o MSClosed, $"root:FMS_DebugMS_"+num2str(index_pos[WriteTo])+"_"+num2str(index_pos[ReadFrom])
		endif
	else
		MSClosed[WriteTo][] = MSClosed[ReadFrom][q]
		if (verbose)
			Print "// FMS_Extrapolate_Closed function overwrote row of NaNs/zeros at position "+num2str(index_pos[WriteTo])+" with spectrum at "+num2str(index_pos[ReadFrom])+" in wave "+ClosedType
		endif
	endif

	Killwaves/z FMSTemp
	
	//1.14M  Raw spectra or UMR
	squirrel_hdf_write(index_pos,MSClosed,ClosedType)        // uses squirrel infrastructure to write to the intermediate file

End


// Function called from within the pre-process code to do the proper extrapolating
// THIS DOES NOT FILL IN "BLANK" spectra!  Instead it inserts proper 'end points' for subsequent interpolation, the 'fill blanks' section.
Function fm_DoExtrapolateClosed(ToDo, ClosedType [, FMSCyclesOnly])	// MJC 2/27/2009
	Wave ToDo
	String ClosedType			// MSSClosed_p or MSClosed_p
	Variable FMSCyclesOnly		// Set if require to abort after generating waves for "start/end of FMS period"

	// Principle of function:
	// When FMS cycle finishes, interpolation of closed wave to the following slow-mode closed point introduces an error, as slow=/fast.
	// To trick squirrel's FillBlanks function, this code finds the last point in each FMS cycle, and writes a full row of MSC over the Nans which
	// pre-exist there in the MSC.... such that the interpolation in FillBlanks remains at the same value as the last real MSC point... ie extrapolation
	
	// Step 0: Idiot check
	if (!(stringmatch(ClosedType, "MSSClosed_p") || stringmatch(ClosedType, "MSClosed_p")))
		abort "Idiot check failure in fm_DoExtrapolateClosed - aborting from fm_DoExtrapolateClosed"
		return 0
	endif
	
	// Step 1: Find all pnt-numbers in rn_series at which transition from FMS to slow. Define pnts here as the *last row in FMS*
	// This operates on the entire experiment - not just the todo wave passed to this function
	Wave allFast = root:allFast
	Wave allFastClosed = root:allFastClosed
	Wave allFastOpen = root:allFastOpen
	Wave all = root:all
	Variable idex, FirstClosed, FMSCycles = 0, NumCases = 0, IsInToDo, IsNaN
	
	Wave FMS_EndRuns = root:index:FMS_EndRuns
	Wave FMS_StartRuns = root:index:FMS_StartRuns
	Wave FMS_StartTypes = root:index:FMS_StartTypes		// starting run is open (1) or closed (0) ?
	Wave FMS_EndTypes = root:index:FMS_EndTypes		// same for ending run
	
	if (ParamIsDefault(FMSCyclesOnly))	// if doing extrapolation
		Make/o/i/n=0 root:index:FMS_Extrapolate
		Wave FMS_Extrapolate = root:index:FMS_Extrapolate
	endif
		
	if (!ParamIsDefault(FMSCyclesOnly))	// don't do extrapolation
		return 0
	endif
	
	// Step 2: Extrapolation is only required if closed cycle begins/ends with open, otherwise SQ will fill blanks appropriately
	
	for (idex=0; idex<numpnts(FMS_StartTypes);idex+=1)
		
		if (FMS_StartTypes[idex]!=2)	
		// Start of FMS cycle requires extrapolation of closed backwards from first closed cycle
		// I don't know how this can happen, it is left for historical purposes
			ReDimension/n=(NumCases+1,2) FMS_Extrapolate
			// Find first closed cycle. Assume first closed point is good for extrapolation (ie run this function AFTER averaging)
			FirstClosed =binarysearch(allFastClosed, FMS_StartRuns[idex])
			if (FirstClosed == -1)	// Extrapolate back from first point
				FirstClosed = 0
			elseif (FirstClosed == -2)
				//. this shouldn't happen...
				FirstClosed = NaN
			else
				FirstClosed += 1
			endif
			FMS_Extrapolate[NumCases][0] = FMS_StartRuns[idex]
			FMS_Extrapolate[NumCases][1] = allFastClosed[FirstClosed]  // This is the first fast closed after FMS_StartRuns[n]
			NumCases += 1
		endif
			
		if (FMS_EndTypes[idex]!=2)	
		// last run in fast cycle is open	// End of FMS cycle requires extrapolation of closed forwards from last closed cycle
		// we fill in FMS_Extrapolate
			ReDimension/n=(NumCases+1,2) FMS_Extrapolate
			// Find last closed cycle. Assume last closed point is good for extrapolation
			FirstClosed =binarysearch(allFastClosed, FMS_EndRuns[idex])
			if (FirstClosed == -1)	// Extrapolate back from first point
				//. this shouldn't happen...
				FirstClosed = NaN				
			elseif (FirstClosed == -2)	// experiment ends on a fast open... there are no more fast closed runs
				FirstClosed = numpnts(allFastClosed)-1
			else
				//FirstClosed -= 1
			endif
			FMS_Extrapolate[NumCases][0] = FMS_EndRuns[idex]
			FMS_Extrapolate[NumCases][1] = allFastClosed[FirstClosed]		// note that this if the first fast closd after the last point in a fast cycle, which is open in this case 
			NumCases += 1
		endif
		
	endfor
			
	// Step 3: Call fetch function to do the overwriting of MSClosed_p of MSSClosed_p
	// go through FMS_Extrapolate, which is only those instances where we don't have nice endings of closed for fast mode cycles
	for (idex=0;idex<dimsize(fms_extrapolate,0);idex+=1)
		// Step 3a: Is the fast run referenced in this row of the FMS_Extrapolate wave in the todowave passed to this function 
		// (will look for either column to avoid issues with only slow or fast run being passed)
		FindValue/i=(FMS_Extrapolate[idex][0]) todo		// check first column
		IsInToDo = V_Value >= 0 ? 1 : 0
		FindValue/i=(FMS_Extrapolate[idex][1]) todo		// check second column
		IsInToDo = V_Value >= 0 || IsInToDo == 1 ? 1 : 0		
		if (IsInToDo)
			// Step 3b: Is the row in the closed wave which we intend to overwrite actually a NaN in the first place? If not, then we don't want to overwrite it! (And my function is badly coded)
				// Actually.... easier to code this in the fetch function as we already have the closed wave open in memory...		
			// Step 3c: Make temporary ToDo
			make/i/o/n=2 root:FMS_Extrapolate_ToDo/Wave=FMS_Extrapolate_ToDo
			FMS_Extrapolate_ToDo = FMS_Extrapolate[idex][p]		// make the row of FMS_Extrapolate into a todo wave
			// Step 3d: Fetch and overwrite
			squirrel_fetch(FMS_Extrapolate_ToDo,fm_ExtrapolateClosed,"Direction:backward;FMS:"+ClosedType,ClosedType)	// overwrite run# in Row 0 of ToDo with that in row 1
		endif
	endfor

	Killwaves/z TempToDo

End


// Sample usage: 
// squirrel_fetch(todo,fm_AvClosed,"closedType:MSClosed_p","MSClosed_p")
Function fm_AvClosed(index_pos,paramstr,acorn,n_acorns)	// MJC 2/21/2009 in Montseny
    wave index_pos	// point nos in rn_series to act on			
    string paramstr	
    variable acorn,n_acorns
	
	// Will average raw or stick MS on all the runs passed to it and overwrite for every run

	wave series_index = root:index:series_index	
	wave spectraClosed=$stringbykey("acorn_0",paramstr)   	// Note this is for MS, not stick pre-processing...	
	string closedType = stringbykey("closedType",paramstr)
	variable hz_op = str2num(stringbykey("hz_op",paramstr))
	variable mzCal_op = str2num(stringbykey("mzCal_op",paramstr))
	variable AllAvg_op = str2num(stringbykey("AllAvg",paramstr))		//1.55J
	
	variable pos, numpos

	if (hz_op)			//1.52O
		sq_Hz(index_pos,spectraClosed)
	endif
	MatrixOP/o NewMSClosed = sumCols(spectraClosed)
	NewMSClosed/=(dimsize(spectraClosed,0))

//	if (AllAvg_op)
		spectraClosed=NewMSClosed[0][q]		// 1.51M
//	else
//		spectraClosed[dimsize(spectraClosed, 0)-1][]=NewMSClosed[0][q]		// 1.55J    just replace the last one with the average
//	endif
	
	fm_SaveTimeAvg(index_pos,index_pos,"")	//1.57D

	//1.14M  Raw spectra
	squirrel_hdf_write(index_pos,spectraClosed,"MSClosed_p")        // uses squirrel infrastructure to write to the intermediate file
															// Function squirrel_hdf_write(index_pos,source,dataname)
	if (mzCal_op)  // && First_op)
		if (acorn==0)
			mz_createGlobalsMzCalibration()	//1.52O
		endif

		numpos=numpnts(index_pos)
		pos = series_index[index_pos[0]]
		nvar mz_FitSlopeVar = root:mzFitting:mz_FitSlopeVar
		nvar mz_FitInterceptVar = root:mzFitting:mz_FitInterceptVar
		nvar mz_FitPowerVar = root:mzFitting:mz_FitPowerVar
		wave mz_FitPower = root:mzFitting:mz_FitPower
		wave mz_FitSlope = root:mzFitting:mz_FitSlope
		wave mz_FitIntercept = root:mzFitting:mz_FitIntercept
		wave/z OneRunRawSpectra = root:mzFitting:OneRunRawSpectra
		wave/z OneRunRawSpectraClosed = root:mzFitting:OneRunRawSpectraClosed
		if (!WaveExists(OneRunRawSpectraClosed))
			make/o/n=(dimsize(spectraClosed,1)) root:mzFitting:OneRunRawSpectra/wave= OneRunRawSpectra
		endif
		OneRunRawSpectra = spectraClosed[0][p]
		mz_FitOneRun(pos, 1, modifyGraphLive=0)
		mz_FitPower[pos, pos+numpos-1] = mz_FitPowerVar
		mz_FitSlope[pos, pos+numpos-1] =mz_FitSlopeVar
		mz_FitIntercept[pos, pos+numpos-1] =mz_FitInterceptVar
	endif
	
	if (acorn==n_acorns-1)
		KillWaves/z NewMSClosed
	endif

End
	
	
// Function called from within the pre-process code to do Closed averaging
Function fm_DoAvClosed(ToDo, ClosedType)  	// MJC 2/21/2009
	Wave ToDo
	String ClosedType	// MSClosed or MSSClosed
	
	// Principle of this function:
	// 1) To determine start and end points in rn_series wave for each and every closed cycle in FMS.
		// pre-req is that the blacklisting of every first (and perhaps second) closed run has been applied
	// 2) To determine mean average MS for each closed cycle
	// 3) To *overwrite* existing MS with the average
	
	// Why do this? MS_Closed is interpolated between each closed cycle so as to facilitate finding the Diff during the open
	// periods. However, at present, the information contained within the intermediate points in each closed cycle is effectively
	// not used, as sq_fillblanks simply interpolates between each end point in the closed cycle. In the event of 1 point
	// remaining in each closed cycle after blacklisting, making an average is clearly meaningless, but the operator should not
	// be running like this anyway, right?
	
	// Issues to consider:
	// * Do NOT want to overwrite original .hdf files. Need to ensure only writing to intermediates, so re-pre-processing without
	// using this function can go back to the original situation
	
	Wave rn_series = root:index:rn_series	
	Wave allFastClosed = allFastClosed	// todo waves generated by Squirrel on loading...
	Variable idex, k, TodoPnts, numRuns
	string TempStr, dutyCyle_opStr, Hz_opStr, preProcessed_opStr, mzCal_op="", AllAvg_op=""
	
	wave allFast = root:allFast
	if (!WaveExists(allFast))
		return 0				// idiot check for future incorporation into real SQ code
	endif
	
	numRuns = numpnts(rn_series)
	sq_initializeGlobalNVar("root:panel:FastMS:DoMzcalOnAvgs", 1)
	nvar DoMzcalOnAvgs=  root:panel:fastMS:DoMzcalOnAvgs

	mzCal_op = "mzCal_op:"+num2str(DoMzcalOnAvgs) +";"
	sq_initializeGlobalNVar("root:panel:fastMS:DoReplaceAllAvg", 1)
	nvar DoReplaceAllAvg=  root:panel:fastMS:DoReplaceAllAvg
	DoReplaceAllAvg=1
	AllAvg_op = "AllAvg_op:"+num2str(DoReplaceAllAvg) +";"
	Wave FMS_ClosedCycles = root:index:FMS_ClosedCycles
 		
	// 2) Go through step-by-step and create todo wave for each closed cycle and pass to averaging function
	Hz_opStr = "Hz_op:1;"
//	dutyCyle_opStr = SelectString(strsearch(ClosedType, "MSS",0)>0, "dutyCyle_op:1;", "")
//	preProcessed_opStr = SelectString(strsearch(ClosedType, "_p",0)>0, Hz_opStr+dutyCyle_opStr, "")

//1.56H 
	nvar/z FMOFRexceptionFlag = root:panel:FMOFRexceptionFlag		//1.56K
	if (!NVar_exists(FMOFRexceptionFlag) || FMOFRexceptionFlag==0 )
		variable/g root:panel:FMOFRexceptionFlag = 0
		make/free/n=(numpnts(rn_series)) OFRexceptionWave=1
	else
		svar/z FMOFRexceptionStr= root:panel:FMOFRexceptionStr
		wave/z FMOFRexceptionWave = $FMOFRexceptionStr
		if (!WaveExists(FMOFRexceptionWave))	
			abort " The wave "+FMOFRexceptionStr+" does not exist.  Aborting from fm_DoAvClosed"
		endif
	endif
	
	for (idex=0; idex<dimsize(FMS_ClosedCycles,0);idex+=1)
		if (FMOFRexceptionFlag && FMOFRexceptionWave[FMS_ClosedCycles[idex][3]-5] < 1 )
			sprintf TempStr, "%d-%d", FMS_ClosedCycles[idex][0], FMS_ClosedCycles[idex][2] - 25
		else
			sprintf TempStr, "%d-%d", FMS_ClosedCycles[idex][0], FMS_ClosedCycles[idex][2]
		endif
		
		sq_create_todo(TempStr+" and "+NameofWave(todo)+" and allFastClosed","FMS_TempTodo")		// don't use blacklisted runs
		wave FMS_TempTodo = root:FMS_TempTodo
		if (numpnts(FMS_TempTodo)>0)
			squirrel_fetch(FMS_TempTodo,fm_AvClosed,AllAvg_op+mzCal_op+Hz_opStr+"closedType:"+ClosedType+";", ClosedType)			
		endif
	endfor

	//1.50D fix
	killwaves/z FMS_TempTodo
	if (DoMzcalOnAvgs)
		wave mz_FitPower = root:mzFitting:mz_FitPower
		wave mz_FitSlope = root:mzFitting:mz_FitSlope
		wave mz_FitIntercept = root:mzFitting:mz_FitIntercept
		make/o/n=(numRuns) origVals, maskwave, dummyWave
		origVals	= numtype(mz_FitIntercept[p])	 // assume nans are same for all 3 waves	
		sq_create_todo(NameofWave(ToDo) +" and allFastOpen","fastSubset")
		wave fastSubset
		sq_makeMaskFromTodofindRun(maskwave,fastSubset, oppositeFlag=1)
		wave/z blacklist
		if (waveExists(blacklist))
			make/o/n=(numRuns) maskblacklist
			sq_makeMaskFromTodofindRun(maskblacklist,blacklist)	
			maskwave = maskblacklist[p]==1 ? nan : maskwave[p]		
		endif
		mz_FitSlope*=maskwave
		mz_FitIntercept*=maskwave
		mz_FitPower*=maskwave

		fastop  dummyWave = mz_FitIntercept

		sq_interpolateWave(mz_FitIntercept, dummyWave, 1)
//		mz_FitIntercept = ( maskwave[p] !=1 ) ? nan : mz_FitIntercept[p]
		fastop dummyWave = mz_FitSlope

		sq_interpolateWave(mz_FitSlope, dummyWave, 1)
//		mz_FitSlope = ( origVals[p] == 2 && maskwave[p] !=1 ) ? nan : mz_FitSlope[p]		
		fastop dummyWave = mz_FitPower

		sq_interpolateWave(mz_FitPower, dummyWave, 1)
//		mz_FitPower = ( origVals[p] == 2 && maskwave[p] !=1 ) ? nan : mz_FitPower[p]
				
		killwaves/z dummyWave, origVals, maskwave, fastSubset, maskblacklist
	endif
				
End


Function fm_FastOnlyCycles()

	wave rn_series = root:index:rn_series
	wave FastKey = root:diagnostics:FastKey
	wave fastMSRunWithinCycle = root:diagnostics:fastMSRunWithinCycle
	
	variable idex, num, NumCyclesTemp
	
	Make/i/o/n=1 root:index:FMS_ClosedOnlySections/Wave=FMS_ClosedOnlySections
	num=numpnts(FastKey)
	idex=-1
	NumCyclesTemp = 0

	do
		do 
			idex+=1
		while (fastKey[idex]!=2 && idex < num && fastMSRunWithinCycle[idex]!=0)	// go through all start of fast closed
		if (idex<num && fastKey[idex]==2)		// not at end of wave and we have a closed.  we are the start of a fast cycle
			ReDimension/n=(NumCyclesTemp+1,4) FMS_ClosedOnlySections
			FMS_ClosedOnlySections[NumCyclesTemp][0] = rn_series[idex]
			FMS_ClosedOnlySections[NumCyclesTemp][1] = idex
			do	// we are at the start of a fast mode cycle.  first run should be closed
				idex+=1
			while (idex < num &&  fastMSRunWithinCycle[idex-1]< fastMSRunWithinCycle[idex] &&  fastKey[idex] ==2 )  // fastKey[idex] ==2 && ) 		//  1.53M
			idex-=1
			FMS_ClosedOnlySections[NumCyclesTemp][2] = rn_series[idex]
			FMS_ClosedOnlySections[NumCyclesTemp][3] = idex
			NumCyclesTemp+=1
		endif
		idex+=1
//		if (idex<num && (fastMSRunWithinCycle[idex]==0 || fastKey[idex]==2)  )
		if (idex<num &&  fastKey[idex]==2  )		// change for TimO may 2013
			idex-=1		// cuz we are gonna add 1 till it is checked again
		endif
	while (idex<num)


End


// Function called from within the pre-process code to deal with zeros
// no longer used 1.50E
Function fm_DoZeros(index_pos,paramstr,acorn,n_acorns)	// MJC 3/6/2009 in Montseny
    wave index_pos	// point nos in rn_series to act on			
    string paramstr	
    variable acorn,n_acorns
	
	wave MSClosed=$stringbykey("acorn_0",paramstr)  
	string ClosedType = StringByKey("FMS",paramstr)
	Variable n

	Make/o/n=(dimsize(MSClosed,1)) root:FMSTemp = nan
	Wave FMSTemp = root:FMSTemp
	for (n=0; n<numpnts(index_pos);n+=1)	
		FMSTemp = MSClosed[n][p]
		if (!sum(FMSTemp)) // if row of zeros
			MSClosed[n][] = NaN	// set to NaN
		endif
	endfor
	
	//1.14M  UMR
	squirrel_hdf_write(index_pos,MSClosed,ClosedType)        // uses squirrel infrastructure to write to the intermediate file
															// Function squirrel_hdf_write(index_pos,source,dataname)
End


//1.57D
// Function called from within the pre-process code to deal with zeros
//Function fm_DoNans(index_pos,paramstr,acorn,n_acorns)	// MJC 3/6/2009 in Montseny  // DTS edited in 1.50D
//    wave index_pos	// point nos in rn_series to act on			
//    string paramstr	
//    variable acorn,n_acorns
//	
//	wave ClosedSpectra = $stringbykey("acorn_0",paramstr)  
//	string closedType = stringbykey("closedType",paramstr)
//
//	wave series_index = root:index:series_index		// 
//	wave KeyWave = root:diagnostics:FastKey		// 0 when closed, 2 when open
//
//	ClosedSpectra = (KeyWave[series_index[index_pos[p]]] == 0 ? nan : ClosedSpectra[p][q] )		// if key wave is nan or 2 keep
//	
//	//1.14M  UMR
//	squirrel_hdf_write(index_pos,ClosedSpectra,ClosedType)       
//	
//End


//new in 1.50E
Function fm_butt_FastKeySeriesTable(ctrlName) : ButtonControl	
	String ctrlName
	DoWindow/F FastKeySeriesTable
	if (V_flag)
		return 0
	endif
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:diagnostics:
	wave fastKey,fastMSRunWithinCycle,fastMSTimeWithinCycle
	
	Edit/W=(5.25,42.5,446.25,242)/K=1/N=FastKeySeriesTable ::index:t_series,::index:rn_series,fastKey,fastMSRunWithinCycle as "FastKeySeriesTable"
	AppendToTable fastMSTimeWithinCycle
	ModifyTable format(Point)=1,width(Point)=38,format(::index:t_series)=8,width(::index:t_series)=99
	ModifyTable width(::index:rn_series)=53,width(fastKey)=41,width(fastMSRunWithinCycle)=89
	ModifyTable width(fastMSTimeWithinCycle)=95
	SetDataFolder fldrSav0
End

Function fm_butt_FastStartEndTable(ctrlName)  : ButtonControl	
	String ctrlName
	DoWindow/F FastStartEndTable
	if (V_flag)
		return 0
	endif
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:index:
	wave FMS_StartRuns,FMS_EndRuns,FMS_StartTypes,FMS_EndTypes, FMS_SlowRunBefore,FMS_SlowRunAfter,FMS_Extrapolate
	Edit/W=(95.25,315.5,658.5,439.25)/K=1/N=FastStartEndTable FMS_StartRuns,FMS_EndRuns,FMS_StartTypes,FMS_EndTypes as "FastStartEndTable"
	AppendToTable FMS_SlowRunBefore,FMS_SlowRunAfter,FMS_Extrapolate
	ModifyTable format(Point)=1,width(Point)=39,width(FMS_StartRuns)=49,width(FMS_EndRuns)=37
	ModifyTable width(FMS_StartTypes)=45,title(FMS_StartTypes)="start type:2=closed;0-open"
	ModifyTable width(FMS_EndTypes)=36,title(FMS_EndTypes)="end type:2=closed;0=open"
	ModifyTable width(FMS_SlowRunBefore)=72,width(FMS_SlowRunAfter)=77,width(FMS_Extrapolate)=98
	SetDataFolder fldrSav0
End

//new in 1.50E
Function fm_butt_FastClosedTable(ctrlName)  : ButtonControl	
	String ctrlName
	DoWindow/F FastClosedRegionsTable
	if (V_flag)
		return 0
	endif
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:index:
	wave FMS_ClosedCycles
	Edit/W=(197.25,175.25,615,449)/K=1/N=FastClosedRegionsTable FMS_ClosedCycles as "FastClosedRegionsTable"
	ModifyTable format(Point)=1
	SetDataFolder fldrSav0
End


// **************************** misc fast mode functions  *************************** 

// MJC's method of 'glueing' species waves from slow and fast mode.
// Functionality not currently accessible via any panel
// Constants in the ConvFactorList are unique to his experiment - Users need to adjust these values themselves!!!!!
Function fm_MergeFS()

	String TypeList = "Diff;Open;Closed"
	String UnitList = "ug;hz"
	String SpeciesList = "Org;NO3;SO4;NH4;Chl;Total"
	String ConvFactorList = "0.89;1;1;0.89;1;1"
	Variable type, unit, species, convfactor
	
	for (unit=0;unit<2;unit+=1)
		for (type=0;type<3;type+=1)
			for (species=0;species<ItemsInList(SpeciesList);species+=1)
				Wave SlowSource = $"root:"+StringFromList(species,specieslist)+"_SSQ"+StringFromList(unit,unitlist)+"_"+StringFromList(type,typelist)
				Wave FastSource = $"root:"+StringFromList(species,specieslist)+"_FSQ"+StringFromList(unit,unitlist)+"_"+StringFromList(type,typelist)
				Make/o/n=(numpnts(SlowSource)) $"root:"+StringFromList(species,specieslist)+"_SQ"+StringFromList(unit,unitlist)+"_"+StringFromList(type,typelist) = nan
				Wave Dest = $"root:"+StringFromList(species,specieslist)+"_SQ"+StringFromList(unit,unitlist)+"_"+StringFromList(type,typelist)
			//	print GetWavesDataFolder(dest,2)
				ConvFactor = str2num(StringFromList(species,convfactorlist))
				Dest = numtype(FastSource[p])==0 ? FastSource[p]/convfactor : SlowSource[p]
			endfor		
		endfor
	endfor

End


// For creating diagnostic values - the ratio of 40 to 28 for fast and slow
// Functionality not currently accessible via any panel
Function fm_Get40to28ratios()

	Wave mz40 = root:mz40_closed
	Wave mz28 = root:mz28_closed
	
	Wave mz40_fast = root:mz40_fast
	Wave mz40_slow = root:mz40_slow
	
	Duplicate/o mz40, root:mz40div28_closed
	Wave mz40div28_closed = root:mz40div28_closed
	mz40div28_closed /= mz28
	
	Duplicate/o mz40div28_closed, root:mz40div28_closedF, root:mz40div28_closedS
	Wave mz40div28_closedF = root:mz40div28_closedF
	Wave mz40div28_closedS = root:mz40div28_closedS
	
	mz40div28_closedF = numtype(mz40_fast[p]) == 0 ? mz40div28_closed : nan
	mz40div28_closedS = numtype(mz40_slow[p]) == 0 ? mz40div28_closed : nan
	
	Wavestats/q mz40div28_closedF
	print "// fast: "+num2str(V_avg)+", sd = "+num2str(V_sdev)+" from "+num2str(V_npnts)+" points"
	Variable n = v_avg
	Wavestats/q mz40div28_closedS
	print "// slow: "+num2str(V_avg)+", sd = "+num2str(V_sdev)+" from "+num2str(V_npnts)+" points"
	print "// Fast/Slow ratio = "+num2str(n/v_avg)

End

// Added in 1.57B
Constant fm_UseFastModeSettings = 1		// else do nothing and let fillblanks do everything
Constant fm_DoAv = 2					// else do not average fast closed
Constant fm_doReplaceAllAvg = 4			// else replace LAST fast closed with average		
Constant fm_doMzCalOnAvgs = 8			// else use m/z calibration panel for determination	
Constant fm_DoExtrap = 16				// else just used next (possibly slow) closed
Constant fm_doCopy = 32					// else interpolate fast closed across fast open

Function fm_setFmPreProcessWave(preproc, UseFastModeSettings, DoAv, doReplaceAllAvg, doMzCalOnAvgs, DoExtrap, doCopy)
wave preproc
variable  UseFastModeSettings, DoAv, doReplaceAllAvg, doMzCalOnAvgs, DoExtrap, doCopy

	wave FastKey = root:diagnostics:FastKey
	wave/z/u FastModePreProcessWave = root:diagnostics:FastModePreProcessWave
	
	variable val, num = numpnts(FastKey)
	
	if (!WaveExists(FastModePreProcessWave) )
		make/u/n=(num) 	root:diagnostics:FastModePreProcessWave/wave = FastModePreProcessWave
		FastModePreProcessWave=0
		string  wnote = "Constant fm_UseFastModeSettings = 1		// else do nothing and let fillblanks do everything\r"
		wnote +="fm_DoAv = 2					// else do not average fast closed\r"
		wnote +="fm_doReplaceAllAvg = 4			// else replace LAST fast closed with average\r"		
		wnote +="fm_doMzCalOnAvgs = 8			// else use m/z calibration panel for determination	\r"
		wnote +="fm_DoExtrap = 16				// else just used next (possibly slow) closed\r"
		wnote +="fm_doCopy = 32					// else interpolate fast closed across fast open\r"
		Note FastModePreProcessWave , wnote

	elseif ( num != numpnts(FastModePreProcessWave) )
		redimension/n=(num)FastModePreProcessWave
		FastModePreProcessWave[num,]=-1
	endif
	make/free/o/n=(num) maskTemp
	sq_makeMaskFromTodofindRun(maskTemp,preproc)
	val = UseFastModeSettings*fm_UseFastModeSettings + DoAv*fm_DoAv + doReplaceAllAvg*fm_doReplaceAllAvg + doMzCalOnAvgs*fm_doMzCalOnAvgs + DoExtrap*fm_DoExtrap + doCopy*fm_doCopy
	FastModePreProcessWave = (maskTemp[p] == 1 & numtype(FastKey[p])== 0) ?   val : FastModePreProcessWave[p]
	
end


// Added in 1.47D
// squirrel_fetch(all,squirrel_FromMemToHDF,"WaveName:MSSDiff_p;PutInMemory:0","MSSDiff_p")
Function sq_FromMemToHDF(index_pos,paramstr,acorn,n_acorns) // The format of a squirrel fetch function
	wave index_pos //& 1D wave of positions in 'run_index' that are being operated on
	string paramstr //& Keyword-identified parameter string
	variable acorn //& Number of the 'acorn' being passed
	variable n_acorns //& The total number of 'acorns' that will be passed

	string WaveNameStr=stringbykey("WaveName",paramstr)		
	variable PutInMemory=numberbykey("PutInMemory",paramstr)	
	wave source=$stringbykey("acorn_0",paramstr)		//^ InfoVal
	string tempStr
	if (PutInMemory)
		squirrel_mem_write(index_pos,source,WaveNameStr,WaveNameStr)
	else
		//1.14M  not applicable to expand
		squirrel_hdf_write(index_pos,source,WaveNameStr)
		if (acorn == n_acorns-1)
			wave w = $"root:"+WaveNameStr
			Killwaves/z w
			tempStr = gen_FindWaveInTableGraph(waveNameStr, "root:")
			if (strlen(tempStr)>0)
				print "// The wave "+wavenamestr+" was attempted to be killed but these windows currently use it: "+tempStr
			endif
		endif
	endif	
	
End


// Added in 1.47D
Function sq_butt_transferMSSDiffpToHDF(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	string tempStr = ""
	Wave/z MSSDiff_p_err = root:MSSDiff_p_err
	Wave/z MSSClosed_p_err = root:MSSClosed_p_err		//1.49B 
	
	tempStr = selectString( WaveExists(MSSDiff_p_err), " and MSSDiff_p_err", "")
	tempStr += selectString( WaveExists(MSSClosed_p_err), " and MSSClosed_p_err", "")

	wave squirrel_index = root:index:squirrel_index
	wave/z MSSDiff_p = root:MSSDiff_p
	nvar/z PutInMemory = root:panel:PutInMemory		// not used yet.  Perhaps it will be used when we enable a reverse process - going from intermediate to mem?

	if (!WaveExists(MSSDiff_p) && FindDimLabel(squirrel_index, 2, "MSSDiff")>=0 )
		abort "The matrix MSSDiff_p appears to have been moved to an intermediate file already. Aborting from sq_butt_transferMSSDiffpToHDF"
	endif
	
	DoAlert 1, "!! You are about to put the MSSDiff_p "+tempStr+"  into an intermediate hdf file to free up RAM. This operation will use the all todo wave. Press Yes to continue, No to abort."
	
	wave all = root:all
	if (V_flag==1)
		squirrel_fetch(all,sq_FromMemToHDF,"WaveName:MSSDiff_p;PutInMemory:0","MSSDiff_p")
		if (WaveExists(MSSDiff_p_err))
			squirrel_fetch(all,sq_FromMemToHDF,"WaveName:MSSDiff_p_err;PutInMemory:0","MSSDiff_p_err")
		endif
		if (WaveExists(MSSClosed_p_err))
			squirrel_fetch(all,sq_FromMemToHDF,"WaveName:MSSClosed_p_err;PutInMemory:0","MSSClosed_p_err")
		endif
		variable/g root:panel:PutInMemory=0
		DoAlert 0, "The movement of the MSSDiff_p"+tempStr+" from memory to an intermediate HDF was successful" 
		print "// The movement of the MSSDiff_p"+tempStr+" from memory to an intermediate HDF was successful on "+ date() + " " + time()
		SaveExperiment		// 
	else
		Abort "You chose to stop this operation. Aborting from sq_butt_transferMSSDiffpToHDF" 
	endif

End

// general purpose function that removes any spaces in list of text waves // new in 1.47F used to clean up frag waves
Function gen_removeSpacesTextWaves(DataFolderStr, WaveStr)
string DataFolderStr, WaveStr

	variable idex, num
	string DFtemp, tempList
	
	DFtemp = GetDataFolder(1)
	SetDataFolder DataFolderStr
	tempList = WaveList("*"+WaveStr+"*", ";", "")
	num = itemsInList(tempList)
	for (idex=0;idex<num;idex+=1)
		wave/t textW = $stringFromList(idex, tempList)
		textW =replaceString(" ", textW[p], "")
	endfor

	SetDataFolder DFtemp

End


// a generic function for finding out what graphs or tables may be using a specific wave (so if one wants to kill it, it is truly killed)
// returns the a list of the names of graphs and tables that use the wave.
Function/s gen_FindWaveInTableGraph(waveNameStr, dataFolderStr)
string waveNameStr, dataFolderStr

	string  allWin, WinStr, allWav, wavStr, DFStr, returnStr
	variable idex, numWin, jdex, numWav

	allWin = WinList("*", ";", "WIN:3")		// 
	numWin=itemsinList(allWin)
	returnStr =""
	
	for(idex=0;idex<numWin;idex+=1)
		WinStr = stringfromlist(idex, allWin)
		jdex=0
		do
			wave/z w = WaveRefIndexed(WinStr, jdex, 1)
			if (WaveExists(w) && stringmatch(NameofWave(w), waveNameStr) && stringmatch(dataFolderStr, GetWavesDataFolder(w,1) )	 )
				returnStr+=WinStr+";"
			endif
			jdex+=1	
		while(WaveExists(w))
				
	endfor
	
	return returnStr
	
End


// squirrel fetch function to extract any entry form parval or infoval.
// is totally flexible as to what values are extracted and where the results go
// presumes a correct and complet get index has already been perfomred.
//usage:
//		squirrel_fetch(all,sq_getNewDiagValuesList,"dataFolderStr:diagnostics;colList:2/4;destList:ParVal2/parVal4","ParVal;")

Function sq_getNewDiagValuesList(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn
	variable n_acorns
	
	wave source=$stringbykey("acorn_0",paramstr)		//^ InfoVal or parVal.  Note that it doesn't work for runInfo
	string colList = stringbykey("colList",paramstr)
	string destList = stringbykey("destList",paramstr)
	string dataFolderStr = stringbykey("dataFolderStr",paramstr)

	wave t_series=root:index:t_series
	wave series_index=root:index:series_index
	
	variable idex, num, numTime, pdex, numRows, pt, numSourceCol, ColDex
	string diagStr
	
	numSourceCol = dimsize(source,1)
	numTime = numpnts(t_series)
	num = itemsInList(colList, "/")
	numRows = numpnts(index_pos)

	if (strLen(dataFolderStr) == 0 || stringMatch("root:",dataFolderStr )  || stringMatch("root",dataFolderStr )  )
		dataFolderStr ="root:"		// not needed again, set in case it may be
		SetDataFolder root:
	elseif( DataFolderExists(dataFolderStr) )		//1.53F
		SetDataFolder $dataFolderStr
	elseif (DataFolderExists("root:"+dataFolderStr) )
		SetDataFolder $"root:"+dataFolderStr
	elseif ( !DataFolderExists(dataFolderStr) )
		if(CheckName(dataFolderStr, 11)!=0 )		//1.53E
			abort "The name of the data folder you want to use, "+dataFolderStr+" has problems.  Aborting from sq_getNewDiagValuesList"
		endif	
		NewDataFolder/o/s $dataFolderStr	//1.53F
	endif

	if (acorn == 0)
		// create dest waves, do some sanity checks	
		if (num != itemsInList(destList, "/") )
			abort "There is something wrong with the column list: "+colList+" and the destination list: "+destList +" aborting from sq_getDiagList"
		endif

		for (idex=0;idex<num;idex+=1)
			diagStr = stringFromList(idex, destList, "/")
			diagStr = CleanUpName(diagStr, 0)
			make/d/o/n=(numTime) $diagStr	=nan	// make by default single precision, nan.
			// check that the value in ColList is valid
			ColDex = str2num( stringFromList(idex, colList, "/") )
			if ( ! (ColDex < numSourceCol) )
				setdatafolder root:
				abort "Strange column number value of "+stringFromList(idex, colList, "/")+ " aborting from sq_getDiagList"
			endif
			
//			edit $diagStr
		endfor	
	endif
	
	for (idex=0;idex<num;idex+=1)
		diagStr = stringFromList(idex, destList, "/")		// redundant, am a bit lazy
		diagStr = CleanUpName(diagStr, 0)
		wave DiagWave = $diagStr
		ColDex = str2num( stringFromList(idex, colList, "/") )
		for (pdex=0;pdex<numRows;pdex+=1)
			pt=series_index[index_pos[pdex]]
			DiagWave[pt] = source[pdex][ColDex]
		endfor
	endfor	
	
	setDataFolder root:
	
End


// 1.47I  change from old scheme.  Currently users never use root:diagnostics:TimePTOFSec
// Sample usage:
// squirrel_fetch(all, sq_recalcTimePTOFSec, "", "InfoVal;ParVal")
Function sq_recalcTimePTOFSec(index_pos,paramstr,acorn,n_acorns)
	wave index_pos
	string paramstr
	variable acorn
	variable n_acorns
	
	wave source0=$stringbykey("acorn_0",paramstr)		//^ InfoVal
	wave source1=$stringbykey("acorn_1",paramstr)		//^ ParVal

	wave series_index = root:index:series_index
	variable p1,idex, num
 
	make/o/n=(numpnts(series_index)) root:diagnostics:TimePTOFSec =nan
	wave TimePTOFSec = root:diagnostics:TimePTOFSec
	num = numpnts(index_pos)
	for(idex = 0;idex<num;idex+=1)
		p1=series_index[index_pos[idex]]
		//	Old, bad formulation.  New way to do things (10/2009 discussions with Jose) is given below		//1.47I
		//	dest[p1]=source0[idex][10]*source1[idex][10]*source1[idex][4]*source1[idex][12]*1e-6
		// t_ptof = (# times through PToF) * (# choppers/time through PToF) * (time/chopper)
		// where time/chopper = (# bins) * (# coadds) * (time/spectrum) * 10e-6   = sec   
		//= Info [10] * Par[10] * Info [16] * Info [14] * par[4] (is in us)] * 10e-6
	 	TimePTOFSec[p1]=source0[idex][10]*source1[idex][10]*source0[idex][16]*source0[idex][14]*source1[idex][4]*1e-6
	endfor
	
End

// returns a string containing the RGB color values of a species.  I.e "org" returns " , , "
Function/S sq_getColorString(species, sqFlag)
string species
variable sqFlag

	string returnStr
	variable pos

	switch (sqFlag)
	case 1:
		wave/T col_names = $"root:frag:Col_names"
		wave Col_R = $"root:frag:Col_R"
		wave Col_G = $"root:frag:Col_G"
		wave Col_B = $"root:frag:Col_B"
		break
	case 2:
		wave/T col_names = $"root:HR:HR_familyName"
		wave Col_R = $"root:HR:HR_family_R"
		wave Col_G = $"root:HR:HR_family_G"
		wave Col_B = $"root:HR:HR_family_B"
		break
	case 3:
		wave/T col_names = $"root:frag:HR_specCorr_list"
		wave Col_R = $"root:HR_frag:HR_specCorr_R"
		wave Col_G = $"root:HR_frag:HR_specCorr_G"
		wave Col_B = $"root:HR_frag:HR_specCorr_B"
	endswitch
	
	pos = sq_findStr(col_names,species,1)
	
	if (pos>=0)		// we have a match
		returnStr = num2str(Col_R[pos]) + "," +num2str(Col_G[pos]) + "," +num2str(Col_B[pos]) 
	else
		returnStr = "1,1,1"
	endif
	
	return returnStr
	
End


// added in 1.48F
Function sq_butt_sortedOrgPlot(ctrlName) : ButtonControl
	String ctrlName

	string OrgWaveStr, wName
	
	setDataFolder root:
	wName=WinName(0,1)
	
	OrgWaveStr = WaveList("*org", ";", "WIN:" )
	
	if (itemsinList(OrgWaveStr)>1)
		abort "There is more than one Org wave in this graph:"+OrgWaveStr+"  aborting from sq_butt_sortedOrgPlot"
	endif
	OrgWaveStr=OrgWaveStr[0, strlen(OrgWaveStr)-2]
	wave OrgWave = $OrgWaveStr

	duplicate/o OrgWave  $OrgWaveStr+"sort_val", $OrgWaveStr+"sort_mz", $OrgWaveStr+"sort_cum"
	wave OrgWaveSort = $OrgWaveStr+"sort_val"
	wave OrgWaveMz = $OrgWaveStr+"sort_mz"
	wave OrgWaveCum = $OrgWaveStr+"sort_cum"
	OrgWaveMz=p+1
	sort/R OrgWaveSort, OrgWaveSort, OrgWaveMz
	OrgWaveCum = sum(OrgWaveSort, 0, p)/sum(OrgWaveSort)

	DoWindow/F $wName+"_OrgSort"
	if (V_flag==1)
		return 0
	endif
	
	PauseUpdate; Silent 1		// building window...
	Display /W=(200,100,600,400) OrgWaveSort,OrgWaveSort
	AppendToGraph/R OrgWaveCum
	ModifyGraph mode($NameOfWave(OrgWaveSort))=1,mode($NameOfWave(OrgWaveSort)+"#1")=3,mode($NameOfWave(OrgWaveCum))=4
	ModifyGraph marker($NameOfWave(OrgWaveCum))=19
	ModifyGraph lSize($NameOfWave(OrgWaveSort))=2
	ModifyGraph rgb($NameOfWave(OrgWaveSort))=(0,39168,19712),rgb($NameOfWave(OrgWaveCum))=(0,0,0)
	ModifyGraph msize($NameOfWave(OrgWaveCum))=1
	ModifyGraph offset($NameOfWave(OrgWaveSort)+"#1")={0,0.001}
	ModifyGraph textMarker($NameOfWave(OrgWaveSort)+"#1")={$NameOfWave(OrgWaveMz),"default",0,0,5,0.00,0.00}
	ModifyGraph grid(right)=2
	ModifyGraph zero(left)=1
	ModifyGraph nticks(right)=9
	ModifyGraph gridRGB(right)=(34816,34816,34816)
	Label left "Org signal"
	Label right "Fraction of Org"
	SetAxis bottom -1,50
	SetAxis/A/E=1 right
	ShowInfo
	
End

// *************************export for AMS data base code

// sets globals for  export to data base panel
Function sq_exportForDataBaseGlobals()

	if ( datafolderexists( "root:ExportForDataBase" ) != 1 )
		newdatafolder root:ExportForDataBase
	endif
	
	// bottom progress region
	sq_initializeGlobalSVar("root:ExportForDataBase:FilePath", "")		// i.e.  Desktop
	sq_initializeGlobalSVar("root:ExportForDataBase:FileName", "X_T_xxxx_yyyy")		// myfilename
	sq_initializeGlobalSVar("root:ExportForDataBase:FileNamePrefix", "X")		// myfilename
	sq_initializeGlobalSVar("root:ExportForDataBase:ExportSourceType", "")	//ambient (A_*_xxx)
	sq_initializeGlobalSVar("root:ExportForDataBase:SpeciesList", "Org")	//Org
	sq_initializeGlobalSVar("root:ExportForDataBase:SourceStr", "yyyy")		// i.e. Burning Oak
	sq_initializeGlobalSVar("root:ExportForDataBase:ExperimentorStr", "your name")		// i.e.GradStudentName
	sq_initializeGlobalSVar("root:ExportForDataBase:GroupStr", "i.e. Jimenez Group, Colorado-Boulder")		// i.e.Jimenez Group, University of Colorado, Boulder 
	sq_initializeGlobalSVar("root:ExportForDataBase:AMSTypeStr", "")		// i.e. C
	sq_initializeGlobalSVar("root:ExportForDataBase:CitationUrl", "i.e. http://direct.sref.org/xxxx-yyyy/acp/2009-x-yyyy")		// JGR etc
	sq_initializeGlobalSVar("root:ExportForDataBase:CitationStr", "i.e. ACP, 2009, Vol.x, pp. yyy, SRef-ID: xxx")		// JGR etc
	sq_initializeGlobalSVar("root:ExportForDataBase:CitationFigStr", "Fig #(s)")	// Fig 3.a
	sq_initializeGlobalSVar("root:ExportForDataBase:CommentsStr", "location, date, field project, misc info")	// This is good data
	sq_initializeGlobalNVar("root:ExportForDataBase:EIEnergy", 70)		// 70 EI volts
	sq_initializeGlobalNVar("root:ExportForDataBase:VaporizerTempC", 600)	// 600 C
	sq_initializeGlobalNVar("root:ExportForDataBase:maxmz", 300)	// 300 is default
	sq_initializeGlobalNVar("root:ExportForDataBase:CreateSuppl", 1)	// create by default
	
	sq_initializeGlobalNVar("root:ExportForDataBase:UMRorHR", 1)	// create by default

	svar ExportSourceType = root:ExportForDataBase:ExportSourceType			
	ExportSourceType ="source (S_*_xxx_yyyy);"
	ExportSourceType +="ambient (A_*_xxx_yyyy);"
	ExportSourceType +="ambient deconvolved (A_DEC_*_xxx_yyyy);"
	ExportSourceType +="laboratory standards (L_STD_*_xxx_yyyy);"
	ExportSourceType +="laboratory SOA (L_SOA_*_xxx_yyyy);"
	ExportSourceType +="laboratory HOP (L_HOP_*_xxx_yyyy;"
	ExportSourceType +="laboratory other (L_OTH_*_xxx_yyyy);"
	
End


// creates a new AMS Data base export tool panel
Function sq_butt_exportDBPanel(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	DoWindow/F AMSDataBaseExport
	if (V_flag==1)
		return 0
	endif
	sq_exportForDataBaseGlobals()
	
	NewPanel/N=AMSDataBaseExport /W=(92,168,527,688) as "AMSDataBaseExport"
	ShowTools/A
	SetDrawLayer UserBack
	SetDrawEnv fsize= 16,fstyle= 1
	DrawText 5,23,"AMS Spectral Database Export Tool 1.1"
	SetDrawEnv fsize= 9
	DrawText 5,39,"This tool helps create an average mass spectra & export it as an Igor itx file."
	Button buttonUMRDB,pos={350,0},size={80,20},proc=sq_URLButton,title="UMR Database"
	Button buttonHRDB,pos={352,23},size={80,20},proc=sq_URLButton,title="HR Database"
	Button buttonUMRhelp,pos={309,45},size={60,20},proc=sq_URLButton,title="UMR wiki"
	Button buttonHRhelp,pos={372,45},size={60,20},proc=sq_URLButton,title="HR wiki"

	CheckBox checkHR,pos={142,54},size={93,14},proc=sq_exportDBUMRorHR,title="HR (pika sticks)"
	CheckBox checkHR,value= 0,mode=1
	CheckBox checkUMR,pos={10,54},size={115,14},proc=sq_exportDBUMRorHR,title="UMR (squirrel sticks)"
	CheckBox checkUMR,value= 1,mode=1
	nvar UMRorHR=root:ExportForDataBase:UMRorHR
	UMRorHR=1
	
	GroupBox group0,pos={4,221},size={423,165},title="Meta data",fColor=(1,1,1)
	PopupMenu ams_todolist_pop,pos={20,77},size={145,21},bodyWidth=120,proc=sq_exportDBToDo,title="Create avg spectra from this todo"
	PopupMenu ams_todolist_pop,fSize=10
	PopupMenu ams_todolist_pop,mode=6,popvalue="Get List",value= #"root:panel:sq_toDoList+\"Get List;\"\t"
	SetVariable setvarAMSType,pos={300,78},size={80,16},title="AMS Type"
	SetVariable setvarAMSType,value= root:ExportForDataBase:AMSTypeStr
	SetVariable setvarSpecies,pos={5,101},size={415,16},title="Species (i.e. Org, SO4. Leave blank HR)"
	SetVariable setvarSpecies,value= root:ExportForDataBase:SpeciesList
	SetVariable setvarmaxmz,pos={5,125},size={410,16},title="Trim data to this max. m/z (it is rare to include > 300 m/z for the data base)"
	SetVariable setvarmaxmz,value= root:ExportForDataBase:maxmz
	PopupMenu popupSigType,pos={5,147},size={330,21},proc=sq_exportDBSigType,title="Source Signal Type"
	PopupMenu popupSigType,mode=4,popvalue="Get List",value= #"root:ExportForDataBase:ExportSourceType"
	SetVariable setvarsource,pos={5,174},size={380,16},proc=sq_exportDBSource,title="Source (i.e. OleicAcid, 30 character max)"
	SetVariable setvarsource,value= root:ExportForDataBase:SourceStr
	SetVariable setvarFname,pos={5,194},size={425,16},title="File Name (updates with user selections; '.itx' will be appended)"
	SetVariable setvarFname,value= root:ExportForDataBase:FileName
	SetVariable setvarVT,pos={10,239},size={170,16},title="Vaporizer Temp. (Deg. C)"
	SetVariable setvarVT,value= root:ExportForDataBase:VaporizerTempC
	SetVariable setvarEI,pos={206,239},size={110,16},title="EI Energy (eV)"
	SetVariable setvarEI,value= root:ExportForDataBase:EIEnergy
	SetVariable setvarContributor,pos={10,259},size={410,16},title="Experimenter Name"
	SetVariable setvarContributor,value= root:ExportForDataBase:ExperimentorStr
	SetVariable setvarpi1,pos={10,280},size={410,16},title="Group/Institution"
	SetVariable setvarpi1,value= root:ExportForDataBase:GroupStr
	SetVariable setvarcit,pos={10,301},size={410,16},title="Citation"
	SetVariable setvarcit,value= root:ExportForDataBase:CitationStr
	SetVariable setvarcit1,pos={10,321},size={410,16},title="Citation url"
	SetVariable setvarcit1,value= root:ExportForDataBase:CitationUrl
	SetVariable setvarfig,pos={10,342},size={200,16},title="Citation Fig #"
	SetVariable setvarfig,value= root:ExportForDataBase:CitationFigStr
	SetVariable setvarcom,pos={10,363},size={410,16},title="Comments"
	SetVariable setvarcom,value= root:ExportForDataBase:CommentsStr
	Button buttonfloc,pos={10,397},size={120,20},proc=sq_butt_exportDBPath,title="Select File Location"
	Button buttonCreateFile,pos={10,471},size={150,20},proc=sq_butt_exportDBCreateFile,title="Create data base file"
	Button buttonCreateFile,fColor=(65280,43520,0)
	Button button0,pos={10,493},size={320,20},proc=sq_butt_exportMailToML,title="Maill newly created files(s) to Philip.Handley@colorado.edu"  //1.55G
	SetVariable setvarfloc,pos={10,420},size={410,16},title="File Location"
	SetVariable setvarfloc,value= root:ExportForDataBase:FilePath
	CheckBox check_suppliment,pos={10,441},size={358,14},title="Create a supplemental file also (with the name *_supp.itx, recommended)"
	CheckBox check_suppliment,variable= root:ExportForDataBase:CreateSuppl
		
End

// create the data base file
Function sq_exportSaveFileDB()

	svar todoStr=root:panel:sq_toDoWvNm
	svar FileName = root:ExportForDataBase:FileName
	nvar maxmz = root:ExportForDataBase:maxmz
	nvar CreateSuppl = root:ExportForDataBase:CreateSuppl
 	
 	svar SpeciesList = root:ExportForDataBase:SpeciesList  //="NO3,SO4,Org,NH4,Chl,PAH"
	svar SourceStr=root:ExportForDataBase:SourceStr		//1.08E

	string sourceTempStr = SourceStr[0, min(9, strlen(SourceStr)-1)]
	wave/t DBInfo = $"root:ExportForDataBase:DBInfo_"+sourceTempStr

	variable idex, num, pos, fileId
	string wList, species, EndingCode=""

	Save/B/O/T/M="\r\n"/P=ExportDBPath "root:ExportForDataBase:DBInfoDesc_"+sourceTempStr+";root:ExportForDataBase:DBInfo_"+sourceTempStr  as FileName+".itx"		// overwrites if it already exists
		
	if  (strlen(SpeciesList)==0)
		SpeciesList="all"
	endif

	num = itemsInList(SpeciesList, ",")
	
	// diff sticks
	wList = "root:ExportForDataBase:amu_wave_"+sourceTempStr+";"
	wave amu_wave = $"root:ExportForDataBase:amu_wave_"+sourceTempStr
	DeletePoints maxmz-1, 1e7, amu_wave
	Save/A/T/M="\r\n"/P=ExportDBPath/B wList as FileName+".itx"
	for(idex=0;idex<num;idex+=1)		// go through each species in list
		species=stringFromList(idex, SpeciesList, ",")
		
		wave DiffStick = $"root:ExportForDataBase:DiffStick_"+species+"_"+sourceTempStr
		if (numpnts(DiffStick)>maxmz-1)	// original data extended out beyond maxmz
			DeletePoints maxmz-1, 1e7, DiffStick
		endif
		wList= GetWavesDataFolder(DiffStick, 2)+";"
		Save/A/T/M="\r\n"/P=ExportDBPath/B wList as FileName+".itx"
	
	endfor
	
	// now save code at the end of file to automatically display spectra
	EndingCode="X Display /W=(260,130,660,330) \r\n" 
	for(idex=0;idex<num;idex+=1)		// go through each species in list
		species=stringFromList(idex, SpeciesList, ",")
		EndingCode+="X AppendtoGraph DiffStick_"+species+"_"+sourceTempStr+" vs amu_wave_"+sourceTempStr+" \r\n"
		EndingCode+="X ModifyGraph rgb(DiffStick_"+species+"_"+sourceTempStr+")=("+sq_getColorString(species,1)+") \r\n"
	endfor
	EndingCode+="X ModifyGraph mode=1 \r\n"
	EndingCode+="X ModifyGraph toMode=3 \r\n"
	EndingCode+="X Label bottom \"m/z\" \r\n"
	EndingCode+="X ModifyGraph lsize=2 \r\n"
	EndingCode+="X legend \r\n"		//1.49E
	
	EndingCode+="X Edit/W=(5.25,42.5,450.75,370.25) DBInfoDesc_"+sourceTempStr+",DBInfo_"+sourceTempStr+" \r\n"			//1.49E
	EndingCode+="X ModifyTable format(Point)=1,width(DBInfoDesc_"+sourceTempStr+")=134,width(DBInfo_"+sourceTempStr+")=144 \r\n"

	Open/A/P=ExportDBPath fileId as FileName+".itx" 
	fprintf fileId, "%s", EndingCode
	Close fileID
	
	if (CreateSuppl)
	
		// deal with InfoVal, ParVal		
		wave/t InfoValText = $"root:ExportForDataBase:InfoValText_"+sourceTempStr
		wave/t ParValText = $"root:ExportForDataBase:ParValText_"+sourceTempStr
		wave InfoVal = $"root:ExportForDataBase:InfoVal_"+sourceTempStr
		wave ParVal = $"root:ExportForDataBase:ParVal_"+sourceTempStr
		wList =GetWavesDataFolder(InfoValText, 2)+";"+GetWavesDataFolder(ParValText, 2)+";"+GetWavesDataFolder(InfoVal, 2)+";"+GetWavesDataFolder(ParVal, 2)+";"
				
		if(FindDimLabel(root:index:squirrel_index, 2, "ComParVal")>=0)
			wave/t ComParValText = $"root:ExportForDataBase:ComParValText_"+sourceTempStr
			wave ComParVal = $"root:ExportForDataBase:ComParVal_"+sourceTempStr
			wList +=GetWavesDataFolder(ComParValText, 2)+";"+GetWavesDataFolder(ComParVal, 2)+";" 
		endif
		
		Save/O/T/M="\r\n"/P=ExportDBPath/B wList as FileName+"_supp.itx"
		
		//  deal with closed sticks
		wave amu_wave = $"root:ExportForDataBase:amu_wave_"+sourceTempStr			// created above	
		wList = "root:ExportForDataBase:amu_wave_"+sourceTempStr+";"
		Save/A/T/M="\r\n"/P=ExportDBPath/B wList as FileName+"_supp.itx"
		for(idex=0;idex<num;idex+=1)		// go through each species in list
			species=stringFromList(idex, SpeciesList, ",")
			wave ClosedStick = $"root:ExportForDataBase:ClosedStick_"+species+"_"+sourceTempStr	
			if (numpnts(ClosedStick)>maxmz-1)	// original data extended out beyond maxmz
				DeletePoints maxmz-1, 1e7, ClosedStick
			endif
			wList = "root:ExportForDataBase:ClosedStick_"+species+"_"+sourceTempStr+";"
			Save/A/T/M="\r\n"/P=ExportDBPath/B wList as FileName+"_supp.itx"
		endfor
	
	 	// raw spectra
	 	wave RawSpectraDiffMz = $"root:ExportForDataBase:RawSpectraDiffMz_"+sourceTempStr
	 	wave RawSpectraClosedMz = $"root:ExportForDataBase:RawSpectraClosedMz_"+sourceTempStr
	 	wave RawSpectraDiff = $"root:ExportForDataBase:RawSpectraDiff_"+sourceTempStr
	 	wave RawSpectraClosed = $"root:ExportForDataBase:RawSpectraClosed_"+sourceTempStr
	
		pos=BinarySearch(RawSpectraClosedMz,maxmz)
		if (pos>0)
			DeletePoints pos+1, 100000, RawSpectraDiffMz, RawSpectraClosedMz, RawSpectraClosed, RawSpectraDiff
		endif
		
		wList = "root:ExportForDataBase:RawSpectraDiffMz_"+sourceTempStr+";root:ExportForDataBase:RawSpectraClosedMz_"+sourceTempStr+";"
		wList +="root:ExportForDataBase:RawSpectraClosed_"+sourceTempStr+";root:ExportForDataBase:RawSpectraDiff_"+sourceTempStr+";"
		Save/A/T/M="\r\n"/P=ExportDBPath/B wList as FileName+"_supp.itx"
	
		EndingCode="X Display /W=(260,130,660,330) \r\n" 
		for(idex=0;idex<num;idex+=1)		// go through each species in list
			species=stringFromList(idex, SpeciesList, ",")
			EndingCode+="X AppendtoGraph ClosedStick_"+species+"_"+sourceTempStr+" vs amu_wave_"+sourceTempStr+" \r\n"
			EndingCode+="X ModifyGraph rgb(ClosedStick_"+species+"_"+sourceTempStr+")=("+sq_getColorString(species,1)+") \r\n"
		endfor
		EndingCode+="X ModifyGraph mode=1 \r\n"
		EndingCode+="X ModifyGraph toMode=3 \r\n"
		EndingCode+="X Label bottom \"m/z\" \r\n"
		EndingCode+="X ModifyGraph lsize=2 \r\n"
		EndingCode+="X legend \r\n"		//1.49E

		EndingCode+="X Display /W=(260,130,660,330) \r\n" 
		EndingCode+="X AppendtoGraph RawSpectraClosed_"+sourceTempStr+" vs RawSpectraClosedMz_"+sourceTempStr+" \r\n"
		EndingCode+="X ModifyGraph rgb(RawSpectraClosed_"+sourceTempStr+")=(1,1,1) \r\n"
		EndingCode+="X AppendtoGraph RawSpectraDiff_"+sourceTempStr+" vs RawSpectraDiffMz_"+sourceTempStr+" \r\n"
		EndingCode+="X ModifyGraph rgb(RawSpectraDiff_"+sourceTempStr+")=(65280,0,0) \r\n"
		EndingCode+="X Label bottom \"m/z\" \r\n"
		EndingCode+="X legend \r\n"		//1.49E

		Open/A/P=ExportDBPath fileId as FileName+"_supp.itx"
		fprintf fileId, "%s", EndingCode
		Close fileID
	endif		
	
	if (stringmatch("all", SpeciesList) )
		SpeciesList=""
	endif

	PathInfo ExportDBPath
	
	print "// On  "+time() +" "+date()+" the file "+FileName+".itx "+selectstring(CreateSuppl, "","and supppliment file ")+"has been created for submission to the AMS data base at "+S_path
	
End


// creates average raw and stick, closed and diff spectra in anticipation of writing these waves to an igor text file.
Function sq_exportForDataBase() 

	svar todoStr=root:panel:sq_toDoWvNm

 	svar ms0_specList = root:panel:ms0_specList
	nvar ms0_graphOutputType= root:panel:ms0_graphOutputType
	nvar ms0_AvGraphType= root:panel:ms0_AvGraphType
	nvar ms0_dataType= root:panel:ms0_dataType

	nvar ms0_ion2mass= root:panel:ms0_ion2mass
	nvar ms0_corr = root:panel:ms0_corr
	nvar ms0_appendErrorBars = root:panel:ms0_appendErrorBars
	nvar ms0_msTseries_suffix_ck = root:panel:ms0_msTseries_suffix_ck
	nvar ms0_ck_trunc2zero = root:panel:ms0_ck_trunc2zero

	nvar CreateSuppl = root:ExportForDataBase:CreateSuppl	
 	svar speciesList = root:ExportForDataBase:speciesList
	svar SourceStr=root:ExportForDataBase:SourceStr
 	
	string paramstr, species,sourceTempStr, dataStr
	variable idex, num
	
	sourceTempStr = SourceStr[0, min(9, strlen(SourceStr)-1)]

	num = itemsinList(SpeciesList, ",")
	// an unhappy compromise for updating popmenus on the main squirrel panel - keep the old values!
	variable old_ms0_graphOutputType, old_ms0_AvGraphType, old_ms0_dataType
	old_ms0_graphOutputType=ms0_graphOutputType
	old_ms0_AvGraphType=ms0_AvGraphType
	old_ms0_dataType=ms0_dataType
	
	wave todo =$"root:"+todoStr
	if (sq_OnlyOneModeInTodo(todo)!=1 )
		abort  "Cannot do mass averaging on a todo wave with different modes (v and w switching) - Aborting from sq_exportForDataBase"
	endif

 	if (!exists("root:diagnostics:corr_fact"))
 		abort "The standard methodology is to use the AB correction factor corr_fact, but this wave has not been created.  aborting from sq_exportForDataBase"
 	endif
 	
  	ms0_specList =speciesList	//"NO3,SO4,Org,NH4,Chl,PAH"
	ms0_speclist = replaceString(" ",ms0_speclist,"")
	ms0_graphOutputType =5		// do nothing
	ms0_ion2mass = 1
	ms0_corr = 1	
	ms0_appendErrorBars = 0	
	ms0_msTseries_suffix_ck = 0
	ms0_ck_trunc2zero = 0
	
//1.57C
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	dataStr= stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu

 	// Diff
 	if (! stringmatch(dataStr, "MSSDiff_p") )
 		abort "The typical data set for the data base is MSSDiff. Please reselect your data type.  Aborting from sq_exportForDataBase."
		//  ms0_dataType=1		// Diff
	endif
	sq_MSCalcPlot_Avg(sourceTempStr, "")
	for(idex=0;idex<num;idex+=1)		// go through each species in list
		species=stringFromList(idex, SpeciesList, ",")
		wave DiffStick = $"root:MSSD_"+sourceTempStr+"_"+species
		duplicate/o  DiffStick $"root:ExportForDataBase:DiffStick_"+species+"_"+sourceTempStr
		// the first species will also have an amu_wave
		if (idex==0)
			duplicate/o DiffStick $"root:ExportForDataBase:amu_wave_"+sourceTempStr
			wave amu_wave = $"root:ExportForDataBase:amu_wave_"+sourceTempStr		
			amu_wave = p+1
		endif	
	endfor

	if (CreateSuppl)
		// First do closed sticks
		ms0_AvGraphType = 1	// sticks
	 	ms0_dataType= WhichListItem("Closed", MSStickList) // 3		// Closed

		sq_MSCalcPlot_Avg(sourceTempStr, "")
		for(idex=0;idex<num;idex+=1)		// go through each species in list
			species=stringFromList(idex, SpeciesList, ",")
			wave ClosedStick = $"root:MSSC_"+sourceTempStr+"_"+species
			duplicate/o  ClosedStick $"root:ExportForDataBase:ClosedStick_"+species+"_"+sourceTempStr
			// the first species will also have an amu_wave
			if (idex==0)
				duplicate/o  ClosedStick $"root:ExportForDataBase:amu_wave_"+sourceTempStr
				wave amu_wave = $"root:ExportForDataBase:amu_wave_"+sourceTempStr		
				amu_wave = p+1
			endif	
		endfor
	
		// raw spectra
		sq_exportForDBRawSpectra() 

		//1.48H  Jose wanted to also dump the parVal, InfoVal and possibly ComParVal values.  Will do this for the first run in the todo wave.
		 sq_exportDBDAQInfo()	//  creates root:ExportForDataBase:ParVal, root:ExportForDataBase:ParValText etc		
		
	else
		ms0_AvGraphType =1		// sticks only
	endif
	
	ms0_graphOutputType=old_ms0_graphOutputType
	ms0_AvGraphType=old_ms0_AvGraphType
	ms0_dataType=old_ms0_dataType
	
End


Function sq_exportDBDAQInfo()

	wave squirrel_index=root:index:squirrel_index
	wave/t file_index=root:index:file_index
	svar todoStr=root:panel:sq_toDoWvNm
	wave todo=$"root:"+todoStr		//1.44B fix
	svar SourceStr=root:ExportForDataBase:SourceStr
	
	variable pos, firstRun, var1, var2, var3
	string sourceTempStr

	sourceTempStr = SourceStr[0, min(9, strlen(SourceStr)-1)]
	firstRun=todo[0]

	make /o/i/n=1 todo_temp = firstRun
	Note todo_temp "TYPE:todo;"
	
	pos = sq_findRun(root:index:squirrel_index,firstRun)
	var1 = FindDimLabel(root:index:squirrel_index, 2, "InfoVal")
	var2 = FindDimLabel(root:index:squirrel_index, 2, "ParVal")
	var3 = FindDimLabel(root:index:squirrel_index, 2, "ComParVal")

	killwaves/z InfoVal_d, ParVal_d, ComParVal_d
		
	squirrel_fetch(todo_temp,sq_dump2memory, "dest:InfoVal_d","InfoVal")
	squirrel_fetch(todo_temp,sq_dump2memory, "dest:ParVal_d","ParVal")
	
	wave ParVal_d = root:ParVal_d
	wave InfoVal_d = root:InfoVal_d
	redimension/n=(dimsize(ParVal_d,1)) ParVal_d
	redimension/n=(dimsize(InfoVal_d,1)) InfoVal_d
	
	duplicate/o ParVal_d, $"root:ExportForDataBase:ParVal_"+sourceTempStr
	duplicate/o InfoVal_d, $"root:ExportForDataBase:InfoVal_"+sourceTempStr
	
	make/t/o/n=0 $"root:ExportForDataBase:InfoValText_"+sourceTempStr
	make/t/o/n=0 $"root:ExportForDataBase:ParValText_"+sourceTempStr
	wave InfoValText =  $"root:ExportForDataBase:InfoValText_"+sourceTempStr
	wave ParValText =  $"root:ExportForDataBase:ParValText_"+sourceTempStr
	
	sq_LoadAttributesFromHDF(file_index[squirrel_index[pos][1][var1]], "InfoVal",  InfoValText)
	sq_LoadAttributesFromHDF(file_index[squirrel_index[pos][1][var2]], "ParVal", ParValText)

	if (var3 >=0)		// we have ComParVal data
		make/t/o/n=0 $"root:ExportForDataBase:ComParValText_"+sourceTempStr
		wave ComParValText =  $"root:ExportForDataBase:ComParValText_"+sourceTempStr
		squirrel_fetch(todo_temp,sq_dump2memory, "dest:ComParVal_d","ComParVal")
		wave ComParVal_d
		duplicate/o ComParVal_d, $"root:ExportForDataBase:ComParVal_"+sourceTempStr
		sq_LoadAttributesFromHDF(file_index[squirrel_index[pos][1][var3]], "ComParVal",  ComParValText)
	endif

	killwaves/z InfoVal_d, ParVal_d, ComParVal_d
	killwaves/z todo_temp

End


//  make a text wave that has metadata
//1.49E  added descriptor text wave
Function sq_exportCompileDBInfo()

	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	svar ExportSourceType = root:ExportForDataBase:ExportSourceType
	svar ExperimentorStr = root:ExportForDataBase:ExperimentorStr
	svar GroupStr = root:ExportForDataBase:GroupStr
	svar AMSTypeStr = root:ExportForDataBase:AMSTypeStr
	svar CitationUrl =root:ExportForDataBase:CitationUrl
	svar CitationStr =root:ExportForDataBase:CitationStr
	svar CitationFigStr = root:ExportForDataBase:CitationFigStr
	svar CommentsStr = root:ExportForDataBase:CommentsStr
	nvar EIEnergy = root:ExportForDataBase:EIEnergy
	nvar VaporizerTempC = root:ExportForDataBase:VaporizerTempC
	svar SourceStr = root:ExportForDataBase:SourceStr

	string  tempStr, sourceTempStr
	
	sourceTempStr = SourceStr[0, min(9, strlen(SourceStr)-1)]
	make/t/o/n=(15) $"root:ExportForDataBase:DBInfo_"+sourceTempStr
	wave/t DBInfo = $"root:ExportForDataBase:DBInfo_"+sourceTempStr

	svar AMSTypeStr = root:ExportForDataBase:AMSTypeStr
	ControlInfo/W=AMSDataBaseExport popupSigType
	tempStr = S_Value	
	DBInfo[0] = tempStr
	DBInfo[1] = ExperimentorStr
	DBInfo[2] = GroupStr
//	ControlInfo/W=AMSDataBaseExport setvarAMSType		// 1.49E bug, there is no popupAMSType
//	tempStr = S_Value
	DBInfo[3] = AMSTypeStr
	DBInfo[4] = CitationUrl
	DBInfo[5] = CitationStr
	DBInfo[6] = CitationFigStr
	DBInfo[7] = CommentsStr
	sprintf tempStr, "%1.1f" ,EIEnergy
	DBInfo[8] = tempStr
	sprintf tempStr, "%1.1f" ,VaporizerTempC
	DBInfo[9] = tempStr
	DBInfo[10] = sq_toDoWvNm		// not necessary, but maybe good for later tracking?
		
// 1.49E
	make/t/o/n=(15) $"root:ExportForDataBase:DBInfoDesc_"+sourceTempStr
	wave/t DBInfoDescriptor = $"root:ExportForDataBase:DBInfoDesc_"+sourceTempStr

	DBInfoDescriptor[0] = "Source Signal Type"
	DBInfoDescriptor[1] = "Experimentor Name"
	DBInfoDescriptor[2] = "Research Group"
	DBInfoDescriptor[3] = "ToF Type (C,V,W)"
	DBInfoDescriptor[4] = "Citation URL"
	DBInfoDescriptor[5] = "Citation"
	DBInfoDescriptor[6] = "Citation Fig#"
	DBInfoDescriptor[7] = "Comments"
	DBInfoDescriptor[8] = "EI volts"
	DBInfoDescriptor[9] = "Vaporizer Temp (Deg. C)"
	DBInfoDescriptor[10] = "local experiment todo wave name"		// not necessary, but maybe good for later tracking?

End


// sets the path for the location of the data base file to be created
Function sq_butt_exportDBPath(ctrlName) : ButtonControl
	String ctrlName

	svar FilePath = root:ExportForDataBase:FilePath
	NewPath/o/M="Where would you like to put thedata base file?"/o ExportDBPath
	PathInfo ExportDBPath
	if (V_flag==1)
		FilePath=S_path
	endif
	
End


// creates an igor text file
Function sq_butt_exportDBCreateFile(ctrlName) : ButtonControl
	String ctrlName

	nvar UMRorHR = root:ExportForDataBase:UMRorHR
	svar SpeciesList = root:ExportForDataBase:SpeciesList
	svar SourceStr = root:ExportForDataBase:SourceStr

	PathInfo ExportDBPath
	if (V_flag==0)
		abort "You must first select that path for the output data base file - aborting from sq_butt_exportDBCreateFile"
	endif

	if (  UMRorHR && strlen(SpeciesList)==0 ) 			//1.08E
		abort "You must select a species such as Org - aborting from sq_butt_exportDBCreateFile"
	endif
	SourceStr = CleanupName(SourceStr,0)
	
	sq_ABsanity()

	sq_exportCompileDBInfo()

	if (UMRorHR)
		sq_exportForDataBase()
		sq_exportSaveFileDB()
	else
		Execute "pk_exportForDataBase()"
		Execute "pk_exportSaveFileDB()"
	endif

End


// go to the AMS UMR data base
//Function sq_butt_exportDBUMRWebsite(ctrlName) : ButtonControl
//	String ctrlName
//

//	BrowseURL "http://cires.colorado.edu/jimenez-group/AMSsd/"
//

//End


// Go to the squirrel web wiki for help
//Function sq_butt_exportDBUMRwiki(ctrlName) : ButtonControl
//	String ctrlName
//

//	BrowseURL "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Exporting_Results_to_the_AMS_Unit_Mass_Resolution_Data_Base"
//

//End
//
//// go to the AMS HR database


//Function sq_butt_exportDBHRWebsite(ctrlName) : ButtonControl
//	String ctrlName
//

//	BrowseURL "http://cires.colorado.edu/jimenez-group/HRAMSsd/"
//

//End
//
//
//// Go to the squirrel web wiki for help



//Function sq_butt_exportDBHRwiki(ctrlName) : ButtonControl
//	String ctrlName
//

//	BrowseURL "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Exporting_Results_to_the_AMS_HR_Mass_Resolution_Data_Base"
//

//End
//
//


//Function sq_butt_exportMailToML(ctrlName) : ButtonControl
//	String ctrlName
//		

//	BrowseURL "mailto:anne.handschy@colorado.edu?subject=AMS Spectral Database&body=Don't%20forget%20to%20attach%20the%20files!!"
//
//End




Function sq_exportDBUMRorHR(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar UMRorHR = root:ExportForDataBase:UMRorHR
	svar FileNamePrefix = root:ExportForDataBase:FileNamePrefix
	svar SourceStr = root:ExportForDataBase:SourceStr
	svar AMSTypeStr = root:ExportForDataBase:AMSTypeStr
	svar Filename = root:ExportForDataBase:Filename
	svar SpeciesList = root:ExportForDataBase:SpeciesList

	if (strsearch(ctrlName, "UMR",0) >0)
		CheckBox checkHR  value = 0
		CheckBox checkUMR value = 1
		UMRorHR =1
	else
		if (DataFolderExists("root:HR_sticks"))	// there is a possibility that we have HR sticks
			CheckBox checkHR  value = 1
			CheckBox checkUMR value = 0
			UMRorHR = 0
		else
			CheckBox checkHR  value = 0
			CheckBox checkUMR value = 1
			UMRorHR =1
			DoAlert 0,  "This does not appear to be an experiment with high resolution sticks"
		endif
	endif

	if (UMRorHR)
		Filename = FileNamePrefix+"_"+AMSTypeStr+"_xxx_"+SourceStr
	else
		Filename = FileNamePrefix+"_HR_xxx_"+SourceStr
		SpeciesList=""
	endif

End

Function sq_exportDBSigType(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr

	svar FileName = root:ExportForDataBase:FileName
	svar AMSTypeStr = root:ExportForDataBase:AMSTypeStr
	svar FileNamePrefix= root:ExportForDataBase:FileNamePrefix
	svar SourceStr = root:ExportForDataBase:SourceStr
	
	nvar UMRorHR = root:ExportForDataBase:UMRorHR

	variable pos1, pos2

	pos1 = strsearch(popStr, "(", 0) 
	pos2 = strsearch(popStr, "_*_", pos1) 
	FileNamePrefix = popStr[pos1+1,pos2-1] 
	if (UMRorHR)
		Filename = FileNamePrefix+"_"+AMSTypeStr+"_xxx_"+SourceStr
	else
		Filename = FileNamePrefix+"_HR_xxx_"+SourceStr
	endif
	
End


Function sq_exportDBToDo(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr

	sq_pop_toDoList(ctrlName,popNum,popStr) 

	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	wave todo = $"root:"+sq_toDoWvNm
	svar AMSTypeStr = root:ExportForDataBase:AMSTypeStr
	svar detectorsused = root:diagnostics:detectorsused
	wave detector_num= root:diagnostics:detector_num
	svar FileName = root:ExportForDataBase:FileName
	svar FileNamePrefix = root:ExportForDataBase:FileNamePrefix
	svar SourceStr = root:ExportForDataBase:SourceStr
	nvar UMRorHR = root:ExportForDataBase:UMRorHR

	variable pos1, pos2
	string type, prefix

	if (sq_OnlyOneModeInTodo(todo)!=1)
		abort "Cannot do mass averaging on a todo wave with different modes (v and w switching) - Aborting from sq_exportDBToDo"
	endif

	AMSTypeStr = StringFromList(detector_num[sq_findRun(root:index:rn_series,todo[0])], detectorsused)
	AMSTypeStr = AMSTypeStr[0]

	if (UMRorHR)
		Filename = FileNamePrefix+"_"+AMSTypeStr+"_xxx_"+SourceStr
	else
		Filename = FileNamePrefix+"_HR_xxx_"+SourceStr
	endif

End


Function  sq_exportDBSource(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	svar FileName = root:ExportForDataBase:FileName
	svar AMSTypeStr = root:ExportForDataBase:AMSTypeStr
	svar FileNamePrefix= root:ExportForDataBase:FileNamePrefix
	svar SourceStr = root:ExportForDataBase:SourceStr
	
	variable pos1, pos2

	SourceStr = CleanUpName(SourceStr,0)
	SourceStr = SourceStr[0, min(strlen(SourceStr)-1, 29)]
	
	Filename = FileNamePrefix+"_"+AMSTypeStr+"_xxx_"+SourceStr

End


Function sq_exportForDBRawSpectra() 

	svar todoStr=root:panel:sq_toDoWvNm
	wave squirrel_index = root:index:squirrel_index
	wave rn_series = root:index:rn_series
	wave l_series = root:index:l_series
	svar SourceStr =root:ExportForDataBase:SourceStr

	wave/z mz_FitInterceptOpen = root:mzFitting:mz_FitInterceptOpen
	wave/z mz_FitSlopeOpen = root:mzFitting:mz_FitSlopeOpen
	wave/z mz_FitPowerOpen = root:mzFitting:mz_FitPowerOpen
	wave/z mz_FitInterceptClosed = root:mzFitting:mz_FitInterceptClosed
	wave/z mz_FitSlopeClosed = root:mzFitting:mz_FitSlopeClosed
	wave/z mz_FitPowerClosed = root:mzFitting:mz_FitPowerClosed
	if (!WaveExists(mz_FitInterceptOpen) || !WaveExists(mz_FitSlopeOpen) || !WaveExists(mz_FitPowerOpen) || !WaveExists(mz_FitInterceptClosed) || !WaveExists(mz_FitSlopeClosed) || !WaveExists(mz_FitPowerClosed) )
		wave mz_FitInterceptOpen = root:mzFitting:mz_FitIntercept
		wave mz_FitSlopeOpen = root:mzFitting:mz_FitSlope
		wave mz_FitPowerOpen = root:mzFitting:mz_FitPower
		wave mz_FitInterceptClosed = root:mzFitting:mz_FitIntercept
		wave mz_FitSlopeClosed = root:mzFitting:mz_FitSlope
		wave mz_FitPowerClosed = root:mzFitting:mz_FitPower
	endif

	string paramStr, sourceTempStr
	variable pos, firstRun, numInRawSpectra
		
	sourceTempStr = SourceStr[0, min(9, strlen(SourceStr)-1)]

	wave todo = $todoStr
	firstRun=todo[0]
	pos = sq_findRun(root:index:rn_series, firstRun)

	numInRawSpectra=squirrel_index[l_series[sq_findrun(rn_series,todo[0])]][4][finddimlabel(squirrel_index,2,"MSOpen")]
	make /o/n=(numInRawSpectra) $("mz_base_"+todoStr)
	wave mz_base_temp =  $("mz_base_"+todoStr)

	make /o/n=(numInRawSpectra) $("root:ExportForDataBase:RawSpectraDiffMz_"+sourceTempStr)/wave=RawSpectraDiffMz 	// we use open for diff
	RawSpectraDiffMz = ( (p-mz_FitInterceptOpen[pos])/mz_FitSlopeOpen[pos])^(1/mz_FitPowerOpen[pos])	
	make /o/n=(numInRawSpectra) $("root:ExportForDataBase:RawSpectraClosedMz_"+sourceTempStr)/wave=RawSpectraClosedMz 
	RawSpectraClosedMz = ( (p-mz_FitInterceptClosed[pos])/mz_FitSlopeClosed[pos])^(1/mz_FitPowerClosed[pos])	

	if (mz_FitInterceptOpen[pos]>0)		//1.14I
		RawSpectraDiffMz[0,ceil(mz_FitInterceptOpen[pos])]=0
	endif
	if (mz_FitInterceptClosed[pos]>0)
		RawSpectraDiffMz[0,ceil(mz_FitInterceptClosed[pos])]=0
	endif
	
	paramStr="mz_w_op:0;mz_base:mz_base_"+todoStr+";new_mz_cal:1;raw_flag:1;cache_op:0;filter_op:1;corr_op:0;product_type:2;ug_op:0;findBaseline_op:0;"
	mz_base_temp = ( (p-mz_FitInterceptClosed[pos])/mz_FitSlopeClosed[pos])^(1/mz_FitPowerClosed[pos])	
	if (mz_FitInterceptClosed[pos]>0)
		mz_base_temp[0,ceil(mz_FitInterceptClosed[pos])]=0
	endif
	squirrel_fetch(todo,sq_MS_concentration,paramStr+"destlist:RawSpectraClosed_temp","MSClosed_p")

	mz_base_temp = ( (p-mz_FitInterceptOpen[pos])/mz_FitSlopeOpen[pos])^(1/mz_FitPowerOpen[pos])	
	if (mz_FitInterceptOpen[pos]>0)
		mz_base_temp[0,ceil(mz_base_temp[pos])]=0
	endif
	squirrel_fetch(todo,sq_MS_concentration,paramStr+"destlist:RawSpectraDiff_temp","MSDiff_p")			
	wave RawSpectraClosed_temp = root:RawSpectraClosed_temp
	wave RawSpectraDiff_temp = root:RawSpectraDiff_temp

	duplicate/o  RawSpectraClosed_temp $"root:ExportForDataBase:RawSpectraClosed_"+sourceTempStr
	duplicate/o  RawSpectraDiff_temp $"root:ExportForDataBase:RawSpectraDiff_"+sourceTempStr

	killwaves/z RawSpectraDiff_temp, RawSpectraClosed_temp

End


// new in 1.49A
//  given a run number returns the ionization type
Function/s sq_getDetectorStr(runNum)
variable runNum

	wave run_series = root:index:rn_series
	wave detector_Num = root:diagnostics:detector_Num
	svar detectorsUsed = root:diagnostics:detectorsUsed

	variable currentRunIndex = sq_findRun(run_series,runNum)
	if (currentRunIndex<0)
		return ""
	else
		return stringFromList(detector_Num[currentRunIndex], detectorsUsed )		
	endif

End

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//// Some PToF functions
// Commented out in 1.52
//// sq_PToFCollapseSizeOneRun sums over the PToF size dimension to give you a stick or raw mass spectra that is somewhat similar to a MSOpen or MSSOpen for the same run.
//// sq_PToFDataSlice extracts section of PToF matrix for one run between BinStart and BinStop (not the entire PToF dimension)
//// sq_PToFExtractEachBinOneRun  For one run, makes each spectra in the PToF dimension its own wave (easier for plotting, function etc)
//// sq_PToFStickDiagOneRun gets one run's PToF and MS data and creates a correlation plot and a mass spectra plot (PToF size dimension summed to result in one spectra)
//// sq_PToFRawDiagOneRun same as sq_PToFStickDiagOneRun only for raw spectra
//// sq_SumPToFSizeGroups  given a PToF matrix, groups PToF bins for a more compact size resolved PToF matrix.
//
//// extracts Raw or Stick data from one run, sums across PToF dimensions (PToF Bins)
//// resultant wave is put in  dataFolderSt with name destStr
//// sample usage: sq_PToFDataThisRunCollapseSize(4601, "", "ePToFSum4601", 1)
//// creates a 18000  pt wave of summed raw spectra
//Function sq_PToFCollapseSizeOneRun(runNum, dataFolderSt, destStr, RawFlag, PreProcessedFlag)		//1.49E
//variable runNum
//string dataFolderSt, destStr
//variable RawFlag, PreProcessedFlag
//
//	string runStr, dataset
//	sprintf runStr, "%u", runNum
//	sq_create_todo(runStr+" and all","tempTodo")
//	wave todo=$"root:tempTodo"
//	
//	if(RawFlag)
//		dataset = "PToF"
//	elseif (PreProcessedFlag)	
//		dataset = "PToF_stick_p"
//	else
//		dataset = "PToF_stick"
//	endif
//
//	squirrel_fetch(todo,sq_dump2memory, "dest:PToF_"+runStr,dataset)
//	
//	wave PToF_d = $"root:PToF_"+runStr
//	
//	matrixOp/o tran=transposeVol(PToF_d,1)		//mode=1:	switch columns and layers; output=w[p][r][q]
//	matrixOp/o $dataFolderSt+destStr = sumBeams(tran)			// sum over all layers, collapses the layers
//
//	wave destWave = $dataFolderSt+destStr
//	Redimension/N=(dimsize(destWave,1)) destWave
//	
//	killwaves/z tempTodo, PToF_d, tran
//	
//End
//
//
//// function, along with modified SQ_backbone_1_48C, that allows for partial extraction of a PToF data set from an hdf file.
//// The data set can either be PToF_stick or PToF   (raw sepctra)
//// will create a wave in root called PToF_d of dimensions (# in todo wave) x (PToFBinMax) x (# of points in raw spectra)
////  sample usage: PToFRawThisTodox(all, 10, 3, 0) 		// gives PToF bins 10, 11, 12
//Function sq_PToFDataSlice(todo, PToFBinStart, PToFBinMax, destStr, RawFlag)
//wave todo
//variable PToFBinStart, PToFBinMax
//string destStr
//variable RawFlag
//	
//	string dataSet
//	
//	if(RawFlag)
//		dataset = "PToF"
//	else
//		if (FindDimLabel(root:index:squirrel_index, 2, "PToF_stick_p") <0)	
//			dataset = "PToF_stick"
//		else
//			dataset = "PToF_stick_p"
//		endif
//	endif
//
//	killwaves/z $destStr
//	squirrel_fetch(todo,sq_dump2memory, "min_cl:"+num2str(PToFBinStart)+";max_cl:"+num2str(PToFBinMax)+";dest:"+destStr,dataset) //1.49E
//
//End
//
//
//// Creates individual ptof bin waves and makes individual waves named PToF0, PToF1, ... PToFmaxBin
//// Currently is set to do for raw spectra, but is easily modifiable for PToF stick
//// Sample usage: sq_PToFExtractEachBinOneRun(4601, "Root:PTOF:" "r4601", 1)
//Function sq_PToFExtractEachBinOneRun(runNum, dataFolderStr, destStr, RawFlag)		//1.49E
//variable runNum, RawFlag
//string dataFolderStr, destStr
//
//	string runStr, dataset
//	variable numRow, numCol, numLay, idex
//	
//	sprintf runStr, "%u", runNum
//	if(RawFlag)
//		dataset = "PToF"
//	else
//		if (FindDimLabel(root:index:squirrel_index, 2, "PToF_stick_p") <0)	
//			dataset = "PToF_stick"
//		else
//			dataset = "PToF_stick_p"
//		endif
//	endif
//
//	sq_create_todo(runStr+" and all","tempTodo")
//	wave todo=$"root:tempTodo"
//
//	killwaves/z PToF_Temp
//	squirrel_fetch(todo,sq_dump2memory, "dest:PToF_Temp",dataset)	
//	wave PToF_Temp
//
//	numCol = dimsize(PToF_Temp, 1)
//	numLay = dimsize(PToF_Temp, 2)
//	 
//	NewDataFolder/o $(dataFolderStr[0, strlen(dataFolderStr)-2])
//	for(idex=0;idex<numCol;idex+=1)
//		make/o/n=(numLay) $(dataFolderStr+destStr+"_"+num2str(idex)) /Wave=results
//		results = PToF_Temp[0][idex][p]
//	endfor
//
//	killwaves/z tempTodo, PToF_Temp
//	
//End
//
//
//// For one run number this sums up all the PToF bins and displays two graphical comparisons.
//// One graph is a spectra with the MS and the PToF values displayed side-by-side, one is a correlation plot.
//// sample usage: PToFStickThisRun(11525, 1)		// 1 indicate use preprocess
//Function sq_PToFStickDiagOneRun(runNum, PreproFlag)
//variable runNum, PreproFlag
//
//	string runStr, suffix
//	variable minM
//	sprintf runStr, "%u", runNum
//		
//	sq_PToFCollapseSizeOneRun(runNum, "", "ePToFSum_"+runStr, 0, PreproFlag)	// use preprocessed data
//
//	sq_create_todo(runStr+" and all","tempTodo")
//	wave todo=$"root:tempTodo"
//	
//	suffix = selectString(PreProFlag, "", "_p")
//
//	killwaves/z $"MSSDiff_"+runStr, $"MSSClosed_"+runStr
//	squirrel_fetch(todo,sq_dump2memory, "dest:MSSDiff_"+runStr,"MSSDiff"+suffix)
//	squirrel_fetch(todo,sq_dump2memory, "dest:MSSClosed_"+runStr,"MSSClosed"+suffix)
//	wave MSSDiff_d = $"MSSDiff_"+runStr
//	wave MSSClosed_d=$"MSSClosed_"+runStr
//	
//	duplicate/o MSSDiff_d $"MSSOpen_"+runStr
//	wave MSSOpen = $"MSSOpen_"+runStr
//	MSSOpen = MSSDiff_d+MSSClosed_d
//	Redimension/N=(dimsize(MSSOpen,1)) MSSOpen
//
//	if(!PreproFlag)
//		wave mStart = root:diagnostics:mStart
//		minM = mStart[sq_findRun(root:index:rn_series,runNum)]
//		wave ePToFSum = $"root:ePToFSum_"+runStr
//		insertpoints 0, minM-1, ePToFSum
//		insertpoints 0, minM-1, MSSOpen		
//	endif
//	make/t/o/n=(dimsize(MSSOpen,0)) root:diagnostics:amusText = num2str(p+1)
//
//	sq_DisplayStickPToF_corr(runNum, "ePToFSum_"+runStr, "MSSOpen_"+runStr)
//	sq_DisplayStickPToF_mz(runNum, "ePToFSum_"+runStr, "MSSOpen_"+runStr)
//
//	killwaves/z MSSDiff_d, MSSClosed_d, tempTodo
//
//End
//
//
//// Similar to sq_PToFStickDiagOneRun only for raw PTOF spectra
//// sample usage: PToFRawThisRun(11004)
//// displays two graphs, a correlation and a mass spectra
//Function sq_PToFRawDiagOneRun(runNum)
//variable runNum
//
//	string runStr
//	sprintf runStr, "%u", runNum
//
//	// first get raw spectra
//	nvar bk_currentRunNum =  root:baselineFitting:bk_currentRunNum
//	bk_currentRunNum = runNum
//
//	bk_setUpRawSpectraThisRun()
//	
//	duplicate/o root:baselineFitting:OneRunRawSpectraOpen $"MSO_"+runStr
//	duplicate/o root:baselineFitting:OneRunRawSpectraMz $"Mz_"+runStr
//		
//	sq_PToFCollapseSizeOneRun(runNum, "", "PToFRawSum_"+runStr, 1,0)
//
//	sq_DisplayRawPToF_corr(runNum, "PToFRawSum_"+runStr, "MSO_"+runStr, "Mz_"+runStr)
//	sq_DisplayRawPToF_mz(runNum, "PToFRawSum_"+runStr, "MSO_"+runStr, "Mz_"+runStr)
//	sq_DisplayRawPToF_iToF(runNum, "PToFRawSum_"+runStr, "MSO_"+runStr)
//
//End
//
//
//// given a dumped, 3-D PToF raw matrix, find the average across grp-many PToF bins.
//Function sq_SumPToFSizeGroups(OneRawPToF, NameStr, grp)
//wave OneRawPtoF
//string nameStr
//variable grp
// 
//	variable numRow, numCol, numLay, idex, numGrps
//	
//	numRow = dimsize(OneRawPtoF, 0)
//	numCol = dimsize(OneRawPtoF, 1)
//	numLay = dimsize(OneRawPtoF, 2)
//	 
//	numGrps = numCol/grp
//	 
//	for(idex=0;idex<numGrps;idex+=1)
//		duplicate/o/R=[0][idex*grp,(idex+1)*grp-1][] OneRawPToF subset
//		matrixop/o tran=transposeVol(subset,1)
//		matrixOP/o PtoFOpen = sumBeams(tran)
//		make/o/n=(numLay) $NameStr+"_"+num2str(idex)/Wave=results
//		results = PtoFOpen[idex][p]/grp
//	endfor
// 
//End
//
//
/////////////////////PTOF graphing functions/////////////////////////////
//
//// displays Raw PToF and MS open spectra in iToF space
//Function sq_DisplayRawPToF_iToF(runNum, PToFWaveName, MSWaveName)
//variable runNum
//string PToFWaveName, MSWaveName
//
//	wave runMS = $MSWaveName
//	wave runPToF = $PToFWaveName
//	
//	Display /W=(40.5,44.75,562.5,297.5) 
//	
//	AppendToGraph runMS
//	AppendToGraph runPToF
//	ModifyGraph rgb($NameofWave(runMS))=(0,0,0)
//	ModifyGraph grid=2
//	ModifyGraph log(left)=1
//	ModifyGraph nticks(bottom)=9
//	ModifyGraph gridRGB=(34816,34816,34816)
//	SetAxis left 0.0001,50
////	SetAxis bottom 10,100
//	ShowInfo
//	Legend
//
//End
//
//// displays Raw PToF and MS open spectra
//Function sq_DisplayRawPToF_Mz(runNum, PToFWaveName, MSWaveName, MzWaveName)
//variable runNum
//string PToFWaveName, MSWaveName, MzWaveName
//
//	wave runMS = $MSWaveName
//	wave runMz = $MzWaveName
//	wave runPToF = $PToFWaveName
//	
//	Display /W=(40.5,44.75,562.5,297.5) 
//	
//	AppendToGraph runMS vs runMz
//	AppendToGraph runPToF vs runMz
//	ModifyGraph rgb($NameofWave(runMS))=(0,0,0)
//	ModifyGraph grid=2
//	ModifyGraph log(left)=1
//	ModifyGraph nticks(bottom)=9
//	ModifyGraph gridRGB=(34816,34816,34816)
//	SetAxis left 0.0001,50
//	SetAxis bottom 10,100
//	ShowInfo
//	Legend
//
//End
//
//// displays Raw PToF and MS open correlation
//Function sq_DisplayRawPToF_corr(runNum, PToFWaveName, MSWaveName, MzWaveName)
//variable runNum
//string PToFWaveName, MSWaveName, MzWaveName
//
//	wave runMS = $MSWaveName
//	wave runMz = $MzWaveName
//	wave runPToF = $PToFWaveName
//	wave one2one = sq_generateOne2OneWave()		//1.49E
//
//	Display /W=(527.25,92.75,844.5,337.25) one2one vs one2one
//	AppendToGraph runMS vs runPToF
//	ModifyGraph mode($NameofWave(runMS))=3
//	ModifyGraph lSize(one2one)=2
//	ModifyGraph rgb(one2one)=(0,0,0)
//	ModifyGraph msize($NameofWave(runMS))=6
//	ModifyGraph gaps(one2one)=0
//	ModifyGraph zColor($NameofWave(runMS))={$NameofWave(runMz),10,100,Rainbow}
//	ModifyGraph grid=2
//	ModifyGraph log=1
//	ModifyGraph nticks=9
//	ModifyGraph minor=1
//	ModifyGraph gridRGB=(34816,34816,34816)
//	SetAxis left 0.0001,50
//	SetAxis bottom 0.0001,50
//	Label left "MS Open";DelayUpdate
//	Label bottom "PToF summed over sizes"
//	ShowInfo
//	Legend
//
//End
//
//
//// displays stick PToF and MS open correlation
//Function sq_DisplayStickPToF_corr(runNum, PToFWaveName, MSWaveName)
//variable runNum
//string PToFWaveName, MSWaveName
//
//	wave runMS = $MSWaveName
//	wave runPToF = $PToFWaveName
//	wave/T amusText = root:diagnostics:amusText
//
//	Display /W=(522,196.25,969,426.5) one2one vs one2one as "PTOF_corr_"+num2str(runNum)
//	AppendToGraph runMS vs runPToF
//	ModifyGraph mode($NameOfWave(runMS))=3
//	ModifyGraph marker($NameOfWave(runMS))=8
//	ModifyGraph lSize(one2one)=2
//	ModifyGraph rgb(one2one)=(0,0,0)
//	ModifyGraph textMarker($NameOfWave(runMS))={amusText,"default",0,0,5,0.00,0.00}
//	ModifyGraph grid=2
//	ModifyGraph log=1
//	ModifyGraph gridRGB=(34816,34816,34816)
//	SetAxis left 0.01,200
//	SetAxis bottom 0.01,200
//	ShowInfo
//	Label left "MSO"
//	Label bottom "Sum PToF"
//	legend
//	
//End
//
//
//// displays stick PToF and MS open spectra
//Function sq_DisplayStickPToF_Mz(runNum, PToFStr, MSStr)
//variable runNum
//string MSStr, PToFStr
//
//	wave runMS = $MSStr
//	wave runPToF = $PToFStr
//	wave amus = root:diagnostics:amus
//
//	Display /W=(298.5,130.25,786.75,383) runMS,runPToF vs amus  as "PTOF_Spec_"+num2str(runNum)
//	ModifyGraph mode=1
//	ModifyGraph lSize=2
//	ModifyGraph rgb($NameOfWave(runMS))=(0,0,0)
//	ModifyGraph offset($NameOfWave(runPToF))={0.3,0}
//	ModifyGraph grid=2
//	ModifyGraph log(left)=1
//	ModifyGraph nticks(bottom)=9
//	ModifyGraph minor(bottom)=1
//	ModifyGraph gridRGB=(34816,34816,34816)
//	SetAxis left 0.01,200
//	SetAxis bottom 8,100.5
//
//End
//
//
///// End PToF functions

// creates and sets the global string root:processed_path containing the path of the intermediate data files.
// Added in 1.49B
Function sq_SetProcessedPaths()
	
	// the processed path is a bit different because it is handy to have the string for the path when writing new or existing intermediate files.
	svar/z processed_path = root:processed_path
	if ( Svar_Exists(processed_path)==0)
		string/g root:processed_path=""
		svar processed_path = root:processed_path
	elseif (strlen(processed_path)>0)
		newpath /o/z/q proc_path, processed_path
		if (v_flag!=0)
			processed_path=""
		endif
	endif
	if (strlen(processed_path)==0)
		newpath /o/z/q/m="Path for intermediate data" proc_path
		if (v_flag!=0)
			Abort "No output path for intermediate data files was selected - write aborted"
		else
			PathInfo proc_path
			processed_path = S_path
		endif
	endif
	
End


// new function in 1.49E 
// moved from sq_butt_getSquirrelIndex for modularity.
// returns the path string for hdfDirPath, else
Function/S sq_SetDAQHDFpath()

	PathInfo hdfDirPath	//^ check to see if path exists first, so that users can set path ahead of time.
	if(!v_flag)  //^ path does not exist
		newpath/o/q/m="Select a folder with ToF AMS DAQ hdf files."  hdfDirPath		//1.47I // changed the name from raw hdf to DAQ hdf
		if(v_flag!=0)	//^ here, a v_flag = 0 indicates sucessful creation of path
			abort "// User cancelled dialog box to get path for indexing."
		endif
	else  //^ Path already exists, check to see if use wants to keep it
		doalert  2, ("Index last used path?\r\r"+S_path)
		if (v_flag==2)	//^ User clicked No, so get a new path.
			newpath/o/m="Select a folder with ToF AMS DAQ hdf files." hdfDirPath
		elseif (v_flag==3)	//^ User clicked cancel 
			abort "User cancelled dialog box to get path for indexing."
		endif
	endif
	
	PathInfo hdfDirPath	// if we get to this part of function it should exist
	return S_path

End


//1.49E
Function sq_PromptForFragWaves()

	string currentFile
	variable pos
	if(!datafolderexists("root:frag"))
		open/r/M=("The frag data folder and the frag waves do not exist.  Please locate an itx file containg frag waves.")/t=(".itx") pos
		currentfile=S_filename
		if(strlen(currentfile)>0)
			close pos
			newdatafolder/s root:frag
			loadwave/T/Q currentfile
			setdatafolder root:
		endif
	endif

End


// 1.49E
static strconstant SQUIRREL_PROC_PREF="AMS_intermediate_" // Prefix for processed data files
Function sq_GetIntermedFileName()

	string tempStr
	svar/z IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName
	if (!svar_Exists(IntermPrefixExpFileName))
		sq_initializeGlobalSVar("root:panel:IntermPrefixExpFileName", SQUIRREL_PROC_PREF)
		svar IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName
	endif
	tempStr = IntermPrefixExpFileName
	Prompt tempStr, "Prefix for intermediate files and experiment name:"	  // Set prompt for y param
	DoPrompt "Enter up to 20 characters for the prefix", tempStr
	if (V_Flag==1|| strlen(tempStr)==0)
		tempStr	=SQUIRREL_PROC_PREF						// User canceled
	elseif(strlen(tempStr)>20)
		tempStr	= tempStr[0,20]
	endif

	if(!stringmatch(tempStr[strlen(tempStr)-1], "_"))
		if (strlen(tempStr)==20)
			tempStr[19]="_"			// force a _ character before the number... may make things easier down the road.
		else
			tempStr[strlen(tempStr)]="_"			// force a _ character before the number... may make things easier down the road.
		endif
	endif
	tempStr = CleanupName(tempStr, 0 )
	IntermPrefixExpFileName=tempStr

End


//1.49E
Function/Wave sq_generateOne2OneWave()

	wave/z one2one=root:panel:one2one
	if (!waveExists(one2one))
		make/o root:panel:one2one={0,1}
		wave one2one=root:panel:one2one
	endif
	return one2one
	
End


//1.49E
Function sq_butt_killWavesInFolder(FolderStr)
string FolderStr

	if (DataFolderExists(FolderStr))
		SetDataFolder $FolderStr
		killwaves/z/a
		SetDataFolder root:
	endif

End



// Tasks to be done in squirrel in preparation for PMF include
// (1) generating the minimum error
// (2) generating the time series spectra matrix and error matrix
// (3) copy and save the time series, amu wave, min error, data matrix and error matrix to an itx
Function sq_TasksForPMFOutput(tempSpecList)
string tempSpecList

	svar ms0_speclist = root:panel:ms0_speclist
	nvar ms0_ion2mass = root:panel:ms0_ion2mass
	nvar ms0_corr = root:panel:ms0_corr
	wave t_series = root:index:t_series
	wave amus = root:diagnostics:amus		// we will resize
	wave dataWave = $"root:"+tempSpecList
	wave errWave = $"root:"+tempSpecList+"_err"
	string suffix, outputList, MinIonStr	
	
	nvar ams_time_custom = root:panel:ams_time_custom		//1.59E
	nvar ams_time_saved = root:panel:ams_time_saved		//1.52N
	nvar ams_time_interval = root:panel:ams_time_interval		//1.52N
	nvar ms0_ion2mass = root:panel:ms0_ion2mass		//1.52N

	if (!ams_time_saved)		//1.59E
		DoAlert, 1, "It is not recommended to do PMF on data that is not in the 'as saved' format.  Continue?"	
		if (V_flag==2)	// no
			return 0
		endif
	endif
	
	// amu wave
	duplicate/o amus root:amus
	wave amus = root:amus		// we will resize
	redimension/n=(dimSize(dataWave,1)) amus

	// This will have to be changed for ePToFSum
	wave/z TimeMeasuringWave=root:diagnostics:TimeAcquiringMSOpenInRun	// root:diagnostics:TimeMSOpen		// 1.48E		//1.53N
	if (waveMax(TimeMeasuringWave)<0)
		wave TimeMeasuringWave=root:diagnostics:TimeMSOpen		// 1.48E		//1.53N
	endif
	 
	MinIonStr = Err_minErr1ion(ms0_ion2mass, TimeMeasuringWave)	
	wave minErr1ion = root:minErr1ion		// we will resize
	suffix=selectString(ms0_ion2mass,"Hz","Ug" )
	
	// standardize wave name
	string species = stringFromList(0,ms0_speclist, ",")
	wave/z Org = $"root:"+species+suffix
	if (WaveExists(Org))
		redimension/n=(dimsize(dataWave,0), dimsize(dataWave,1)) Org
		Org=dataWave
		killwaves/z dataWave
	else
		rename datawave $species+suffix
	endif
	wave/z OrgErr = $"root:"+species+suffix+"Err"
	if (WaveExists(OrgErr))
		redimension/n=(dimsize(errWave,0), dimsize(errWave,1)) OrgErr
		OrgErr=errWave
		killwaves/z errWave
	else
		rename errwave $species+suffix+"Err"
	endif
	
	// deal with non 'as saved' time base
	if (ams_time_saved)		
		outputList = "root:index:t_series;root:index:rn_series;root:"+MinIonStr+";"
	elseif (ams_time_interval)
		nvar ams_time_int_val = root:panel:ams_time_int_val		
		wave/z TimeMSOpen=root:diagnostics:TimeAcquiringMSOpenInRun	// root:diagnostics:TimeMSOpen		// 1.48E		//1.53N
		if (!WaveExists(TimeMSOpen) || waveMax(TimeMSOpen)<0)
			wave/z TimeMSOpen=root:diagnostics:TimeMSOpen		// 1.48E		//1.53N
		endif
		wave t_base=$"root:"+sq_tbase()
		sq_sumOrAvgOverTbase(t_base, timeMSopen, "TimeMSOpen_xmin", 1)		// overwrite minErr1ion!
		wave/z TimeMSOpen_xmin = root:TimeMSOpen_xmin		//1.54C
		make/O/N=(numpnts(t_base)) minErr1ion = 1/TimeMSOpen_xmin	

		if(ms0_ion2mass == 1)		
			wave/Z ioneff = root:diagnostics:ioneff
			wave/Z flowrate = root:diagnostics:flowrate
			wave/Z corr_fact = root:diagnostics:corr_fact	
			if (!WaveExists(ioneff))
				wave/Z ioneff = root:diagnostics:ioneff_logged
			endif
			make/o/n=(numpnts(timeMSopen)) ugfac_wav_tmp
			ugfac_wav_tmp=(PMF_AW_NO3/PMF_AVOGADRO)*1e12/(ioneff[p]*flowrate[p])     // presumes ioneff exists; you did the AB corrections
			if(ms0_corr)
				ugfac_wav_tmp*=corr_fact[p]      // if you want to fold in the Airbeam correction factor
			endif	
			sq_sumOrAvgOverTbase(t_base, ugfac_wav_tmp, "ugfac_wav_xmin", 0)	
			wave ugfac_wav_xmin = root:ugfac_wav_xmin
			minErr1ion *= ugfac_wav_xmin	
			killwaves/z 	ugfac_wav_xmin, TimeMSOpen_xmin, ugfac_wav_tmp
		endif
		string tstr=num2str(ams_time_int_val)
		tstr = ReplaceString(".", tstr ,"")				//1.59E
		duplicate/o t_base $"root:time_"+tstr+"_min"/wave=NewTimeWave  // we need for this to be one point smaller so folks won't get confused when inputting into pmf		
		deletepoints 0,1, NewTimeWave, minErr1ion
		outputList = "root:"+NameOfWave(NewTimeWave)+";root:minErr1ion;"
	else			//custom  // should NOT happen
		ABORT "Cannot proceed with the custom time wave operation.  Aborting from sq_TasksForPMFOutput"			//1.59E
	endif
	
	outputList += "amus;"+species+suffix+";"+species+suffix+"Err;"
//	print outputList
	Save/T/O/B outputList as "PMFInput.itx"
	
	//1.54C addition
		NewDataFolder/o root:PMFOutput
		variable idex
		string str
		for(idex=0;idex<ItemsInList(outputList);idex+=1)		// we DO NOT wave to move t_series
			wave w = $StringFromList(idex, outputList)
			str = NameofWave(w)
			if (stringMatch(str,  "t_series"))
				duplicate/o w, $"root:PMFOutput:t_series"
				continue
			endif
			if (stringMatch(str,  "rn_series"))
				duplicate/o w, $"root:PMFOutput:rn_series"
				continue
			endif
			if (Exists("root:PMFOutput:"+str))
				wave Wold = $"root:PMFOutput:"+str
				duplicate/o w, $"root:PMFOutput:"+str
			else
				MoveWave w, root:PMFOutput:
			endif			
		endfor

	print "// The time series wave, amu, "+species+", "+ species+"Err, and min error were saved in the data folder PMFOutput for  preparation for PMF input. " //1.54C
//	Killwaves/z amus, NewTimeWave, TimeMSOpen_xmin
	
End


// added in 1.50M
Function sq_changeOrgLessPAH(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	wave/t frag_organic = root:frag:frag_organic
	wave/z/t frag_orgLessPAH = root:frag:frag_orgLessPAH
	variable LessPAH = !stringMatch(ctrlName, "check_OrgPlusPAH")	
	if (LessPAH)
		if (WaveExists(frag_orgLessPAH))
			frag_organic[195,*] = frag_orgLessPAH[p]	
		else
			CheckBox check_OrgPlusPAH value = LessPAH
			CheckBox check_OrgLessPAH value = !LessPAH
			abort "Cannot find the frag wave containing the entries for separating out the organic contributions from PAHs.  Import a frag_OrgLessPAH wave." 
		endif
	else
		frag_organic[195,*] = num2str(p+1)
	endif

	CheckBox check_OrgPlusPAH value = !LessPAH
	CheckBox check_OrgLessPAH value = LessPAH

End


Function sq_FillBlankSpectraTypes(todo, RawSpectraTodoList, num, dataSetStr, calcDiff_flag, diffDest, diffDataSetStr, [AvgFlag])		//1.56K
wave todo
string RawSpectraTodoList,dataSetStr, diffDest, diffDataSetStr  //1.152 
variable num, calcDiff_flag, AvgFlag

	nvar ams_sqprog	= root:panel:ams_sqprog		// major but progress bar  1.52O
	variable idex
	wave run_index = root:index:run_index				
		
	for(idex=0;idex<num;idex+=1)
		
		ams_sqprog=100*( idex/num)
		sq_create_todo(NameOfWave(todo)+" and "+ stringFromList(idex,RawSpectraTodoList),"tempTodo")
		wave tempTodo=root:tempTodo	

		if (numpnts(tempTodo)>0)
			squirrel_fetch(tempTodo,sq_FindBlanksFetch,"min_cl:0;max_cl:1","MSClosed")		// generates fillblank_todo and fillblank_blanks
			wave /z/i fillblank_todo,fillblank_blanks
			if (waveexists(fillblank_todo) && numpnts(fillblank_todo)>0)	// april 2014 bug  //1.53M
//				print idex, numpnts(fillBlank_todo)
				// first deal with raw
				if (!ParamIsDefault(AvgFlag ) && !AvgFlag)		//1.56K
					squirrel_fetch(fillblank_todo,sq_MS_preprocess,"dest:MSClosed_p;hz_op:1;SaveMS_op:1","MSClosed")	  //1.56J
				endif
				sq_journal_add("Fillblank_MS:1;")
				squirrel_fetch(fillblank_todo,sq_fillblanks,"dest:"+dataSetStr+";fill_id:fillblank_blanks",dataSetStr)
				
				// deal with sticks
				if (calcDiff_flag)  // as in when we are in fast open
					duplicate/o fillblank_blanks fillblanks_blank_todo // kinda klunky generation of todo wave
					fillblanks_blank_todo = run_index[fillblank_blanks[p]]
	//				squirrel_fetch(fillblanks_blank_todo,sq_diffcalc,"hdf_op:1;raw:0;dest:MSSDiff_p","MSSOpen_p;MSSClosed_p")
					squirrel_fetch(fillblanks_blank_todo,sq_diffcalc,"hdf_op:1;raw:0;dest:"+diffDest,diffDataSetStr)
				endif
//				killwaves /z fillblank_todo,fillblank_blanks, fillblanks_blank_todo
			endif
		endif
	endfor
	
	ams_sqprog=100*(1)
	killwaves/z tempTodo
	killwaves /z fillblank_todo,fillblank_blanks, fillblank_blanks_temp, fillblank_todo_temp
End


//Function sq_MSStickSpectraTypes(todo, RawSpectraTodoList, num, paramStr, DataSetStr)
//wave todo
//string RawSpectraTodoList,paramStr, DataSetStr  //1.52
//variable num
//

//	nvar ams_sqprog	= root:panel:ams_sqprog		// major but progress bar  1.52O
//	variable idex
//			

//	for(idex=0;idex<num;idex+=1)
//		ams_sqprog=100*( idex/num)
//		sq_create_todo(NameOfWave(todo)+" and "+ stringFromList(idex,RawSpectraTodoList),"tempTodoSS")
//		wave tempTodoSS=root:tempTodoSS	

//		if(numpnts(preproc)>0)
//			squirrel_fetch(tempTodoSS,sq_MSstick,paramStr+";MaxMz:"+num2str(sq_FindMaxMinMz(tempTodoSS,1,0)),DataSetStr)
//		endif
//	endfor
//	

//	ams_sqprog=100*(1)
//	killwaves/z tempTodoSS
//

//End

// *************************************************
//  Kills all killable waves in list.
//  It does not generate an error if one of the waves in the list is in use (and cannot be deleted)
//  It does not generate an error if the wave in the list does not exist
// It also used to be called KillTheseWaves
//new in 1.52
Function sq_KillWavesInList(wList)
	String wList

	variable oneWaveVar = 0, oneWaveNum = ItemsInList(wList)
	string oneWaveStr 
	
	for (oneWaveVar=0; oneWaveVar<oneWaveNum; oneWaveVar+=1)
		oneWaveStr = StringFromList(oneWaveVar, wList, ";")
		if (exists(oneWaveStr)==1)
			Killwaves/Z $oneWaveStr
		else
	//		print  "This one doesn't exist "+oneWaveStr
		endif
	endfor

End


// returns a string containing the name of the wave that has the mz x axis wave for a todo wave
// added in 1.51L
Function/s sq_FindRawMzBase(numRaw,todo, newMzParamFlag, AsSavedFlag, [mz_reg_dm, mz_reg_min, mz_reg_max, waveNameSuffix])  // 1.60Q
variable numRaw
wave todo
variable newMzParamFlag,AsSavedFlag, mz_reg_dm, mz_reg_min, mz_reg_max
string waveNameSuffix

	wave rn_series = root:index:rn_series
	wave squirrel_index = root:index:squirrel_index
//	wave l_series = root:index:l_series
	wave run_index = root:index:run_index
	string todoStr, wName
	variable FirstRun, mz_int, mz_sl, mz_exp,npnts, indexPos
	
	todoStr = NameOfWave(todo)
	if (AsSavedFlag) //& 'As Saved' - The application of recalculated calibrations will have to be added
		firstrun=sq_findrun(rn_series,todo[0])
		if (newMzParamFlag) //& Use the recalibrated m/z parameters
			wave /z mzSlope=root:mzFitting:mz_FitSlope		//1.56M
			wave /z mzInt=root:mzFitting:mz_FitIntercept		//1.56M
			wave /z mzPower = root:mzFitting:mz_FitPower		//1.56M		
		endif
		if (!newMzParamFlag || !waveexists (mzSlope))
			wave mzSlope=root:diagnostics:mzSlope
			wave mzInt=root:diagnostics:mzint
			mz_exp=1/0.5
		else
			mz_exp=1/mzPower[firstrun]
		endif
		mz_int=mzint[firstrun]
		mz_sl=mzslope[firstrun]
		indexPos = sq_findrun(run_index,todo[0])
		npnts=squirrel_index[indexPos][4][finddimlabel(squirrel_index,2,"MSOpen")]		// could use closed  1.60T
	else //& On a prescribed m/z base
		mz_sl=2*mz_reg_dm/sqrt(28)
		mz_int=-sqrt(mz_reg_min)*mz_sl
		npnts=round((sqrt(mz_reg_max)*mz_sl)+mz_int)
		mz_exp=2
	endif
	
//	wName = SelectString(!ParamIsDefault(waveNameSuffix), "mz_base_"+todostr, "mz_base_"+waveNameSuffix)  //1.60Q
	if (!ParamIsDefault(waveNameSuffix) && strlen(waveNameSuffix)>0)
		wName = "mz_base_"+waveNameSuffix
	else
		wName = "mz_base_"+todostr
	endif
		
	make /o/n=(npnts) $wName/wave=mzbase
	multithread mzbase=((p-mz_int)/mz_sl)^mz_exp		//1.60Z

	Return wName
	
End


//1.51M
Function gen_InterpolateAcrossTime(xWave, yWave)		// assumes x wave is time, is monotonically increasing
wave xWave, yWave

	variable idex, num
	
	num = numpnts(yWave)
	if (num != numpnts(xWave) || num==0 )
		abort "The number of points in the x and y wave must be the same"
	endif
	
	wavestats/q /m=1 yWave
	if (V_npnts==0)
		abort "There must be some non nan points in the wave.  Aborting from gen_InterpolateAcrossTime"
	endif
	
	if (numtype(yWave[0])!=0)
		yWave[0] = yWave[gen_FindFirst(yWave, 0)]
	endif

	if (numtype(yWave[num-1])!=0)
		yWave[num-1] = yWave[gen_Findlast(yWave, num-1)]
	endif

	make/d/FREE/o/n=(num) xwaveNoNan = xWave[p]
	make/d/FREE/o/n=(num) ywaveNoNan = yWave[p]
	// first make non-nan versions
	gen_RemoveNaNsXY(xwaveNoNan, ywaveNoNan)	
	
	for (idex=0;idex<num;idex+=1)
		if(numtype(yWave[idex])!=0)
			ywave[idex] = Interp(xwave[idex], xwaveNoNan, yWaveNoNan)
		endif
	endfor

End

// *************************************************
// Returns the first non-nan value after and including beginPt in a wave.
// If all values after beginPt are nans, Findfirst will return number of points.
//1.52
Function gen_FindFirst(w, beginPt)
	Wave w
	Variable beginPt

	variable i=beginPt,  n=numpnts(w)

	if (i >= n)
		return n
	endif

	if (i < 0)
		return -1
	endif
		
	if (numtype(w[i])== 0 )	// is w[beginPt] a number?
		return i	
	endif

	do
		i+=1
	while  ( (i <n ) &&  (numtype(w[i])!=0) )		//1.60B
	
	return i

End
  
  
  
  // *************************************************
// Returns the last non-nan value before (or including) endPt in a wave.
// If the entire wave is nans, FindLast will return -1.
// It steps through the wave backwards; in decreasing point number.
//1.52
Function gen_FindLast(w, endPt)		
	Wave w
	Variable endPt

	variable i=endPt, n=numpnts(w)

	if (i >= n)
		return n
	endif

	if (i < 0)
		return -1
	endif

	if (numtype(w[i])==0)// is the w[endPt] a number?
		return i		
	endif

	do
		i-=1
	while  ( (i >=0 ) && (numtype(w[i])!=0)  )		//1.60B
	
	return i

End


// RemoveNaNsXY(theXWave, theYWave)
//	Removes all points in an XY pair if either wave has the value NaN.
//	A NaN represents a blank or missing value.
//	Returns the number of points removed.
//1.52
Function gen_RemoveNaNsXY(theXWave, theYWave)
	Wave theXWave
	Wave theYWave

	Variable p, numPoints, numNaNs
	Variable xval, yval
	
	numNaNs = 0
	p = 0											// the loop index
	numPoints = numpnts(theXWave)			// number of times to loop

	do
		xval = theXWave[p]
		yval = theYWave[p]
		if ((numtype(xval)==2) %| (numtype(yval)==2))		// either is NaN?
			numNaNs += 1
		else										// if not an outlier
			theXWave[p - numNaNs] = xval		// copy to input wave
			theYWave[p - numNaNs] = yval		// copy to input wave
		endif
		p += 1
	while (p < numPoints)
	
	// Truncate the wave
	DeletePoints numPoints-numNaNs, numNaNs, theXWave, theYWave
	
	return(numNaNs)
End



// 1.51M this function returns a todo wave to be used for finding MS values for PToF normalization where
//  overhauled in 1.56E
//function sq_PToFnoMSFindRuns(PToFtodo, MStodo, Timedelta, newWaveName)
//wave/i PToFtodo, MStodo
//variable Timedelta
//string newWaveName
//
//	variable idex, num, firstPToF, lastPToF, numRuns, numTodo, firstRun, lastRun, foundFlag
//	variable FastExistsFlag, gotItFlag, currentRun, firstPos, lastPos
//	string firstStr, lastStr
//	wave rn_series = root:index:rn_series
//	wave t_series = root:index:t_series
//	wave/z allMS = root:allMS
//	wave/z allPToF = root:allPToF
//	wave/z allFastOpen = root:allFastOpen
//	wave/z allFast = root:allFast
//	
//	numRuns = numpnts(rn_series)
//	numTodo = numpnts(todoPToFRuns)
//	
//	FastExistsFlag = WaveExists(allFast)
//	firstRun = rn_series[0]	
//	lastRun = rn_series[numRuns-1]	
//	firstPToF = todoPToFRuns[0]
//	lastPToF = todoPToFRuns[numTodo-1]
//	firstPos = sq_findRun(rn_series,firstPToF)
//	lastPos = sq_findRun(rn_series,lastPToF)
//	make/i/o/n=(2) todoPToFRunsResult
//	
//	if (!waveExists(allMS))		// every run has ms, so just use todoPToFRuns	
//		duplicate/o todoPToFRuns $newWaveName
//		return 0
//	endif
//
//	// changed in 1.56E
//	duplicate/o/i todoPToFRuns todoPToFRunsPlusOne
//	todoPToFRunsPlusOne+=1
//
//	duplicate/o/i todoPToFRuns todoPToFRunMinusOne
//	todoPToFRunMinusOne-=1
//	
//	// only look for runs that are +- 1 run away from each ptof run
//	sq_create_todo("todoPToFRunsPlusOne OR todoPToFRuns OR todoPToFRunMinusOne and allMS",newWaveName)
//
//	killwaves/z todoPToFRunsPlusOne, todoPToFRunMinusOne
//	
////	gotItFlag=0
////	// first find the left most run
////	if (sq_findRun(allMS,firstPToF)>=0  )		// first PToF run also has MS, so just use it
////		todoPToFRunsResult[0] = firstPToF
////		gotItFlag=1
////	endif
////	if (!gotItFlag)
////		idex=0
////		foundFlag=0
////		currentRun = firstPToF
////		do
////			if (sq_findRun(allMS,currentRun)>=0)		// this run has MS data
////				if (FastExistsFlag && sq_findRun(allfast,currentRun)>=0)	// is this a fast mode run?					
////					if (sq_findRun(allFastOpen,currentRun)>=0)		// is a fast open
////						foundFlag=1
////					else
////						idex-=1
////						currentRun = rn_series[firstPos+idex]
////					endif
////				else		// run isn't fast mode data
////					foundFlag=1
////				endif
////			else
////				idex-=1
////				currentRun = rn_series[firstPos+idex]
////			endif
////		while(firstPos+idex>=0 && !foundFlag)
////		
////		if (foundFlag)		// did we get out of loop because we found an MS run?
////			todoPToFRunsResult[0] = currentRun
////		else		// we don't have an MS before the first PToF run... so find the first MS run after the first PToF run 
////			idex=0
////			do
////				if (sq_findRun(allMS,firstPToF-idex)>=0)
////					foundFlag=1
////				else
////					idex+=1
////					currentRun = rn_series[firstPos+idex]
////				endif
////			while(firstPos+idex<numRuns && !foundFlag)
////			if (foundFlag)		// did we get out of loop because we found an MS run?
////				todoPToFRunsResult[0] = currentRun
////			else		// we don't have an MS before the first PToF run... so find the first MS run after the first PToF run 
////				abort "Something went wrong in looking for the first MS run in the PToF todo wave "+nameofWave(todoPToFRuns)
////			endif
////		endif
////	endif
////	
////	// first find the right most run
////	currentRun = lastPToF
////	gotItFlag=0
////	if (sq_findRun(allMS,lastPToF)>=0  )		// first PToF run also has MS, so just use it
////		todoPToFRunsResult[1] = lastPToF
////		gotItFlag=1
////	endif
////	
////	if (!gotItFlag)
////		idex=0
////		foundFlag=0
////		do
////			if (sq_findRun(allMS,currentRun)>=0)		// this run has MS data
////				if (FastExistsFlag && sq_findRun(allfast,currentRun)>=0)	// is this a fast mode run?					
////					if (sq_findRun(allFastOpen,currentRun)>=0)		// is a fast open
////						foundFlag=1
////					else
////						idex+=1
////						currentRun = rn_series[lastPos+idex]
////					endif
////				else		// run isn't fast mode data
////					foundFlag=1
////				endif
////			else
////				idex+=1
////				currentRun = rn_series[lastPos+idex]
////			endif
////		while(lastPToF+idex>=numRuns && !foundFlag)
////		
////		if (foundFlag)		// did we get out of loop because we found an MS run?
////			todoPToFRunsResult[1] = currentRun
////		else		// we don't have an MS before the first PToF run... so find the first MS run after the first PToF run 
////			idex=0
////			do
////				if (sq_findRun(allMS,currentRun)>=0)
////					foundFlag=1
////				else
////					idex-=1
////					currentRun = rn_series[lastPos+idex]
////				endif
////			while(lastPos+idex>=0 && !foundFlag)
////			if (foundFlag)		// did we get out of loop because we found an MS run?
////				todoPToFRunsResult[1] = currentRun
////			else		// we don't have an MS before the first PToF run... so find the first MS run after the first PToF run 
////				abort "Something went wrong in looking for the first MS run in the PToF todo wave "+nameofWave(todoPToFRuns)
////			endif
////		endif
////	endif
////	
////	sprintf firstStr,"%d" todoPToFRunsResult[0]
////	sprintf lastStr,"%d", todoPToFRunsResult[1]
////	sq_create_todo(firstStr + "-"+lastStr+" and allMS",newWaveName)
////	killwaves/z todoPToFRunsResult
////	
//End



//1.51N
Function sq_CreateRandom(howMany, parentTodo, resultTodoNameStr)
variable howMany
wave/i parentTodo
string resultTodoNameStr

	variable num = numpnts(parentTodo)
	howMany =  howmany<=0 ? num : howmany	// make sure howMany>0
	howMany = howMany>num ?  num	: howMany	// make sure howMany is < numpnts(parentTodo)
#if (IgorVersion()>=7)			//1.60Y
		StatsSample /N=(howMany)/Z parentTodo
		wave W_Sampled
		duplicate/o W_Sampled $"root:"+resultTodoNameStr/wave=randomTodo
		killwaves/z W_sampled
		sort randomTodo, randomTodo
#else
		Make/i/o/N=(howmany) $"root:"+resultTodoNameStr = round(enoise(1)*(num/2) + (num/2))
		Wave randomTodo = $"root:"+resultTodoNameStr
		sort randomTodo, randomTodo
		duplicate/free randomTodo randomTodoFree
		randomTodo = parentTodo[randomTodoFree[p]]			//1.58G
#endif	
End


// 1.51N
Function gen_findMedian(WaveWithNans)
wave waveWithNans

	duplicate/o/FREE WaveWithNans waveWithNoNans
	sq_RemoveNaNs(waveWithNoNans)
	variable median = StatsMedian(waveWithNoNans)
	return median
End


// updates data wave PToF_DCGr_oneMz, display string PToF_DCgr_UseRegions
// calls sq_PToF_DCGr_butt_plotDC to update the yellow DC marker regions in the graph
// for ePToF, updates the confid limit value, the confid limit displayed wave, test region
Function sq_PToF_DCGr_setVar_mz(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	nvar PToF_DCgr_mzchoice = root:panel:PToF_DCgr_mzchoice
	nvar PToF_DCgr_runNumber = root:panel:PToF_DCgr_runNumber
	svar PToF_DCgr_UseRegions = root:panel:PToF_DCgr_UseRegions
	svar cor3_region1channels = root:panel:cor3_region1channels
	svar cor3_region2channels = root:panel:cor3_region2channels
	svar PToF_DCgr_runInfo = root:panel:PToF_DCgr_runInfo
	nvar ptof_dcRegion1Allnot2 = root:panel:ptof_dcRegion1Allnot2		//1.59E
	nvar PToF_DCgr_maxMz = root:panel:PToF_DCgr_maxMz
	nvar PToF_DCgr_minMz = root:panel:PToF_DCgr_minMz

	wave PToF_DCGr_oneMz = root:panel:PToF_DCGr_oneMz
	wave PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix
	variable reg1, reg2, pos
	
	wave PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix
	PToF_DCgr_mzChoice = min(PToF_DCgr_maxMz, PToF_DCgr_mzChoice)		//1.60D
	PToF_DCgr_mzChoice = max(PToF_DCgr_minMz, PToF_DCgr_mzChoice)  //1.60D

	nvar/z ePToFExists = root:diagnostics:ePToFExists
	if ( !Nvar_exists(ePToFExists))
		sq_SetePToFExists()
		nvar ePToFExists = root:diagnostics:ePToFExists
	endif
	
	if (ePToFExists)

		nvar PToF_ePToF_Mulitplier=root:panel:PToF_ePToF_Mulitplier	
		svar DCGr_ePToFInfoStr=root:panel:DCGr_ePToFInfoStr	
	
		Wave/z ePToF_TestRegion = root:diagnostics:ePToF_TestRegion
		if (!WaveExists(ePToF_TestRegion))		// we have eptof, but have not deconvolved
			make/o/n=(numpnts(root:index:rn_series))  root:panel:ePToF_TestRegion/wave=ePToF_TestRegion
			ePToF_TestRegion = nan
		endif
			
		if (PToF_ePToF_Mulitplier>0)	// this run is ePToF  // variable PToF_ePToF_Mulitplier
			// even though a user may have preprocessed, they could have chosen Joel or not to deconvolve.... maye we should warn if thye do try to do this?
			PToF_DCgr_UseRegions = "Use test region"					
			nvar deconvolveMike = root:panel:deconvolveMike	
			if (deconvolveMike && strlen(WinList("PTOFePTOF_Tool*", ";", "WIN:1"))>0)
			endif

		else			// treat just like regular PToF
			reg1 = WhichListItem(num2str(PToF_DCgr_mzchoice), cor3_region1channels, "," )
			reg2 = WhichListItem(num2str(PToF_DCgr_mzchoice), cor3_region2channels, "," )
			if (reg1>=0)
				if (ptof_dcRegion1Allnot2)
					PToF_DCgr_UseRegions = "Use region 1 only"	
				elseif (reg2>=0)
					PToF_DCgr_UseRegions = "Use neither region 1 or 2 - ERROR!"
				else
					PToF_DCgr_UseRegions = "Use region 1 only"			
				endif
			elseif(reg2>=0)
				PToF_DCgr_UseRegions = "Use region 2 only"	
			else
				PToF_DCgr_UseRegions = "Use region 1 and 2"					
			endif
		endif
	
	else
		reg1 = WhichListItem(num2str(PToF_DCgr_mzchoice), cor3_region1channels, "," )
		reg2 = WhichListItem(num2str(PToF_DCgr_mzchoice), cor3_region2channels, "," )
		if (reg1>=0)
			if (ptof_dcRegion1Allnot2)
				PToF_DCgr_UseRegions = "Use region 1 only"	
			elseif (reg2>=0)
				PToF_DCgr_UseRegions = "Use neither region 1 or 2 - ERROR!"
			else
				PToF_DCgr_UseRegions = "Use region 1 only"			
			endif
		elseif(reg2>=0)
			PToF_DCgr_UseRegions = "Use region 2 only"	
		else
			PToF_DCgr_UseRegions = "Use region 1 and 2"					
		endif
	endif

	sq_PToF_DCGr_butt_plotDC("") 
	if (numpnts(PToF_DCgr_onePToFMatrix)>1 && PToF_DCgr_mzChoice>=dimsize(PToF_DCgr_onePToFMatrix,2))  //1.60E
		PToF_DCGr_oneMz = PToF_DCgr_onePToFMatrix[p][PToF_DCgr_mzChoice - 1]
	endif
End


//1.52O  the Main workhorse of sq_PToFDCgr_GetThisMatrix()
// It calls a fetch function to retrieve data and, if ePToF, fills in ePToF parameters
// always only works
Function sq_PToF_DCGr_FetchMatrix(todo, dataSet, subtractDCflag)
wave todo
string dataSet
variable subtractDCflag

	string paramStr ="", dummyStr=""
	variable pos, j, isEPToF
		
	nvar cor3_chamber=root:panel:cor3_chamber	// not in panel, loaded in get index
	nvar chopper_duty=root:diagnostics:chopper_duty	// not in panel, loaded in get index
//	nvar ePToF_postmatrixInvDC = root:panel:ePToF_postmatrixInvDC
//	ePToF_postmatrixInvDC=1

	nvar deconvolveNone = root:panel:deconvolveNone
	nvar testRegion = root:panel:PToF_ePToF_TestRegion
	wave ePToF_oversampling = root:diagnostics:ePToF_oversampling
	wave ePToF_enabled = root:diagnostics:ePToF_enabled

	pos = sq_findRun(root:index:rn_series,todo[0])
	
	isEPToF = sq_TodoHasPToF(todo, ptofFlag=0)		//1.59C

	if (isEPToF && !deconvolveNone)		//1.19C
		if ( ! (testRegion>0 && testRegion<0.9) )
			abort "The ePToF baseline region parameter needs to be between 0 and 0.9  - aborting from sq_ePTOF_DCMarker_viewings"
		endif	
	endif
	
// here are the parameters needed for the sq_insert_Matrix function which will be called inside of  the conc function
//	wave source=$"root:hoard:acorn_0"
//	string text=stringbykey("text",paramstr)
//	string dest=stringbykey("dest",paramstr)
//	variable ptof_flag=1		// dimsize(source,2)>0?(1):(0)
	variable hz_op=	1	// numberbykey("hz_op",paramstr)
	variable hdf_op=0		// numberbykey("hdf_op",paramstr)
	variable hdfwrite=0		//=strlen(dest)>0 && hdf_op
	variable duty_op=1 //=numberbykey("duty_op",paramstr)
	variable applyDC=0 // =numberbykey("applyDC",paramstr)==1
//	variable ePToF_flag=numberbykey("ePToF_flag",paramstr)==1
	variable ePToF_OS=numberbykey("ePToF_OS",paramstr)
//	variable idex,insertdiff
	paramStr ="hz_op:1;hdf_op:0;duty_op:1;applyDC:0;"

	//1.57D
	variable collapsePToF_op=numberbykey("collapsePToF_op",paramstr)
	variable collapsePToF_Avg=numberbykey("collapsePToF_Avg",paramstr)
	string collapsePToF_dest=stringbykey("collapsePToF_dest",paramstr)

	paramStr+="ePToF_flag:"+num2str(isEPToF)+";"		//1.53N
	paramStr+="PostAvgFlag:0;"	  	// avg across runs, deconvolve THEN apply frag ............ cannot have time dependent frags!
	make/n=(numpnts(ePToF_enabled))/o/free OS = ePToF_oversampling*ePToF_enabled
	paramStr+="osFactor:"+num2str(Wavemax(OS))+";"		//1.57L

	paramStr+="lc:"+num2str(cor3_chamber)+";"
	paramStr+="chop_duty:"+num2str(chopper_duty)+";"  		//1.53  ONly comes into play for regular ptof not eptof
	paramStr+="ug_op:0"
	paramStr+="filter_op:0;"
	paramStr+="product_type:6;"
	paramStr+="d_base:;"
	paramStr+="t_base:;"
	paramStr+="dlog_op:0;"
	paramstr+="frag_exclude:;" 
	paramstr+="fraglist:all;" 
	paramstr+="speclist:all;" 
//	paramstr+=selectString(stringmatch(dataSet, "ptof_stick"), "", "hz_op:1")
	paramStr+="timeweight_op:4;"
	paramStr+="destlist:temp_PToFmatrix;"
	paramStr+="ignoreChop:1;"		// we want to do the same thing for ePToF as we did for PToF.... Do not consider the ePToF duty correction until PToF products are formed.
	paramStr+="osFactor:"+selectString(WaveExists(ePToF_oversampling) , "", num2str(ePToF_oversampling[pos])) +";"

	paramStr+="daqPToFStick:"+num2str(stringmatch(dataSet, "ptof_stick"))+";"

	// Step 3.  Fetch  to get PToF results
//	print paramstr
	squirrel_fetch(todo,sq_MS_concentration,paramstr,dataSet)
	
	wave temp_PToFmatrix = root:temp_PToFmatrix
	// convert to Hz and do duty cycle so units are same as when we get the data via PToF tab, calculate buttons, no ug/m3
	
	duplicate/o temp_PToFmatrix  root:panel:PToF_DCgr_onePToFMatrix

	wave PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix
	MatrixTranspose PToF_DCgr_onePToFMatrix

//	variable samplingInterval = sq_nSecMSsamplingIntervalConst()
//	if (stringmatch(dataSet, "ptof_stick"))
//		make/o/n=(numpnts(todo))/i index_pos
//		// set the acorn_refs wave,  which tells the place of the runs of acorn_index, within run_index

//		wave run_index = root:index:run_index
//		for (j=0;j<numpnts(todo);j+=1)	// for each run in this acorn
//			findvalue/i=(todo[j]) run_index		// JDA fix in 1.42A
//			if (v_value==-1)
//				findvalue /i=(todo[j]) run_index
//			endif
//			index_pos[j]=v_value
//		endfor
//	
//		sq_Hz(index_pos,PToF_DCgr_onePToFMatrix)
//		sq_correctSamplingTimeUnit(index_pos, PToF_DCgr_onePToFMatrix, nSecMSsamplingIntervalVal = samplingInterval)		//1.54D
//		sq_dutyCycleCorr(PToF_DCgr_onePToFMatrix,1)
//	endif
	
// #if exists("demux") != 0		// we have the ePToF DC marker graph
	nvar/z ePToFExists = root:diagnostics:ePToFExists
	if ( !Nvar_exists(ePToFExists))
		sq_SetePToFExists()
		nvar ePToFExists = root:diagnostics:ePToFExists
	endif
	
	if (ePToFExists)
	// we need to fill in the variables for the preprocessed data
		sq_ePTOF_DCMarker_viewings(todo, PToF_DCgr_onePToFMatrix)
		if (subtractDCflag) 		// ePToF_postmatrixInvDC)
			duplicate/free PToF_DCgr_onePToFMatrix, DC 
			variable bins = dimsize(DC,0)		// number of rows
			variable n = round(bins*(1-testregion))-1// cuz we count from zero
			DC[0,n][]=0
			matrixop/o/free avg = sumCols(DC)/(bins-n-1)
			PToF_DCgr_onePToFMatrix-=avg[0][q]
		endif
	endif
// #endif

	killwaves/z temp_PToFmatrix
	Killwaves/z 

End


Function sq_ePTOF_DCMarker_viewings(todo, PToF_DCgr_onePToFMatrix)
wave todo, PToF_DCgr_onePToFMatrix

	// we need to fill in the variables for the preprocessed data
	//1.52D  ePToF
	nvar chopper_duty=root:diagnostics:chopper_duty	// not in panel, loaded in get index
	Wave ePToF_enabled = root:diagnostics:ePToF_enabled
	Wave ePToF_oversampling = root:diagnostics:ePToF_oversampling
	wave rn_series = root:index:rn_series

	nvar deconvolve = root:panel:deconvolve 		//Rich
	nvar deconvolveJoel = root:panel:deconvolveJoel
	nvar deconvolveNone = root:panel:deconvolveNone
	nvar/z deconvolveMike = root:panel:deconvolveMike
	if (!Nvar_exists(deconvolveMike))
		variable/g root:panel:deconvolveMike
		nvar deconvolveMike = root:panel:deconvolveMike
	endif	
	nvar PToF_ePToF_Mulitplier = root:panel:PToF_ePToF_Mulitplier
	nvar PToF_ePToF_testRegion = root:panel:PToF_ePToF_testRegion
	nvar PToF_DCMarkerSingleRun = root:panel:PToF_DCMarkerSingleRun
	nvar PToF_DCgr_runNumber = root:panel:PToF_DCgr_runNumber
	nvar PToF_DCgr_mzChoice = root:panel:PToF_DCgr_mzChoice
//	svar ePToF_waveNamePrefix = root:panel:ePToF_waveNamePrefix
	nvar chopper_duty=root:diagnostics:chopper_duty	// not in panel, loaded in get index
	wave ChopperFreq=root:diagnostics:ChopperFreq	// not in panel, loaded in get index

	svar DCGr_ePToFInfoStr = root:panel:DCGr_ePToFInfoStr
	nvar PToF_DCgr_maxMz = root:panel:PToF_DCgr_maxMz

	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	
	
	wave/z DCGr_ePToF_confidLimWave = root:panel:DCGr_ePToF_confidLimWave		// for display	...mz number of points big // should be updated by sq_PToFDCgr_GetThisMatrix
	if (!WaveExists(DCGr_ePToF_confidLimWave))		//1.53D
		make/o/n=(PToF_DCgr_maxMz) root:panel:DCGr_ePToF_confidLimWave/wave= DCGr_ePToF_confidLimWave		// for display	...mz number of points big // should be updated by sq_PToFDCgr_GetThisMatrix
	endif
	
	variable pos, ug_fac, DeconvolvedDone
	
	pos = sq_findRun(root:index:rn_series,todo[0])

	if ( abs(ePToF_enabled[pos])!=0)		// this run IS ePToF   		//1.55B
			
		PToF_ePToF_Mulitplier = ePToF_oversampling[pos]
		
		sq_SeqExpand(PToF_ePToF_Mulitplier)
		Wave SeqOutExp = root:PToF:SeqOutExp

		nvar/z DCgr_smoothVar = root:panel:DCgr_smoothVar  //moved here in 1.60T
		if ( !Nvar_exists(DCgr_smoothVar) )// !Nvar_exists(DCgr_ck_alsoSmooth) ||  //1.59D
			variable/g root:panel:DCgr_smoothVar
			nvar DCgr_smoothVar = root:panel:DCgr_smoothVar
		elseif(deconvolveJoel && DCgr_smoothVar>1)// DCgr_ck_alsoSmooth && 		//1.59D
			sq_ePToF_2DsmoothCol(PToF_DCgr_onePToFMatrix, DCgr_smoothVar)
		endif

		if  ( deconvolveJoel  || deconvolveMike) 		// deconvolve 
			if (!DataFolderExists("root:TWEPToF:" )  )
				TWEPToF_globals(OS=ePToF_oversampling[pos])		//1.60X
			endif
			duplicate/o/free PToF_DCgr_onePToFMatrix, deconvolved2DData
			sq_EPToFDeconvolve2D(PToF_DCgr_onePToFMatrix, PToF_ePToF_Mulitplier, deconvolved2DData, DCGr_ePToF_confidLimWave,SeqOutExp, 0)  //1.60A	
			PToF_DCgr_onePToFMatrix =deconvolved2DData[p][q]
		endif

		DCGr_ePToFInfoStr="DAQ"

	else
		PToF_ePToF_Mulitplier=nan
		DCGr_ePToFInfoStr="Not ePToF"
	endif
	
	killwaves/z oneDdata, deconvolved1DData

End


// set var control function called from DCMarkerGr.  Sets run number of PToF matrix to examine
Function sq_PToF_DCGr_setVar_Run(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName	
	
	if (strlen(ctrlName)>0)		// user changed the run number via the control
		sq_DCGr_UpdateRunNumParams()
		// sq_PToFDCgr_GetThisMatrix()		//1.57N
 	endif	

End


// set var control function called from DCMarkerGr.  Sets various controls on panel to update to the latest run values
Function sq_DCGr_UpdateRunNumParams()	
	
	wave mFinish = root:diagnostics:mFinish
	wave mStart = root:diagnostics:mStart		
	wave TimeAcquiringPToFInRun = root:diagnostics:TimeAcquiringPToFInRun

	wave rn_series = root:index:rn_series
			
	nvar lengthChamber = root:panel:cor3_chamber		// chamber length
	svar PToF_DCgr_RunInfo = root:panel:PToF_DCgr_RunInfo
	nvar PToF_DCgr_runNumber = root:panel:PToF_DCgr_runNumber
	nvar PToF_DCgr_numBins = root:panel:PToF_DCgr_numBins
	
	nvar PToF_DCgr_t0 = root:panel:PToF_DCgr_t0
	nvar PToF_DCgr_tstep = root:panel:PToF_DCgr_tstep
	nvar PToF_DCgr_minMz = root:panel:PToF_DCgr_minMz
	nvar PToF_DCgr_maxMz = root:panel:PToF_DCgr_maxMz
	nvar PToF_DCgr_mzChoice = root:panel:PToF_DCgr_mzChoice
	nvar PToF_DCMarkerDuration = root:panel:PToF_DCMarkerDuration

	nvar/z PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	if (!Nvar_exists(PToF_DCgr_IsEPToF))
		variable/g root:panel:PToF_DCgr_IsEPToF
		nvar PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	endif
	
	wave PToF_DCgr_displayX = root:panel:PToF_DCgr_displayX		// is x axis for other traces in graph
	wave PToF_DCgr_displayY = root:panel:PToF_DCgr_displayY		// shows black dots for size locations
	wave PToF_DCgr_oneMz = root:panel:PToF_DCgr_oneMz	// shows one m/z size profile
	wave PToF_DCgr_regionY = root:panel:PToF_DCgr_regionY	// colored region 1 and 2
	wave/z ptof_dVaDisplaySize = root:panel:ptof_dVaDisplaySize
	wave/z ptof_dVaDisplayTime = root:panel:ptof_dVaDisplayTime
	if (!WaveExists(ptof_dVaDisplaySize) || !WaveExists(ptof_dVaDisplaySize) )
		make/o/n=1 root:panel:ptof_dVaDisplaySize, root:panel:ptof_dVaDisplayTime
		wave ptof_dVaDisplaySize = root:panel:ptof_dVaDisplaySize
		wave ptof_dVaDisplayTime = root:panel:ptof_dVaDisplayTime
	endif
	wave/z PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix	// shows PToF matrix
	if (!WaveExists(PToF_DCgr_onePToFMatrix)  )
		make/o/n=1 root:panel:PToF_DCgr_onePToFMatrix
		wave PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix	// shows PToF matrix
	endif
		
	variable existVar, pos, mzSize, temp
	string dataStr

	pos = sq_FindRun(rn_series, PToF_DCgr_runNumber)		//1.51Q
	if (pos<0)		//1.59D
		abort "Please reselect the run number"
	endif
	existVar=sq_DoesPToFDataExist(PToF_DCgr_runNumber)		// should be unnecessary  1 means we have some type of PToF data (num secs >0), 0 means no PToF data, -1 means not a good run
	
	make/o/FREE/n=20 DVa_wave, ptof_dVa, ptof_dTime
	sq_GetPToFParams(DVa_wave, pos)		
	Redimension/n=(DVa_wave[%NumPToFBins]) ptof_dVa, ptof_dTime

	ptof_dTime = DVa_wave[%t0] + p*DVa_wave[%step]
	nvar deconvolveMike = root:panel:deconvolveMike		//1.60X  the tw deconvolution already adjusts the PToF t0
	if (PToF_DCgr_IsEPToF && deconvolveMike)
		sq_CorrectPToFTimeForTWDecon(DVa_wave, ptof_dTime)
	endif
	if (DVa_wave[%NumPToFBins]>0)		//1.19C 
		ptof_dVa = sq_ptof2dva(lengthChamber,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],ptof_dTime[p])  // will be changed if MikeDeconv
	endif

	nvar/z ePToFExists = root:diagnostics:ePToFExists
	if ( !Nvar_exists(ePToFExists))
		sq_SetePToFExists()
		nvar ePToFExists = root:diagnostics:ePToFExists
	endif
	
	if (existVar<1)
		if (existVar<0)
			PToF_DCgr_RunInfo="Non-existent run"		// run isn't valid
			PToF_DCgr_displayX=nan	
		else 
			PToF_DCgr_RunInfo="No PToF/ePToF data"
			PToF_DCgr_displayX=nan
			PToF_DCgr_displayY=nan
			PToF_DCgr_regionY=nan	
			PToF_DCgr_oneMz=nan	
		endif
		PToF_DCgr_maxMz = nan
		PToF_DCgr_minMz = nan
		PToF_DCgr_t0 = nan
		PToF_DCgr_tstep = nan
		PToF_DCgr_numBins = nan
		PToF_DCMarkerDuration = nan
		PToF_DCgr_IsEPToF=nan
//		ModifyGraph/W=PToFePTOF_Tool#DCMarkerGr hideTrace(PToF_DCgr_confidLim)=0
	else 
		// set displays
		PToF_DCgr_RunInfo="PToF"
		PToF_DCgr_maxMz = mFinish[pos]
		PToF_DCgr_minMz = mStart[pos]
		PToF_DCgr_t0 = DVa_wave[%t0] // ptof_t0[pos]  1.59E
		PToF_DCgr_tstep = DVa_wave[%step]  // ptof_step[pos]  1.59E
		PToF_DCgr_numBins = DVa_wave[%NumPToFBins] // ptofNumSpectraPerChop[pos]
		PToF_DCMarkerDuration = TimeAcquiringPToFInRun[pos]
		
		if(PToF_DCgr_mzChoice< mStart[pos])
			PToF_DCgr_mzChoice=mStart[pos]
		elseif (PToF_DCgr_mzChoice> mFinish[pos])
			PToF_DCgr_mzChoice=mFinish[pos]		
		endif
		
		redimension/n=(PToF_DCgr_numBins) PToF_DCgr_displayX, PToF_DCgr_oneMz, PToF_DCgr_displayY, PToF_DCgr_regionY
		redimension/n=(PToF_DCgr_numBins, mzSize) 	PToF_DCgr_onePToFMatrix	
		PToF_DCgr_displayX = 1e6 * ptof_dTime //PToF_DCgr_t0 + PToF_DCgr_tstep*p		//1.59E  removed 1e6 *   //1.60X  this will not be correct for ePToF tw deconvol
		PToF_DCgr_oneMz = nan
		PToF_DCgr_displayY=1
		PToF_DCgr_regionY=nan
		
		temp = BinarySearch(ptof_dVa, 10 )
		PToF_DCgr_displayY[round(temp)]=2
		temp = BinarySearch(ptof_dVa, 100 )
		PToF_DCgr_displayY[round(temp)]=2
		temp = BinarySearch(ptof_dVa, 1000 )
		temp = temp > 0 ? temp : 0		//1.60D  for folks with PToF ranges < 1000nm.
		PToF_DCgr_displayY[round(temp)]=2

		if (ePToFExists) 
			Wave ePToF_enabled = root:diagnostics:ePToF_enabled
			Wave ePToF_oversampling = root:diagnostics:ePToF_oversampling
			nvar PToF_ePToF_Mulitplier = root:panel:PToF_ePToF_Mulitplier
			if (abs(ePToF_enabled[pos])!=0)
				PToF_DCgr_IsEPToF=1
				PToF_ePToF_Mulitplier = ePToF_oversampling[pos]
				PToF_DCgr_RunInfo="ePToF"
			else
				PToF_DCgr_IsEPToF=0
				PToF_ePToF_Mulitplier = nan
			endif	
			Titlebox PToF_Help fstyle = !(PToF_DCgr_IsEPToF)
			Titlebox PToF_step1a fstyle = !(PToF_DCgr_IsEPToF), fsize=SelectNumber (!PToF_DCgr_IsEPToF, 12,14)
			Titlebox ePToF_step1 fstyle = (PToF_DCgr_IsEPToF) , fsize=SelectNumber (!PToF_DCgr_IsEPToF, 14,12)
			Titlebox ePToF_Help fstyle = (PToF_DCgr_IsEPToF)
//			ModifyGraph/W=PToFePTOF_Tool#DCMarkerGr hideTrace(PToF_DCgr_confidLim)=!PToF_DCgr_IsEPToF
		endif
	endif	
//	PToF_DCgr_confidLim = nan
	if (PToF_DCMarkerDuration>-1 && PToF_DCMarkerDuration<1 )	// less than 1 second is arbitrary
		if (stringmatch(WinName(0,64), "ePToFPToFTool") )
			ValDisplay DCgr_DurationOfPToF fstyle=1
		endif
	else
		if (stringmatch(WinName(0,64), "ePToFPToFTool") )
			ValDisplay DCgr_DurationOfPToF fstyle=0
		endif
	endif
		
	return ExistVar
	
End


// 1.59A
Function sq_butt_PToFReg1Only(ctrlName) : ButtonControl
	String ctrlName
	
	svar cor3_region1channels=root:panel:cor3_region1channels
	svar cor3_region2channels=root:panel:cor3_region2channels
	
	wave amus = root:diagnostics:amus
	Variable idex, num
	cor3_region1channels=""
	if (strsearch(ctrlName, "PToF_buttSetRegion1OnlyMz", 0)>=0)
		for(idex=12;idex<numpnts(amus);idex+=1)
			cor3_region1channels +=num2str(idex)+","
		endfor
		for(idex=0;idex<numpnts(amus);idex+=1)
			cor3_region1channels = RemoveFromList(stringFromList(idex, cor3_region2channels, ","), cor3_region1channels, ",", 0)
		endfor
	endif	
End


// button control function called from DCMarkrerGr
// updates yellow shaded region in DCMarkrerGr
// PToF_DCgr_regionY and optionally PToF_ePToF_testRegion
Function sq_PToF_DCGr_butt_plotDC(ctrlName) : ButtonControl
	String ctrlName
 
	svar PToF_DCgr_runInfo = root:panel:PToF_DCgr_runInfo
	nvar PToF_DCgr_mzchoice = root:panel:PToF_DCgr_mzchoice
	wave PToF_DCgr_regionY = root:panel:PToF_DCgr_regionY
	wave ptof_dcMarkersPtWave = root:panel:ptof_dcMarkersPtWave
	nvar PToF_DCGr_runNumber = root:panel:PToF_DCGr_runNumber
	nvar deconvolveNone = root:panel:deconvolveNone
//	nvar PToF_DCGr_DAQSticks = root:panel:PToF_DCGr_DAQSticks

	svar cor3_region1channels = root:panel:cor3_region1channels
	svar cor3_region2channels = root:panel:cor3_region2channels
 
	nvar ptof_dcRegion1Allnot2 = root:panel:ptof_dcRegion1Allnot2

	variable pos, DeconvolvedDone
	pos = sq_FindRun(root:index:rn_series, PToF_DCGr_runNumber) 
 	if (pos<0)
 		abort "Please reselect the run number. aborting from sq_PToF_DCGr_butt_plotDC"		//1.50L
 	endif
 
// 	PToF_DCgr_displayY
 	PToF_DCgr_regionY=nan
	nvar/z ePToFExists = root:diagnostics:ePToFExists
	if ( !Nvar_exists(ePToFExists))
		sq_SetePToFExists()
		nvar ePToFExists = root:diagnostics:ePToFExists
	endif
	
	variable InRegion2 = WhichListItem(num2str(PToF_DCgr_mzchoice), cor3_region2channels, ",")>=0
	variable InRegion1 = WhichListItem(num2str(PToF_DCgr_mzchoice), cor3_region1channels, ",")>=0
	if (ePToFExists)
// #if exists("demux") != 0		// we have the ePToF DC marker graph

		Wave ePToF_enabled = root:diagnostics:ePToF_enabled
		nvar PToF_ePToF_testRegion = root:panel:PToF_ePToF_testRegion
		if (abs(ePToF_enabled[pos])!=0)		// ePToF			//1.55B
			make/i/o/n=1 temptodo = PToF_DCGr_runNumber
//			DeconvolvedDone = sq_checkNoDCPreprocPToF(temptodo, 1)	//1.19C
	 
//			if (!PToF_DCGr_DAQSticks && DeconvolvedDone)		//  preprocessed
//				wave ePToF_TestRegion = root:diagnostics:ePToF_TestRegion		// should exist
//				PToF_ePToF_testRegion= ePToF_TestRegion[pos]
//			endif
			PToF_DCgr_regionY=1
			if (!deconvolveNone)
				PToF_DCgr_regionY[ numpnts(PToF_DCgr_regionY)*(1-PToF_ePToF_testRegion),] = 2
			endif
		else		// regular PToF data
	 		sq_dcMarkersExamine(pos)	// updates ptof_dcMarkersPtWave	
			PToF_DCgr_regionY[ptof_dcMarkersPtWave[0],ptof_dcMarkersPtWave[1]] = 2
			PToF_DCgr_regionY[ptof_dcMarkersPtWave[2],ptof_dcMarkersPtWave[3]] = 2
			if (ptof_dcRegion1Allnot2)
				if (InRegion2)
					PToF_DCgr_regionY[ptof_dcMarkersPtWave[0],ptof_dcMarkersPtWave[1]] = nan
				else
					PToF_DCgr_regionY[ptof_dcMarkersPtWave[2],ptof_dcMarkersPtWave[3]] = nan
				endif
			else
				if(numpnts(PToF_DCgr_regionY)>0 && InRegion2)
					PToF_DCgr_regionY[ptof_dcMarkersPtWave[0],ptof_dcMarkersPtWave[1]] = nan
				endif
			endif
		endif
		killwaves/z temptodo
	elseif (strsearch(lowerStr(PToF_DCgr_runInfo), "false", 0) <0)
 		sq_dcMarkersExamine(pos )	// updates ptof_dcMarkersPtWave	
 		PToF_DCgr_regionY = nan
		if (numpnts(PToF_DCgr_regionY)>0 && !InRegion2)		//1.59E
			PToF_DCgr_regionY[ptof_dcMarkersPtWave[0],ptof_dcMarkersPtWave[1]] = 2
		endif
		if (!ptof_dcRegion1Allnot2)
			if(numpnts(PToF_DCgr_regionY)>0 && !InRegion1) //1.59E
				PToF_DCgr_regionY[ptof_dcMarkersPtWave[2],ptof_dcMarkersPtWave[3]] = 2
			endif
		elseif(ptof_dcRegion1Allnot2 && InRegion2) 
			PToF_DCgr_regionY[ptof_dcMarkersPtWave[2],ptof_dcMarkersPtWave[3]] = 2  //1.60E
		endif
	endif	
End


//1.59E
Function sq_PToF_Region1Check(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			svar cor3_region1channels = root:panel:cor3_region1channels
			if (cba.checked)
				cor3_region1channels = "all m/zs not in Region 2 only"
			else 
				cor3_region1channels = ""
			endif
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


// not needed?  1.52
//Function sq_PToF_ug_CheckProc(cba) : CheckBoxControl
//	STRUCT WMCheckboxAction &cba
//
//	switch( cba.eventCode )
//		case 2: // mouse up	
//			sq_PToF_NormSanity()
//			break
//		case -1: // control being killed
//			break
//	endswitch
//
//	return 0
//
//End


// not needed?  1.52
//Function sq_PToF_NormSanity()
//
//	nvar tof1_ugconv = root:panel:tof1_ugconv  // variable name
//	nvar tof1_datatype = root:panel:tof1_datatype  // variable name and popmenu of diameter type and variable name
//	
//	if (tof1_ugconv==0)		// variable name
//		SetVariable tof0_minda disable=2
//		CheckBox tof1_norm disable=2
//		nvar tof1_norm = root:panel:tof1_norm //  // control name and variable name
//		tof1_norm=0
//	else
//		SetVariable tof0_minda disable=0
//		CheckBox tof1_norm disable=0
//	endif
//	
//	if (tof1_datatype==1)		// dXdlogDa vs lodDa
////		ControlList
//		SetVariable tof0_minda disable=0
//		CheckBox tof1_norm disable=0
//	else // X vs ToF
//		SetVariable tof0_minda disable=2
//		CheckBox tof1_norm disable=2
//		nvar tof1_norm = root:panel:tof1_norm //  // control name and variable name
//		tof1_norm=0
//	endif
//End


// not needed?  1.52
//Function sq_PToF_diamAxisPopMenu(ctrlName,popNum,popStr) : PopupMenuControl
//	String ctrlName
//	Variable popNum
//	String popStr
//
//	sq_pop_getVariable(ctrlName,popNum,popStr)
//	sq_PToF_NormSanity()
//	
//End


// 1.51O
// A one button function for usual processing of Fast mode data
Function fm_butt_DoUsual(ctrlName) : ButtonControl // MJC 3/9/2009 - Define start and end of FMS cycles
	String ctrlName
	
	fm_butt_DefineCycles("")
	fm_butt_makeFirstFastToDos("")
	
	nvar Blacklist1Transitions = root:panel:fastMS:Blacklist1Transitions

	if (Blacklist1Transitions)
		sq_create_todo("blacklist or First1Open","blacklist")		// add run to blacklist wave
		sq_create_todo("blacklist or First1Closed","blacklist")		// add run to blacklist wave	

		sq_blacklist()		// goes through all existing todo waves to remove all runs in blacklist

		print "// The first runs in the fast mode transtions were blacklisted."
	endif    

End


// new in 1.52
// Checkbox for DC marker graph
Function sq_ck_PToF_SingleRunTodo(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar PToF_DCMarkerSingleRun=root:panel:PToF_DCMarkerSingleRun

	PToF_DCMarkerSingleRun = strsearch(ctrlName, "SingleRun", 0)>=0
	Checkbox DCgr_Todo value = !PToF_DCMarkerSingleRun, win=PToFePToF_Tool
	Checkbox DCgr_SingleRun value = PToF_DCMarkerSingleRun, win=PToFePToF_Tool
	
	if (!PToF_DCMarkerSingleRun)
	// at this point it is important to know if different PToF runs have different DAQ settings.
		svar sq_toDoWvNm = root:panel:sq_toDoWvNm
		wave todo = $"root:"+sq_toDoWvNm
		if (numpnts(todo) == 0)
			abort "This todo wave has zero runs.  Aborting from sq_ck_PToF_SingleRunTodo"
		endif
		sq_checkPToFparamsSameTodo(todo)
		nvar PToF_DCgr_runNumber = root:panel:PToF_DCgr_runNumber
		PToF_DCgr_runNumber=todo[0]
	endif		// we have a single run
	
	sq_DCGr_UpdateRunNumParams()		// update # PToF bins, etc controls, resize display waves

End


// new in 1.52
// Popmenu for todo wave in DC marker graph
Function sq_PToFDC_PopMenuProc(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr

	sq_pop_toDoList("ams_todolist_pop",popNum,popStr)
	if (!stringMatch("Get List",ctrlName ) && strlen(ctrlName)>0) 
		sq_ck_PToF_SingleRunTodo("",1)
	endif
End


// new in 1.52
// called within DCMarker_gr whenever new todo, run, DAQ/preprocessed Sticks or deconvolve/no deconvolve is selected in DCMarker_gr
// Not called from PToF tab nor tw deconv panel
Function sq_PToFDCgr_GetThisMatrix()

	nvar PToF_DCMarkerSingleRun=root:panel:PToF_DCMarkerSingleRun		// else Todo	
//	nvar PToF_DCgr_DAQsticks=root:panel:PToF_DCgr_DAQsticks			// else preprocessed
	nvar PToF_DCGr_runNumber = root:panel:PToF_DCGr_runNumber
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	
	wave/z blacklist
	wave todo = $"root:"+sq_toDoWvNm
	wave squirrel_index = root:index:squirrel_index
	wave run_index = root:index:run_index
	variable indexpos, dimLay

	if (!PToF_DCMarkerSingleRun)		// do we have pre processed data for the requested run?  just check first run in todo
		indexpos = sq_findRun(run_index,todo[0])
	else
		indexpos = sq_findRun(run_index,PToF_DCGr_runNumber)
	endif
	if (indexpos<0)
		abort "This run doesn't exist. - aborting from sq_PToFDCgr_GetThisMatrix"	
	elseif (WaveExists(blacklist) && sq_findRun(blacklist,PToF_DCGr_runNumber)>=0 )
		abort "This run has been blacklisted - aborting from sq_PToFDCgr_GetThisMatrix"	
	endif

// now get to work     make the a temporary todo wave that has the values we like
	if (PToF_DCMarkerSingleRun)		// single run
		
		make/o/i/n=1 root:todo_temp = PToF_DCGr_runNumber
		wave todo =root:todo_temp  
		
	else		//todo
	
		// first check that the currently viewed todo wave matches the one in the main squirrel panel
		ControlInfo ams_todolist_pop
		if (!stringmatch(S_value,sq_toDoWvNm) )
			abort "Please reselect the todo wave.  Aborting from sq_PToFAvgDCAverageButt"
		endif
		if (numpnts(todo)>100)
			DoAlert, 1, "The averaging of PToF sticks for many runs (>100) can take a very long time.  Press yes to continue, no to abort."
			if (V_flag==2)		// choser chose no
				abort "The user chose to abort"
			endif
		endif
		wave/z allPToF = root:allPToF
		if (waveExists(allPToF))	// there are some runs without PToF data				
			sq_create_todo(sq_toDoWvNm+" and allPToF","todo_temp")
			wave todo = root:todo_temp
			if (numpnts(todo)==0)
				killwaves/z todo
				abort "The todo wave you chose has zero PToF runs in it."
			endif
		endif
//		if (  !PToF_DCgr_DAQsticks && squirrel_index[indexpos][0][dimLay]<=0)		// we want preprocessed ptof sticks for this todo wave
//			abort "There does not appear to be preprocessed data for the run/todo wave you requested.  Aborting from sq_PToFDCgr_GetThisMatrix"
//		endif			

	endif		// single run or todo
	
	PToF_DCGr_runNumber=todo[0]		// this is only really needed if user selected todo
	sq_DCGr_UpdateRunNumParams()		// update # PToF bins, etc controls, resize display waves  PToF TIme

//	sq_PToF_DCGr_FetchMatrix(todo, selectString(PToF_DCgr_DAQsticks, "PToF_stick_p", "PToF_stick" ))
	nvar deconvolveJoel = root:panel:deconvolveJoel
	
	sq_PToF_DCGr_FetchMatrix(todo, "PToF_stick",deconvolveJoel )

	wave PToF_DCGr_oneMz = root:panel:PToF_DCGr_oneMz			// updated by sq_PToF_DCGr_FetchMatrix
	wave PToF_DCgr_onePToFMatrix = root:panel:PToF_DCgr_onePToFMatrix 	// updated by sq_PToF_DCGr_FetchMatrix
	
	nvar PToF_DCgr_mzChoice = root:panel:PToF_DCgr_mzChoice
//	PToF_DCGr_oneMz = PToF_DCgr_onePToFMatrix[p][PToF_DCgr_mzChoice - 1]
 	sq_PToF_DCGr_SetVar_mz("",nan,"","") 
			
	killwaves/z todo_temp

End

// new in 1.52
// From the main PToF tab, adds option to allow plotting of DC marker regions
Function sq_AddDCmarker2Plot(PToFtodo, bottomAxisNm, seriesPos)
wave PToFtodo
variable bottomAxisNm, seriesPos

	variable dc1, dc2, dc3, dc4, UseBinNumUnits, num, isePToF, numDiff
	string reg1Str, reg2str
	
	isePToF = sq_TodoHasPToF(PToFTodo, ptofFlag=0)  //1.59C
	
	if (!isePToF)	
		numDiff = sq_PToF_DC_Same(PToFtodo, UseBinNumUnits, dc1, dc2, dc3, dc4,seriesPos )
		if (numDiff>0)		// assume that if one is missing, all are
			abort "You have used different DC parameters for runs in this todo wave.  Aborting from sq_AddDCmarker2Plot"
		elseif (numtype(numDiff)==2)
			sq_appendDCregions(UseBinNumUnits, dc1, dc2, dc3, dc4, bottomAxisNm, seriesPos)
		else		// just use values that are in the panel
			sq_appendDCregions(UseBinNumUnits, dc1, dc2,  dc3, dc4,  bottomAxisNm, seriesPos)
		endif
	else		// ePToF data
		numDiff = sq_PToF_ePToFDevonv_Same(PToFtodo, dc3, dc4, seriesPos )
		if (numDiff>0)		// assume that if one is missing, all are
			abort "You have used different DC parameters for runs in this todo wave.  Aborting from sq_AddDCmarker2Plot"
		endif
		sq_appendDCregions(1, nan, nan,  dc3, dc4, bottomAxisNm, seriesPos, isePToF = isePToF)
	endif

End
	

// new in 1.52
// Adds DC marker regions to PToF plots
Function sq_appendDCregions(UseBinNumUnits, dc1, dc2, dc3, dc4, bottomAxisNm, seriesPos, [isePToF])
	variable UseBinNumUnits, dc1, dc2, dc3, dc4, bottomAxisNm, seriesPos, isePToF	

	nvar lc=root:panel:cor3_chamber	// not in panel, loaded in get index

	variable left1, right1, top1, bottom1, left2, right2, top2, bottom2
	make/o/n=4 root:panel:DCregionX/wave=DCregionX
			
	make/free DVa_wave
	sq_GetPToFParams(DVa_wave, seriesPos)		//1.59E

	wave/z ptof_dcMarkersPtWave =  root:panel:ptof_dcMarkersPtWave
	if(!WaveExists(ptof_dcMarkersPtWave))
		make/o/n=4 root:panel:ptof_dcMarkersPtWave=0		// not in panel, but used in the DC marker graph aid
		wave ptof_dcMarkersPtWave =  root:panel:ptof_dcMarkersPtWave
	endif

	if (DVa_wave[%isEPToF]) 
		sq_dcMarkersExamine(seriesPos)	// creates or overwrites root:panel:ptof_dcMarkersPtWave	
	else
		sq_dcMarkersExamine_ePToF(seriesPos)		// creates or overwrites root:panel:ptof_dcMarkersPtWave
	endif

	duplicate/o/FREE ptof_dcMarkersPtWave ptof_dcMarkersTimeWave
	ptof_dcMarkersTimeWave = DVa_wave[%t0] + DVa_wave[%step]*ptof_dcMarkersPtWave[p]		// no matter the x axis units we first find it in PToF time dimesion
//  PToF time will not be modified for tw deconvolution

	// get units corrects for input into DCMarkerDisplay
	DoUpdate
	if (bottomAxisNm)
		DCregionX[] = sq_ptof2dva(lc,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],ptof_dcMarkersTimeWave[p])		
		GetAxis/q bottom		
		DCregionX[0] =max(DCregionX[0], V_min)		
		DCregionX[1] =max(DCregionX[1], V_min)
	else		// bottom axis is in PToF time
		DCregionX[] = ptof_dcMarkersTimeWave[p]
	endif
	
	if (!isePToF) 
		left1=DCregionX[0]
		right1=DCregionX[1]
	else
		left1=nan
		right1=nan
	endif

	left2=DCregionX[2]
	right2=DCregionX[3]

	GetAxis/q left
	top1=V_min
	bottom1=V_max
	top2=V_min
	bottom2=V_max

	SetDrawLayer/K ProgBack

	SetDrawEnv xcoord= bottom,ycoord= left,fillpat= 3,fillfgc= (56576,56576,56576),fillbgc=(56576,56576,56576), linefgc= (56576,56576,56576)
	if (left1>-inf && right1>-inf)
		DrawRect left1, top1, right1, bottom1
	endif
	
	SetDrawLayer ProgBack
	SetDrawEnv xcoord= bottom,ycoord= left,fillpat= 3,fillfgc= (56576,56576,56576),fillbgc=(56576,56576,56576), linefgc= (56576,56576,56576)
	DrawRect left2, top2, right2, bottom2

End


// CE ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Function taken from A.M. Middlebrook, R. Bahreini, J.L. Jimenez, and M.R. Canagaratna. 
// Evaluation of Composition-Dependent Collection Efficiencies for the Aerodyne Aerosol 
// Mass Spectrometer using Field Data. Aerosol Science and Technology, 46, 258271, 2012
// DOI:10.1080/02786826.2011.620041 PDF (March 1, 2012) 
// Donna S cleaned up and altered slightly October 2011
//
// Creates the following waves and puts them in the root folder
// PredNH4_CE1 = predicted NH4 with a collection efficiency of 1
// NH4_MeasToPredict = ratio of NH4 measured to predicted (anion and cation balance)
// ANMF = ammonium nitrate mass fraction
// CE_dry = collection efficiency of theoretically dry particles
// CE_fPhase = collection efficiency as a function of its phase, or composition, i.e. H2SO4 droplets vs pure dry HNO3

static constant Mass_NH4=18
static constant Mass_SO4=96
static constant Mass_NO3=62
static constant Mass_Chl=35.45
static constant Mass_NH4NO3=80

//1.52
// Creates the phase dependent CE panel
Function sq_CreatePhaseDepCE() 

	DoWindow/F CE_Panel
	if (V_flag)
		return 0
	endif
	
	NewDataFolder/o root:CE
	sq_initializeGlobalSVar("root:CE:CEStatsStr", "")
	
	NewPanel/N=CE_Panel /W=(117,94,744,430) as "CE_Panel"
	ModifyPanel fixedSize=1		//1.57L
	ShowTools/A
	SetDrawLayer UserBack
	SetDrawEnv fsize= 18,fstyle= 1
	DrawText 5,22,"Composition Dependent CE"
	SetDrawEnv fsize= 14
	DrawText 7,38,"ver. 1.0"
	DrawText 7,59,"*Only applicable to ambient data*"
	SetDrawEnv fsize= 10
	DrawText 7,94,"Step 0. Finalize your NH4 RIE."
	SetDrawEnv fsize= 10
	DrawText 27,185,"units=g/m3, with CE=1, with AB correction"
	SetDrawEnv fsize= 10
	DrawText 5,334,"Step 7. (Opt.) Enter CE_fphase in Batch table."
	SetDrawEnv fsize= 10
	DrawText 5,215,"Step 3. (Optional)"
	SetDrawEnv fsize= 10
	DrawText 5,254,"Step 5. (Optional)"
	SetDrawEnv fsize= 10
	DrawText 2,195,"if NH4 < min level, default CE (step 4) will be used"

	Button buttonUrlMiddlebrook,pos={79,21},size={170,20},fsize=10,proc=sq_URLButton,title="Middlebrook et al. paper pdf url"
	Button ceHelp,pos={200,43},size={50,20},proc=sq_URLButton,title="help"
	Button ceReviewNH4RIE,pos={214,77},size={40,20},fsize=10,proc=sq_butt_reviewNH4RIE,title="Batch"
	Button sq_butt_CENH4AcidityGraph,pos={175,77},size={40,20},fsize=10,proc=sq_butt_CENH4AcidityGr,title="Graph"

	GroupBox groupParams,pos={1,144},size={255,153},fsize=10,title="CDCE user parameters"
	GroupBox groupParams,fColor=(1,1,1)
	GroupBox groupOptionalPrelim,pos={1,62},size={255,78},fsize=10,title="Preliminary calculations using CE=1"
	GroupBox groupOptionalPrelim,fColor=(1,1,1)

	SetVariable CE4LowNH4,pos={5,218},size={245,16},fsize=10,title="Step 4. Set default CE (when comp. indep.)"
	SetVariable CE4LowNH4,format="%1.2f",limits={0,10,0},fsize=10,value= _NUM:0.5
	SetVariable NH4DetLim,pos={5,157},size={245,16},fsize=10,title="Step 2. Set min. NH4 level to use in calcs"
	SetVariable NH4DetLim,format="%1.3f",limits={0,1,0},value= _NUM:nan
	CheckBox checkUseRH,pos={105,239},size={145,14},fsize=10,title="Use RH of sampling line, %"
	CheckBox checkUseRH,value= 0
	CheckBox checkUseSmooth,pos={105,200},size={112,14},fsize=10,title="Num. pts. to smooth"
	CheckBox checkUseSmooth,value= 0
	SetVariable Num2SmoothVar,pos={224,201},size={30,16},fsize=10,bodyWidth=35,value= _NUM:nan
	SetVariable setvarRH,pos={23,256},size={230,16},fsize=10,title="RH wave of AMS sampling line, in root",size={230,16}
	SetVariable setvarRH,value= _STR:""

	Button buttonCalcCE,pos={5,297},size={240,20},fsize=10,proc=sq_butt_Calc_CDCE,title="Step 6. Calculate composition dependent CE"
	Button buttonCalcCE,fColor=(65280,43520,0)
	Button buttonCalcTSforCE,pos={5,118},size={210,20},fsize=10,proc=sq_butt_CalcTS_CDCE,title="Step 1. Calc aerosol TS with CE=1 for todo"
	Button buttonCalcTSforCE,fColor=(65280,43520,0)
	Button CEis1_TSGraph,pos={217,118},size={40,20},fsize=10,proc=sq_create_CEis1_TSgraph,title="Graph"
	Button ceSetInflectionPoints,pos={3,274},size={220,18},fsize=10,proc=sq_CEbutt_SetInflectPts,title="Advanced users only - Set inflection points"
	Button ceSetInflectionPoints,fSize=10

	TabControl tabCE,pos={258,0},size={365,330},proc=Sq_CETabProc
	TabControl tabCE,tabLabel(0)="CE Hist",tabLabel(1)="CE Stats",tabLabel(2)="NH4"
	TabControl tabCE,tabLabel(3)="NO3",tabLabel(4)="SO4",tabLabel(5)="Org"
	TabControl tabCE,tabLabel(6)="Chl",value= 0

	// begin tab dependent controls

	TitleBox titleCEStats,pos={262,22},size={188,65},fsize=10,disable=1,frame=0
	TitleBox titleCEStats,variable= root:CE:CEstatsStr
	TitleBox titleTSLegend,pos={495,60},size={100,52},fsize=10,frame=0,title="Gray:CE=user default\r(via mult. offset)\rColors indicate which\rfactor controls CE"
	TitleBox titleTSLegend,frame=0, disable=1
	TitleBox titleTSLegendStats,pos={490,25},size={123,26},fsize=10,disable=1,frame=0

	PopupMenu ams_todolist_pop,pos={7,96},size={148,21},fsize=10,bodyWidth=120,proc=sq_pop_toDoList,title="Todo"
	PopupMenu ams_todolist_pop,fSize=10,size={145.00,19.00}
	PopupMenu ams_todolist_pop,mode=1,popvalue="all",value= #"root:panel:sq_toDoList+\"Get List;\"\t"

	Button ceSetInflectionPoints,pos={3,274},size={220,18},fsize=10,proc=sq_butt_CEAdvPanel,title="Advanced users only - Set inflection points"


	Button sq_but_SQ_CECorrGraph,pos={492,121},size={40,20},fsize=10,proc=sq_butt_popThis,title="<- Pop", disable=1
	Button sq_but_SQ_CETSGraph,pos={574,121},size={40,20},fsize=10,proc=sq_butt_popThis,title="Pop", disable=1
	
	Button sq_but_SQ_CECorrGraph,pos={492,121},size={40,20},fsize=10,proc=sq_butt_popThis,title="<- Pop"
	Button sq_but_SQ_CETSGraph,pos={574,121},size={40,20},fsize=10,proc=sq_butt_popThis,title="Popv"
	Button sq_but_SQ_CEHistGraph title="Pop^",pos={472,120},fsize=10,proc=sq_butt_popThis,size={40,20}, disable=1

	Button sq_but_SQ_AcidityHistGraph,pos={566,140},size={40,20},fsize=10,disable=1,proc=sq_butt_popThis,title="^Pop"
	Button sq_but_SQ_ANMFOrgMFHistGraph,pos={307,140},size={40,20},fsize=10,disable=1,proc=sq_butt_popThis,title="Popv"
	Button sq_but_SQ_RelHumHistGraph,pos={521,140},size={40,20},fsize=10,disable=1,proc=sq_butt_popThis,title="Popv"
	Button sq_but_SQ_NH4DetLimHistGraph,pos={262,140},size={40,20},fsize=10,disable=1,proc=sq_butt_popThis,title="Pop^"
	Button sq_but_SQ_CEfphaseTable,pos={393,140},size={100,20},fsize=10,disable=1,proc=sq_butt_popThis,title="CE_fphase Table"

	Button sq_but_CETypeFlagLegend,pos={264,104},size={130,20},fsize=10,proc=sq_butt_CETypeFlagLegend,title="Pop CETypeFlag Legend",disable=1

	// get paramters from last time this was calculated.
	wave/z ANMF_hist = root:CE:ANMF_hist		// any one of several waves could do to check values.
	if (WaveExists(ANMF_hist))		// things were calculated before.  Try to find the last values.
		wave/z CE_fphase = root:CE_fphase		// any one of several waves could do to check values.
		if (WaveExists(CE_fphase) && strlen(Note(CE_fphase))>0)		// assume that nothing has been tampered with
			string CEnote = Note(CE_fphase)
//			print CEnote
			SetWindow CE_panel userdata(defaultCE)=StringByKey("defaultCE",CEnote)
			SetWindow CE_panel userdata(NH4DetLim)=StringByKey("NH4DetLim",CEnote)
			SetWindow CE_panel userdata(todo)=StringByKey("todo",CEnote)
			SetWindow CE_panel userdata(UseRH)=StringByKey("UseRH",CEnote)
			SetWindow CE_panel userdata(RHwave)=StringByKey("RHwave",CEnote)
			SetWindow CE_panel userdata(UseSmooth)=StringByKey("UseSmooth",CEnote)
			SetWindow CE_panel userdata(num2smooth)=StringByKey("num2smooth",CEnote)

			SetVariable CE4LowNH4,value = _NUM:(str2num(StringByKey("defaultCE",CEnote)))
			SetVariable NH4DetLim,value= _NUM:(str2num(StringByKey("NH4DetLim",CEnote)))
			CheckBox checkUseRH,value= str2num(StringByKey("UseRH",CEnote))
			SetVariable setvarRH,value= _STR:(StringByKey("RHwave",CEnote))					
			CheckBox checkUseSmooth,value=str2num(StringByKey("UseSmooth",CEnote))
			SetVariable Num2SmoothVar,value= _NUM:(str2num(StringByKey("num2smooth",CEnote)))
		endif			
	endif

	Sq_CETabProc("tabCE",0)  // update graphs by simulating  selecting the Total tab

End
 

// This function generates time series of NH4, SO4, NO3, Chl, Org using a CE of 1 and then calls CalcCE_fPhase.
// The units of the time series waves is ug/m3 
// Can be used with or without the AB correction, no AB is used here.
//1.52
Function sq_butt_CalcTS_CDCE(ctrlName) : ButtonControl
	String ctrlName

	wave/t spec_list  = root:frag:spec_list
	wave CEfac_list  = root:frag:CEfac_list
	wave/t speccorr_list  = root:frag:speccorr_list
	wave/t/z CEWave_list  = root:frag:CEWave_list
	wave t_series  = root:index:t_series

	if (!WaveExists(CEWave_list))
		make/t/o/n=(numpnts(CEfac_list)) root:frag:CEWave_list /wave=CEWave_list
		CEWave_list=""
	endif
	
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm	
	ControlInfo /w=CE_panel ams_todolist_pop
	if (!stringmatch(S_Value,sq_toDoWvNm ))
		abort "Please reselect the todo wave."
	endif	
	wave todowave = $"root:"+sq_toDoWvNm

// Manjula wanted folks to automatically use all or allV
//	nvar VWSwitching = root:diagnostics:VWSwitching
//	if (VWSwitching)
//		wave todowave = root:allV
//		sq_toDoWvNm = "allV"
//	else
//		wave todowave = root:all
//		sq_toDoWvNm = "all"
//	endif	
//	sq_pop_toDoList("ams_todolist_pop",0,sq_toDoWvNm) 
		
	nvar ms0_appendErrorBars=root:panel:ms0_appendErrorBars	
	nvar ms0_msTseries_suffix_ck=root:panel:ms0_msTseries_suffix_ck
	svar ms0_speclist=root:panel:ms0_speclist
	nvar ms0_graphOutputType=root:panel:ms0_graphOutputType
	nvar ms0_dataType=root:panel:ms0_dataType
	nvar ms0_ion2mass=root:panel:ms0_ion2mass	// ug/m3
	nvar ams_time_saved=root:panel:ams_time_saved	// don't do any time averaging
	nvar ms0_corr=root:panel:ms0_corr
	// we do not use the AB correction by default because we look at ratios and these ratios should be unaffected

	variable NH4Row, SO4Row, NO3Row, ChlRow, OrgRow
	variable NH4_CEVal, SO4_CEVal, NO3_CEVal, Chl_CEVal, Org_CEVal
	variable killFlag, numTSeries, UseRH=0, detectorFlag
	string NH4_CorrStr, SO4_CorrStr, NO3_CorrStr, Chl_CorrStr, Org_CorrStr
	string NH4_CECorrStr, SO4_CECorrStr, NO3_CECorrStr, Chl_CECorrStr, Org_CECorrStr
	string RHWaveStr	, CEnote, dataStr
	variable temp_ms0_graphOutputType

	temp_ms0_graphOutputType=ms0_graphOutputType
	wave/z corr_fact = root:diagnostics:corr_fact
	if (!WaveExists(corr_fact))
		abort "You must first generate an airbeam correction factor before proceeding. aborting from sq_CalcCompDepCE_ButtonProc"
	endif
	
	detectorFlag=sq_TodoWaveHasOnlyOneDetType(todowave)
	if (detectorFlag>=0)
		DoAlert, 2, "The chosen todo wave has runs from different detection schemes (i.e. V and W mode).  To proceed, press Yes, to abort, press Cancel, to see which run had problems,   press No."
		if (V_flag==2)
			edit root:diagnostics:detector_num, root:index:rn_series
			ModifyTable topLeftCell=(detectorFlag,0)	
		elseif(V_flag==3)
			Abort "The user has chosen to abort"
		endif
	endif
	
	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList
	dataStr= stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu
	if (strsearch(dataStr, "Diff", 0)<0)
		abort "Please select the data type i.e. MSSDiff. from the drop down menu.  Aborting from sq_butt_CalcTS_CDCE"
	endif
//	ms0_dataType = 1 // = Diff

	// we do alot of preparations
	// first find the species in the batch table
	NH4Row = sq_findStr(spec_list,"NH4",1)
	SO4Row = sq_findStr(spec_list,"SO4",1)
	NO3Row = sq_findStr(spec_list,"NO3",1)
	ChlRow = sq_findStr(spec_list,"Chl",1)
	OrgRow = sq_findStr(spec_list,"Org",1)

	if (NH4Row==-1 || SO4Row==-1 || NO3Row==-1 || ChlRow==-1 || OrgRow==-1 )
		abort "Cannot find one of the species NH4, NO3, SO4, Chl, or Org in root:frag:spec_list - cannot proceed."
	endif
	
	wave todowave = $"root:"+sq_toDoWvNm
	if (numpnts(todowave) < numTSeries/4)		// numTSeries/4 is an estimate.  We really don't care what todo wave is chosen, but ideally it would be one that encompassed all the data
		DoAlert 1,  "The todo wave you have chosen, "+sq_toDoWvNm+" should encompass all data, but doesn't have to.  Press yes to continue using this todo wave."
		if (V_flag==2)
			return 0		// User chose to quit
		endif
	endif
	
	// CalcCE_fPhase relies on the CE being 1 (or at least identical) for its calculations so save the old values and replace them when we are done.
	//  Jose suggested that we don't change the CE values in the batch table, in case something goes wrong. 
	NH4_CEVal = CEfac_list[NH4Row]
	SO4_CEVal = CEfac_list[SO4Row]
	NO3_CEVal = CEfac_list[NO3Row]
	Chl_CEVal = CEfac_list[ChlRow]
	Org_CEVal = CEfac_list[OrgRow]

	//  Check to see that the values are empty (is default)
	NH4_CorrStr = speccorr_list[NH4Row]
	SO4_CorrStr = speccorr_list[SO4Row]
	NO3_CorrStr = speccorr_list[NO3Row]
	Chl_CorrStr = speccorr_list[ChlRow]
	Org_CorrStr = speccorr_list[OrgRow]
	
	//  Check to see that the values are empty (is default)
	NH4_CECorrStr = CEWave_list[NH4Row]
	SO4_CECorrStr = CEWave_list[SO4Row]
	NO3_CECorrStr = CEWave_list[NO3Row]
	Chl_CECorrStr = CEWave_list[ChlRow]
	Org_CECorrStr = CEWave_list[OrgRow]

	if (Strlen(NH4_CorrStr)!=0 || Strlen(SO4_CorrStr)!=0 || Strlen(NO3_CorrStr)!=0 || Strlen(Chl_CorrStr)!=0 || Strlen(Org_CorrStr)!=0  )
		// we shouldn't overwrite the values in the spec corr list UNLESS all values are the old calculated CE_fPhase.
		// The user will have to decide to enter/modify the values in speccorr_list wave him/herself if they want to retain their speccorr_list waves
		DoAlert 1, "In the speccorr_list wave in the batch table there was a non blank entry for one of the species: NH4, SO4, NO3, Chl, or Org. Press yes to continue without using this speccorr value."
		if (V_flag==2)
			return 0		// User chose to quit
		endif
 	endif

	// prepare global variables in squirrel panel in anticipation of calling CalcCE_fPhase  by default CE and RIE will be 1
	ms0_appendErrorBars=0
	ms0_ion2mass=1
	ms0_msTseries_suffix_ck = 1
	ms0_speclist="NH4,SO4,NO3,Chl,Org"
	ms0_graphOutputType = 5 // = do nothing	

	sq_timebase_check("ams_time_saved",1) 
	ms0_corr=1		// use AB correction
	

	sq_MSCalcPlot_TSeries("CE1", "")		// calculate the time series of the 5 species with a CE of 1 
	// If there are waves in the speccorr_list They are applied!!
	//  because we don't want to interfere with the get parameter function we manually undo any values that are in the batch table
	
	ms0_graphOutputType=temp_ms0_graphOutputType	// set this back to original value

	wave NH4_CE1 = root:NH4_CE1	// the suffix we give these waves is CE1
	wave SO4_CE1 = root:SO4_CE1
 	wave NO3_CE1 = root:NO3_CE1
  	wave Chl_CE1 = root:Chl_CE1
 	wave Org_CE1 = root:Org_CE1

	// in SQ_MSConc we divide by CE so now we multiply
	NH4_CE1 *= NH4_CEVal	
	SO4_CE1 *= SO4_CEVal
	NO3_CE1 *= NO3_CEVal
	Chl_CE1 *= Chl_CEVal
	Org_CE1 *= Org_CEVal

	wave/z NH4_CECorrWave = $NH4_CECorrStr
	if (WaveExists(NH4_CECorrWave))
		NH4_CE1*=	NH4_CECorrWave
	endif
	wave/z SO4_CECorrWave = $SO4_CECorrStr
	if (WaveExists(SO4_CECorrWave))
		SO4_CE1*=	SO4_CECorrWave
	endif
	wave/z NO3_CECorrWave = $NO3_CECorrStr
	if (WaveExists(NO3_CECorrWave))
		NO3_CE1*=	NO3_CECorrWave
	endif
	wave/z Org_CECorrWave = $Org_CECorrStr
	if (WaveExists(Org_CECorrWave))
		Org_CE1*=	Org_CECorrWave
	endif
	wave/z Chl_CECorrWave = $Chl_CECorrStr
	if (WaveExists(Chl_CECorrWave))
		Chl_CE1*=	Chl_CECorrWave
	endif

	// in SQ_MSConc we use Spec Corr so now we undo it
//	NH4_CorrStr = speccorr_list[NH4Row]
//	SO4_CorrStr = speccorr_list[SO4Row]
//	NO3_CorrStr = speccorr_list[NO3Row]
//	Chl_CorrStr = speccorr_list[ChlRow]
//	Org_CorrStr = speccorr_list[OrgRow]
//
//	wave/z NH4_CorrWave = $"root:"+NH4_CorrStr
//	if (strlen(NH4_CorrStr)>0 && WaveExists(NH4_CorrWave))
//		NH4_CE1 *= NH4_CorrWave		// in SQ_MSConc we divide by CE so now we multiply
//	endif
//	wave/z SO4_CorrWave = $"root:"+SO4_CorrStr
//	if (strlen(SO4_CorrStr)>0 && WaveExists(SO4_CorrWave))
//		SO4_CE1 *= SO4_CEVal
//	endif
//	wave/z NO3_CorrWave = $"root:"+NO3_CorrStr
//	if (strlen(NO3_CorrStr)>0 && WaveExists(NO3_CorrWave))
//		NO3_CE1 *= NO3_CEVal
//	endif
//	wave/z Chl_CorrWave = $"root:"+Chl_CorrStr
//	if (strlen(Chl_CorrStr)>0 && WaveExists(Chl_CorrWave))
//		Chl_CE1 *= Chl_CEVal
//	endif
//	wave/z Org_CorrWave = $"root:"+Org_CorrStr
//	if (strlen(Org_CorrStr)>0 && WaveExists(Org_CorrWave))
//		Org_CE1 *= Org_CEVal
//	endif

	duplicate/o Org_CE1 root:CE:Total_CE1/wave=Total_CE1
 	Total_CE1 = NH4_CE1+SO4_CE1+NO3_CE1+Chl_CE1+Org_CE1

	//put results into CE folder.
	newDataFolder/o root:CE
	duplicate/o NH4_CE1 root:CE:NH4_CE1
	duplicate/o SO4_CE1 root:CE:SO4_CE1
	duplicate/o NO3_CE1 root:CE:NO3_CE1
	duplicate/o Chl_CE1 root:CE:Chl_CE1
	duplicate/o Org_CE1 root:CE:Org_CE1
	
	killwaves/z NH4_CE1, SO4_CE1, NO3_CE1, Chl_CE1, Org_CE1
	SetWindow CE_panel userdata(todo)= sq_toDoWvNm
	
	sq_create_CEis1_TSgraph("") 

End


//1.52
// In CDCE panel show Acidity plot in FragChecks Panel
Function sq_butt_CENH4AcidityGr(ctrlName) : ButtonControl
	String ctrlName

	wave/z NH4_predict = root:quantifChecks:NH4_predict
	if (WaveExists(NH4_predict))
		sq_butt_popThis("button_FC_NH4MeasPredGraph")
	else	
		abort "You must first do the Frag table correction checks before doing the composition dependent CE   aborting from sq_butt_CENH4AcidityGr"
	endif
End


//1.52
// After generating time series waves of 5 aerosol species with CE=1, find the time dependent CE
Function sq_butt_Calc_CDCE(ctrlName) : ButtonControl
	String ctrlName

	variable numTSeries, UseRH, NH4_DetLimit, varCE_lowNH4, SmoothVar, SmoothTypeVar, UseSmooth=0
	string RHWaveStr, CENote
	 	
	wave NH4_CE1 = root:CE:NH4_CE1
	wave SO4_CE1 = root:CE:SO4_CE1
 	wave NO3_CE1 = root:CE:NO3_CE1
  	wave Chl_CE1 = root:CE:Chl_CE1
 	wave Org_CE1 = root:CE:Org_CE1

	DoWindow/F CE_Panel
	
	numTSeries = numpnts(NH4_CE1)		// can use any species

	SmoothTypeVar=nan
	SmoothVar=nan
	RHWaveStr=""

	// get user input and do sanity checks
	ControlInfo/w=CE_Panel NH4DetLim
	NH4_DetLimit=V_value
	if ( !(NH4_DetLimit>0))
		abort "The NH4 detection limit must be > 0.  Aborting from sq_CalcCompDepCE_ButtonProc"
	endif
	
	ControlInfo/w=CE_Panel CE4LowNH4
	varCE_lowNH4=V_value
	if ( varCE_lowNH4<0.001  || varCE_lowNH4>10 || numtype(varCE_lowNH4)!=0)
		abort "The CE for low NH4 must be > 0.001 and less than 10.  Aborting from sq_CalcCompDepCE_ButtonProc"
	endif

	ControlInfo/w=CE_Panel checkUseSmooth 
	if (V_value)
		controlinfo/w=ams_panel misc_smooth
		SmoothTypeVar=v_value
		ControlInfo Num2SmoothVar; SmoothVar=V_value 
		if (!(SmoothVar>=1))
			abort "The number of points to smoothe must be >=1.  Aborting from sq_CalcCompDepCE_ButtonProc"
		endif
		UseSmooth=1
	endif
	
	ControlInfo/w=CE_Panel checkUseRH
	if (V_value)
		wave/z RHSampleLineWave = gen_returnSelectedWave("setVarRH", DFstr="root:", num=numTSeries, minVal=0, maxVal=110, nansOK=0)
		if (!WaveExists(RHSampleLineWave) )
			abort "Something was wrong with the chosen RH wave. aborting from sq_CalcCompDepCE_ButtonProc"
		endif
		RHWaveStr=nameofWave(RHSampleLineWave)
		UseRH=1
	endif

 	//  finally, call the function to calculate CE_fPhase
 	if (WaveExists(RHSampleLineWave))
 		if (SmoothVar>=1)
 			sq_CalcCE_fPhase(NH4_DetLimit,varCE_lowNH4, SO4_CE1, NH4_CE1, NO3_CE1, Chl_CE1, Org_CE1, RH_SampLine= RHSampleLineWave, SmoothVariable=SmoothVar, SmoothTypeVariable=SmoothTypeVar)
 		else
  			sq_CalcCE_fPhase(NH4_DetLimit,varCE_lowNH4, SO4_CE1, NH4_CE1, NO3_CE1, Chl_CE1, Org_CE1, RH_SampLine= RHSampleLineWave)
		endif
 	else
 		if (SmoothVar>=1)
 			sq_CalcCE_fPhase(NH4_DetLimit,varCE_lowNH4, SO4_CE1, NH4_CE1, NO3_CE1, Chl_CE1, Org_CE1, SmoothVariable=SmoothVar, SmoothTypeVariable=SmoothTypeVar)
 		else
	   		sq_CalcCE_fPhase(NH4_DetLimit,varCE_lowNH4, SO4_CE1, NH4_CE1, NO3_CE1, Chl_CE1, Org_CE1)
   		endif
 	endif
 	
	// the result!!		// note that CD_fphase has to be retained in the root folder if it is used in the speccorr_list column
	wave CE_fPhase = root:CE_fPhase
	
	duplicate/o NH4_CE1 root:CE:NH4_CDCE/wave=NH4_CDCE
	duplicate/o SO4_CE1 root:CE:SO4_CDCE/wave=SO4_CDCE
	duplicate/o NO3_CE1 root:CE:NO3_CDCE/wave=NO3_CDCE
	duplicate/o Chl_CE1 root:CE:Chl_CDCE/wave=Chl_CDCE
	duplicate/o Org_CE1 root:CE:Org_CDCE/wave=Org_CDCE

	NH4_CDCE/=CE_fPhase
	SO4_CDCE/=CE_fPhase
	NO3_CDCE/=CE_fPhase
	Chl_CDCE/=CE_fPhase
	Org_CDCE/=CE_fPhase

	duplicate/o Org_CDCE root:CE:Total_CDCE/wave=Total_CDCE
 	Total_CDCE = NH4_CDCE+SO4_CDCE+NO3_CDCE+Chl_CDCE+Org_CDCE
 	
	SetWindow CE_panel userdata(defaultCE)=num2str(varCE_lowNH4)
	SetWindow CE_panel userdata(NH4DetLim)= num2str(NH4_DetLimit)
	SetWindow CE_panel userdata(UseRH)= num2str(UseRH)
	SetWindow CE_panel userdata(RHwave)=RHWaveStr
	SetWindow CE_panel userdata(UseSmooth)=num2str(UseSmooth)
	SetWindow CE_panel userdata(num2smooth)=num2str(SmoothVar)

	// create a wave note for root:CE_fPhase that has all the pertinant info
	CEnote = "defaultCE:"+num2str(varCE_lowNH4)+";"
	CEnote += "NH4DetLim:"+num2str(NH4_DetLimit)+";"
	CEnote += "todo:"+ GetUserData("CE_panel", "", "todo")+";"
	CEnote += "UseRH:"+num2str(UseRH)+";"
	CEnote += "RHwave:"+RHWaveStr+";"
	CEnote += "UseSmooth:"+num2str(UseSmooth)+";"
	CEnote += "num2smooth:"+num2str(SmoothVar)+";"
	
	DoWindow/F AdvUserCEPanel
	if (V_flag) 
		ControlInfo checkUseTheseInflPts
		if (V_value)		// User wants to set their own inflection points.  We use varCE_lowNH4 as the default CE for all cases
			// sanity checks
			ControlInfo Acidity_inflectionPt
			CEnote += "AcidicCutoff:"+num2str(V_Value)+";"
			ControlInfo ANMF_inflectionPt
			CEnote += "ANMFcutoff:"+num2str(V_Value)+";"
			ControlInfo Humidity_inflectionPt
			CEnote += "Humiditycutoff:"+num2str(V_Value)+";"
		endif		// we use user settable inflection points
	endif
	
	Note/K CE_fPhase CEnote

	if (UseRH)
		sq_calcCDCE_extras(UseRH, RHWave =RHSampleLineWave )
	else
		sq_calcCDCE_extras(UseRH)
	endif
	
	ControlInfo/w=CE_Panel tabCE
	sq_plotCEGrs(V_Value)		// update plots

End


//1.52
// does the work of calculating the phase dependent CE
Function sq_CalcCE_fPhase(NH4_DetLimit,varCE_lowNH4, SO4_CE1, NH4_CE1, NO3_CE1, Chl_CE1, Org_CE1, [RH_SampLine, SmoothVariable, SmoothTypeVariable])
	variable NH4_DetLimit,varCE_lowNH4, SmoothVariable, SmoothTypeVariable
	wave SO4_CE1, NH4_CE1, NO3_CE1, Chl_CE1, Org_CE1, RH_SampLine
	// NH4_DL = ammonium detection limit
	// varCE_lowNH4 = CE for points where ammonium is below its detection limit
	// SO4, NH4, NO3, Chl, Org are all calculated using a CE of 1 (and an anticipated speccorr_list value being blank)
	// RH_SampLine = t_series length wave or sampling line RH in % 
	// SmoothVariable = number of points to smooth.  In Middlebrook et al paper data is gaussian smoothed with number of points = 1
	// SmoothTypeVariable is 1=gaussian or 2=boxcar smoothing and is determined by the popup menu in the squirrel misc tab setting
	
	//  all variables below are from Ann's paper.  Use these unless user sets their own inflection points
	variable Eq4_slope = 0.9167		// ANMF equation   if ANMF=.4546 then CE = 0.0833+0.9167*(.4546) = .5
	variable Eq4_intercept = 0.0833	// ANMF equation  Inflection point is .4546
	variable ANMFcutoff =0.4546	// NOT USED IN EQUATIONS but is already determined by Eq 4 slope and intercept

	variable Eq6_slope = -0.73		// acidity equation       if NH4Meas/NH4Predict=.75 then CE = 1 - 0.73*(.75 ) = .4546
	variable Eq6_intercept = 1		// acidity equation
	variable AcidicCutoff = 0.75
//	For Reference:
//	Acidity CE by Quinn et al 2006:
//	CE_Acidity_dry = NH4_MeasToPredict[p]>=0.5 ? varCE_lowNH4 : 1.0-1.1*NH4_MeasToPredict[p])
// 	(5CEdry -4)+((1-CEdry)/20)RH)
	variable Eq7_slopeA = 5		// humidity equation
	variable Eq7_interceptA = -4	// humidity equation
	variable Eq7_slopeB = -1		// humidity equation
	variable Eq7_interceptB = 1	// humidity equation
	variable Eq7_slopeC = 20		// humidity equation
	variable humidityCutoff = 80		// 80 %  we need rel hum to be in percent
	 	
	DoWindow/F AdvUserCEPanel
	if (V_flag)		// window exists
		ControlInfo checkUseTheseInflPts
		if (V_value)		// User wants to set their own inflection points.  We use varCE_lowNH4 as the default CE for all cases
			// sanity checks
			ControlInfo Acidity_inflectionPt
			if ( ! (V_value > 0 && V_Value < 1) )
				abort "The acidity inflection point must be between 0 and 1. aborting from sq_CalcCE_fPhase"
			endif			
			AcidicCutoff  = V_Value
			Eq6_intercept = 1		// acidity equation... this is retained.  We have two points (0,1) and (defaultCE, AcidicCutoff)
			Eq6_slope = (1-varCE_lowNH4)	/(0-AcidicCutoff)// acidity equation   slope = deltay/deltax
			
			ControlInfo ANMF_inflectionPt
			if ( ! (V_value > 0 && V_Value < 1) )
				abort "The ANMF inflection point must be between 0 and 1. aborting from sq_CalcCE_fPhase"
			endif
			ANMFcutoff = V_Value 	// ANMF equation... this is retained.  We have two points (1,1) and (defaultCE, ANMFcutoff)
			Eq4_slope = (1-varCE_lowNH4)/(1-ANMFcutoff)	
			Eq4_intercept =1-Eq4_slope  // if ANMF=.4546 then CE = 0.0833+0.9167*(.4546) = .5
						
			ControlInfo Humidity_inflectionPt
			if ( ! (V_value > 0 && V_Value < 100 && !ParamisDefault(RH_SampLine) ) )
				abort "The relative humidity inflection point must be between 0 and 1. aborting from sq_CalcCE_fPhase"
			endif			
			humidityCutoff=V_Value	// RH equation We have two points (100,1) and (defaultCE, humidityCutoff) 
			//  (5CEdry-4)+(1-CEdry)/((20)RH) 
			//  (100-humidityCutoff/100)/(100-humidityCutoff)   +(1-CEdry)/((100-humidityCutoff)RH) 
			Eq7_slopeA = 100/(100-humidityCutoff) 	//5
			Eq7_interceptA = - humidityCutoff/(100-humidityCutoff) 	// -4
			Eq7_slopeB = -1		// 
			Eq7_interceptB = 1	// 
			Eq7_slopeC = (100-humidityCutoff) 	// 20	
		
		endif
	endif
	DoWindow/F CE_Panel
	
	// Create waves of each species to smooth for the calculations.  
	// These waves will be killed automatically when the function is completed.
	duplicate/o SO4_CE1 root:CE:SO4_CE1_smooth	/wave=SO4_CE1_smooth	// the suffix _CE1 indicates that the values were calculated with a CE of 1
	duplicate/o NH4_CE1 root:CE:NH4_CE1_smooth/wave=NH4_CE1_smooth
	duplicate/o NO3_CE1 root:CE:NO3_CE1_smooth/wave=NO3_CE1_smooth
	duplicate/o Chl_CE1 root:CE:Chl_CE1_smooth/wave=Chl_CE1_smooth
	duplicate/o Org_CE1 root:CE:Org_CE1_smooth/wave=Org_CE1_smooth

	// first smooth if applicable	
	if ( !ParamIsDefault(SmoothVariable) && !ParamIsDefault(SmoothTypeVariable) && SmoothVariable>0)
		// interpolate across time   If we don't interpolate we get extra nans where we might not want them
		gen_InterpolateAcrossTime(root:index:t_series,SO4_CE1_smooth)	
		gen_InterpolateAcrossTime(root:index:t_series,NH4_CE1_smooth)	
		gen_InterpolateAcrossTime(root:index:t_series,NO3_CE1_smooth)	
		gen_InterpolateAcrossTime(root:index:t_series,Org_CE1_smooth)	
		gen_InterpolateAcrossTime(root:index:t_series,Chl_CE1_smooth)	
		if (SmoothVariable ==2)		// boxcar smoothing
			Smooth/B=(SmoothVariable), SmoothVariable, SO4_CE1_smooth,NH4_CE1_smooth,NO3_CE1_smooth,Chl_CE1_smooth, Org_CE1_smooth			//1.57J
		else
			Smooth SmoothVariable, SO4_CE1_smooth,NH4_CE1_smooth,NO3_CE1_smooth,Chl_CE1_smooth, Org_CE1_smooth	
		endif
		NH4_CE1_smooth = numtype(NH4_CE1[p])==0 ? NH4_CE1_smooth[p] : nan
		SO4_CE1_smooth = numtype(SO4_CE1[p])==0 ? SO4_CE1_smooth[p] : nan
		NO3_CE1_smooth = numtype(NO3_CE1[p])==0 ? NO3_CE1_smooth[p] : nan
		Chl_CE1_smooth = numtype(Chl_CE1[p])==0 ? Chl_CE1_smooth[p] : nan
		Org_CE1_smooth = numtype(org_CE1[p])==0 ? Org_CE1_smooth[p] : nan		
	endif
	
	variable idex, tempCE, num = numpnts(SO4_CE1)		// can use any wave to get the number of points of waves created below

	SetDataFolder root:CE
	make/o/n=(num)/free PredNH4_CE1
	make/o/n=(num) ANMF, CE_dry, NH4_MeasToPredict		// waves that will be retained in root upon completion of function 
	make/o/n=(num) CE_Acidity, CE_ANMF, CE_Humidity, CETypeFlag
	SetDataFolder root:
	
	make/o/n=(num) root:CE_fPhase/wave=CE_fPhase=nan

	// Get all the parts we need for the CE formulation:  ANMF & NH4_MeasToPredict
	PredNH4_CE1=Mass_NH4*(2*SO4_CE1_smooth/Mass_SO4+NO3_CE1_smooth/Mass_NO3+Chl_CE1_smooth/Mass_Chl)	// presume Org doesn't contribute to acidity 
	  
	NH4_MeasToPredict = NH4_CE1_smooth/PredNH4_CE1
	
	// replace values < 0 with nans
	NH4_MeasToPredict = ( NH4_CE1_smooth[p]<0 || PredNH4_CE1[p]<0 ) ? nan : NH4_MeasToPredict[p] 
	
	ANMF=(Mass_NH4NO3/Mass_NO3)*NO3_CE1_smooth/(NO3_CE1_smooth+SO4_CE1_smooth+NH4_CE1_smooth+Org_CE1_smooth+Chl_CE1_smooth)	
	
	// replace values < 0 and > 1  with nans
	ANMF =  (ANMF[p]<0 ||  ANMF[p]> 1 || NO3_CE1_smooth[p]<0) ? nan : ANMF[p] 

	// Calculate the dry collection efficiency, CE_dry	
	// estimate CE_dry via the measured to predicted.  If >= .75 use  0.0833+0.9167*ANMF[idex]
	// Middlebrook et al describes that when ANMF is high, we typically don't have high acidity and visa versa
	// so that we typically don't have both, competing effects (high ANMF AND high acidity) 
	
//	CETypeFlag=8 means NH4 below detection limit
//	CETypeFlag=3 means NH4 ~= predicted.  Not very acidic
//	CETypeFlag=10 means NH4 < predicted.  Acidic
//	CETypeFlag=12 means no data
//	CETypeFlag =1 means we use the relative humidity in the calculations
	
	CETypeFlag=0
	for (idex=0;idex<num;idex+=1)

		if(numtype(PredNH4_CE1[idex])!=0) 		// typo caught by Will, was PredNH4_CE1[p]
			CE_dry[idex] = nan
			CETypeFlag[idex]=12
		
		elseif (PredNH4_CE1[idex]<NH4_DetLimit)		// we are below NH4 det limit, use default value

			CE_dry[idex]=varCE_lowNH4	// note that in ann's paper this value is nanned
			CETypeFlag[idex]=8		

		elseif(NH4_MeasToPredict[idex]>=AcidicCutoff)		//   not acidic AcidicCutoff = .75, use ANMF equation.
			// note that if ANMF is *small* CE_dry will be < user default CE = varCE_lowNH4
			// ANMF inflection point is built into Eq4_intercept and Eq4_slope
			//  So a CETypeflag of 3 can either mean use default OR use the equation.
			tempCE=Eq4_intercept+ Eq4_slope*ANMF[idex]
			if (tempCE>varCE_lowNH4)
				CE_dry[idex]=tempCE
				CETypeFlag[idex]=3	// Use ANMF
			else
				CE_dry[idex]=varCE_lowNH4
				CETypeFlag[idex]=4 // Use default
			endif
			
		elseif(NH4_MeasToPredict[idex] <AcidicCutoff)	//   AcidicCutoff = .75
			// if NH4_MeasToPredict is *small* CE_dry will be close to 1
			// Any point in between < AcidicCutoff
			CE_dry[idex]=Eq6_intercept+ Eq6_slope*NH4_MeasToPredict[idex]	
			CETypeFlag[idex]=10

		else 	
			// by default NH4 meas/NH4 precit will always be either >= or < AcidicCutoff
			// so this case just defined where we have nans in time series. 
			CE_dry[idex] = nan
			CETypeFlag[idex]=12
		endif
	endfor
	
	// line below does 2 things.  sets the min CE to varCE_lowNH4 and the max CE to 1
	CE_dry = min(1, (max(varCE_lowNH4,CE_dry)))		// replaced 0.45 with varCE_lowNH4    // retains nans & maximizes values to 1
		
//	For Reference:
//	CE_ANMF by Crosier et al 2007:
//	CE_ANMF = 0.393 + 0.582*ANMF  // where ANMF is calculated ignoring both Org and Chl
//	CE_ANMF by Matthew et al 2008 for pure ANMF:
//	CE_ANMF = ANMF[p]>=0.55 ? 0.24 : 1.0-1.1*ANMF[p])
//	CE_ANMF by Nemitz et al 2011 for EUCAARI :
//	CE_ANMF = ANMF[p]>=0.35 ? 0.5 : need from Eiko Nemtiz (manuscript under preparation)
//	CE_ANMF by Middlebrook et al 2012:
//	CE_ANMF =  ANMF[p]>=0.4 ? 0.45 : 0.0833+0.9167*ANMF[p] identical to max(0.45,0.0833+0.9167*ANMF[p])
			
	if (!ParamIsDefault(RH_SampLine)==1)
		// Apply Equation 7
		CE_fPhase=  (Eq7_slopeA*CE_dry + Eq7_interceptA) + ((Eq7_interceptB + Eq7_slopeB*CE_dry)/Eq7_slopeC )*RH_SampLine		// calculate for all values
//		CE_fPhase= (  (5*CE_dry -4) + (1  -CE_dry)/20) *RH_SampLine		// calculate for all values
//		CE_fPhase= (  (CE_dry -) + (1  -CE_dry)/20) *RH_SampLine		// calculate for all values

		for (idex=0;idex<num;idex+=1)
			if (RH_SampLine[idex]<humidityCutoff || numtype(RH_SampLine[idex]!=0 )	  )	// if dry or we don't have an RH value
				CE_fPhase[idex]=CE_dry[idex]
			elseif(numtype(CE_dry[idex])==0)	// aerosol is wet, keep the CEfPhase formulation
				CETypeFlag[idex]=1		//  keep track of when we use the RH correction
			endif
		endfor
	else
		CE_fPhase=CE_dry
	endIf
	
End
 
 
//1.52
// Calcs stats and other waves for CDCE panel
Function sq_calcCDCE_extras(UseRH, [RHWave])	// Manjula wanted these plots.  Fig 1 (&2,3) in the supplemental part of middlebrook paper 
variable UseRH
wave RHWave
	
	svar CEStatsStr = root:CE:CEStatsStr
	wave CETypeFlag = root:CE:CETypeFlag
	wave CE_fphase = root:CE_fphase
	wave ANMF = root:CE:ANMF
	wave NH4_MeasToPredict = root:CE:NH4_MeasToPredict
	wave Total_CE1 = root:CE:Total_CE1

	wave Chl_CE1 = root:CE:Chl_CE1
	wave Org_CE1 = root:CE:Org_CE1
	wave NO3_CE1 = root:CE:NO3_CE1
	wave NH4_CE1 = root:CE:NH4_CE1
	wave SO4_CE1 = root:CE:SO4_CE1
	wave Chl_CDCE = root:CE:Chl_CDCE
	wave Org_CDCE = root:CE:Org_CDCE
	wave NO3_CDCE = root:CE:NO3_CDCE
	wave NH4_CDCE = root:CE:NH4_CDCE
	wave SO4_CDCE = root:CE:SO4_CDCE
	
	make/o/n=(6,2) root:CE:SpeciesStats/wave=SpeciesStats 
	variable var1, numNonNans, lowNH4Val, num, defaultCEvar, delta,startHist
	string tempStr, tempColorStr
	
	WaveStats/q/m=0 Org_CE1		// could use any species wave
	numNonNans = V_npnts
	num = numpnts(Org_CE1)
	
	defaultCEvar=str2num(getuserdata("CE_Panel","","defaultCE") )// number	

	// rows are just like tabs: NH4=0, NO3=1, SO4 = 2, Org = 3, Chl = 4
	//avgCE1=SpeciesStats[tabNum-2][0]
	//avgCDCE=SpeciesStats[tabNum-2][1]

	WaveStats/q/m=0 NH4_CE1
	SpeciesStats[0][0]=V_avg/defaultCEvar
	WaveStats/q/m=0 NH4_CDCE
	SpeciesStats[0][1]=V_avg
	
	WaveStats/q/m=0 NO3_CE1
	SpeciesStats[1][0]=V_avg/defaultCEvar
	WaveStats/q/m=0 NO3_CDCE
	SpeciesStats[1][1]=V_avg

	WaveStats/q/m=0 SO4_CE1
	SpeciesStats[2][0]=V_avg/defaultCEvar
	WaveStats/q/m=0 SO4_CDCE
	SpeciesStats[2][1]=V_avg

	WaveStats/q/m=0 Org_CE1
	SpeciesStats[3][0]=V_avg/defaultCEvar
	WaveStats/q/m=0 Org_CDCE
	SpeciesStats[3][1]=V_avg

	WaveStats/q/m=0 Chl_CE1
	SpeciesStats[4][0]=V_avg/defaultCEvar
	WaveStats/q/m=0 Chl_CDCE
	SpeciesStats[4][1]=V_avg
		
	duplicate/o Total_CE1 root:CE:Org_MassFraction/wave=Org_MassFraction
	Org_MassFraction=Org_CE1/Total_CE1
	
	duplicate/o Total_CE1 root:CE:SO4_MassFraction/wave=SO4_MassFraction
	SO4_MassFraction=SO4_CE1/Total_CE1

	setDataFolder root:CE
	Make/N=20/O ANMF_Hist, OrgMF_Hist, SO4MF_Hist, Acidity_Hist, Humidity_Hist, NH4_hist, CE_hist

	// ANMF ranges from 0 to 1
	Histogram/B={0,0.05,20} ANMF,ANMF_Hist
	ANMF_Hist/=numNonNans	//  Sum(y)=1
	ANMF_Hist/=0.05		// resulting in Sum(y)*deltax=1     1.52 E James email regarding units
		
	// Org_MassFraction ranges from 0 to 1
	Histogram/B={0,0.05,20} Org_MassFraction,OrgMF_Hist
	OrgMF_Hist/=numNonNans// resulting in Sum(y)=1
	OrgMF_Hist/=0.05		// resulting in Sum(y)*deltax=1     1.52 E James email regarding units
	
	// SO4_MassFraction ranges from 0 to 1
	Histogram/B={0,0.05,20} SO4_MassFraction,SO4MF_Hist	
	SO4MF_Hist/=numNonNans
	SO4MF_Hist/=0.05		// resulting in Sum(y)*deltax=1     1.52 E James email regarding units
		
	// NH4_MeasToPredict can range from 0 to 2 (in theory could be more)
	Histogram/B={0,0.05,40} NH4_MeasToPredict,Acidity_Hist	
	Acidity_Hist/=numNonNans
	Acidity_Hist/=0.05		// resulting in Sum(y)*deltax=1     1.52 E James email regarding units

	// we do CE histogram at the end, after we interpolate
	// CE_fphase ranges from user default to 1.  Because CE_fphase has been interpolated to all points, we need to divide by numpnts
//	Histogram/B={0.5,0.025,20} CE_fphase, CE_hist
//	CE_hist/=num

	lowNH4Val=str2num(getuserdata("CE_Panel","","NH4DetLim") )	
	var1 = ceil(Wavemax(NH4_CE1))
	var1 = min(var1, num)
	delta =  ceil(var1/(min(0.1,lowNH4Val))  )		// minimum delta is .1 or user set-able lowNH4Val
	startHist=0
	if (WaveMin(NH4_CE1)<0)
		delta+=1
		startHist=-lowNH4Val
	endif
	Make/N=(delta)/O NH4_hist
	Histogram/B={startHist,lowNH4Val,delta} NH4_CE1,NH4_hist
	NH4_hist/=numNonNans
	NH4_hist/=lowNH4Val  	// resulting in Sum(y)*deltax=1     1.52 E James email regarding units
	
	if (UseRH)		
		// RHWave can range from 0 to 100 (in theory could be more)
		Histogram/B={0,5,20} RHWave,Humidity_Hist
		wavestats/q/m=1 RHWave
		Humidity_Hist/=V_npnts	
		Humidity_Hist/=5  	// resulting in Sum(y)*deltax=1     1.52 E James email regarding units
	else
		Humidity_Hist=nan
	endif
	
	// calculate stats string
	Make/N=14/O root:CE:CETypeFlag_Hist/wave=CETypeFlag_Hist
	Histogram/B={0,1,15} root:CE:CETypeFlag,CETypeFlag_Hist  // not normalized... just get counts of each

	SetDataFolder root:
	ColorTab2Wave dBZ14		// generates M_colors
	wave M_colors = root:M_colors
	
	CEStatsStr=""
	
// number values are mostly arbitrary.  They reflect colors we want to use in  dBZ14 to correspond to NO3, etc
//	CETypeFlag=8 means NH4 below detection limit
//	CETypeFlag=3 means NH4 ~= predicted.  Not acidic and ANMF is bigish
//	CETypeFlag=4 means NH4 ~= predicted.  ANMF is small, use default
//	CETypeFlag=13 means NH4 < predicted.  Acidic
//	CETypeFlag=12 means no data
//	CETypeFlag =1 means we use the relative humidity in the calculations

	sprintf tempStr, "%2.1f", 100*CETypeFlag_Hist[8]/numNonNans		// had 8s in CETypeFlag
	tempColorStr = "\\K("+num2str(M_colors[8-1][0])+","+num2str(M_colors[8-1][1])+","+num2str(M_colors[8-1][2])+") "
	CEStatsStr+=tempColorStr+"CETypeFlag=8, "+ "\\K(1,1,1)"+ "Below Min NH4:\t"+tempStr+"%\r"	
	
	sprintf tempStr, "%2.1f", 100*CETypeFlag_Hist[4]/numNonNans		// had 3s in CETypeFlag
	tempColorStr = "\\K("+num2str(M_colors[4-1][0])+","+num2str(M_colors[4-1][1])+","+num2str(M_colors[4-1][2])+") "
	CEStatsStr+= tempColorStr+"CETypeFlag=4, "+"\\K(1,1,1)"+"neutral, low ANMF:\t"+tempStr+"%\r"	

	sprintf tempStr, "%2.1f", 100*CETypeFlag_Hist[3]/numNonNans		// had 3s in CETypeFlag
	tempColorStr = "\\K("+num2str(M_colors[3-1][0])+","+num2str(M_colors[3-1][1])+","+num2str(M_colors[3-1][2])+") "
	CEStatsStr+= tempColorStr+"CETypeFlag=3, "+"\\K(1,1,1)"+"Used ANMF:\t"+tempStr+"%\r"	
	
	sprintf tempStr, "%2.1f", 100*CETypeFlag_Hist[10]/numNonNans		// had 10s in CETypeFlag
	tempColorStr = "\\K("+num2str(M_colors[10-1][0])+","+num2str(M_colors[10-1][1])+","+num2str(M_colors[10-1][2])+") "
	CEStatsStr+= tempColorStr+"CETypeFlag=10, "+"\\K(1,1,1)"+"Acidic:\t"+tempStr+"%\r"
	
	sprintf tempStr, "%2.1f", 100*CETypeFlag_Hist[1]/numNonNans		// had 1s in CETypeFlag
	tempColorStr = "\\K("+num2str(M_colors[1-1][0])+","+num2str(M_colors[1-1][1])+","+num2str(M_colors[1-1][2])+") "
	CEStatsStr+= tempColorStr+"CETypeFlag=1, "+"\\K(1,1,1)"+"RH high:"+tempStr+"%\r"	

	sprintf tempStr, "%d", CETypeFlag_Hist[12]	// had 12s in CETypeFlag
	tempColorStr = "\\K("+num2str(M_colors[12-1][0])+","+num2str(M_colors[12-1][1])+","+num2str(M_colors[12-1][2])+") "
	CEStatsStr+=tempColorStr+"CETypeFlag=12, "+"\\K(1,1,1)"+ "nan pt after step 1."  ///   \\:\r\t\t"+tempStr

	killwaves/z M_colors
	
	// make wave for plotting
	duplicate/o ANMF  root:CE:CEdefault/wave=CEdefault
	CEdefault = str2num(GetUserData("CE_Panel", "", "defaultCE" ) )

	// interpolate across time  The values in CETypeFlag can tell you if point was interpolated or not
	wave t_series = root:index:t_series
	gen_InterpolateAcrossTime(t_series,root:CE_fphase)	

	Histogram/B={0.5,0.025,20} CE_fphase, CE_hist
	CE_hist/=num
	CE_hist/=0.025  // resulting in Sum(y)*deltax=1     1.52 E James email regarding units

	setDataFolder root:

End 


//1.52
// Advanced users panel for setting inflection points for CDCE panel
Function sq_butt_CEAdvPanel(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/F AdvUserCEPanel
	if (V_flag)
		return 0
	endif

	NewPanel/N=AdvUserCEPanel /W=(1100,62,1464,400) as "AdvUserCEPanel"
	SetDrawLayer UserBack
	SetDrawEnv fsize= 18,fstyle= 1
	DrawText 26,20,"Advanced Users CE Panel"
	DrawText 4,40,"To correctly set values in this panel, users must be able"
	DrawText 4,54,"to use external measurements of aerosol mass loadings"
	DrawText 4,69,"and to generate plots similar to the non-supplemental"
	DrawText 4,84,"figures in Middlebrook et al."
	SetDrawEnv fsize= 10
	DrawText 10,146,"The inflection point at which aerosol is deemed acidic."
	SetDrawEnv fsize= 10
	DrawText 10,158,"For each point if NH4meas/NH4predict < inflection point acidity correction"
	SetDrawEnv fsize= 10
	DrawText 10,218,"The inflection point at which aerosol is deemed mostly AN."
	SetDrawEnv fsize= 10
	DrawText 10,171,"is applied. Else user defined default CE (Step 4.) is used."
	SetDrawEnv fsize= 10
	DrawText 10,231,"For each point if ANMF > inflection point ANMF correction"
	SetDrawEnv fsize= 10
	DrawText 10,245,"is applied. Else user defined default CE (Step 4.) is used."
	SetDrawEnv fsize= 10
	DrawText 10,287,"The inflection point at which aerosol is deemed to be 'wet'."
	SetDrawEnv fsize= 10
	DrawText 10,300,"For each point if RH > inflection point RH correction is applied."
	SetDrawEnv fsize= 10
	DrawText 10,314,"Else previoulsy calculated CE (CE_dry) is used."
	SetVariable Humidity_inflectionPt,pos={7,257},size={290,16},title="Relative Humidity Inflection Point, %, Default = 80"
	SetVariable Humidity_inflectionPt,value= _NUM:80
	SetVariable Acidity_inflectionPt,pos={5,116},size={280,16},title="Acidity Inflection Point, unitless, Default = 0.75"
	SetVariable Acidity_inflectionPt,value= _NUM:0.75
	SetVariable ANMF_inflectionPt,pos={6,186},size={290,16},title="ANMF Inflection Point, unitless, Default = 0.4545"
	SetVariable ANMF_inflectionPt,value= _NUM:0.4545
	CheckBox checkUseTheseInflPts,pos={7,91},size={341,14},title="Use inflection points below (this panel must remain open)"
	CheckBox checkUseTheseInflPts,fStyle=1,value= 0

	AutoPositionWindow
	
End


// 1.52
// Creates the time series graph of 5 aerosol species with CE = 1 after step 1 is calculated.
Function sq_create_CEis1_TSgraph(ctrlName) : ButtonControl
	String ctrlName
	
	DoWindow/F CEis1_TSgraph
	if (V_flag)
		return 0
	endif
	PauseUpdate; Silent 1	
	Display /W=(35.25,42.5,429.75,251)/N=CEis1_TSgraph as "CEis1_TSgraph"
	AppendToGraph root:CE:Org_CE1 vs :index:t_series
	AppendToGraph root:CE:NO3_CE1 vs :index:t_series
	AppendToGraph root:CE:SO4_CE1 vs :index:t_series
	AppendToGraph root:CE:NH4_CE1 vs :index:t_series
	AppendToGraph root:CE:Chl_CE1 vs :index:t_series
	ModifyGraph lSize=2
	ModifyGraph rgb(Org_CE1)=(0,52224,0),rgb(NO3_CE1)=(0,0,65535)
	ModifyGraph rgb(NH4_CE1)=(65535,43690,0),rgb(Chl_CE1)=(65280,0,52224)
	ModifyGraph gaps=0
	ModifyGraph zero(left)=1
	ModifyGraph nticks(bottom)=9
	ModifyGraph minor(bottom)=1
	ModifyGraph dateInfo(bottom)={0,1,0}
	Label left "g/m3, CE=1"
	Label bottom " "
	SetAxis/A/E=3 left
End


//1.52
// Link to Middlebrook CDCE paper
//Function sq_CEpaperURL_buttonProc(ctrlName) : ButtonControl
//	String ctrlName
//
//	browseurl /z "http://cires.colorado.edu/jimenez/Papers/2011_AST_Middlebrook_CE.pdf"
//
//End


//1.52
Function Sq_CETabProc(ctrlName,tabNum) : TabControl
	String ctrlName
	Variable tabNum

	// don't display anything if we didn't press the calc CD composition button yet.
	wave/z NO3_CDCE = root:CE:NO3_CDCE		// assume that if this wave exists, all others exist
	if (WaveExists(NO3_CDCE) )
		sq_plotCEGrs(tabNum)
	else
//		DoAlert, 1, "You must first calculate the CDCE before viewing graphs."
	endif

End


//1.52
Function	sq_plotCEGrs(tabNum)
variable tabNum
		
	variable useRH, avgCE1, avgCDCE
	String SpecStr, tempStr, CE1str, CDCEstr
		
 	SetActiveSubwindow CE_Panel
 	
 	useRH = str2num( GetUserData("CE_Panel", "", "UseRH" ))
 	gen_Killsubwindows("CE_Panel")
 	if ( tabNum>=2 )		// individual species
 		SetActiveSubwindow CE_Panel
		
		Display/W=(265,145,615,325)/HOST=CE_Panel
		RenameWindow CE_Panel#G0, SQ_CETSGraph
		SQ_populate_CETSGraph()
		SetActiveSubwindow CE_Panel
		
		Display/W=(265,20,485,140)/HOST=CE_Panel
		RenameWindow  CE_Panel#G0,SQ_CECorrGraph
		SQ_populate_CECorrGraph()
		SetActiveSubwindow CE_Panel
		
		wave SpeciesStats = root:CE:SpeciesStats
		// rows are just like tabs: NH4=0, NO3=1, SO4 = 2, Org = 3, Chl = 4
		SpecStr=StringfromList(tabNum-2, "NH4;NO3;SO4;Org;Chl;")
		avgCE1=SpeciesStats[tabNum-2][0]
		avgCDCE=SpeciesStats[tabNum-2][1]
		sprintf CE1str, "%1.2f",avgCE1
		sprintf CDCEstr, "%1.2f",avgCDCE
		tempStr="Def. CE: "+SpecStr+"  Avg = "+CE1str+"\r"
		tempStr+="CDCE: "+SpecStr+"  Avg = "+CDCEstr
		Titlebox titleTSLegendStats title =tempStr
		TitleBox titleTSLegend, title="Gray:CE=user default\r(via mult. offset)\rColors indicate which\rfactor controls CE", disable=0

 	elseif ( tabNum==1 )		// CE stats
 	
		SetActiveSubwindow CE_Panel
		
		Display/W=(475,20,610,115)/HOST=CE_Panel 
		RenameWindow CE_Panel#G0, SQ_CEHistGraph
		SQ_populate_CEHistGraph()
		SetActiveSubwindow CE_Panel

		Display/W=(265,145,615,325)/HOST=CE_Panel
		RenameWindow CE_Panel#G0,SQ_CETSGraph
		SQ_populate_CETSGraph()
		SetActiveSubwindow CE_Panel

		Titlebox titleTSLegendStats title =""
		wave SpeciesStats = root:CE:SpeciesStats
		tempStr = ""
		TitleBox titleTSLegend, title=tempStr
		
	else		// CE parts histograms
	
		Display/W=(265,25,435,140)/HOST=CE_Panel
		RenameWindow CE_Panel#G0,NH4DetLimHist		// bottom left
		sq_populate_NH4DetLimHistGraph()
		SetActiveSubwindow CE_Panel
	
		Display/W=(440,25,610,140)/HOST=CE_Panel
		RenameWindow CE_Panel#G0,AcidityHist		// top left
		sq_populate_AcidityHistGraph()
		SetActiveSubwindow CE_Panel
	
		Display/W=(265,162,435,287)/HOST=CE_Panel
		RenameWindow CE_Panel#G0,ANMFOrgMFHist	// top right
		sq_populate_ANMFOrgMFHistGraph()
		SetActiveSubwindow CE_Panel
		
		if (UseRH)
			Display/W=(440,162,610,287)/HOST=CE_Panel
			RenameWindow CE_Panel#G0,RelHumHist		// bottom right
			sq_populate_RelHumHistGraph()
			SetActiveSubwindow CE_Panel
		endif
		Titlebox titleTSLegendStats title =""
		TitleBox titleTSLegend, title=""
	endif
			
	Button SQ_but_SQ_CEHistGraph disable = !( tabNum==1)
	Button sq_but_CETypeFlagLegend disable = !( tabNum==1)

	Titlebox titleCEStats disable = !( tabNum==1)
//	Titlebox titleTSLegend disable = ( tabNum==1)
	Titlebox titleTSLegendStats disable = !( tabNum>=1)

	button SQ_but_SQ_CECorrGraph disable = !( tabNum>1)
	
	button SQ_but_SQ_CETSGraph disable = !( tabNum>=1)
	
	Button sq_but_SQ_AcidityHistGraph, disable =  tabNum>=1		// top left
	Button sq_but_SQ_ANMFOrgMFHistGraph, disable =  tabNum>=1	// top right
	Button sq_but_SQ_NH4DetLimHistGraph, disable =  tabNum>=1	// bottom left
	Button SQ_but_SQ_RelHumHistGraph, disable =  tabNum>=1	// bottom right
	Button SQ_but_SQ_CEfphaseTable, disable =  tabNum>=1

	if (!useRH)
		Button SQ_but_SQ_RelHumHistGraph disable=1
	endif
	
	wave/z ANMF_hist = root:CE:ANMF_hist		// any one of several waves could do to check values.
	if (!WaveExists(ANMF_hist))
		button SQ_but_SQ_CECorrGraph disable =1
		button SQ_but_SQ_CETSGraph disable = 1
		Titlebox titleTSLegend disable =1
		Titlebox titleTSLegendStats disable =1
		
		Button sq_but_SQ_AcidityHistGraph, disable =1	// top left
		Button sq_but_SQ_ANMFOrgMFHistGraph, disable =1// top right
		Button sq_but_SQ_NH4DetLimHistGraph, disable = 1	// bottom left
		Button SQ_but_SQ_RelHumHistGraph, disable =1	// bottom right
		Button SQ_but_SQ_CEfphaseTable, disable = 1	
	endif
	
End


// t series 
Function SQ_populate_CETSGraph()

	wave t_series = root:index:t_series

	string species, specColorList

	doWindow/f CE_Panel
 	ControlInfo/W=CE_Panel tabCE
	Species= S_value

	if (stringmatch("CE Stats", species))  // CE tab.... show CE1 and CDCE
		wave/z Spec_CE1 =$"root:CE:CEdefault"
		wave/z Spec_CDCE = $"root:CE_fPhase"
	elseif(stringmatch("Total", species))		// 
		wave/z Spec_CE1 =$"root:CE:ToTal_CE1"
		wave/z Spec_CDCE =$"root:CE:Total_CDCE"
	else
		wave/z Spec_CE1 =$"root:CE:"+species+"_CE1"
		wave/z Spec_CDCE = $"root:CE:"+species+"_CDCE"
	endif
	
	if (!WaveExists(Spec_CE1) || !WaveExists(Spec_CDCE) )
		return 0
		// abort "Perhaps you have changed your todo wave.  Could not find waves "+nameofWave(Spec_CE1) +" or "+nameofWave(Spec_CDCE) +"  aborting from SQ_populate_CETSGraph"
	endif
	
	SpecColorList = SQ_getColorListSpecies(Species)

	AppendToGraph Spec_CE1 vs t_series
	AppendToGraph Spec_CDCE vs t_series
	
	ModifyGraph lSize($NameofWave(Spec_CE1))=2
	ModifyGraph rgb($NameOfWave(Spec_CE1))=(34816,34816,34816)
	ModifyGraph rgb($NameofWave(Spec_CDCE))=(str2num(stringFromList(0, SpecColorList)) ,str2num(stringFromList(1, SpecColorList)),str2num(stringFromList(2, SpecColorList)))
	
	SetAxis/A/E=1 left
	ModifyGraph gaps=0
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph zero(left)=1
	ModifyGraph nticks=9
	ModifyGraph minor=1
	ModifyGraph mode=4,marker=19,msize=1,lsize=1
	ModifyGraph dateInfo(bottom)={0,1,0}
	Label left "g/m3,"+Species
	Label bottom " "

	variable defaultCE = str2num(GetUserData("CE_Panel", "", "defaultCE" ) )
	if (stringmatch(Species, "CE Stats"))
		SetAxis/A/W=CE_Panel#SQ_CETSGRAPH left  defaultCE*.9,1
	else
		ModifyGraph offset={0,0},muloffset($NameofWave(Spec_CE1))={0,1/defaultCE}
		SetAxis/A/E=1/W=CE_Panel#SQ_CETSGRAPH left
	endif
	ModifyGraph 	zColor($NameofWave(Spec_CDCE))={root:CE:CETypeFlag,1,15,dBZ14,0}
 
 End


//  t series correlation
Function SQ_populate_CECorrGraph()

	variable minTemp, maxTemp
	string SpecColorList, Species
	
	doWindow/f CE_Panel
 	ControlInfo/W=CE_Panel tabCE
	Species = S_value

	if (stringmatch("CE", species))  // CE tab.... show CE1 and CDCE
		wave/z Spec_CE1 =$"root:CE:CEdefault"
		wave/z Spec_CDCE = $"root:CE_fPhase"
	elseif(stringmatch("Tot", species))		// renamed tab Tot instead of Total to save space
		wave/z Spec_CE1 =$"root:CE:ToTal_CE1"
		wave/z Spec_CDCE =$"root:CE:Total_CDCE"
	else		// CE tab.... show CE1 and CDCE
		wave/z Spec_CE1 =$"root:CE:"+species+"_CE1"
		wave/z Spec_CDCE = $"root:CE:"+species+"_CDCE"
	endif
	
	//1.09A
	if (!WaveExists(Spec_CE1) || !WaveExists(Spec_CDCE) )
		return 0
		// abort "Perhaps you have changed your todo wave.  Could not find waves "+nameofWave(Spec_CE1) +" or "+nameofWave(Spec_CDCE) +"  aborting from SQ_populate_CETSGraph"
	endif

	wave/z One2one = root:panel:One2one		//1.07A
	if (!WaveExists(One2One))
		make/o/n=2 root:panel:One2One = {0,1}
		wave One2one = root:panel:One2one		//1.07A
	endif
	
	SpecColorList = SQ_getColorListSpecies(Species)

	if (WhichListItem("one2one", TraceNameList(WinName(1, 1), ";", 1 ))<0 )
		AppendToGraph one2one vs one2one
	endif
	AppendToGraph Spec_CDCE vs Spec_CE1
	
	ModifyGraph mode($NameofWave(Spec_CDCE))=2
	ModifyGraph lSize($NameofWave(Spec_CDCE))=2
	ModifyGraph rgb($NameofWave(Spec_CDCE))=(str2num(stringFromList(0, SpecColorList)) ,str2num(stringFromList(1, SpecColorList)),str2num(stringFromList(2, SpecColorList)))
	
	ModifyGraph rgb($NameOfWave(one2one))=(0,0,0)
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph nticks=9
	ModifyGraph minor=1
	Label bottom "g/m3, CE=user default, "+Species		// +", g/m3"
	Label left "g/m3, CE=CD,  "+Species		// +", g/m3"

	waveStats/q Spec_CDCE
	minTemp = V_min
	maxTemp = V_max 
	waveStats/q Spec_CE1
	minTemp = min(0, min( V_min, minTemp))
	maxTemp = max(V_max, maxTemp)

	if (!stringmatch(Species, "CE Stats"))
		variable defaultCE = str2num(GetUserData("CE_Panel", "", "defaultCE" ) )
		ModifyGraph offset={0,0},muloffset(One2One)={maxTemp,(1/defaultCE)*maxTemp}
	endif

	ModifyGraph 	zColor($NameofWave(Spec_CDCE))={root:CE:CETypeFlag,1,14,dBZ14,0}
	
	SetAxis left minTemp,maxTemp
	SetAxis bottom minTemp, maxTemp

End


//1.52
Function sq_populate_CEHistGraph()
	AppendtoGraph root:CE:CE_hist
	ModifyGraph mode=6
	ModifyGraph rgb=(65280,16384,35840)
	Label left "normalized frequency"
	Label bottom "CE_fphase"
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)
End


//1.52
Function sq_CE_ButtonProc(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	sq_CreatePhaseDepCE() 		// do the calculations for CDCE

End


//1.52
//Function sq_CEHelpButtonProc(ctrlName) : ButtonControl
//	String ctrlName
//	
//	browseurl /z "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Composition_Dependent_Collection_Efficiency_.28CE_Panel.29"
//
//End


//1.52
// Button on CDCE panel for batch table NH4 RIE
Function sq_butt_reviewNH4RIE(ControlName) : ButtonControl
	string controlname

	sq_butt_reviewBatch(ControlName) 
	ModifyTable/W=ReviewBatchTable selection=(5 , 3, 5 , 3, 5,3), topLeftCell=(0,0)

End


//1.52
Function sq_populate_CEfphaseTable() 

	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave CETypeFlag,ANMF,NH4_MeasToPredict,NH4_CE1,CE_dry
	AppendtoTable CETypeFlag,::CE_fPhase,ANMF,NH4_MeasToPredict,NH4_CE1,CE_dry
	ModifyTable format(Point)=1,width(Point)=51,width(CETypeFlag)=239,title(CETypeFlag)="8=belowMinNH4;3=ANMF;10=acidic;1=UseRH;12=nan"
	ModifyTable sigDigits(::CE_fPhase)=3,width(::CE_fPhase)=60,sigDigits(ANMF)=3,width(ANMF)=50
	ModifyTable sigDigits(NH4_MeasToPredict)=3,width(NH4_MeasToPredict)=48,sigDigits(NH4_CE1)=3
	ModifyTable width(NH4_CE1)=53,sigDigits(CE_dry)=3,width(CE_dry)=51
	SetDataFolder fldrSav0

	variable useRH = str2num( GetUserData("CE_Panel", "", "UseRH" ))
	if (useRH)
		string RHWaveStr = GetUserData("CE_Panel", "", "RHwave" )
		wave RHwave = $"root:"+RHWaveStr
		AppendToTable RHwave
//		ModifyTable width($NameofWave(RHwave))=44, sigDigits($NameofWave(RHwave))=3
	endif

End


//1.52
Function sq_populate_AcidityHistGraph()
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave Acidity_Hist
	AppendToGraph Acidity_Hist
	variable mymax =WaveMax(acidity_hist)
	SetDataFolder fldrSav0
	ModifyGraph mode=6
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	Label left "Normalized Frequency"
	Label bottom "NH4 meas/NH4 predict"
	SetDrawLayer UserBack
	SetDrawEnv xcoord= bottom,ycoord= left,linefgc= (65280,65280,32768),fillpat= 34,fillfgc= (65280,65280,32768),fillbgc= (65280,65280,16384)
	DrawRect 0,0,0.75,mymax		// instead of using .75 perhaps we should attach to humidityCutoff parameter in CE_fphase function
	DrawText 0.2,0.2,"is acidic"
End


Function sq_populate_ANMFHistGraph() 		// in Ann's paper but now combined into sq_populate_ANMFOrgMF_hist_graph
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave ANMF_Hist
	AppendToGraph ANMF_Hist
	SetDataFolder fldrSav0
	ModifyGraph mode=6
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	Label left "normalized frequency"
	Label bottom "ANMF"
End


Function sq_populate_OrgMFHistGraph()	// in Ann's paper but now combined into sq_populate_ANMFOrgMF_hist_graph
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave OrgMF_Hist
	AppendToGraph OrgMF_Hist
	SetDataFolder fldrSav0
	ModifyGraph mode=6
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	Label left "normalized frequency"
	Label bottom "Org MF"
End


Function sq_populate_ANMFOrgMFHistGraph() 
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave ANMF_Hist, OrgMF_Hist, SO4MF_Hist
	AppendToGraph ANMF_Hist, OrgMF_Hist, SO4MF_Hist
	SetDataFolder fldrSav0
	ModifyGraph mode=6
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	Label left "normalized frequency"
	Label bottom "ANMF, OrgMF SO4MF"
	ModifyGraph rgb(ANMF_Hist)=(24576,24576,65280),rgb(OrgMF_Hist)=(0,39168,0), rgb(SO4MF_Hist)=(65280,0,0)
End


Function sq_populate_RelHumHistGraph()
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave Humidity_Hist
	AppendToGraph Humidity_Hist
	variable mymax=WaveMax(humidity_hist)
	SetDataFolder fldrSav0
	ModifyGraph mode=6
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	Label left "normalized frequency"
	Label bottom "RH, %"
	SetAxis/A/E=1 left
	SetDrawLayer UserBack
	SetDrawEnv xcoord= bottom,ycoord= left,linefgc= (65280,65280,32768),fillpat= 34,fillfgc= (65280,65280,32768),fillbgc= (65280,65280,16384)
	DrawRect 80,0,100,mymax		// instead of using 80 perhaps we should attach to humidityCutoff parameter in CE_fphase function
	DrawText 0.594736842105263,0.160087719298246,"is wet"
End


Function sq_populate_NH4DetLimHistGraph()
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:CE:
	wave NH4_hist
	Appendtograph NH4_hist
	SetDataFolder fldrSav0
	ModifyGraph mode=6
	Label left "normalized frequency"
	Label bottom "NH4, CE=1, g/m3"
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph rgb=(52224,34816,0)
	variable lowNH4Val=str2num(getuserdata("CE_Panel","","NH4DetLim") )	
	lowNH4Val = numtype(lowNH4Val)==0 ? lowNH4Val : 0
	SetDrawLayer UserBack
	SetDrawEnv xcoord= bottom,ycoord= left,linefgc= (65280,65280,32768),fillpat= 34,fillfgc= (65280,65280,32768),fillbgc= (65280,65280,16384)
	DrawRect pnt2x(root:CE:NH4_hist, 0 ),0,lowNH4Val,Wavemax(root:CE:NH4_hist)
	SetAxis/A/E=1 left
	DrawText 0.2,0.2,"<NH4 Min"
	ModifyGraph zero(bottom)=1
	ModifyGraph nticks=9

End


//1.52
// Generates small panel with CDCE flag legend
Function sq_butt_CETypeFlagLegend(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/F CETypeFlag_Legend
	if (V_flag)
		return 0
	endif
	NewPanel/N=CETypeFlag_Legend/W=(150,77,371,166) as "CETypeFlag_Legend"
	TitleBox title0 variable=:CE:CEStatsStr, frame=0,pos={1,1}
	
End


// CE end ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

Function/s SQ_getColorListSpecies(Species)
string Species

	wave col_r=root:frag:col_r
	wave col_g=root:frag:col_g
	wave col_b=root:frag:col_b
	wave /z/t col_names=root:frag:col_names

	variable idex, num
	string returnList = "0;0;0"		// default to black
	
	idex=sq_findstr(col_names,Species, 1)
	
	if (idex>=0)
		return num2str(col_r[idex])+";"+num2str(col_g[idex])+";"+num2str(col_b[idex])
	endif
	
	return returnList

End


// Not needed ? 1.52  
// returns a list of waves in the current folder that have 1 dimension and numX number of points
Function/S gen_Get1DWavesofLengthX(numX)
variable numX

	string WList, str	
	variable idex, numWaves, numList
	
	WList = Wavelist("*", ";", "DIMS:1")
	numList = itemsInList(WList)
	// search the string from the end to the front because we may be deleting items
	for(idex=numList-1;idex>=0;idex-=1)
		str = StringFromList(idex,WList )
		wave wav = $str 
		if (numpnts(wav)!= numX)
			WList = RemoveListItem(idex, WList)
		endif
	endfor

	return WList

End


//1.52
Function gen_ListToWave(TempWave, tempList)
 wave/t TempWave
 string tempList
 
 redimension/n=(ItemsInList(tempList)) TempWave
 TempWave = stringFromList(p, TempList)
 End
 
 
//1.52
//  returns the index value of the place where there is a change in the detecotr type
Function sq_TodoWaveHasOnlyOneDetType(todowave)
wave todowave

	wave detector_num = root:diagnostics:detector_num
	variable idex, runPos, detTypeInWave

	runPos = sq_findRun(root:index:rn_series,todowave[0])
	detTypeInWave=detector_num[runPos]

	make/free/u/o/n=(numpnts(detector_num)) todoMask
	sq_makeMaskFromTodofindRun(TodoMask,todowave)
	
	make/u/o/n=(numpnts(detector_num))/FREE tempMask  //1.55G
	tempMask = detector_num[p] == detTypeInWave && TodoMask[p]
	
	if (numpnts(todowave)!=sum(tempMask))
		 for(idex=0;idex<numpnts(detector_num);idex+=1)
			if (TodoMask[idex] !=tempMask[idex])
				return idex
			endif
		endfor
	endif
	
	return -1
	
End


//1.52
Function gen_Killsubwindows(winstr)
string winStr

	string childwinList = ChildWindowList(winStr)
	variable idex, num
	num=itemsinlist(childwinlist)
	for (idex=0;idex<num;idex+=1)
		KillWindow $winstr+"#"+StringFromList(idex, childwinList)
	endfor
End


//1.52
// given a control name in the top most panel return a wave reference for the wave selected
Function/WAVE gen_returnSelectedWave(ControlName, [DFstr, num, minVal, maxVal, nansOK])
string ControlName, DFstr
variable num, minVal, maxVal, nansOK

	string waveStr
	
	ControlInfo $ControlName 
	waveStr=S_value 
	wave/z selWave = $DFstr+waveStr
	if (!waveExists(selWave) && !ParamIsDefault(num) && numpnts(selWave) != num)
		abort "The wave "+waveStr +" either doesn't exist or doesn't have the correct number of points.  Aborting from gen_returnSelectedWave"
	endif
	
	wavestats/m=1/q selWave
	if (!ParamIsDefault(minVal) && V_min<minVal)
		abort "The wave "+waveStr +" detected values <"+num2str(minVal)+ ". Aborting from gen_returnSelectedWave" 
	endif		
	if (!ParamIsDefault(maxVal) && V_max>maxVal)
		abort "The wave "+waveStr +" detected values >"+num2str(maxVal)+ ". Aborting from gen_returnSelectedWave" 
	endif		
	if (!ParamIsDefault(nansOK) && !nansOK && V_numNans>0)
		abort "The wave "+waveStr +" has "+num2str(V_numNans) + " nans. Aborting from gen_returnSelectedWave" 
	endif

	return selWave
End


//1.52
// Table for PToF time, DVa values
Function sq_butt_PToF_DVaTable(ctrlName) : ButtonControl
	String ctrlName

	Dowindow/F PToF_DVaTable
	if (V_flag)
		return 0
	endif
	wave/z ptof_dVaDisplaySize = root:panel:ptof_dVaDisplaySize
	wave/z ptof_dVaDisplayTime = root:panel:ptof_dVaDisplayTime
	if (!WaveExists(ptof_dVaDisplaySize) || !WaveExists(ptof_dVaDisplaySize) )
		make/o/n=0 root:panel:ptof_dVaDisplayTime
		make/o/n=0 root:panel:ptof_dVaDisplaySize
		wave/z ptof_dVaDisplaySize = root:panel:ptof_dVaDisplaySize
		wave/z ptof_dVaDisplayTime = root:panel:ptof_dVaDisplayTime
	endif
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:panel:
	Edit/W=(5.25,42.5,294,242.75)/N=PToF_DVaTable ptof_dVaDisplaySize,ptof_dVaDisplayTime as "PToF_DVaTable"
	ModifyTable format(Point)=1,title(Point)="PToF Bin #",title(ptof_dVaDisplaySize)="PToF Size (nm)"
	ModifyTable width(ptof_dVaDisplayTime)=92,title(ptof_dVaDisplayTime)="PToF Time (s)"
	SetDataFolder fldrSav0
End


//1.52 
// Tab in new DVa panel
Function sq_DvaTab(ctrlName,tabNum) : TabControl
	String ctrlName
	Variable tabNum
 	
	gen_removeTracesFromGraph("dVa_gr#DVaDiam")
 	if (tabNum==1)		// param time series
		ControlInfo button_sq_DVaDiamGraph
		if (V_flag==1)		// V_flag==0 means control does not exist
			Button button_sq_DVaDiamGraph rename=button_sq_DVaTSeriesGraph
 		endif
		SetActiveSubwindow dVa_gr#DVaDiam
		sq_populate_DVaTSeriesGraph() 	
		SetActiveSubwindow ##
 	else		// diameter graph
		ControlInfo button_sq_DVaTSeriesGraph
		if (V_flag==1)		// V_flag==0 means control does not exist
			Button button_sq_DVaTSeriesGraph rename=button_sq_DVaDiamGraph
 		endif
		SetActiveSubwindow dVa_gr#DVaDiam
	 	sq_populate_DVaDiamGraph()
		SetActiveSubwindow ##
 	endif
 	
End


//1.52
// returns todoSubsetStr as a new wave (possibly overwritten)
Function/s sq_GetTodoSubsetWithPToF(todo, todoSubsetStr)
wave todo
string todoSubsetStr

	// Check if todo wave has >0 PToF spectra.  We possibly reduce the selected todo wave to run that have PToF (todo = tempTodo)
	wave/z allPToF = root:allPToF	
	if (WaveExists(allPToF))
		setDataFolder root:
		sq_create_todo(NameofWave(todo)+" and allPTOF",todoSubsetStr)
		wave todoSubset = $"root:"+todoSubsetStr
		if (numpnts(todoSubset)==0)
			killwaves/z todoSubset
			abort "There are no PToF runs in "+NameofWave(todo)+".  Aborting from sq_GetTodoSubsetWithPToF"
		endif
	else
		duplicate/o todo  $"root:"+todoSubsetStr
	endif
	return todoSubsetStr
	
end


//
// presumes that all runs in todo wave have PToF data  // checks "ptof_vl;ptof_vg;ptof_b;ptof_dx;ptof_step;ptof_t0;ChopperFreq;ptofNumSpectraPerChop;detector_Num;"
Function sq_checkPToFparamsSameTodo(todo)
wave todo

	variable idex, runPos, nTodo, num, baseval
	string PToFstr, PToFList = "ptof_vl;ptof_vg;ptof_b;ptof_dx;ptof_step;ptof_t0;ChopperFreq;ptofNumSpectraPerChop;detector_Num;"		// first 6 can be overwritten (without a _logged suffix)
		//1.59C  added detectorNum
		
	make/free/o/n=(numpnts(root:index:rn_series)) tempMaskWave
	sq_makeMaskFromTodofindRun(tempMaskWave,todo)
	duplicate/o/Free tempMaskWave tempMaskWaveDup		// dup never changes
	nTodo = numpnts(todo)
	num = itemsInList(PToFList)
	runPos=sq_findrun(root:index:rn_series,todo[0])
	for (idex=0;idex<num;idex+=1)	//^check these 6 parameters: vl;vg;b;dx;step;t0
		PToFstr=stringfromlist(idex,PToFList)
		wave/z source=$"root:diagnostics:"+PToFstr
		if (waveexists(source)==0 && idex<5)
			wave source = $"root:diagnostics:"+PToFstr+"_logged"		//^ 136C
		endif
		baseval=source[runPos]
		tempMaskWave = abs(source[p]-baseval)<1e-6 && (tempMaskWaveDup[p]==1) 	// tricky to check equality with roundoff errors
		if (sum(tempMaskWave) !=nTodo)
			Abort "The parameter "+PToFstr +" is not constant within the specified todo. This is probably due to a change in the size calibration or MS pulsing rate. Aborting from sq_checkPToFparamsSameTodo"
		endif
	endfor

End


//1.52
// Generates DVa graph in DVa panel
Function sq_populate_DVaDiamGraph() 

	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:panel:
	WAVE ptof_dVaDisplaySize, ptof_dVaDisplayTime
	AppendToGraph ptof_dVaDisplaySize vs ptof_dVaDisplayTime
	ModifyGraph mode(ptof_dVaDisplaySize)=4,rgb(ptof_dVaDisplaySize)=(29440,0,58880)
	ModifyGraph log(left)=1
	SetDataFolder fldrSav0

	ModifyGraph grid=2
	ModifyGraph gridRGB=(29440,0,58880)
	ModifyGraph nticks(bottom)=9
	ModifyGraph minor(bottom)=1

	Label left "Aerodyn. Diam., nm"
	Label bottom "time, (s)" 		//  1.59E\\F'Symbol'm\\F'Arial's"
	SetAxis/A/E=1 bottom
	
End


//1.52
// Generates time series graph of DVa parameters in DVa panel
Function sq_populate_DVaTSeriesGraph() 

	Wave rn_series = root:index:rn_series

	wave/z vl=root:diagnostics:ptof_vl	
	if (!WaveExists(vl))
		wave vl=root:diagnostics:ptof_vl_logged
		duplicate/o vl root:diagnostics:ptof_vl
	endif
	
	wave/z vg=root:diagnostics:ptof_vg
	if (!WaveExists(vg))
		wave vg=root:diagnostics:ptof_vg_logged
		duplicate/o vg root:diagnostics:ptof_vg
	endif
	
	wave/z b=root:diagnostics:ptof_b	
	if (!WaveExists(b))
		wave b=root:diagnostics:ptof_b_logged
		duplicate/o b root:diagnostics:ptof_b
	endif
	
	wave/z dx=root:diagnostics:ptof_dx
	if (!WaveExists(dx))
		wave dx=root:diagnostics:ptof_dx_logged
		duplicate/o dx root:diagnostics:ptof_dx
	endif
	
	AppendToGraph/L vg vs rn_series
	AppendToGraph/L=vl vl vs rn_series
	AppendToGraph/L=dx dx vs rn_series
	AppendToGraph/L=b b vs rn_series
	ModifyGraph grid=2
	ModifyGraph gridRGB=(29440,0,58880)
	ModifyGraph nticks(bottom)=9
	ModifyGraph minor(bottom)=1
	ModifyGraph rgb($NameofWave(vg))=(39168,39168,0),rgb($NameofWave(vl))=(16384,65280,16384),rgb($NameofWave(dx))=(65280,16384,55552), rgb($NameofWave(b))=(65280,43520,0)
	ModifyGraph lblPos(vl)=55,lblPos(dx)=55,lblPos(b)=55, lblPos(left)=55
	ModifyGraph freePos(vl)={0,bottom}
	ModifyGraph freePos(dx)={0,bottom}
	ModifyGraph freePos(b)={0,bottom}
	ModifyGraph axisEnab(left)={0.02,0.25}
	ModifyGraph axisEnab(vl)={0.27,0.5}
	ModifyGraph axisEnab(dx)={0.52,0.75}
	ModifyGraph axisEnab(b)={0.77,1}
	Label left "Vg"
	Label vl "Vl"
	Label dx "Dx"
	Label b "b"
	Label bottom "run number"
End


//*****************************************   MSvsPToF_Panel and MSSCvsDC_Panel  Start *********************************************************
// Set of function below  are used for the MSvsPToF_Panel and MSSCvsDC_Panel

//1.52
// button from main squirrel panel
Function sq_button_MSvsPToF(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
 	doWIndow/f MSvsPToF_Panel
  	if(V_flag==0)
 		sq_ViewMSvsPToF_Panel()
		sq_plotMSvsPToFGrs()
 	endif	

End


//1.52
// called from sq_button_MSvsPToF
Function/s sq_MSvsPToF_calcWaves()

	// flags on MS tab in AMS panel
	nvar ms0_corr=root:panel:ms0_corr
	nvar ms0_ion2mass=root:panel:ms0_ion2mass
	nvar ms0_msTseries_suffix_ck=root:panel:ms0_msTseries_suffix_ck
	nvar ms0_appendErrorBars=root:panel:ms0_appendErrorBars	
	nvar ms0_dataType=root:panel:ms0_dataType		// a numerical value
	nvar ams_time_saved=root:panel:ams_time_saved
	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$(todoStr)
	
	// flags on PToF tab
	nvar tof1_ugconv=root:panel:tof1_ugconv
	nvar tof0_corrop=root:panel:tof0_corrop
	nvar tof1_norm=root:panel:tof1_norm
	nvar tof_Stats=root:panel:tof_Stats
	nvar tof1_datatype=root:panel:tof1_datatype
	nvar tof0_d_reg=root:panel:tof0_d_reg
	nvar tof0_d_reg_n=root:panel:tof0_d_reg_n
	nvar tof0_d_reg_min=root:panel:tof0_d_reg_min
	nvar tof0_d_reg_max=root:panel:tof0_d_reg_max
	nvar tof1_graphOption=root:panel:tof1_graphOption
	nvar tof0_maxmz=root:panel:tof0_maxmz
	nvar tof0_suffix_ck = root:panel:tof0_suffix_ck		//1.57
	
	string waveNameSuffix, paramStrPartial, datastr
	variable temp_tof1_graphOption
	temp_tof1_graphOption = tof1_graphOption
	
	// prepare MS and PToF calculations
	variable temppToFsuffix = tof0_suffix_ck
	variable tempMSsuffix = ms0_msTseries_suffix_ck
	tof0_suffix_ck=0
	ms0_msTseries_suffix_ck=0
	
	if (tof1_datatype!=1)
		abort "You must select the dXdlogDa axis - aborting from sq_MSvsPToF_calcWaves"
	endif
	if (tof0_d_reg_n!=1)
		abort "You must select only one bin size diameter base encompassing aerosol signal  - aborting from sq_MSvsPToF_calcWaves"
	endif
	if (tof0_d_reg_min<1 || tof0_d_reg_max> 10000 || tof0_d_reg_min>=tof0_d_reg_max)
		abort "The min and max diameter sized don't make sense  -  aborting from sq_MSvsPToF_calcWaves"
	endif

	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList
	datastr = stringFromList(ms0_dataType-1 ,MSStickDataList)	//	ms0_dataType is one higher because of the popmenu
 	if (! stringmatch(dataStr, "MSSDiff_p") )
 		abort "The typical data set for the data base is MSSDiff. Please reselect your data type in the MS tab.  Aborting from sq_exportForDataBase."
		//  ms0_dataType=1		// Diff
	endif

	waveNameSuffix = todoStr

	// set species list to be the same
	sq_butt_MSSpeciesDefault( "")			// set SQ species list
	sq_butt_ToFSpeciesDefault("")		// set PToF species list
	
	// set MS settings to PToF settings
	ms0_ion2mass = tof1_ugconv		// ug or Hz
	ms0_corr = tof0_corrop				// use AB or no

	ms0_appendErrorBars = 0
	ms0_msTseries_suffix_ck=1		//slightly different interface in SQ
			
	tof1_norm=0
	tof_Stats=0
	tof1_graphOption=4
			
	sq_timebase_check("time_saved",1)  //1.60E
	//ams_time_saved=1				// always do TS for MS and PToF in as saved time units

// do the calcs for the TS
	if (tof0_maxmz>0)
		doAlert 1, "You have chose to use a maximum m/z value of "+num2str(tof0_maxmz)+".  The code will temporarily change the frag_organic wave to show blanks above this m/z to calculate the MS and PToF values.  If something goes wrong be sure to check frag_organic.  Continue?"
		if (V_flag==2)
			abort "The user chose to abort"
		endif
		wave/t frag_organic  = root:frag:frag_organic
		duplicate/o frag_organic root:frag:frag_organic_duplicate
		frag_organic[tof0_maxmz,]=""
	endif

// MS data
	sq_MSCalc_Tseries(waveNameSuffix, 0)
// do the calcs for the MS
	sq_MSCalc_avgStick(waveNameSuffix) 
	if (tof0_maxmz>0)		//1.56O
		wave/t frag_organic_duplicate  = root:frag:frag_organic_duplicate
		duplicate/o frag_organic_duplicate root:frag:frag_organic
	endif

// PToF data 
	sq_butt_ToFConc("tof1_imconc")		// image plot	
	// waves are named by default ug_log_Orgim_all_d, ug_log_Spedim_todo_d  ("ug_  or " sig_)
	// waves are named by default ug_log_Orgms_all_MS_d, ug_log_Spedim_todo_d  ("ug_  or " sig_)

	sq_butt_ToFConc("tof1_mscon")	// mass spectra

	sq_MSvsPToFrenamePToF(tof1_ugconv, todoStr)
		
// Info string
	string/g root:panel:MSvsPToFInfo
	svar MSvsPToFInfo=root:panel:MSvsPToFInfo
	MSvsPToFInfo =""
	MSvsPToFInfo +="todo:"+todoStr +"\r"
//	MSvsPToFInfo +="units: "+SelectString(tof1_ugconv, "Hz","ug/m3")  +"\r"
	MSvsPToFInfo +="use AB correction: "+SelectString(tof0_corrop, "No"," Yes")+"\r"
	MSvsPToFInfo +="diam. min: "+num2str(tof0_d_reg_min) +"nm  diam. max: "+num2str(tof0_d_reg_max)+"nm"
	
	tof1_graphOption = temp_tof1_graphOption

	sq_PToFDiffHz_calcWaves()		// generates PToFDiff

	tof0_suffix_ck = temppToFsuffix
	ms0_msTseries_suffix_ck = tempMSsuffix

End


//1.52
// used in sq_MSvsPToF_calcWaves
// not only renames the waves, but redimensions the PToF 1 size bin image plots
// also stores waves in panel data folder
Function sq_MSvsPToFrenamePToF(ugFlag, todoStr)
variable ugFlag	
string todoStr

	nvar tof0_d_reg_min = root:panel:tof0_d_reg_min
	nvar tof0_d_reg_max = root:panel:tof0_d_reg_max
	
	string specList, specStr, tempStr
	variable idex, num
	
	speclist = ReplaceString(",", MSTSERIES_SPECIES_DEFAULT_LIST, ";")
	num = itemsinlist(speclist)
	for (idex=0;idex<num;idex+=1)
		specStr = stringfromlist(idex, specList)
		
		// MS mode time series
		NewDataFolder/o root:PToF
		wave/z MSSpecTS =$"root:"+specStr+"_"+todoStr
		duplicate/o MSSpecTS $"root:PToF:"+specStr+"_"+todoStr			// duplicate always easier than moveWave
		killwaves/z MSSpecTS
		// MS mode mass spec
		wave MSSpecStick = $"root:MSSD_"+todoStr+"_"+specStr
		duplicate/o MSSpecStick $"root:PToF:MSSD_"+todoStr+"_"+specStr	// duplicate always easier than moveWave
		killwaves/z MSSpecStick
		
		// PToF mode  time series
		// waves are named by default ug_log_Orgim_all_d, ug_log_Spedim_todo_d  ("ug_  or " sig_)		// we need to multiply by the DlogDt
		wave/z ptofwave =$"root:"+selectString(ugFlag,"sig_", "ug_")+"log_"+specStr+"im_"+todoStr+"_d"
		duplicate/o ptofwave $"root:PToF:PToF_ts_"+todoStr+"_"+specStr/wave = PToFTseries
		killwaves/z ptofwave
		Redimension/N=-1 PToFTseries
		PToFTseries*= (log( tof0_d_reg_max) - log( tof0_d_reg_min)  )
		
		// PToF mode mass spec waves
		tempStr = selectString(ugFlag,"sig_", "ug_")+"log_"+specStr+"ms_"+todoStr+"_MS_d"
		tempStr = CleanUpName(tempStr, 0)
		wave/z ptofwave =$"root:"+tempStr
		// waves are named by default ug_log_Orgms_all_MS_d, ug_log_Spedim_todo_d  ("ug_  or " sig_)
		duplicate/o ptofwave $"root:PToF:PToF_ms_"+todoStr+"_"+specStr/wave = PToFMS
		killwaves/z ptofwave
		Redimension/N=-1 PToFMS
	endfor
end


//1.52
// tab function for MSvsPToF_Panel
Function sq_MSVsPToFTabProc(ctrlName,tabNum) : TabControl
	String ctrlName
	Variable tabNum

 	ControlInfo/W=MSvsPToF_Panel tabSpecies
	setwindow MSvsPToF_Panel,userdata(Species)=S_Value
	
	sq_plotMSvsPToFGrs()
End


// plot the graphs on MSvsPToF_Panel
Function	sq_plotMSvsPToFGrs()
		
	svar todoStr=root:panel:sq_toDoWvNm
	nvar tof1_ugconv=root:panel:tof1_ugconv
	nvar tof0_corrop=root:panel:tof0_corrop

	string Species

 	ControlInfo/W=MSvsPToF_Panel tabSpecies
	Species = S_value
	
	doWindow/f MSvsPToF_Panel

	setwindow MSvsPToF_Panel,userdata(todoStr)=todoStr
	setwindow MSvsPToF_Panel,userdata(Species)=Species

	SetActiveSubwindow MSvsPToF_Panel#sq_MSvsPToFTSGraph
	gen_removeTracesFromGraph("MSvsPToF_Panel#sq_MSvsPToFTSGraph")
	sq_populate_MSvsPToFTSGraph()
	SetActiveSubwindow ##

	SetActiveSubwindow MSvsPToF_Panel#sq_MSvsPToFTSCorrGraph
	gen_removeTracesFromGraph("MSvsPToF_Panel#sq_MSvsPToFTSCorrGraph")
 	sq_populate_MSvsPToFTSCorrGraph()
	SetActiveSubwindow ##
	
	SetActiveSubwindow MSvsPToF_Panel#sq_MSvsPToFMSGraph
	gen_removeTracesFromGraph("MSvsPToF_Panel#sq_MSvsPToFMSGraph")
	sq_populate_MSvsPToFMSGraph()
	SetActiveSubwindow ##
	
	SetActiveSubwindow MSvsPToF_Panel#sq_MSvsPToFMSCorrGraph
	gen_removeTracesFromGraph("MSvsPToF_Panel#sq_MSvsPToFMSCorrGraph")
	sq_populate_MSvsPToFMSCorrGraph()
	SetActiveSubwindow ##

End

//1.52
// t series for the MSvsPToF_Panel
Function sq_populate_MSvsPToFTSGraph()

	string waveNameSuffix, Species
	string SpecColorList
	
	waveNameSuffix= getuserdata("MSvsPToF_Panel","","todoStr")
	Species = getuserdata("MSvsPToF_Panel","","Species")

	wave/z MSSpecTS =$"root:PToF:"+Species+"_"+waveNameSuffix
	wave/z PToFspecTS = $"root:PToF:PToF_ts_"+waveNameSuffix+"_"+Species
	wave t_series = root:index:t_series
	
	//1.09A
	if (!WaveExists(MSSpecTS) || !WaveExists(PToFspecTS) )
		abort "Perhaps you have changed your todo wave.  Could not find waves "+nameofWave(MSSpecTS) +" or "+nameofWave(PToFspecTS) +"  aborting from sq_populate_MSvsPToFTSGraph"
	endif
	
	SpecColorList = sq_getColorListSpecies(Species)

	AppendToGraph MSSpecTS vs root:index:t_series
	AppendToGraph PToFspecTS vs root:index:t_series
	
	ModifyGraph lSize($NameofWave(MSSpecTS))=2
	ModifyGraph rgb($NameOfWave(PToFspecTS))=(0,0,0)
	ModifyGraph rgb($NameofWave(MSSpecTS))=(str2num(stringFromList(0, SpecColorList)) ,str2num(stringFromList(1, SpecColorList)),str2num(stringFromList(2, SpecColorList)))
	
	Label left "MS=Hz, PToF=Hz" //  1.56H   Hz^2"
	SetAxis/A/E=3
	ModifyGraph gaps=0
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph zero(left)=1
	ModifyGraph nticks=9
	ModifyGraph minor=1

	ModifyGraph dateInfo(bottom)={0,1,0}
	Label bottom " "
	
End


//1.52
// mass spec for the MSvsPToF_Panel
Function sq_populate_MSvsPToFMSGraph()
	
	string waveNameSuffix, Species
	
	waveNameSuffix= getuserdata("MSvsPToF_Panel","","todoStr")
	Species = getuserdata("MSvsPToF_Panel","","Species")

	wave MSSpecStick = $"root:PToF:MSSD_"+waveNameSuffix+"_"+Species
	wave PToFspecStick = $"root:PToF:PToF_ms_"+waveNameSuffix+"_"+Species
	wave amus = root:diagnostics:amus
	
	string SpecColorList
	SpecColorList = sq_getColorListSpecies(Species)

	AppendToGraph MSSpecStick vs amus
	AppendToGraph PToFspecStick vs amus
	
	ModifyGraph mode=1
	ModifyGraph lSize=2
	ModifyGraph rgb($NameOfWave(PToFspecStick))=(0,0,0)
	ModifyGraph offset($NameOfWave(PToFspecStick))={0.3,0}
	ModifyGraph rgb($NameOfWave(MSSpecStick))=(str2num(stringFromList(0, SpecColorList)) ,str2num(stringFromList(1, SpecColorList)),str2num(stringFromList(2, SpecColorList)))

	SetAxis/A/E=3 left		//1.55H
	ModifyGraph gaps=0
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph zero(left)=1
	ModifyGraph nticks=9
	ModifyGraph minor=1

	Label left "Nitrate equivalent"
	Label bottom "m/z, PToF is offset by 0.3"
	
	SetAxis bottom 1, numpnts(PToFspecStick) + 1

End


//1.52
// mass spec correlation for the MSvsPToF_Panel
Function sq_populate_MSvsPToFMSCorrGraph()

	string waveNameSuffix, Species
	
	waveNameSuffix= getuserdata("MSvsPToF_Panel","","todoStr")
	Species = getuserdata("MSvsPToF_Panel","","Species")

	wave MSSpecStick = $"root:PToF:MSSD_"+waveNameSuffix+"_"+Species
	wave PToFspecStick = $"root:PToF:PToF_ms_"+waveNameSuffix+"_"+Species
	wave amus = root:diagnostics:amus

	wave One2one = root:panel:One2one		//1.07A
	if (!WaveExists(One2one))
		make/o root:panel:One2one={0,1}
		wave/z One2one = root:panel:One2one		//1.07A
	endif
	string SpecColorList
	variable minTemp, maxTemp, maxMz

	SpecColorList = sq_getColorListSpecies(Species)

	if (WhichListItem("one2one", TraceNameList(WinName(1, 1), ";", 1 ))<0 )		//1.09H
		AppendToGraph one2one vs one2one
	endif
	AppendToGraph PToFspecStick[0,numpnts(MSSpecStick)] vs MSSpecStick
	
	ModifyGraph mode($NameofWave(PToFspecStick))=3
	ModifyGraph msize($NameofWave(PToFspecStick))=5
	ModifyGraph mrkThick($NameofWave(PToFspecStick))=2
	ModifyGraph textMarker($NameofWave(PToFspecStick))={amus,"default",0,0,5,0.00,0.00}
	
	ModifyGraph rgb($NameofWave(PToFspecStick))=(str2num(stringFromList(0, SpecColorList)) ,str2num(stringFromList(1, SpecColorList)),str2num(stringFromList(2, SpecColorList)))

	Label left "PToF"
	Label bottom "MS"
	ModifyGraph rgb($NameofWave(one2one))=(0,0,0)
	ModifyGraph grid=2	
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph nticks=9
	ModifyGraph minor=1
	SetAxis/A/E=3

	waveStats/q MSSpecStick
	minTemp = V_min
	maxTemp = V_max 
	waveStats/q PToFspecStick
	minTemp = min( V_min, minTemp)
	maxTemp = max(V_max, maxTemp)
	SetAxis left minTemp, maxTemp
	SetAxis bottom minTemp, maxTemp
	ModifyGraph muloffset(one2one)={maxTemp,maxTemp}

End


//1.52
//  t series correlation for the MSvsPToF_Panel
Function sq_populate_MSvsPToFTSCorrGraph()

	string waveNameSuffix, Species
	
	waveNameSuffix= getuserdata("MSvsPToF_Panel","","todoStr")
	Species = getuserdata("MSvsPToF_Panel","","Species")

	wave MSSpecTS =$"root:PToF:"+Species+"_"+waveNameSuffix
	wave PToFspecTS = $"root:PToF:PToF_ts_"+waveNameSuffix+"_"+Species
	wave/z One2one = root:panel:One2one		//1.07A
	if (!WaveExists(One2one))
		make/o root:panel:One2one={0,1}
		wave/z One2one = root:panel:One2one		//1.07A
	endif
	
	variable minTemp, maxTemp
	string SpecColorList
	SpecColorList = sq_getColorListSpecies(Species)

	if (WhichListItem("one2one", TraceNameList(WinName(1, 1), ";", 1 ))<0 )
		AppendToGraph one2one vs one2one
	endif
	AppendToGraph PToFspecTS vs MSSpecTS
	
	ModifyGraph mode($NameofWave(PToFspecTS))=2
	ModifyGraph lSize($NameofWave(PToFspecTS))=2
	ModifyGraph rgb($NameofWave(PToFspecTS))=(str2num(stringFromList(0, SpecColorList)) ,str2num(stringFromList(1, SpecColorList)),str2num(stringFromList(2, SpecColorList)))
	
	ModifyGraph rgb($NameOfWave(one2one))=(0,0,0)
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph nticks=9
	ModifyGraph minor=1
	Label left "PToF "+Species		// +", g/m3"
	Label bottom "MS "+Species		// +", g/m3"
	SetAxis/A/E=3

	waveStats/q MSSpecTS
	minTemp = V_min
	maxTemp = V_max 
	waveStats/q PToFspecTS
	minTemp = min(0, min( V_min, minTemp))
	maxTemp = max(V_max, maxTemp)
	SetAxis left minTemp, maxTemp
	SetAxis bottom minTemp, maxTemp

	ModifyGraph muloffset(one2one)={maxTemp,maxTemp}

End


//1.52
// generates the MSvsPToF_Panel
Function sq_ViewMSvsPToF_Panel()

	NewPanel/N=MSvsPToF_Panel /W=(638,334,1138,779) as "MSvsPToF_Panel"
	ModifyPanel fixedSize=1		//1.57L
	SetDrawLayer UserBack
	DrawText 10,90,"Time Series"
	DrawText 280,90,"Time Series Scatter"
	DrawText 10,270,"Mass Spec"
	DrawText 280,270,"Mass Spec Scatter"
	SetDrawEnv fsize= 18,fstyle= 1
	DrawText 10,22,"MS mode Diff vs PToF v1.0"
	DrawText 10,39,"Black=PToF mode; Colored = MS mode"
	TitleBox title0,pos={261,4},size={173,39},frame=0
	TitleBox title0,variable= root:panel:MSvsPToFInfo

	TabControl tabSpecies,pos={5,45},size={490,390},tabLabel(0)="Org",tabLabel(1)="SO4"
	TabControl tabSpecies,tabLabel(2)="NO3",tabLabel(3)="NH4",tabLabel(4)="Chl"
	TabControl tabSpecies proc=sq_MSvsPToFTabProc, value=0
	setwindow MSvsPToF_Panel, userdata(Species)="Org"		//default

	Button sq_but_sq_MSvsPToFTSGraph,pos={200,70},size={50,20},proc=sq_butt_popThis,title="Pop"
	Button sq_but_sq_MSvsPToFTSCorrGraph,pos={430,70},size={50,20},proc=sq_butt_popThis,title="Pop"
	Button sq_but_sq_MSvsPToFMSGraph,pos={200,250},size={50,20},proc=sq_butt_popThis,title="Pop"
	Button sq_but_sq_MSvsPToFMSCorrGraph,pos={430,250},size={50,20},proc=sq_butt_popThis,title="Pop"

	Display/W=(10,100,270,240)/HOST=# 
	RenameWindow #,sq_MSvsPToFTSGraph
	SetActiveSubwindow ##
	
	Display/W=(10,280,270,420)/HOST=# 
	RenameWindow #,sq_MSvsPToFMSGraph
	SetActiveSubwindow ##
	
	Display/W=(280,100,480,240)/HOST=# 
	RenameWindow #,sq_MSvsPToFTSCorrGraph
	SetActiveSubwindow ##
	
	Display/W=(280,280,480,420)/HOST=# 
	RenameWindow #,sq_MSvsPToFMSCorrGraph
	SetActiveSubwindow ##

	sq_MSVsPToFTabProc("tabSpecies",0)

End


// called from sq_MSvsPToF_calcClosedWaves to get 1D waves
Function sq_Create1DwaveFromDataSet(index_pos,paramstr,acorn,n_acorns)
	wave index_pos 	//& 1D wave of positions in 'run_index' that are being operated on
	string paramstr 	//& Keyword-identified parameter string
	variable acorn 	//& Number of the 'acorn' being passed
	variable n_acorns 	//& The total number of 'acorns' that will be passed

	wave source=$stringbykey("acorn_0",paramstr)		//^ can be stick or raw spectra
	string destStr = ReplaceString("/", stringbykey("dest",paramstr), ":")

	wave series_index = root:index:series_index
	variable idex, num = numpnts(index_pos)
	if (acorn==0)
		make/o/n=(numpnts(series_index))	$"root:"+destStr/wave=destWave		
		destWave=nan
	else
		wave destWave = $"root:"+destStr	
	endif
	
	for(idex=0;idex<num;idex+=1)
		if (index_pos[idex]>=0)
			destWave[series_index[index_pos[idex]]]=source[idex]	
		endif
	endfor
		
End


// for MSSCvsDC_Panel
Function sq_populate_MSSCDCTopGraph()

	string topOrBottomStr=  "top" //GetUserData("MSSCvsDC_Panel", "", "active")
	string mzStr = SelectString(stringmatch("top",topOrBottomStr), GetUserData("MSSCvsDC_Panel", "", "mzTop"), GetUserData("MSSCvsDC_Panel", "", "mzBottom"))
	string legendStr
	
	wave/z ClosedMSmz = $"root:PToF:mz_MSSC_"+topOrBottomStr
	wave/z DCRegion1mz = $"root:PToF:mz_PToFDC1_"+topOrBottomStr
	wave/z DCRegion2mz = $"root:PToF:mz_PToFDC2_"+topOrBottomStr
	wave/z DCRegionAvgMz = $"root:PToF:mz_PToFDCavg_"+topOrBottomStr
	wave/z mz_MSDiff = $"root:PToF:mz_MSSD_"+topOrBottomStr
	wave/z mz_PToFDiff = $"root:PToF:mz_PToFDiff_"+topOrBottomStr
	wave t_series = root:index:t_series

	if (!WaveExists(ClosedMSmz))
		variable num = numpnts(t_series)
		make/o/n=(num) $"root:PToF:mz_MSSC_"+topOrBottomStr/wave=ClosedMSmz
		make/o/n=(num) $"root:PToF:mz_PToFDC1_"+topOrBottomStr/wave=DCRegion1mz
		make/o/n=(num) $"root:PToF:mz_PToFDC2_"+topOrBottomStr/wave=DCRegion2mz
		make/o/n=(num) $"root:PToF:mz_PToFDCavg_"+topOrBottomStr/wave=DCRegionAvgMz
		make/o/n=(num) $"root:PToF:mz_PToFDiff_"+topOrBottomStr/wave=mz_PToFDiff
	endif
	
	// first Diff waves
	AppendToGraph/r mz_MSDiff, mz_PToFDiff vs t_series
	ModifyGraph marker($NameOfWave(mz_MSDiff))=19,marker($NameOfWave(mz_PToFDiff))=14
	ModifyGraph rgb($NameOfWave(mz_MSDiff))=(0,0,0), rgb($NameOfWave(mz_PToFDiff))=(58880,0,0)
	Label right "MSSDiff, PToFDIff (Hz)"
	SetAxis/A/E=3 right
	
	AppendTograph DCRegion2mz,DCRegion1mz, DCRegionAvgMz,ClosedMSmz vs t_series
	ModifyGraph marker=19
	ModifyGraph lSize($NameOfWave(ClosedMSmz))=1, lSize($NameOfWave(DCRegionAvgMz))=1
	ModifyGraph rgb($NameOfWave(DCRegion1mz))=(24576,24576,65280),rgb($NameOfWave(DCRegion2mz))=(0,39168,0)
	ModifyGraph rgb($NameOfWave(ClosedMSmz))=(34816,34816,34816),rgb($NameOfWave(DCRegionAvgMz))=(29440,0,58880)
	ModifyGraph grid(left)=2
	SetAxis/A/E=3 left
	Label left "MSSC, DC (Hz)"

	ModifyGraph marker(mz_MSSD_top)=19,marker(mz_PToFDiff_top)=16,marker(mz_PToFDC2_top)=1
	ModifyGraph marker(mz_PToFDCavg_top)=8,marker(mz_MSSC_top)=19

	ModifyGraph lSize=1
	ModifyGraph gaps=0
	ModifyGraph nticks=9
	ModifyGraph minor=1
	ModifyGraph mode=4
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph msize=1
	Label bottom " "
	ModifyGraph grid(bottom)=2
	ModifyGraph dateInfo(bottom)={0,1,0}
	
	Legend/C/N=text0/J/X=10/Y=10 "\\s(mz_MSSC_top) MSSC\r\\s(mz_PToFDC1_top) DC1\r\\s(mz_PToFDC2_top) DC2\r\\s(mz_PToFDCavg_top) DCAvg\r\\s(mz_MSSD_top) MSDiff"
	AppendText "\\s(mz_PToFDIff_top) PToFDiff"
End


// for MSSCvsDC_Panel
Function sq_populate_MSSCDCBotGraph()

	string topOrBottomStr= "bottom" //GetUserData("MSvsPToF_Panel", "", "active")
	string mzStr = SelectString(stringmatch("top",topOrBottomStr), GetUserData("MSSCvsDC_Panel", "", "mzTop"), GetUserData("MSSCvsDC_Panel", "", "mzBottom"))
	string legendStr
	
	wave/z ClosedMSmz = $"root:PToF:mz_MSSC_"+topOrBottomStr
	wave/z DCRegion1mz = $"root:PToF:mz_PToFDC1_"+topOrBottomStr
	wave/z DCRegion2mz = $"root:PToF:mz_PToFDC2_"+topOrBottomStr
	wave/z DCRegionAvgMz = $"root:PToF:mz_PToFDCavg_"+topOrBottomStr
	wave/z mz_MSDiff = $"root:PToF:mz_MSSD_"+topOrBottomStr
	wave/z mz_PToFDiff = $"root:PToF:mz_PToFDiff_"+topOrBottomStr
	wave t_series = root:index:t_series

	if (!WaveExists(ClosedMSmz))
		variable num = numpnts(t_series)
		make/o/n=(num) $"root:PToF:mz_MSSC_"+topOrBottomStr/wave=ClosedMSmz
		make/o/n=(num) $"root:PToF:mz_PToFDC1_"+topOrBottomStr/wave=DCRegion1mz
		make/o/n=(num) $"root:PToF:mz_PToFDC2_"+topOrBottomStr/wave=DCRegion2mz
		make/o/n=(num) $"root:PToF:mz_PToFDCavg_"+topOrBottomStr/wave=DCRegionAvgMz
		make/o/n=(num) $"root:PToF:mz_PToFDiff_"+topOrBottomStr/wave=mz_PToFDiff
	endif

	// first Diff waves
	AppendToGraph/r mz_MSDiff, mz_PToFDiff vs t_series
	ModifyGraph marker($NameOfWave(mz_MSDiff))=19,marker($NameOfWave(mz_PToFDiff))=14
	ModifyGraph rgb($NameOfWave(mz_MSDiff))=(0,0,0), rgb($NameOfWave(mz_PToFDiff))=(58880,0,0)
	Label right "MSSDiff, PToFDIff (Hz)"
	SetAxis/A/E=3 right
		
	AppendTograph DCRegion2mz,DCRegion1mz, DCRegionAvgMz,ClosedMSmz vs t_series
	ModifyGraph mode=4
	ModifyGraph marker(mz_MSSD_bottom)=19,marker(mz_PToFDiff_bottom)=16,marker(mz_PToFDC2_bottom)=1
	ModifyGraph marker(mz_PToFDCavg_bottom)=8,marker(mz_MSSC_bottom)=19
	ModifyGraph lSize($NameOfWave(ClosedMSmz))=1, lSize($NameOfWave(DCRegionAvgMz))=1
	ModifyGraph rgb($NameOfWave(DCRegion1mz))=(24576,24576,65280),rgb($NameOfWave(DCRegion2mz))=(0,39168,0)
	ModifyGraph rgb($NameOfWave(ClosedMSmz))=(34816,34816,34816),rgb($NameOfWave(DCRegionAvgMz))=(29440,0,58880)
	ModifyGraph msize=1
	ModifyGraph grid=2
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph dateInfo(bottom)={0,1,0}
	ModifyGraph nticks=9
	ModifyGraph minor(left)=1
	ModifyGraph gaps=0
	SetAxis/A/E=3 left
	legendStr="\\s("+NameofWave(ClosedMSmz)+") MS Closed\r\\s("+NameofWave(DCRegion1mz)+") DC1\r\\s("+NameofWave(DCRegion2mz)+") DC2\r\\s("+NameofWave(DCRegionAvgMz)+") Avg"
	Label left "MSSC, DC (Hz)"
	Label bottom " "
	
	Legend/C/N=text0/J/X=10/Y=10 "\\s(mz_MSSC_bottom) MSSC\r\\s(mz_PToFDC1_bottom) DC1\r\\s(mz_PToFDC2_bottom) DC2\r\\s(mz_PToFDCavg_bottom) DCAvg"
	AppendText "\\s(mz_MSSD_bottom) MSDiff\r\\s(mz_PToFDiff_bottom) PToFDiff"

End


// for MSSCvsDC_Panel
Function sq_populate_MSSCDCTopCorrGraph()

	string topOrBottomStr="top" // GetUserData("MSvsPToF_Panel", "", "active")
	string mzStr = SelectString(stringmatch("top",topOrBottomStr), GetUserData("MSSCvsDC_Panel", "", "mzTop"), GetUserData("MSSCvsDC_Panel", "", "mzBottom"))

	wave/z ClosedMSmz = $"root:PToF:mz_MSSC_"+topOrBottomStr
	wave/z DCRegion1mz = $"root:PToF:mz_PToFDC1_"+topOrBottomStr
	wave/z DCRegion2mz = $"root:PToF:mz_PToFDC2_"+topOrBottomStr
	wave/z DCRegionAvgMz = $"root:PToF:mz_PToFDCavg_"+topOrBottomStr
	wave/z mz_MSDiff = $"root:PToF:mz_MSSD_"+topOrBottomStr
	wave/z mz_PToFDiff = $"root:PToF:mz_PToFDiff_"+topOrBottomStr
	wave t_series = root:index:t_series

	if (!WaveExists(ClosedMSmz))
		variable num = numpnts(t_series)
		make/o/n=(num) $"root:PToF:mz_MSSC_"+topOrBottomStr/wave=ClosedMSmz
		make/o/n=(num) $"root:PToF:mz_PToFDC1_"+topOrBottomStr/wave=DCRegion1mz
		make/o/n=(num) $"root:PToF:mz_PToFDC2_"+topOrBottomStr/wave=DCRegion2mz
		make/o/n=(num) $"root:PToF:mz_PToFDCavg_"+topOrBottomStr/wave=DCRegionAvgMz
		make/o/n=(num) $"root:PToF:mz_PToFDiff_"+topOrBottomStr/wave=mz_PToFDiff
	endif
	
	AppendToGraph mz_PToFDiff vs mz_MSDiff
	ModifyGraph mode($NameOfWave(mz_PToFDiff))=3,marker($NameOfWave(mz_PToFDiff))=16, msize($NameOfWave(mz_PToFDiff))=1

	AppendToGraph DCRegion1mz,DCRegion2mz, DCRegionAvgMz vs ClosedMSmz
	make/o root:panel:One2One={0,100}
	AppendToGraph root:panel:One2One vs root:panel:One2One
	
	ModifyGraph mode($NameOfWave(DCRegion1mz))=3,mode($NameOfWave(DCRegion2mz))=3, mode($NameOfWave(DCRegionAvgMz))=3
	ModifyGraph marker($NameOfWave(DCRegion1mz))=0,marker($NameOfWave(DCRegion2mz))=1, marker($NameOfWave(DCRegionAvgMz))=8
	ModifyGraph lSize($NameOfWave(DCRegion1mz))=2,lSize($NameOfWave(DCRegion2mz))=2
	ModifyGraph rgb($NameOfWave(DCRegion1mz))=(16384,28160,65280),rgb($NameOfWave(DCRegion2mz))=(0,52224,0),rgb($NameOfWave(DCRegionAvgMz))=(29440,0,58880)
	ModifyGraph rgb(One2One)=(0,0,0)
	ModifyGraph msize($NameOfWave(DCRegion1mz))=2,msize($NameOfWave(DCRegion2mz))=2
	
	variable mymax = max(max(waveMax(ClosedMSmz), waveMax(DCRegionAvgMz)),waveMax(DCRegion2mz))
	ModifyGraph muloffset(One2One)={mymax,mymax}
	ModifyGraph grid=2
	ModifyGraph gridRGB=(43520,43520,43520)
	ModifyGraph nticks=9
	ModifyGraph minor(left)=1
	Label left "PToF"+mzStr+", Hz"
	Label bottom "MS"+mzStr+", Hz"
	
	Legend/C/N=text0/J/X=10/Y=10 "\\s(mz_PToFDC1_top) DC1\r\\s(mz_PToFDC2_top) DC2\r\\s(mz_PToFDCavg_top) DCavg\r\\s(mz_PToFDiff_top) PToFDiff"
End


//1.52
// for MSSCvsDC_Panel
Function sq_populate_MSSCDCBotCorrGraph()

	string topOrBottomStr="bottom" // GetUserData("MSvsPToF_Panel", "", "active")
	string mzStr = SelectString(stringmatch("top",topOrBottomStr), GetUserData("MSSCvsDC_Panel", "", "mzTop"), GetUserData("MSSCvsDC_Panel", "", "mzBottom"))

	wave/z ClosedMSmz = $"root:PToF:mz_MSSC_"+topOrBottomStr
	wave/z DCRegion1mz = $"root:PToF:mz_PToFDC1_"+topOrBottomStr
	wave/z DCRegion2mz = $"root:PToF:mz_PToFDC2_"+topOrBottomStr
	wave/z DCRegionAvgMz = $"root:PToF:mz_PToFDCavg_"+topOrBottomStr
	wave/z mz_MSDiff = $"root:PToF:mz_MSSD_"+topOrBottomStr
	wave/z mz_PToFDiff = $"root:PToF:mz_PToFDiff_"+topOrBottomStr
	wave t_series = root:index:t_series

	if (!WaveExists(ClosedMSmz))
		variable num = numpnts(t_series)
		make/o/n=(num) $"root:PToF:mz_MSSC_"+topOrBottomStr/wave=ClosedMSmz
		make/o/n=(num) $"root:PToF:mz_PToFDC1_"+topOrBottomStr/wave=DCRegion1mz
		make/o/n=(num) $"root:PToF:mz_PToFDC2_"+topOrBottomStr/wave=DCRegion2mz
		make/o/n=(num) $"root:PToF:mz_PToFDCavg_"+topOrBottomStr/wave=DCRegionAvgMz
		make/o/n=(num) $"root:PToF:mz_PToFDiff_"+topOrBottomStr/wave=mz_PToFDiff
	endif
	
	AppendToGraph mz_PToFDiff vs mz_MSDiff
	ModifyGraph mode($NameOfWave(mz_PToFDiff))=3,marker($NameOfWave(mz_PToFDiff))=16, msize($NameOfWave(mz_PToFDiff))=1

	AppendToGraph DCRegion1mz,DCRegion2mz, DCRegionAvgMz vs ClosedMSmz
	make/o root:panel:One2One={0,100}
	AppendToGraph root:panel:One2One vs root:panel:One2One
	
	ModifyGraph mode($NameOfWave(DCRegion1mz))=3,mode($NameOfWave(DCRegion2mz))=3, mode($NameOfWave(DCRegionAvgMz))=3
	ModifyGraph marker($NameOfWave(DCRegion1mz))=0,marker($NameOfWave(DCRegion2mz))=1, marker($NameOfWave(DCRegionAvgMz))=8
	ModifyGraph lSize($NameOfWave(DCRegion1mz))=2,lSize($NameOfWave(DCRegion2mz))=2
	ModifyGraph rgb($NameOfWave(DCRegion1mz))=(16384,28160,65280),rgb($NameOfWave(DCRegion2mz))=(0,52224,0),rgb($NameOfWave(DCRegionAvgMz))=(29440,0,58880)
	ModifyGraph rgb(One2One)=(0,0,0)
	ModifyGraph msize($NameOfWave(DCRegion1mz))=2,msize($NameOfWave(DCRegion2mz))=2
	
	variable mymax = max(max(waveMax(ClosedMSmz), waveMax(DCRegionAvgMz)),waveMax(DCRegion2mz))
	ModifyGraph muloffset(One2One)={mymax,mymax}
	ModifyGraph grid=2
	ModifyGraph gridRGB=(43520,43520,43520)
	ModifyGraph nticks=9
	ModifyGraph minor(left)=1
	Label left "PToF"+mzStr+", Hz"
	Label bottom "MS"+mzStr+", Hz"
	
	Legend/C/N=text0/J/X=10/Y=10 "\\s(mz_PToFDC1_bottom) DC1\r\\s(mz_PToFDC2_bottom) DC2\r\\s(mz_PToFDCavg_bottom) DCavg\r\\s(mz_PToFDiff_bottom) PToFDiff"

End


//1.52
// for MSSCvsDC_Panel
Function sq_MSvsPToFSetVarProc(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	string topOrBottomStr = selectString(strsearch(ctrlName, "bottom", 0) >=0, "top", "bottom")

	SetWindow kwTopWin, userdata(active)=topOrBottomStr
	if (stringmatch("top", topOrBottomStr) )
		 SetWindow kwTopWin, userdata(mzTop)=varStr
 	else
		 SetWindow kwTopWin, userdata(mzBottom)=varStr
	endif

 	sq_MSvsPToF_calcClosedWaves(topOrBottomStr, varNum)
	sq_MSvsPToF_calcPToFDiffWaves(topOrBottomStr, varNum)
		
	if (stringmatch("top", topOrBottomStr) )
		SetActiveSubwindow MSSCvsDC_Panel#sq_MSSCDCTopCorrGraph
		gen_updateone2oneCorr()
		SetActiveSubwindow ##
 	else
		SetActiveSubwindow MSSCvsDC_Panel#sq_MSSCDCBotCorrGraph
		gen_updateone2oneCorr()
		SetActiveSubwindow ##
	endif

	sq_UpdateMSSCvsPToFDCStats(topOrBottomStr, varNum)
	sq_UpdateMSSCvsPToFDCStats(topOrBottomStr, varNum)
	
End


//1.52
// creates 4 waves for the MSSCvsDC_Panel  (one set each for the top and bottom sets of graphs in the panel)
Function sq_MSvsPToF_calcClosedWaves(topOrBottomStr, mz)
string topOrBottomStr
variable mz

	svar MSvsPToFInfo = root:panel:MSvsPToFInfo
//	svar todoStr=root:panel:sq_toDoWvNm  we don't set this to the current todo but to the todo used in last calculations
//	string todoStr = StringByKey("todo", MSvsPToFInfo, "\r")
	string todoStr = MSvsPToFInfo[6-1, strsearch(MSvsPToFInfo, "\r", 0)-1]

	variable pos
	wave todo=$"root:"+todoStr
	string mzStr = num2str(mz)
	string paramstr = ""
	paramstr += "min_cl:"+num2str(mz-1)+";"		// we count from zero
	paramstr += "max_cl:"+num2str(mz-1)+";"
	
	squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_MSSC_"+topOrBottomStr,"MSSClosed_p")
	squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_MSSD_"+topOrBottomStr,"MSSDiff_p")

	wave/z deconvolveType = root:diagnostics:deconvolveType
	
	wave mz_MSSD = $"root:PToF:mz_MSSD_"+topOrBottomStr
	variable numMz
	if (sq_isRunePToF(todo[0]) )  // todo is ePToF 		//1.55B
		numMz = dimsize(mz_MSSD,1)
		wave rn_series = root:index:rn_series
		pos =sq_findRun(rn_series,todo[0])
		if (deconvolveType[pos]  == 2)		// value of 2 = matrix inversion + ePToF_postmatrixInvDC
			make/o/n=(numMz)  $"root:PToF:mz_PToFDC1_"+topOrBottomStr = nan
			make/o/n=(numMz)  $"root:PToF:mz_PToFDC2_"+topOrBottomStr = nan
			squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_PToFDCavg_"+topOrBottomStr,"DCregionAvg")
		else		// do not do DC marker region  subtraction
			make/o/n=(numMz) $"root:PToF:mz_PToFDC1_"+topOrBottomStr = nan
			make/o/n=(numMz) $"root:PToF:mz_PToFDC2_"+topOrBottomStr = nan
			make/o/n=(numMz) $"root:PToF:mz_PToFDCavg_"+topOrBottomStr=nan
		endif
				
	else
	
		wave/z DCregion1Start = root:diagnostics:DCregion1Start		// these are created in 1.51P squirrel
		wave/z DCregion1Stop = root:diagnostics:DCregion1Stop 
		wave/z DCregion2Start = root:diagnostics:DCregion2Start
		wave/z DCregion2Stop = root:diagnostics:DCregion2Stop
	
		if (!WaveExists(DCregion1Start))
			abort "You must redo your PToF DC markers to save the DC regions before proceding.  aborting from sq_MSvsPToF_calcClosedWaves"	
		endif
		
		squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_PToFDC1_"+topOrBottomStr,"DCregion1")
		squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_PToFDC2_"+topOrBottomStr,"DCregion2")
		squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_PToFDCavg_"+topOrBottomStr,"DCregionAvg")

		wave ClosedMSmz = $"root:PToF:mz_MSSC_"+topOrBottomStr
		wave DCRegion1mz = $"root:PToF:mz_PToFDC1_"+topOrBottomStr
		wave DCRegion2mz = $"root:PToF:mz_PToFDC2_"+topOrBottomStr
		
	//	duplicate/o DCRegion2mz $"root:PToF:mz_PToFDCavg_"+topOrBottomStr/wave=DCRegionavgmz
		wave DCRegion2mz = $"root:PToF:mz_PToFDCavg_"+topOrBottomStr
		
		duplicate/o DCRegion2mz $"root:PToF:mz_PToFDiff_"+topOrBottomStr/wave=DCRegionavgmz
		
		Note/k ClosedMSmz, "mz:"+mzStr
		Note/k DCRegion1mz, "mz:"+mzStr
		Note/k DCRegion2mz, "mz:"+mzStr
		Note/k DCRegionavgmz, "mz:"+mzStr
	
		duplicate/o /Free ClosedMSmz, DCregion1Delta, DCregion2Delta, wave1, wave2
		DCregion1Delta = DCregion1Stop - DCregion1Start
		DCregion1Delta = numtype(DCregion1Delta[p])==0 ? DCregion1Delta[p] : 0
		DCregion2Delta = DCregion2Stop - DCregion2Start
		DCregion2Delta = numtype(DCregion2Delta[p])==0 ? DCregion2Delta[p] : 0
		
		wave1=DCregion1Delta[p]*(numtype(DCRegion1mz[p])==0 ? DCRegion1mz[p] : 0)
		wave2= DCregion2Delta*(numtype(DCRegion2mz[p])==0 ? DCRegion2mz[p] : 0)
	
		// weighted average
		DCRegionavgmz =(wave1+wave2)/( (numtype(DCRegion1mz[p])==0 ? DCregion1Delta[p] : 0) + (numtype(DCRegion2mz[p])==0 ? DCregion2Delta[p] : 0) )

	endif
	
End


//1.52
// creates MSSCvsDC_Panel
Function sq_ViewMSSCvsDC_Panel()

	NewPanel /W=(396,133,913,660)/N=MSSCvsDC_Panel as "MSSCvsDC_Panel"
	ModifyPanel fixedSize=1		//1.57L
	SetDrawLayer UserBack
	DrawText 9,139,"Time Series"
	DrawText 16,363,"Time Series"
	SetDrawEnv fsize= 18,fstyle= 1
	DrawText 5,23,"MS mode Closed vs"
	DrawText 6,68,"DC regions 1 and 2 are those retrieved from the last DC marker corrections."
	DrawText 4,83," These are not necessarily what current settings in DC marker window indicate."
	DrawText 432,140,"Scatter Plot"
	DrawText 436,359,"Scatter Plot"
	SetDrawEnv fsize= 18,fstyle= 1
	DrawText 4,41,"PToF mode DC Regions v1.0"

	GroupBox group1,pos={4,304},size={500,215}
	GroupBox group0,pos={1,86},size={500,215}

	Button sq_but_sq_MSSCDCTopGraph,pos={259,146},size={15,50},proc=sq_butt_popThis,title="P\ro\rp"
	Button sq_but_sq_MSSCDCTopCorrGraph,pos={486,145},size={15,50},proc=sq_butt_popThis,title="P\ro\rp"
	Button sq_but_sq_MSSCDCBotGraph,pos={256,361},size={15,50},proc=sq_butt_popThis,title="P\ro\rp"
	Button sq_but_sq_MSSCDCBotCorrGraph,pos={486,365},size={15,50},proc=sq_butt_popThis,title="P\ro\rp"

	SetVariable setvar_mztop,pos={3,90},bodyWidth=40,size={110,16},proc=sq_MSvsPToFSetVarProc,title="Results for m/z"
	SetVariable setvar_mztop,value= _NUM:12		// default for top is 12
	SetVariable setvar_mzbottom,pos={13,315},bodyWidth=40, size={110,16},proc=sq_MSvsPToFSetVarProc,title="Results for m/z"
	SetVariable setvar_mzbottom,value= _NUM:13	// default for bottom is 13

	ValDisplay MSDiffAvgTop,pos={249,109},size={115,14},title="MS Diff Avg"
	ValDisplay MSDiffAvgTop,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay MSDiffAvgTop,value= _NUM:0
	ValDisplay PToFDCAvgTop,pos={125,92},size={115,14},title="PToF DC Avg"
	ValDisplay PToFDCAvgTop,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay PToFDCAvgTop,value= _NUM:0
	ValDisplay MSSCAvgTop,pos={124,108},size={115,14},title="MS Closed Avg"
	ValDisplay MSSCAvgTop,format="%d",limits={0,0,0},barmisc={0,1000},value= _NUM:0
	ValDisplay MSSCDiffTop,pos={370,107},size={125,14},title="MS Closed/Diff "
	ValDisplay MSSCDiffTop,format="%1.3f",limits={0,0,0},barmisc={0,1000}
	ValDisplay MSSCDiffTop,value= _NUM:0
	ValDisplay DCMSSCRatioTop,pos={125,124},size={115,14},title="DC/MS Closed"
	ValDisplay DCMSSCRatioTop,format="%2.3f",limits={0,0,0},barmisc={0,1000}
	ValDisplay DCMSSCRatioTop,value= _NUM:0
	ValDisplay PToFDiffAvgTop,pos={250,95},size={115,14},title="PToF 'Diff' Avg"
	ValDisplay PToFDiffAvgTop,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay PToFDiffAvgTop,value= _NUM:0
	ValDisplay DCPToFDiffAvgTop,pos={369,91},size={125,14},title="DC/PToF Diff "
	ValDisplay DCPToFDiffAvgTop,format="%1.3f",limits={0,0,0},barmisc={0,1000}
	ValDisplay DCPToFDiffAvgTop,value= _NUM:0
	ValDisplay PToFDCAvgBottom,pos={128,312},size={115,14},title="PToF DC Avg"
	ValDisplay PToFDCAvgBottom,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay PToFDCAvgBottom,value= _NUM:0
	ValDisplay MSSCAvgBottom,pos={127,329},size={115,14},title="MS Closed Avg"
	ValDisplay MSSCAvgBottom,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay MSSCAvgBottom,value= _NUM:0
	ValDisplay DCMSSCRatioBottom,pos={128,345},size={115,14},title="DC/MS Closed"
	ValDisplay DCMSSCRatioBottom,format="%2.3f",limits={0,0,0},barmisc={0,1000}
	ValDisplay DCMSSCRatioBottom,value= _NUM:0
	ValDisplay PToFDiffAvgBottom,pos={253,316},size={115,14},title="PToF 'Diff' Avg"
	ValDisplay PToFDiffAvgBottom,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay PToFDiffAvgBottom,value= _NUM:0
	ValDisplay MSDiffAvgBottom,pos={252,330},size={115,14},title="MS Diff Avg"
	ValDisplay MSDiffAvgBottom,format="%d",limits={0,0,0},barmisc={0,1000}
	ValDisplay MSDiffAvgBottom,value= _NUM:0
	ValDisplay DCPToFDiffAvgBottom,pos={372,312},size={125,14},title="DC/PToF Diff "
	ValDisplay DCPToFDiffAvgBottom,format="%1.3f",limits={0,0,0},barmisc={0,1000}
	ValDisplay DCPToFDiffAvgBottom,value= _NUM:0
	ValDisplay MSSCDiffBottom,pos={373,328},size={125,14},title="MS Closed/Diff "
	ValDisplay MSSCDiffBottom,format="%1.3f",limits={0,0,0},barmisc={0,1000}
	ValDisplay MSSCDiffBottom,value= _NUM:0

	TitleBox title0,pos={305,1},size={181,47},frame=2
	TitleBox title0,variable= root:panel:MSvsPToFInfo

	Display/W=(10,145,250,295)/HOST=# 
	RenameWindow #,sq_MSSCDCTopGraph
	sq_populate_MSSCDCTopGraph()
	SetActiveSubwindow ##
	
	Display/W=(10,365,250,510)/HOST=# 
	RenameWindow #,sq_MSSCDCBotGraph
	sq_populate_MSSCDCBotGraph()
	SetActiveSubwindow ##
	
	Display/W=(280,145,480,295)/HOST=# 
	RenameWindow #,sq_MSSCDCTopCorrGraph
	sq_populate_MSSCDCTopCorrGraph()
	SetActiveSubwindow ##
	
	Display/W=(280,365,480,510)/HOST=# 
	RenameWindow #,sq_MSSCDCBotCorrGraph
	sq_populate_MSSCDCBotCorrGraph()
	SetActiveSubwindow ##

	sq_MSvsPToFSetVarProc("setvar_mztop",12,"","")		//12 is default
	sq_MSvsPToFSetVarProc("setvar_mzbottom",13,"","")		//12 is default

End


// from main AMS panel, generates MSSCvsDC_Panel and does caclulations
Function sq_button_MSSCvsDC(ctrlName) : ButtonControl
	String ctrlName
 	
	sq_GetIndexNotDoneYet()
 	doWIndow/f MSSCvsDC_Panel
  	if(V_flag==0)
 		sq_ViewMSSCvsDC_Panel()
		sq_MSvsPToF_calcClosedWaves("top", 12)		// arbitrary default mz of 12
		sq_MSvsPToF_calcClosedWaves("bottom", 13)	// arbitrary default mz of 13
		sq_MSvsPToF_calcPToFDiffWaves("top", 12)		// 1.56O
		sq_MSvsPToF_calcPToFDiffWaves("bottom", 13)		// 1.56O
 	endif
 	
End


//1.52
//  for a graph with the trace one2one and standard left and bottom axis,
// change the multiplicative offset of one2one to reflect the range of the data in the axis
// and set the ranges for the left and bottom axes.
Function gen_updateone2oneCorr()

	string wstr, wlist = TraceNameList("",";",1)
	//WaveList("!*one2one", ";", "WIN:" )
	variable idex, num, wmin=inf, wmax=-inf
	num=itemsinList(wlist)
	for (idex=0;idex<num;idex+=1)
		if (!stringmatch(StringFromList(idex, wlist), "one2one"))
			wave wav = TraceNameToWaveRef("", StringFromList(idex, wlist))
			wmin=min(numtype(Wavemin(wav))==0 ? Wavemin(wav) : inf , wmin)
			wmax=max(numtype(Wavemax(wav))==0 ? Wavemax(wav) : -inf, wmax)
			wave wav = XWaveRefFromTrace("", StringFromList(idex, wlist))
			wmin=min(numtype(Wavemin(wav))==0 ? Wavemin(wav) : inf , wmin)
			wmax=max(numtype(Wavemax(wav))==0 ? Wavemax(wav) : -inf, wmax)
		endif
	endfor

	if (numtype(wmin)==0 && numtype(wmax)==0)
		SetAxis left wmin,wmax
		SetAxis bottom wmin,wmax
		ModifyGraph muloffset(One2One)={wmax,wmax}
	endif	

End


Function sq_PToFCollapseSizeOneRun(runNum, dataFolderSt, destStr, RawFlag, PreProcessedFlag)		//1.49E
variable runNum
string dataFolderSt, destStr
variable RawFlag, PreProcessedFlag

	string runStr, dataset
	sprintf runStr, "%u", runNum
	sq_create_todo(runStr+" and all","tempTodo")
	wave todo=$"root:tempTodo"
	
	if(RawFlag)
		dataset = "PToF"
	elseif (PreProcessedFlag)	
		dataset = "PToF_stick_p"
	else
		dataset = "PToF_stick"
	endif

	squirrel_fetch(todo,sq_dump2memory, "dest:PToF_"+runStr,dataset)
	
	wave PToF_d = $"root:PToF_"+runStr
	
	matrixOp/o tran=transposeVol(PToF_d,1)		//mode=1:	switch columns and layers; output=w[p][r][q]
	matrixOp/o $dataFolderSt+destStr = sumBeams(tran)			// sum over all layers, collapses the layers

	wave destWave = $dataFolderSt+destStr
	Redimension/N=(dimsize(destWave,1)) destWave
	
	killwaves/z tempTodo, PToF_d, tran
	
End


//1.52 
// Does all the cals for MS vs PToF panels
Function sq_butt_ToFvsPtoFCalcs(ctrlName) : ButtonControl
	String ctrlName

	sq_GetIndexNotDoneYet()
	string d_base=sq_dbase()
	wave/z d_baseWave = $d_base
	if (!WaveExists(d_baseWave) || numpnts(d_baseWave)!=2)
		Abort "For the calculations comparing PToF and MS we want to use one diameter base encompassing all anticpated aerosols, i.e. 20 - 2000nm.  Aborting from sq_butt_ToFvsPtoFCalcs"
	endif

	//  MSvsPToF_Panel	
	sq_MSvsPToF_calcWaves()		// calculates avg MS and ts for main aerosol species	for MSSDiff vs PToF species panel
	// also sets root:panel:MSvsPToFInfo

	//  generates default waves for MSSCvsDC_Panel
	// generate waves for the MSSCvsDC panel
	variable mztop, mzbottom
	DoWindow/F MSSCvsDC_Panel
	
	if (V_flag)   // panel exists
		ControlInfo setvar_mztop
		mztop = V_value	
		ControlInfo setvar_mzbottom
		mzbottom = V_value
	else
		mztop =12
		mzbottom =13		// Defaults
	endif
	
	// MSSCvsDC_Panel	
	sq_MSvsPToF_calcClosedWaves("top", mztop)	
	sq_MSvsPToF_calcClosedWaves("bottom", mzbottom)	
	
	sq_MSvsPToF_calcPToFDiffWaves("top", mztop)	
	sq_MSvsPToF_calcPToFDiffWaves("bottom", mzbottom)	

End


// function that sets up fetch call to sq_MS_concentrationPTOFDiff
// which generates a data set PToFDiff_p written to intermediate files
Function sq_PToFDiffHz_calcWaves()

	svar MSvsPToFInfo = root:panel:MSvsPToFInfo
	string todoStr = MSvsPToFInfo[6-1, strsearch(MSvsPToFInfo, "\r", 0)-1]
	wave todo = $"root:"+todoStr
	
	nvar cor3_chamber=root:panel:cor3_chamber	// not in panel, loaded in get index
	nvar chopper_duty=root:diagnostics:chopper_duty	// not in panel, loaded in get index
	
	string d_base, ParamStr = ""
	
	d_base=sq_dbase()
	wave d_baseWave = $d_base
	
	paramStr+="lc:"+num2str(cor3_chamber)+";"
	paramStr+="corr_op:0;"
	paramStr+="d_base:"+d_base+";"
	paramStr+="dlog_op:1;"
	paramStr+="chop_duty:"+num2str(chopper_duty)+";"  
	paramStr+="ePToF_flag:"+num2str(sq_isRunePToF(todo[0]))+";"  
	
	squirrel_fetch(todo,sq_MS_concentrationPTOFDiff,paramstr,"PToF_stick_p;")

End

 
// in some ways this function is very much like our big sq_MS_concentration function.  The difference is that
// we want the calculations done within an acorn and results sent to intermediate HDFs.
//This function relies on the PToF size parameters to be constant across all runs, so it should be called for a todo within one PToF group
// result is a run x mz matrix that is just like MSSDiff_p
// The tricky part is that the mapping wants to happen for all runs... we short-circuit that method and do the matrix dot product ourselves.
Function sq_MS_concentrationPTOFDiff(index_pos,paramstr,acorn,n_acorns)
	wave index_pos 	//& 1D wave of positions in 'run_index' that are being operated on
	string paramstr 	//& Keyword-identified parameter string
	variable acorn 	//& Number of the 'acorn' being passed
	variable n_acorns 	//& The total number of 'acorns' that will be passed
	
//  Step 1. Identify & set global and local variables
	// identify data waves to be worked on
	wave source=$stringbykey("acorn_0",paramstr)		//^ can be stick or raw spectra
	
	// identify global waves 
	wave rn_series=root:index:rn_series
	wave series_index=root:index:series_index
	wave t_series=root:index:t_series
	nvar deconvolveMike = root:panel:deconvolveMike
	
	// velocity calibration waves
	wave/z vl=root:diagnostics:ptof_vl	
	wave/z vg=root:diagnostics:ptof_vg
	wave/z b=root:diagnostics:ptof_b	
	wave/z dx=root:diagnostics:ptof_dx
	if (!WaveExists(vl))
		wave vl=root:diagnostics:ptof_vl_logged	//^ 1.35
	endif
	if (!WaveExists(vg))
		wave vg=root:diagnostics:ptof_vg_logged	//^ 1.35
	endif
	if (!WaveExists(b))
		wave b=root:diagnostics:ptof_b_logged	//^ 1.35
	endif
	if (!WaveExists(dx))
		wave dx=root:diagnostics:ptof_dx_logged	//^ 1.35
	endif
	wave ptof_step=root:diagnostics:ptof_step
	wave ptof_t0=root:diagnostics:ptof_t0
	wave ChopperFreq = root:diagnostics:ChopperFreq		
	 
	// parse important flags, entities from paramsStr
//	wave/z t_base=$stringbykey("t_base",paramstr) // Time base for destination data (null if t_series used)
	wave/z d_base=$stringbykey("d_base",paramstr) // Diameter base for destination data (null if dsig used)

	variable lc=numberbykey("lc",paramstr) // Chamber length
	variable chop_duty=numberbykey("chop_duty",paramstr) // Chopper duty cycle
	variable n_t=dimsize(source,1)		// for MS sticks, number of mz, for PToF sticks number of PToF bins
	variable mz_points=dimsize(source,2)	// raw spectra averaging
	variable d_points=numpnts(d_base)	
	
	variable ePToF_flag=numberbykey("ePToF_flag",paramstr) //1.53N
//	variable chopperDutyWave_op=numberbykey("chopperDutyWave_op",paramstr)
//	if (chopperDutyWave_op)
//		wave chopperDutyWave = root:diagnostics:chopperDutyWave
//	endif

	// declare local variables used in calculations
	variable j,n_vals,p1, t1, t2, ugfac, TotalAreaXWidth
	string deststr
	
	n_vals=numpnts(index_pos)		// number of runs in this acorn

// Step 2. Create waves needed for calculations:
	// destination waves,  weighting waves, error waves conversion waves
	p1=series_index[index_pos[0]]

	make/free/n=15 DVa_wave
	sq_GetPToFParams(DVa_wave, p1)
	if (acorn==0)	
//		t2=ptof_step[p1]			//1.61A
//		t1=ptof_t0[p1] // Assumes that the time point represents the mean time of sampling - need to check
		make/FREE/o/n=(DVa_wave[%numPToFBins]) PToFTimeCenters = DVa_wave[%t0]+((p)*DVa_wave[%step])
		make/FREE/o/n=(DVa_wave[%numPToFBins]) PToFTimeEdges= DVa_wave[%t0]+((p-0.5)*DVa_wave[%step])
		if (DVa_wave[%ePToFenabled] && deconvolveMike)
			sq_CorrectPToFTimeForTWDecon(DVa_wave, PToFTimeCenters)
			sq_CorrectPToFTimeForTWDecon(DVa_wave, PToFTimeEdges)
		endif
		
		make /o/n=(n_t) dtdlogdp_tmp=sq_dtdlogdp(lc,vl[p1],vg[p1],b[p1],PToFTimeCenters[p])
		make /o/n=(d_points) log_d_base_tmp=log(d_base)		// 1.59D
		make /o/n=(n_t+1) log_dsig_tmp=log(sq_ptof2dva(lc,vl[p1],vg[p1],b[p1],dx[p1],PToFTimeEdges[p]))
		sq_make_map(log_dsig_tmp,log_d_base_tmp,"d_map")
		wave d_map
		make/o/n=(dimsize(source,1)) dwave = d_map[p][1]
		
		make /o/n=(numpnts(t_series)) ugfac_wav_tmp
			if (ePToF_flag)		//1.53N
				fastop ugfac_wav_tmp=(1/ePToFFractionOpen)*ChopperFreq // we are in open half the time  //1.55B  twas 2
//			elseif (chopperDutyWave_op)
//				fastop ugfac_wav_tmp = ChopperFreq/chopperdutyWave
			else
				fastop ugfac_wav_tmp=(1/chop_duty)*ChopperFreq
			endif
		
	endif	// endif acorn ==0

	wave log_d_base_tmp
	wave dtdlogdp_tmp
	wave ugfac_wav_tmp
	wave dwave

	source *=dtdlogdp_tmp[q]
	MatrixOP/o mass_tmp = source x dwave		// row x PToF x mz    x  PToF
	imagetransform /g=1 transposevol mass_tmp	//  /g=1 M_VolumeTranspose=imageMatrix [p][r][q]
	wave m_volumetranspose				

	m_volumetranspose*=ugfac_wav_tmp[p1]
	
	TotalAreaXWidth = log_d_base_tmp[1] - log_d_base_tmp[0]
	m_volumetranspose *= TotalAreaXWidth
	
	redimension/n=(n_vals,mz_points ) m_volumetranspose
	
	//1.14M  UMR
	squirrel_hdf_write(index_pos,m_volumetranspose,"PToFDiff_p")

	// Step 6. Delete temporary waves
	if (acorn==n_acorns-1)
		sq_ams_stat_upd("Deleting temporary data")
		killwaves /z mass_tmp,mass_tmp_err,vec_tmp,dtdlogdp_tmp,d_map,t_map,log_d_base_tmp,log_dsig_tmp, ms_conc_tmp,mz_tmp
		killwaves /z m_volumetranspose,m_convolution,smooth_tmp,mz_map,t_source,mz2_base_tmp,dtdmz_tmp, mpos, ugfac_wav_tmp
		killwaves /z op_tmp,opfac_tmp, dummyWave
		killwaves /z op_dep1,op_dep2, source_err2  //1.45 addition from James
		killwaves /z mass_tmp_bl, bk_tmp
		killwaves /z dest_n				
		killwaves /z m_volumetranspose				
		killwaves /z $"conc_weight_0"
		killwaves /z $"PToFDiffMe"		//1.53F
	endif

End


//1.52
// creates  waves for the MSSCvsDC_Panel  (one set each for the top and bottom sets of graphs in the panel)
Function sq_MSvsPToF_calcPToFDiffWaves(topOrBottomStr, mz)
string topOrBottomStr
variable mz

	svar MSvsPToFInfo = root:panel:MSvsPToFInfo
//	svar todoStr=root:panel:sq_toDoWvNm  we don't set this to the current todo but to the todo used in last calculations
//	string todoStr = StringByKey("todo", MSvsPToFInfo, "\r")
	string todoStr = MSvsPToFInfo[6-1, strsearch(MSvsPToFInfo, "\r", 0)-1]

	wave todo=$"root:"+todoStr
	string mzStr = num2str(mz)
	string paramstr = ""
	paramstr += "min_cl:"+num2str(mz-1)+";"		// we count from zero
	paramstr += "max_cl:"+num2str(mz-1)+";"

	squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_PToFDiff_"+topOrBottomStr,"PToFDiff_p")
	wave mz_PToFDiff = $"root:PToF:mz_PToFDiff_"+topOrBottomStr	
	Note/k mz_PToFDiff, "mz:"+mzStr

	squirrel_fetch(todo,sq_Create1DwaveFromDataSet,paramstr+"dest:PToF/mz_MSSD_"+topOrBottomStr,"MSSDiff_p")
	wave mz_MSSD = $"root:PToF:mz_MSSD_"+topOrBottomStr	
	Note/k mz_PToFDiff, "mz:"+mzStr
End


//1.52
// Stats for MSSCvsDCMarker panel
Function sq_UpdateMSSCvsPToFDCStats(topOrBottomStr, varNum)
string topOrBottomStr
variable varNum

	wave/z ClosedMSmz = $"root:PToF:mz_MSSC_"+topOrBottomStr
	wave/z DCRegion1mz = $"root:PToF:mz_PToFDC1_"+topOrBottomStr
	wave/z DCRegion2mz = $"root:PToF:mz_PToFDC2_"+topOrBottomStr
	wave/z DCRegionAvgMz = $"root:PToF:mz_PToFDCavg_"+topOrBottomStr
	wave/z mz_MSDiff = $"root:PToF:mz_MSSD_"+topOrBottomStr
	wave/z mz_PToFDiff = $"root:PToF:mz_PToFDiff_"+topOrBottomStr

	variable MSCAvg, DCAvg, PToFDiffAvg, MSDiffAvg

	Wavestats/q/m=1 ClosedMSmz
	MSCAvg=V_avg
	ValDisplay $("MSSCAvg"+topOrBottomStr),value= _NUM:V_avg, Win=MSSCvsDC_Panel

	Wavestats/q/m=1 DCRegionAvgMz
	DCAvg=V_avg
	ValDisplay $("PToFDCAvg"+topOrBottomStr),value= _NUM:V_avg, Win=MSSCvsDC_Panel

	Wavestats/q/m=1 mz_MSDiff
	MSDiffAvg=V_avg
	ValDisplay $("MSDiffAvg"+topOrBottomStr),value= _NUM:V_avg, Win=MSSCvsDC_Panel

	Wavestats/q/m=1 mz_PToFDiff
	PToFDiffAvg=V_avg
	ValDisplay $("PToFDiffAvg"+topOrBottomStr),value= _NUM:V_avg, Win=MSSCvsDC_Panel

	ValDisplay $("MSSCDiff"+topOrBottomStr),value= _NUM:(MSCAvg/MSDiffAvg)	, Win=MSSCvsDC_Panel
	ValDisplay $("DCMSSCRatio"+topOrBottomStr),value= _NUM:(DCAvg/MSCAvg), Win=MSSCvsDC_Panel	
	ValDisplay $("DCPToFDiffAvg"+topOrBottomStr),value= _NUM:(DCAvg/PToFDiffAvg), Win=MSSCvsDC_Panel	

End

//*****************************************   MSvsPToF_Panel and MSSCvsDC_Panel  Stop *********************************************************

//1.09 x
Function gen_removeTracesFromGraph(winStr)
string winStr

	variable idex, num
	string wList, tracename
	
	wList = TracenameList(winStr,";",1)
	num = itemsInList(wList)
	for(idex=0;idex<num;idex+=1)
		tracename=StringFromList(0,StringFromList(idex, wList), "#")	
		RemoveFromGraph/Z/W=$winStr $tracename
	endfor

End


Function sq_SetDimLabelsABCorrToFType()

	svar/z detectorsUsed = root:diagnostics:detectorsUsed
	if (!svar_exists(detectorsUsed))
		string/g  root:panel:tempDetectorsUsed=""		//1.52K  This is INELEGANT 
		svar detectorsUsed = root:panel:tempDetectorsUsed
	endif
	variable idex
	make/o/n=(5,itemsInList(detectorsUsed) ) root:panel:airbeamCorrToFTypeValue/wave =airbeamCorrToFTypeValue
		
	SetDimLabel 0,0, $"IONEFF", airbeamCorrToFTypeValue
	SetDimLabel 0,1, $"AIRBEAM_HZ", airbeamCorrToFTypeValue
	SetDimLabel 0,2, $"airbeamPToF_Hz", airbeamCorrToFTypeValue
	SetDimLabel 0,3, $"singleIon", airbeamCorrToFTypeValue
	SetDimLabel 0,4, $"flowRate", airbeamCorrToFTypeValue
	
	for(idex=0;idex<itemsInList(detectorsUsed);idex+=1)	
		SetDimLabel 1,idex, $StringFromList(idex, detectorsUsed), airbeamCorrToFTypeValue	
	endfor

End

//1.52J
Function sq_populate_ABTable() 

	string fldrSav0 = GetDataFolder(1) 
	SetDataFolder root:panel:
	WAVE airbeamCorrToFTypeValue
	AppendToTable  airbeamCorrToFTypeValue.ld
	ModifyTable format(Point)=1,width(Point)=0,format(airbeamCorrToFTypeValue.ld)=5
	ModifyTable digits(airbeamCorrToFTypeValue.ld)=2,width(airbeamCorrToFTypeValue.l)=77
	ModifyTable width(airbeamCorrToFTypeValue.d)=52, showParts=0x7D
	ModifyTable statsArea=85

	SetDataFolder fldrSav0

End


Function sq_fileExtensionCheckProc(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	sq_initializeGlobalSVar("root:panel:HdfFileExtension", "hdf")  //1.52M
	svar HdfFileExtension= root:panel:HdfFileExtension		//1.52M
	
	variable NewHdf = strsearch(ctrlName, "h5",0)>=0
	CheckBox misc_h5 value = NewHdf
	CheckBox misc_hdf value = !NewHdf
	HdfFileExtension= selectString(NewHdf, "hdf", "h5")
	
End


///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//  BEGIN EPTOF FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//1.52D
// creates  root:PToF:ePToF_seq127 and the inverse root:PToF:ePToF_invSeq127
// Code taken from seq127 wave joel sent plus Joels original igor function createInverseSeq
Function sq_EPToFMakeSequenceInv()

	variable idex, num=127
	
	NewDataFolder/o root:PToF
	wave/z/i ePToF_seq127 = root:PToF:ePToF_seq127
	
	if (!WaveExists(ePToF_seq127))
		make/o/i/n=(num) root:PToF:ePToF_seq127/wave=ePToF_seq127
		ePToF_seq127=0	
		// special sequence given to me by joel, fall 2012, corresponding to the encoded PToF chopper wheel.
		ePToF_seq127[0,4]=1
		ePToF_seq127[8]=1
		ePToF_seq127[10,11]=1
		ePToF_seq127[13,14]=1
		ePToF_seq127[17,18]=1
		ePToF_seq127[22,23]=1
		ePToF_seq127[17,18]=1
		ePToF_seq127[22,23]=1
		ePToF_seq127[25]=1
		ePToF_seq127[28,29]=1
		ePToF_seq127[31,37]=1
		ePToF_seq127[39,41]=1
		ePToF_seq127[44,47]=1
		ePToF_seq127[49]=1
		ePToF_seq127[55]=1
		ePToF_seq127[57]=1
		ePToF_seq127[59,62]=1
		ePToF_seq127[65]=1
		ePToF_seq127[68]=1
		ePToF_seq127[72]=1
		ePToF_seq127[77]=1
		ePToF_seq127[80,82]=1
		ePToF_seq127[84,85]=1
		ePToF_seq127[87]=1
		ePToF_seq127[89]=1
		ePToF_seq127[91]=1
		ePToF_seq127[94]=1
		ePToF_seq127[96,98]=1
		ePToF_seq127[100]=1
		ePToF_seq127[102,103]=1
		ePToF_seq127[110,111]=1
		ePToF_seq127[114]=1
		ePToF_seq127[116]=1
		ePToF_seq127[120,122]=1

		// now create the inverse 1D wave  this is always twice the size no matter the oversampling value
		make/o/N=(2*(num))  root:PToF:ePToF_invSeq127/wave=ePToF_invSeq127
		ePToF_invSeq127= ePToF_Seq127[mod(p,num)] ? 1 : -1
	endif				
end

//--------------------------------------------------------------
Function sq_SeqExpand(BitsPerChip)
	variable BitsPerChip
	
	wave/z ePToF_seq127=root:PToF:ePToF_seq127
	if (!WaveExists(ePToF_seq127))
		sq_EPToFMakeSequenceInv()
		wave/z ePToF_seq127=root:PToF:ePToF_seq127		//1.53G??
	endif 
	variable nptsin, nptsout, ii, jj
	
	nptsin=numpnts(ePToF_seq127)
	nptsout=nptsin*BitsPerChip
	Make/D/O/N=(nptsout) root:PToF:SeqOutExp/Wave=SeqOutExp

	for (ii=0; ii<nptsout; ii+=1)
		jj=floor(ii/BitsPerChip)
		SeqOutExp[ii]=ePToF_seq127[jj]
	endfor
End


//  1.52  assumes that 2 D matrix is such that columns are mz (like MSSDiff) 
Function/wave sq_EPToFDeconvolve2D(twoDdata, osFactor, deconvolved2DData, Param1Run, SeqOutExp, ePToFNorm  [, minMz])			// for mzs with all zeros such as mz1 code will return nans and mess things up	
variable osFactor, ePToFNorm		// oversampling factor		//1.60A
wave twoDdata, deconvolved2DData, Param1Run, SeqOutExp
variable minMz

	variable idex, maxMz, numbins, pnts,minMzSetFlag

	minMzSetFlag =ParamIsDefault(minMz)		// returns true if minMz NOT specified

	nvar PToF_ePToF_TestRegion =  root:panel:PToF_ePToF_TestRegion
//	nvar PToF_ePToF_Denoise =  root:panel:PToF_ePToF_Denoise
//	nvar PToF_ePToF_Sharpening =  root:panel:PToF_ePToF_Sharpening
	nvar PToF_ePToF_Mulitplier =  root:panel:PToF_ePToF_Mulitplier
//	nvar/z ePToF_demux_adaptiveDenoise =  root:panel:ePToF_demux_adaptiveDenoise
//	if (!NVar_exists(ePToF_demux_adaptiveDenoise))		//1.57K
//		variable/g  root:panel:ePToF_demux_adaptiveDenoise=0
//		nvar ePToF_demux_adaptiveDenoise =  root:panel:ePToF_demux_adaptiveDenoise
//	endif
	
	nvar/z ePToFExists = root:diagnostics:ePToFExists
	if ( !Nvar_exists(ePToFExists))
		sq_SetePToFExists()
		nvar ePToFExists = root:diagnostics:ePToFExists
	endif
	
	nvar deconvolveJoel =  root:panel:deconvolveJoel
	nvar deconvolve =  root:panel:deconvolve
	nvar/z deconvolveMike = root:panel:deconvolveMike
	if (!Nvar_exists(deconvolveMike))
		variable/g root:panel:deconvolveMike
		nvar deconvolveMike = root:panel:deconvolveMike
	endif	

	PToF_ePToF_Mulitplier=osFactor
		
	nvar/z ePToFMirrorBackwardsFlag =  root:panel:ePToFMirrorBackwardsFlag
	if (NVar_Exists(ePToFMirrorBackwardsFlag))
 		sq_ePToFMirrorBackwardsFix(twoDdata)		// SOAS fix, for when chopper when 'punched' backwards
 	endif
 	
	nvar/z ePToFChopperRotated =  root:panel:ePToFChopperRotated
	if (NVar_Exists(ePToFChopperRotated) && ePToFChopperRotated>0)
 		matrixop/o MyRotate = rotateRows(twoDdata,ePToFChopperRotated)  // Liine data
		wave twoDdata = MyRotate
 	endif

 	maxMz=dimsize(twoDdata, 1)
	numbins = dimsize(twoDdata,0)
	pnts = (numbins/osFactor)  // should be 127

	if (pnts != 127)
		abort "The oversampling factor seems to be incorrect.  Value sent to function is "+num2str(osFactor)+" data wants "+num2str(numbins/127)+" aborting from sq_EPToFDeconvolve2D"
	endif
	
	Wave/Z /I ePToF_Inv2Dseq = root:PToF:ePToF_Inv2Dseq	// 2D inverse sequence (created in sq_EPToFMake2DSequenceInv)
	if (!WaveExists(ePToF_Inv2Dseq))
		sq_EPToFMake2DSequenceInv(osFactor = OsFactor)
		Wave/I ePToF_Inv2Dseq = root:PToF:ePToF_Inv2Dseq	// 2D inverse sequence (created in sq_EPToFMake2DSequenceInv)
	endif

	NewDataFolder/o root:PToF
	Redimension/N=(numbins, maxMz) deconvolved2DData
	make/o/n=(numbins) oneDdata, deconvolved1DData

	if(!deconvolve && !deconvolveJoel && !deconvolveMike)
		fastop Param1Run=(nan)
		fastop deconvolved2DData = twoDdata
	else		// Rich or Joel
		if(deconvolveJoel)
			Redimension/N=(maxMz) Param1Run
			fastop Param1Run= (nan)
			for(idex=MinMz; idex<maxMz; idex+=1)	// for loop over all mzs
				MatrixOP/o oneDdata=col(twoDdata,idex)   // oneDdata=twoDdata[p][idex]
				MatrixOp /O deconvolved1DData = ePToF_Inv2Dseq x OneDdata			//1.59D
//				sq_EPToFFastDeconvolve1D(OneDdata, osFactor, deconvolved1DData)		//1.59D		
				ImageTransform/G=(idex)/D=deconvolved1DData putCol deconvolved2DData
			endfor
		elseif(deconvolveMike)
			Redimension/N=(4, maxMz) Param1Run
			variable sp,ep  //1.60D
			ep=PToF_ePToF_Mulitplier*ePToFSingleNUm -1
			sp = round(PToF_ePToF_Mulitplier*ePToFSingleNUm*(1-PToF_ePToF_testRegion))	// 1.60 O
			TWEPToF_SetDimLabels(Param1Run,0)
			if (tweptof#deconv2d( twoDdata, deconvolved2DData, Param1Run, ePToFNorm,sp,ep))
				abort "Deconvolution didn't work"		//1.60 O
			endif  //1.60D
		else		// don't deconvolve
			fastop deconvolved2DData = twoDdata
		endif
	endif

	killvariables/z ConfidLimVal, paramWave

	nvar/z ePToFMirrorBackwardsFlag =  root:panel:ePToFMirrorBackwardsFlag
	if (NVar_Exists(ePToFMirrorBackwardsFlag))
 		sq_ePToFMirrorBackwardsFix(deconvolved2DData)
	endif	
End


Function TWDeconExists()

	variable returnVal = exists("tweptof#deconv2d" )
	return returnVal

End


Function deconv2dProto( undeconv2D, deconv2d, NewDeconvParam)
wave undeconv2D, deconv2d,NewDeconvParam

	abort "Within deconv2dProto.. aborting"

End


//1.53N
threadsafe function demux_proto(TDwave, SeqExp, demuxdata, PtsPerChip,sharpness, denoise, testfraction)
	wave TDwave, SeqExp, demuxdata
	variable PtsPerChip, sharpness, denoise, testfraction
	print  "// Within demux_proto - this shouldn't happen!!"
End


//  1.52  assumes that 2D matrix is such that columns are mz (like MSSDiff) 
// at this point we don't worry about or care if runs have been blacklisted.  Presume calling funciton will deal with that.
Function sq_EPToFDeconvolve3D(threeDdata, osFactor, deconvolved3DData, ParamMx, ParamMx1run, SeqOutExp, killflag, ePToFNorm [,minMz, smoothVal] )
variable osFactor, smoothVal, ePToFNorm //1.60A		// oversampling factor
wave threeDdata, deconvolved3DData, ParamMx, ParamMx1run, SeqOutExp
variable minMz, killflag

	variable idex, maxMz, numbins, pnts,numRuns, minMzSetFlag

	maxMz=dimsize(threeDdata, 2)
	numbins = dimsize(threeDdata,1)
	numRuns = dimSize(threeDdata,0)
	
	pnts = (numbins/osFactor)  // should be 127

	if (pnts != 127)
		abort "The oversampling factor seems to be incorrect.  Value sent to function is "+num2str(osFactor)+" data wants "+num2str(pnts)+" aborting from sq_EPToFDeconvolve3D"
	endif
	
	nvar deconvolveJoel = root:panel:deconvolveJoel
	nvar/z deconvolveMike = root:panel:deconvolveMike
	if (!Nvar_exists(deconvolveMike))
		variable/g root:panel:deconvolveMike=0
		nvar deconvolveMike = root:panel:deconvolveMike
	endif	

	minMzSetFlag =ParamIsDefault(minMz)		// returns true if minMz NOT specified
		
	Redimension/N=(numRuns, numbins, maxMz) deconvolved3DData
		
	make/o/n=(numbins, maxMz) twoDdata, deconvolved2Ddata // Need some command to clear newData values?

	if (deconvolveMike && TWDeconExists())
		Redimension/N=(numRuns, 4, maxMz) ParamMx
		Redimension/N=(4, maxMz) ParamMx1run
		FUNCREF TWEPToF_SetDimLabelsProto TWEPToF_SetDim= $"TWEPToF_SetDimLabels"
		if (Exists("TWEPToF_SetDimLabels"))		
			TWEPToF_SetDim(ParamMx,1)
			TWEPToF_SetDim(ParamMx1run,0)
		endif
	else
		Redimension/N=(numRuns, maxMz) ParamMx
		Redimension/N=(maxMz) ParamMx1run
	endif	
	
	ParamMx=nan		// we want zeros instead of nans because we will treat the confid limits like sticks/// no longer true
	sq_ams_stat_upd("Deconvolving PToF...")

//	nvar DCgr_ck_alsoSmooth = root:panel:DCgr_ck_alsoSmooth
	nvar DCgr_smoothVar = root:panel:DCgr_smoothVar

	if (deconvolveJoel  && DCgr_smoothVar>1) //&&DCgr_ck_alsoSmooth //1.59D !ParamIsDefault(smoothVal) && smoothVal>1)			//1.57N
		DCgr_smoothVar = round(DCgr_smoothVar)
		for(idex=0;idex<dimsize(threeDdata,0);idex+=1)	
			ImageTransform/PTYP=(2)/P=(idex) getPlane threeDdata	//	/PTYP=(2) means YZ plane
			wave M_ImagePlane
			sq_ePToF_2DsmoothCol(M_ImagePlane, DCgr_smoothVar)
			threeDdata[idex][][]=M_ImagePlane[q][r]
		endfor
		killwaves/z M_ImagePlane
	endif
	
	ImageTransform/G=(4) transposeVol threeDdata		//  /G= 4	M_VolumeTranspose=imageMatrix [q][r][p]
	wave M_VolumeTranspose  //  numbins x mz x run number

	make/o/n=(numbins, maxMz, numRuns)/FREE deconvolved3DDataTRANSP

	for(idex=0; idex<numRuns; idex+=1)		// for loop over all runs
		sq_ams_prog_upd(100*idex/numRuns)
//		MatrixOP twoDdata=threeDdata[idex][][]		//MatrixOP   don't want to bother transposing
		if (numRuns == 1)
			make/o/n= (numbins, maxMz) M_ImagePlane = threeDdata[0][p][q]    // (numbins, maxMz) 
		else
			ImageTransform/PTYP=(0)/P=(idex) GetPlane M_VolumeTranspose		//1.57N 1.53D the /PTYP=(2) YZ plane
			wave M_ImagePlane    // (numbins, maxMz) 
		endif

//		fastop twoDdata = M_ImagePlane
		if (Numtype(WaveMax(M_ImagePlane))!=0 )
//			fastop confidLim1D = (nan)
//			ImageTransform/O/D=confidLim1D/G=(idex) putRow confidLimitMx
//			ImageTransform/O/D=M_ImagePlane/P=(idex) setplane deconvolved3DDataTRANSP
			continue
		endif

		if (minMzSetFlag)
			sq_EPToFDeconvolve2D(M_ImagePlane, osFactor, deconvolved2Ddata,ParamMx1run, SeqOutExp, ePToFNorm)
		else
			sq_EPToFDeconvolve2D(M_ImagePlane, osFactor, deconvolved2Ddata, ParamMx1run, SeqOutExp, ePToFNorm, minMz=MinMz)
		endif
		if (deconvolveMike)
			ParamMx[idex][][] = ParamMx1run[q][r]
		else
			ImageTransform/O/D=ParamMx1run/G=(idex) putRow ParamMx
		endif
		ImageTransform/O/D=deconvolved2Ddata/P=(idex) setplane deconvolved3DDataTRANSP  //   /PTYP=2 means do for YZ plane

	endFor	

	ImageTransform/G=(2) transposeVol deconvolved3DDataTRANSP		//M_VolumeTranspose=imageMatrix [r][p][q]
	wave M_VolumeTranspose
	fastop deconvolved3DData = M_VolumeTranspose

	if (killflag)
		killwaves/z oneDdata, deconvolved1DData
		killwaves/z  twoDdata, deconvolved2Ddata
		killwaves/z M_VolumeTranspose, M_ImagePlane
	endif	

End


Function TWEPToF_SetDimLabelsProto(NewDeconParams, dim)
wave NewDeconParams
variable dim

End

////  EPTOF functions from Joel
//// Function given to Donna by Joel, fall 2012
//// now incorporated into sq_MakeEPToFSequenceInv
//// createInverseSeq
//// Create inverse sequence for use in deconvolution
//// parameters:
////	sequence:  1D array.  Encoding sequence used for modulation of the PToF beam
////	iSequence:  1D array. inverse sequence calculated from sequence.  Has length = 2x length of sequence 
//
//Function createInverseSeq(sequence, iSequence)
//wave sequence 
//wave iSequence
//
//variable Pnts, ii, pnt, r, c
//Pnts = numPnts(sequence)
//
//// A double-length sequence for easier use in deconvolve function
//redimension /N=(2*Pnts) iSequence
//
//For (ii=0; ii<2*Pnts; ii+=1)
//pnt = mod(ii, Pnts)
//If (sequence[pnt]==1) 
//		iSequence[ii] = 1
//	Else
//		iSequence[ii] = -1
//	EndIf
//endfor
//End Function
//////////////////////////////
//// deconvolve
//// Deconvolutes 1D ePTOF data
////parameters:
////	data:  1D array.  encoded PToF data
////	iSequence: inverse encoded sequence, calculated using function createInverseSeq
////	osFactor: oversampling factor used for acquisition of ePToF data.  Most commonly 3.
////		should equal (length of data)/(length of iSequenc/2)  
//// 	newData: 1D array, populated with deconvolved PToF data.  length = length of data.  
//
//Function deconvolve(data, iSequence, osFactor, newData)
//wave data
//wave iSequence
//variable osFactor
//wave newData
//
//variable pnts, r, c, n
//
//pnts = (numPnts(data)/osFactor)
//
//Redimension/N=(numPnts(data)) newData
//
//// Need some command to clear newData values?
//
//For(r=0; r<pnts; r+=1)
//	For(c=0; c<pnts; c+=1)
//		For (n=0; n<osFactor; n+=1)
//			newData[r*osFactor+n] += ( iSequence[pnts - r + c]*data[c*osFactor+n])		
//		Endfor
//	EndFor
//EndFor
//
//End Function
//
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//  END EPTOF FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

Function sq_DCMarkerGr()

	nvar/z ePToFExists = root:diagnostics:ePToFExists		//1.53F
	if ( !Nvar_exists(ePToFExists))
		sq_SetePToFExists()
		nvar ePToFExists = root:diagnostics:ePToFExists
	endif
	String fldrSav0

	if (ePToFExists)
		//	PauseUpdate; Silent 1		// building window...
		sq_initializeGlobalNVar("root:panel:ePToF_postmatrixInvDC", 1)
		
		killstrings/z root:panel:PToF_DCgr_Info2A, root:panel:PToF_DCgr_Info2, root:panel:PToF_DCgr_Info2, root:panel:PToF_DCgr_Info2A
		
		sq_initializeGlobalNVar("root:panel:ms0_mz_saved_regrid", 1)
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info2", "Step 0. Select a run or todo.")
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info2A", "Step 1. if ePToF run, elect deconvolve options (DAQ)")
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info3A", "")
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info4", "")
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info4A", "")
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_RunInfo", "")
		sq_initializeGlobalSVar("root:panel:ePToF_Info", "")
	
		sq_initializeGlobalNVar("root:panel:deconvolveNone", 1)		
		sq_initializeGlobalNVar("root:panel:deconvolveJoel", 0)		
		sq_initializeGlobalNVar("root:panel:deconvolveMike", 0)		
		sq_initializeGlobalNVar("root:panel:deconvolve", 0)			// rich	
	
		sq_initializeGlobalNVar("root:panel:PToF_ePToF_Mulitplier", nan)	
//		sq_initializeGlobalNVar("root:panel:PToF_ePToF_Denoise", 0)		//1.57G default changed from 1 to 0
//		sq_initializeGlobalNVar("root:panel:PToF_ePToF_Sharpening", 0)	//1.57G default changed from 1 to 0
		sq_initializeGlobalNVar("root:panel:PToF_ePToF_TestRegion", 0.25)	
		sq_initializeGlobalNVar("root:panel:PToF_ePToF_confidLim", nan)	
		sq_initializeGlobalNVar("root:panel:eptof_appendCopied", 1)		
	
		sq_initializeGlobalSVar("root:panel:ePToF_waveNamePrefix", "")
		sq_initializeGlobalSVar("root:panel:PToF_DCgr_Info2Z", "DC marker calcs not performed.")			// rich	
		sq_initializeGlobalSVar("root:panel:DCGr_ePToFInfoStr", "")			// rich	
	
		sq_initializeGlobalNVar("root:panel:PToF_DCgr_ePToFSumDiffScaling", 0)		
	endif

	sq_PToFePToF_Tool()  // SQ_Mar2015EPToFDCMarker()
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	PopupMenu ams_todolist_pop,mode=16,popvalue=sq_toDoWvNm	//1.53D
	
	nvar PToF_DCMarkerSingleRun=root:panel:PToF_DCMarkerSingleRun

	CheckBox DCgr_SingleRun,value= PToF_DCMarkerSingleRun,mode=1

	CheckBox DCgr_Todo,value= !PToF_DCMarkerSingleRun,mode=1

//	nvar PToF_DCgr_DAQsticks=root:panel:PToF_DCgr_DAQsticks
////	CheckBox PToF_DCgr_UseDAQ,pos={21,316},size={78,15},proc=sq_ck_PToF_DCgr_DAQSticks,title="DAQ sticks"
//	CheckBox PToF_DCgr_UseDAQ,variable= root:panel:PToF_DCgr_DAQsticks,mode=1
////	CheckBox PToF_DCgr_UsePreProc,pos={115,315},size={166,15},proc=sq_ck_PToF_DCgr_DAQSticks,title="pre-processed PToF sticks"
//	CheckBox PToF_DCgr_UsePreProc,value= !PToF_DCgr_DAQsticks,mode=1

	//1.55B
	nvar PToF_DCgr_runNumber =root:panel:PToF_DCgr_runNumber
	wave/z todo = $sq_toDoWvNm
	PToF_DCgr_runNumber=todo[0]
	
End


Function DC_RecalcDeconvlButtonProc(ctrlName) : ButtonControl
	String ctrlName

	sq_PToFDCgr_GetThisMatrix() 
End


Function DC_CopyEPtoF_ButtonProc(ctrlName) : ButtonControl
	String ctrlName

//	svar ePToF_waveNamePrefix = root:panel:ePToF_waveNamePrefix
	wave PToF_DCgr_oneMz = root:panel:PToF_DCgr_oneMz
	wave PToF_DCgr_displayX = root:panel:PToF_DCgr_displayX
	
	nvar/z deconvolveMike = root:panel:deconvolveMike
	if (!Nvar_exists(deconvolveMike))
		variable/g root:panel:deconvolveMike
		nvar deconvolveMike = root:panel:deconvolveMike
	endif	
	nvar deconvolve = root:panel:deconvolve 		//Rich
	nvar deconvolveJoel = root:panel:deconvolveJoel
	nvar deconvolveNone = root:panel:deconvolveNone
	nvar PToF_DCMarkerSingleRun = root:panel:PToF_DCMarkerSingleRun
	nvar PToF_DCgr_runNumber = root:panel:PToF_DCgr_runNumber
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm

	nvar PToF_ePToF_Mulitplier = root:panel:PToF_ePToF_Mulitplier
//	nvar PToF_ePToF_denoise = root:panel:PToF_ePToF_denoise
//	nvar PToF_ePToF_sharpening = root:panel:PToF_ePToF_sharpening
	nvar PToF_ePToF_testRegion = root:panel:PToF_ePToF_testRegion

//	nvar ePToF_demux_adaptiveDenoise = root:panel:ePToF_demux_adaptiveDenoise
//	nvar ePToF_demux_BLmax = root:panel:ePToF_demux_BLmax
//	nvar ePToF_demux_ECLulim = root:panel:ePToF_demux_ECLulim
//	nvar ePToF_demux_DNmax = root:panel:ePToF_demux_DNmax
//	nvar ePToF_demux_DNulim = root:panel:ePToF_demux_DNulim

	nvar/z PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	if (!Nvar_exists(PToF_DCgr_IsEPToF))
		variable/g root:panel:PToF_DCgr_IsEPToF
		nvar PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	endif

	string Wname

	if (PToF_DCMarkerSingleRun)	// single run
		sprintf Wname, "%u" ,PToF_DCgr_runNumber
		Wname= "r"+Wname
	else
		Wname= sq_toDoWvNm
	endif

	if (numtype(PToF_DCgr_IsEPToF) !=0) 
		return 0
	elseif (PToF_DCgr_IsEPToF==0)
		Wname+="_P"		// deconvolved none
	elseif (deconvolveNone)	// none
		Wname+="_N"		// deconvolved none
	elseif(deconvolveJoel) 		// inversion
		Wname+="_I"		
	elseif(deconvolveMike) 		// inversion
		Wname+="_M"		
	else		// demux
//		if (ePToF_demux_adaptiveDenoise)
//			Wname+="_D"+num2str(round(PToF_ePToF_denoise))+num2str(round(PToF_ePToF_sharpening))
//		else
//			Wname+="_D"+num2str(round(ePToF_demux_BLmax))+num2str(round(ePToF_demux_ECLulim))+num2str(round(ePToF_demux_DNmax))+num2str(round(ePToF_demux_DNulim))
//		endif
	endif


	duplicate/o PToF_DCgr_oneMz $Wname+"_Y"	/wave=myY
	duplicate/o PToF_DCgr_displayX $Wname+"_X"/wave=myx
	
	Note/k myY
	Note/k myX
	
	if (deconvolveNone)
		Note myY, "Deconvolve:None"
		Note myX, "Deconvolve:None"	
	elseif (deconvolveJoel)
		Note myY, "Deconvolve:Joel;OS:"+num2str(PToF_ePToF_Mulitplier)+";"
		Note myX, "Deconvolve:Joel;OS:"+num2str(PToF_ePToF_Mulitplier)+";"	
	elseif (deconvolveMike)
		Note myY, "Deconvolve:Mike;OS:"+num2str(PToF_ePToF_Mulitplier)+";"
		Note myX, "Deconvolve:Mike;OS:"+num2str(PToF_ePToF_Mulitplier)+";"	
	else
//		Note myY, "Deconvolve:Rich;OS:"+num2str(PToF_ePToF_Mulitplier)+";Denoise:"+num2str(PToF_ePToF_denoise)+";Sharpening:"+num2str(PToF_ePToF_sharpening)+";TestRegion:"+num2str(PToF_ePToF_testRegion)+";"
//		Note myX, "Deconvolve:Rich;OS:"+num2str(PToF_ePToF_Mulitplier)+";Denoise:"+num2str(PToF_ePToF_denoise)+";Sharpening:"+num2str(PToF_ePToF_sharpening)+";TestRegion:"+num2str(PToF_ePToF_testRegion)+";"	
	endif
	
	if (strsearch(TraceNameList("PToFePTOF_Tool#DCMarkerGr", ";", 1 ), Wname, 0)<0)
		appendtograph/W=PToFePTOF_Tool#DCMarkerGr myY vs myX	
		ModifyGraph/W=PToFePTOF_Tool#DCMarkerGr  rgb($NameofWave(myY))=(0,15872,65280)
	endif
	
End


Function DCgr_erase(ctrlName) : ButtonControl
	String ctrlName

	string str, list = TraceNameList("PToFePTOF_Tool#DCMarkerGr", ";", 1 )
	variable idex
	for(idex=0;idex<ItemsInList(list);idex+=1)
		str = stringFromList(idex, list)
		if (!stringmatch("PToF_DCgr_", str[0, 9])  )
			wave/z myY= $str
			wave/z myx= $ReplaceString("_Y", str, "_X")
			if (WaveExists(myY) )
				removeFromGraph/W=PToFePTOF_Tool#DCMarkerGr $NameOfWave(myY)
				killwaves/z myY, myX  
			endif
		endif
	endfor
End


// helper function for parsing todo strings using p or d format
// i.e. p2047-p2091 goes to rows 2047 through 2091 in run series and makes a todo wave
// format for date entries look lik yymmdd and yymmddhhmmss
// i.e. d130805130601-d130805130901
Function/s sq_parsePandDinTodoCreation(runIntervalString)
string runIntervalString

	string todoitem, substr1, substr2, replacementStr, subStr, runstr, yymmddhhmmss_str
	variable numItems, pos1, pos2, idex, jdex,num, pos
	
	wave rn_series = root:index:rn_series
	wave t_series = root:index:t_series
	
	num = numpnts(rn_series)	
	
	numItems=itemsinlist(runIntervalString," ")	
	replacementStr=""
	for (idex=0;idex<numItems;idex+=1)
		
		todoitem=stringfromlist(idex,runIntervalString," ")
		wave/z todoItemWave=$todoitem
		
		if (!stringMatch(todoitem,"not") && !stringMatch(todoitem,"and") && !stringMatch(todoitem,"or") && !WaveExists(todoItemWave))
		
			if (stringMatch(lowerStr(todoitem[0]), "p") )  	//  i.e. p458,p9901
				
				if (strsearch(todoitem, ",", 0)>0 && itemsinlist(todoitem,",")>0)			//  i.e. p458,p9901,p444
					subStr=""
					
					for (jdex=0;jdex< itemsinlist(todoitem,",");jdex+=1)		// parse list such as p458,p9901,p444
						substr1 = stringFromList(jdex, todoItem, ",")		//p458
						if (stringMatch(lowerStr(substr1[0]), "p") )
							pos = str2num(substr1[1, strlen(substr1)-1])
							if (pos>=0 && pos<num && numtype(pos)==0)
								sprintf substr1, "%d", rn_series[pos]	
							else
								print "//  Could not parse the entry in the todo run string "+substr1
							endif
						else		// something unusual... just keep?
							// substr1
						endif			
						substr +=substr1+","	
					endfor
					todoitem = substr[0,strlen(substr)-2]		// remove last ,
					
				elseif(strsearch(todoitem, "-", 0)>0 && itemsinlist(todoitem,"-")==2)  	//  i.e. p458-p901
					substr1 = stringFromList(0, todoItem, "-")
					if (stringMatch(lowerStr(substr1[0]), "p") )
						pos1 = str2num(substr1[1, strlen(substr1)-1])
						if (pos1>=0 && pos1<num && numtype(pos1)==0)		// 1.57Kfixed bug for p0 case
							sprintf substr1, "%d", rn_series[pos1]	
						else
							print "//  Could not parse the entry in the todo run string "+substr1
						endif
					endif			
					substr2 = stringFromList(1, todoItem, "-")
					if (stringMatch(lowerStr(substr2[0]), "p") )
						pos2 = str2num(substr2[1, strlen(substr2)-1])
						if (pos2>0 && pos2<num && numtype(pos2)==0)
							sprintf substr2, "%d", rn_series[pos2]	
						else
							print "//  Could not parse the entry in the todo run string "+substr2
						endif
					endif
					todoitem = substr1+"-"+substr2		
				else		// p454
					pos = str2num(todoitem[1, strlen(todoitem)-1])
					if (pos>0 && pos<num && numtype(pos)==0)
						sprintf todoitem, "%d", rn_series[pos]	
					else
						print "//  Could not parse the entry in the todo run string "+todoitem
					endif				
				endif

			elseif (stringMatch(lowerStr(todoitem[0]), "d") )		// i.e. dyymmddhhmmss
				
				if (strsearch(todoitem, ",", 0)>0 && itemsinlist(todoitem,",")>0)			//  i.e.d130616,d130612
					subStr=""
					
					for (jdex=0;jdex< itemsinlist(todoitem,",");jdex+=1)		// parse list such as p458,p9901,p444
						substr1 = stringFromList(jdex, todoItem, ",")		//i.e.d130616
						if (stringMatch(lowerStr(substr1[0]), "d") )
							subStr+= sq_ParseDinRunString(substr1)
						endif			
						substr +=substr1+" or "	
					endfor
				
					todoitem= subStr[0, strlen(substr)-5]
				
				elseif(strsearch(todoitem, "-", 0)>0 && itemsinlist(todoitem,"-")==2)  	//  i.e. d130614-d130615
					substr1 = stringFromList(0, todoItem, "-")
					substr2 = stringFromList(1, todoItem, "-")
					if (str2num(substr1[1, strlen(substr1)-1])>str2num(substr2[1, strlen(substr2)-1]))
						abort "The two different dates "+todoitem+" are not in chronological order "
					endif
					if (stringMatch(lowerStr(substr1[0]), "d") )
						substr1= sq_ParseDinRunString(substr1)
					endif			
					if (stringMatch(lowerStr(substr2[0]), "d") )
						substr2= sq_ParseDinRunString(substr2)
					endif
					if (itemsInList(substr1, "-")>1)		// single day
						substr1=stringFromList(0,substr1, "-") 
					endif
					if (itemsInList(substr2, "-")>1)		// single day
						substr2=stringFromList(1,substr2, "-") 
					endif
					todoitem = substr1+"-"+substr2		
				else		// p454
					todoitem= sq_ParseDinRunString(todoItem)
				endif
			endif
				
		endif	// todoitem is not the string 'not', 'and' nor 'or' nor a wave in root
		replacementStr+=todoitem+" "	
	endfor
	
	subStr = replacementStr[0, strlen(replacementStr)-2]		//1.58G
	
	return subStr
	
End


Function/s sq_ParseDinRunString(dyymmddhhmmssStr)	// get sent dyymmhhmmss 
string dyymmddhhmmssStr

	variable len = strlen(dyymmddhhmmssStr)
	if (!stringMatch(lowerStr(dyymmddhhmmssStr[0]), "d")  ||  !(len==7 || len==13) )		// i.e. dyymmddhhmmss
		return dyymmddhhmmssStr
	endif
	
	string yy,hh,mm,dd,ii,ss, runstr, yymmddhhmmss, StartRun, StopRun,replacementStr
	variable y,m,d,h,mi,s, StartTime, StopTime, num, pos, diurnalTime,dayTime
	
	wave rn_series = root:index:rn_series
	wave t_series = root:index:t_series
	
	num = numpnts(rn_series)	
	
	replacementStr=""

	yymmddhhmmss=dyymmddhhmmssStr[1, strlen(dyymmddhhmmssStr)-1]
	len=strlen(yymmddhhmmss)
									
	yy=		yymmddhhmmss[0,1]
	mm=	SelectString(len>=4, "01", yymmddhhmmss[2,3])
	dd=		SelectString(len>=6, "01", yymmddhhmmss[4,5])		// had hopes of making this very general but bailed
	hh=		SelectString(len>=8, "00", yymmddhhmmss[6,7])
	ii=		SelectString(len>=10, "00", yymmddhhmmss[8,9])
	ss=		SelectString(len>=12, "00", yymmddhhmmss[10,11])
	
	y =		str2num(yy)			
	m =		str2num(mm)
	d =		str2num(dd)
	h =		str2num(hh)
	mi =	str2num(ii)
	s =		str2num(ss)

	// sanity checks
	if (y>50 || m>13 || d>31 || h>25 || mi >60 || s >60)
		abort "The date time string doesn't make sense"
	endif
	
	dayTime = date2secs(2000+y, m, d) 
	diurnalTime = 3600*h+60*mi+s
	
	StartTime = dayTime+diurnalTime
	pos = binarysearch(t_series, StartTime)
	
	if (pos>=0 && pos<num && numtype(pos)==0) // well behaved
		sprintf StartRun, "%d", rn_series[pos]	
	elseif (pos==-1 &&  binarysearch(t_series, dayTime+24*3600)>=0 )		// first point is the same day
		sprintf StartRun, "%d", rn_series[0]	
	elseif (pos==-2 &&  binarysearch(t_series, dayTime-24*3600)>=0 )		// last point is the same day
		sprintf StartRun, "%d", rn_series[numpnts(rn_series)-1]	
	else		// too early or too late
		abort "The time you chose, "+dyymmddhhmmssStr+",  is too soon or too early for this data set."
	endif
		
	if (len==6)		// user specified yymmdd so we need the whole day
		StopTime=dayTime+24*3600
		pos = binarysearch(t_series, StopTime)
		if (pos>=0 && pos<num && numtype(pos)==0)		// well behaved
			sprintf StopRun, "%d", rn_series[pos]	
//		elseif (pos==-1 &&  binarysearch(t_series, dayTime+24*3600)>=0 )		// first point is the same day
//			sprintf StopRun, "%d", rn_series[0]	
		elseif (pos==-2 &&  binarysearch(t_series, dayTime)>=0 )		// last point is the same day
			sprintf StopRun, "%d", rn_series[numpnts(rn_series)-1]	
		else		// too early or too late
			abort "The time you chose, "+dyymmddhhmmssStr+",  is too soon or too early for this data set."
		endif
		replacementStr= StartRun+"-"+StopRun
	else
		replacementStr=StartRun
	endif
	
	return replacementStr

End


Function fms_interpolateOrCopy_CheckProc(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar doCopy =  root:panel:fastMS:doCopy
//	nvar doNans =  root:panel:fastMS:doNans

	variable InterpolateNotCopy = stringmatch(ctrlName, "check_FmInterpolate")
	doCopy = !InterpolateNotCopy 
	
//	doNans=InterpolateNotCopy
//	doCopy=!InterpolateNotCopy

//1.57D
	CheckBox check_FmInterpolate value = InterpolateNotCopy
//	CheckBox check_FmCopy
End


//1.52N
Function sq_ePToFMirrorBackwardsFix(twoDdata)		// mirror
wave twoDdata
	
	//we split this up into two operations... one flips first to last, the second is an offset
	variable NumRows = dimsize(twoDdata, 0)
	duplicate/o twoDdata root:PToF:temp2DePTOF/wave=temp2DePTOF
	ImageRotate/O/H temp2DePTOF

	variable offset = 4				// determined empirically.... should be made a global
	variable rotatingvVal = NumRows- 4				// determined empirically.... should be made a global
	MatrixOp/o twoDdata = rotateRows(temp2DePTOF,rotatingvVal) // 1.53G

End


Function sq_NextInTodoButtonProc(ctrlName) : ButtonControl
	String ctrlName
	
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	wave todo = $sq_toDoWvNm

	string myVarStr = ReplaceString("butt_", ctrlName, "")	// i.e. butt_bk_currentRunNum becomes bk_currentRunNum	
	
	Strswitch(myVarStr[0,1])
	Case "bk":
		nvar MyVar = $"root:baselineFitting:"+myVarStr
	break
	
	Default	:
		nvar MyVar = $"root:panel:"+myVarStr
	endswitch
	
	variable runLocation = sq_findRun(todo,MyVar)
	variable numInTodo = numpnts(todo)
		
	runLocation = binarysearch(todo, MyVar)
	if (runLocation==-1) 
		MyVar = todo[0]
	elseif(runLocation ==-2)
		MyVar = todo[numInTodo-1]
	elseif(runLocation >=0)
		MyVar = todo[min(runLocation+1, numpnts(todo)-1)]
	endif	

	Strswitch (myVarStr[0,1])
	Case "bk":
		bk_setVar_runNumberVW("",nan,"","")
	break
	Case "PT":		// DC marker graph
		sq_ck_PToF_SingleRunTodo("SingleRun",1)
	break
	
	Default :
	endswitch
	
End


Function sq_PrevNextInTodoButtonProc(ctrlName) : ButtonControl
	String ctrlName
	
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	wave todo = $sq_toDoWvNm

	string myVarStr =ReplaceString("prev_", ReplaceString("next_", ReplaceString("butt_", ctrlName, ""), ""), "")	// i.e. butt_bk_currentRunNum becomes bk_currentRunNum	
	variable nextFlag = stringMatch("next",StringFromList(1, ctrlName, "_") )
	
	ctrlName=StringFromList(2, ctrlName, "_")	// i.e. butt_bk_currentRunNum becomes bk_currentRunNum		

	ControlInfo ams_todolist_pop
	if (V_flag==3	 && !stringmatch(S_Value, sq_toDoWvNm)  )
		abort "Please reselect the todo wave in this panel.  Righ now it does not match the todo wave in the main ams panel.  Aborting from sq_PrevNextInTodoButtonProc"
	endif
	
	Strswitch(myVarStr[0,1])
		Case "bk":
			nvar MyVar = $"root:baselineFitting:"+myVarStr
		break		
		Case "DC":
			nvar MyVar = $"root:panel:PToF_DCgr_runNumber"
		break		

		Default	:
			nvar MyVar = $"root:panel:"+myVarStr
	endswitch
	
	variable runLocation = sq_findRun(todo,MyVar)
	variable numInTodo = numpnts(todo)
		
	runLocation = binarysearch(todo, MyVar)
	if (runLocation==-1) 
		MyVar = todo[0]
	elseif(runLocation ==-2)
		MyVar = todo[numInTodo-1]
	elseif(runLocation ==0)
		if (nextFlag)
			MyVar = todo[min(runLocation+1, numInTodo-1)]
		else
			MyVar = todo[0]
		endif
	else		// (runLocation >0)
		if (nextFlag)
			MyVar = todo[min(runLocation+1, numInTodo-1)]
		else
			MyVar = todo[runLocation-1]
		endif
	endif	

	Strswitch (myVarStr[0,1])
		Case "bk":
			bk_setVar_runNumberVW("",nan,"","")
		break
		Case "DC":		// DC marker graph
			sq_ck_PToF_SingleRunTodo("SingleRun",1)
			sq_PToF_DCGr_setVar_Run("setvarRunNumber",MyVar,"","")
		Default :
	endswitch
	
End


Threadsafe Function eEPToF_protofunc(TDwave, SeqExp, demuxdata, PtsPerChip, sharpness, denoise, testfraction)
	wave TDwave, SeqExp, demuxdata
	variable PtsPerChip, sharpness, denoise, testfraction
	print "within proto"
End


//1.53E
Function sq_ePToF_exists()			//1.57G
	wave ePToF_enabled = root:diagnostics:ePToF_enabled
	return WaveMax(ePToF_enabled)>=1
End


//1.53N
Function sq_SetePToFExists()

	sq_initializeGlobalNVar("root:diagnostics:ePToFExists", 0)	
	nvar ePToFExists = root:diagnostics:ePToFExists
	
	ePToFExists = sq_ePToF_exists()
	
	if (ePToFExists)			//1.56P		
		// we need to fix these waves: pToF_t0, pToF_step, ePToF_oversampling, chopperDutyWave
		
		nvar chopper_duty = root:diagnostics:chopper_duty
//		nvar cor3_t_offset = root:panel:cor3_t_offset			// 1.59E
		wave SecsInPToF = root:diagnostics:SecsInPToF
		wave TimePToFSec = root:diagnostics:TimePToFSec
		wave ePToF_enabled = root:diagnostics:ePToF_enabled		//1.57F
		wave ePToF_oversampling = root:diagnostics:ePToF_oversampling		//1.57F
		wave pToF_t0 = root:diagnostics:PToF_t0
		wave pToF_step = root:diagnostics:pToF_step
		wave ptofCoAdd = root:diagnostics:ptofCoAdd
		wave ChopperFreq = root:diagnostics:ChopperFreq
		wave pToF_delay_us = root:diagnostics:pToF_delay_us
		wave ToFPulserInHz = root:diagnostics:ToFPulserInHz
		wave ptofNumTimesThrough = root:diagnostics:ptofNumTimesThrough
		wave squirrel_index = root:index:squirrel_index
		wave series_index = root:index:series_index

		variable num = numpnts(ePToF_enabled)
		variable pos = FindDimLabel(squirrel_index, 2, "ptof_stick" )

		pToF_step = ePToF_enabled[p]? (1/ToFPulserInHz[p]) : (1/ToFPulserInHz[p]) *ptofCoAdd[p] // for regular PToF we need to account for PToFcoadd

		pToF_t0 = ePToF_enabled[p] ? -0.5*(1/127)/ChopperFreq[p]  : ptof_delay_us[p]*0.000001 - 0.5*chopper_duty/ChopperFreq[p]		//1.58B  cor3_t_offset + removed in 1.59E
		
		make/o/n=(num) root:diagnostics:chopperDutyWave/wave=chopperDutyWave
		chopperDutyWave = ePToF_enabled[p] ? ePToFFractionOpen : chopper_duty*(ptofNumTimesThrough[p]>0)
	
		if (pos>0 && WaveMax(ePToF_oversampling)<0)
			make/o/n=(num)/free ePToF_oversamplingFlag = squirrel_index[p][4][pos]/127	
			ePToF_oversampling = ePToF_oversamplingFlag[series_index[p]] * ePToF_enabled[p]
		endif
	endif

End


//  Slight modified by Donna for Inclusion of Squirrel/pika
// DTS we don't user areamass, zcolor
// calculates (and plots) MD tile plot: takes mass spec. and base as input, bins into mass and MD tiles
// HS r33 added z color as input value: 1: signal (default); 2: oxidation state
Function tw_ea_CalcMDTile(MS, MS_base, MS_bsl, dmq, excList, lowthresh, logflag, areamass, zcolor, win, printflag)
Wave MS, MS_base
Wave/Z MS_bsl
Variable dmq, printflag, lowthresh, logflag, areamass, zcolor	//
String excList, win

	Variable nmq, nUMR, nmd, i, startpt, meanval, nMB, startmQ, stoppt		// DTS replaced sumVal with meanVal
	Variable ppt, qpt, currUMR, pos, foundmQ
	String grname, notestr, id
	dfref datdfr = GetWavesDataFolderDFR(MS_base)
	
	notestr = "MS:"+GetWavesDataFolder(MS, 2)+";"
	notestr += "MS_base:"+GetWavesDataFolder(MS_base, 2)+";"
	if (WaveExists(MS_bsl))
		notestr += "MS_bsl:"+GetWavesDataFolder(MS_bsl, 2)+";"
	endif
	notestr += "win:"+win+";"
	if (WaveExists(MS_bsl))
		Duplicate/FREE MS, MS_nobsl
		MS_nobsl = MS - MS_bsl
		Wave MS = MS_nobsl
	endif
	
	id = StringFromList(1, NameofWave(MS), "_")		//DTS
	WaveStats/Q/M=1 MS_base		//DTS
	startmQ = round(V_min)
	nUMR = round(V_max)-startmQ+1
	nmq = (nUMR-1) / dmq + 1
	nmd = round(1/dmq)
	
	NewDataFolder/O datdfr:MD_Tile
	dfref tiledfr = datdfr:MD_Tile
	Make/N=(ItemsinList(excList))/FREE excw
	excw = round(Str2num(StringFromList(p,excList)))
	Sort excw, excw
	nMB = nUMR*nmd*4/1024/1024
	if (printflag)
		print "making",nUMR,"x",nmd,"matrix of", nMB, "MB."
	endif
	Make/N=(nUMR, nmd)/O tiledfr:$"MD_TileM_"+id
	Wave MD_TileM = tiledfr:$"MD_TileM_"+id
	SetScale/P y -0.5,dmq,"", MD_TileM
	SetScale/P x startmQ,1,"", MD_TileM
	MD_TileM = NaN

	Note MD_TileM, notestr
	
	For (i=0; i<nmq; i+=1)
		startpt = binarysearch(MS_base, i*dmq+startmQ-0.5)+1
		stoppt = binarysearch(MS_base, i*dmq+startmQ+dmq-0.5)
		if (startpt>-1 && stoppt>-1)
			meanval = mean(MS, pnt2x(MS,startpt), pnt2x(MS,stoppt))		//DTS replaced sumVal with meanVal
			currUMR = round(i*dmq+startmQ-0.5)
			pos = binarysearch(excw, currUMR)
			if (pos>-1)
				foundmQ = excw[pos]
			else
				foundmQ = -1
			endif
			if (abs(foundmQ-currUMR)>1e-8 && meanval>lowthresh)		//DTS replaced sumVal with meanVal		
				ppt = round(i*dmq-0.5)
				qpt = mod(i,nmd)
				if (logflag)
					meanval = log(meanval)
				endif
//				if (zcolor==2) // r33 calculate oxidation state
//					sumval = tw_ea_OsCFromMQMD(i*dmq+startmQ,qpt*dmQ-0.5)
//				endif
				MD_TileM[ppt][qpt] = (meanval)
			endif
		endif
	EndFor
End Function


Function tw_ea_cb_UpdMDTile(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			Variable checked = cba.checked
			tw_ea_UpdMDTile(cba.win)
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


Function tw_ea_sv_UpdMDTile(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			tw_ea_UpdMDTile(sva.win)
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


Function tw_ea_pm_UpdMDTile(pa) : PopupMenuControl
	STRUCT WMPopupAction &pa

	switch( pa.eventCode )
		case 2: // mouse up
			Variable popNum = pa.popNum
			String popStr = pa.popStr
			tw_ea_UpdMDTile(pa.win)
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


// HS r33 added z color as additional option
Function tw_ea_UpdMDTile(win)
String win

	Variable dmq, printflag, lowthresh, logflag, areamass, zcolor
	String excList, trList, notestr

	trList = ImageNameList(win,";") 
	if (!StrLen(trList))
		return 1
	endif
	Wave MD_TileM = ImageNameToWaveRef("", StringFromList(0, trList))
	Dfref MDFold = GetWavesDataFolderDFR(MD_TileM)
	Dfref ParFold = ::MDFold
	notestr = note(MD_TileM)
	Wave MS = $(StringByKey("MS",notestr))
	Wave MS_base = $(StringByKey("MS_base",notestr))
	Wave/Z MS_bsl = $(StringByKey("MS_bsl",notestr))

	Controlinfo/W=$win MDTi_p0_cb_log
	if (V_Value>0)
		logflag = 1
	else
		logflag = 0
	endif
	areamass=nan		// DTS
	Controlinfo/W=$win MDTi_p0_sv_dmQ
	if (V_Flag>0)
		dmq = V_Value
	else
		dmq = 0.01
	endif
	Controlinfo/W=$win MDTi_p0_sv_exList
	if (V_Flag>0)
		excList = S_Value
	else
		excList = ""
	endif
	Controlinfo/W=$win MDTi_p0_sv_thr
	if (V_Flag>0)
		lowthresh = V_Value
	else
		lowthresh = 0.05  // DTS0.5
	endif
	ColorScale/W=$win/C/N=colscale/F=0/A=RB vert=0,image=MD_TileM "Log{mean[Bin intensity(ions / sec)]}"		//DTS

	tw_ea_CalcMDTile(MS, MS_base, MS_bsl, dmq, excList, lowthresh, logflag, areamass, zcolor, win, printflag)
	
End


// copied from Harald's code in tofware  //1.53N
Function tw_ea_makeMDTilePlot(win, MS, MS_base, MS_bsl)
String win
Wave MS, MS_base
Wave/Z MS_bsl
 
	String grname, excList, notestr, currform, currmod, startlist, modlist, tr, legendstr, id
	Variable ll, tt, dmq, printflag, lowthresh, logflag, areamass, nlines, currmq, i, j, retval
	Variable minmQ, maxmQ, currmD, startmQ, startmD, deltamQ, deltamD,zcolor
	
	// make plot
	if (StrLen(win))
		grname = "MD_Tile_"+StringFromList(2,win,"_")+"_"+StringFromList(3,win,"_")
	else
		grname = UniqueName("MD_Tile", 6, 0)
	endif
	
	dfref datdfr = GetWavesDataFolderDFR(MS_base)
	
	id=StringFromList(1, NameofWave(MS), "_")
	NewDataFolder/O datdfr:MD_Tile
	dfref tiledfr = datdfr:MD_Tile
	Make/N=(1, 1)/O tiledfr:$"MD_TileM_"+id // dummy wave to be able to append
	Wave MD_TileM = tiledfr:$"MD_TileM_"+id
	notestr = "MS:"+GetWavesDataFolder(MS, 2)+";"
	notestr += "MS_base:"+GetWavesDataFolder(MS_base, 2)+";"
	if (WaveExists(MS_bsl))
		notestr += "MS_bsl:"+GetWavesDataFolder(MS_bsl, 2)+";"
	endif
	notestr += "win:"+win+";"
	Note MD_TileM, notestr
	
	Dowindow/K $grname
	Display/N=$grname/W=(35,35,663,484)/K=0		//DTS removed the K=1
	AppendImage MD_TileM
	ModifyImage $NameofWave(MD_TileM) ctab= {,,Rainbow,1}
	
	Controlbar 25
	// elements in controlbar
	ll = 0
	tt = 0
	// log checkbox, checked by default
	CheckBox MDTi_p0_cb_log,pos={ll,tt},size={40,16},title="Log",value= 1, proc=tw_ea_cb_UpdMDTile
	CheckBox MDTi_p0_cb_log,font="calibri",fsize=11,fstyle=0
	// area x mass checkbox, checked by default
//	ll += 40
	// delta mQ setvariable
	ll += 80
	SetVariable MDTi_p0_sv_dmQ,pos={ll,tt},size={100,16},title="delta MD", proc = tw_ea_sv_UpdMDTile		//DTS
	SetVariable MDTi_p0_sv_dmQ,limits={0,1,0.01},value=_NUM:0.01,font="calibri",fsize=11,fstyle=0
	// exclusion list setvariable
	ll += 90 		// 95  DTS
	SetVariable MDTi_p0_sv_exList,pos={ll,tt},size={300,16},title="exclude m/z", proc = tw_ea_sv_UpdMDTile  // DTS size
	SetVariable MDTi_p0_sv_exList,limits={0,1,0.01},font="calibri",fsize=11,fstyle=0		// DTS  value=_STR:"59;60;119"
	SetVariable MDTi_p0_sv_exList,value=_STR:"14;16;18;28;32;40;182;183;184;186"	// DTS 
			
	// threshold
	ll += 330 	// 160 DS
	SetVariable MDTi_p0_sv_thr,pos={ll,tt},size={100,16},title="Threshold", proc = tw_ea_sv_UpdMDTile		//DTS
	SetVariable MDTi_p0_sv_thr,value=_NUM:0.002 // DTS	
//	// z color

	// call update function to calculate data
	tw_ea_UpdMDTile(grname)
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm  //DTS
	legendstr = sq_toDoWvNm		//DTS
	
	ColorScale/C/N=colscale widthPct=60
	Legend legendstr
	Label left "Mass defect m/z"  // (Th)"
	Label bottom "m/z " //Q (Th)"
	
	ModifyGraph zero(left)=1  //DTS
	ModifyGraph nticks=9  //DTS
	ModifyGraph minor=1  //DTS
	ModifyGraph grid=2,gridRGB=(34816,34816,34816)   //DTS
End


//1.53N
Function sq_checkNoDCPreprocPToF(todo, ePToFflag)
wave todo
variable ePToFflag

	variable idex, sPos, totolnum, num
	num = numpnts(todo)
	
	make/FREE/o/n=1 maskwave
	sq_makeMaskFromTodofindRun(maskwave,todo)
	duplicate/FREE maskwave tempWave

	if (ePToFflag)  		// waves are set to non -nan sq_preProcessEPToF
//		wave/z EPToF_denoise =  root:diagnostics:EPToF_denoise
//		wave/z EPToF_sharpening = root:diagnostics:EPToF_sharpening
		wave/z EPToF_testregion = root:diagnostics:EPToF_testregion
		wave/z deconvolveType = root:diagnostics:deconvolveType
//		if (!waveExists(EPToF_denoise) || !waveExists(EPToF_sharpening) || !waveExists(EPToF_testregion) || !waveExists(deconvolveType))
		if ( !waveExists(EPToF_testregion) || !waveExists(deconvolveType))
			return 0		// we haven't deconvolved yet
		endif
//		tempWave=maskwave * EPToF_denoise
		Wavestats/q/m=1 tempWave		//1.53J
		// we only test for one wave but in theory we should test all waves
		if (num !=V_npnts)
			return 0 	// we haven't deconvolved yet
		else
			return 1	// we have deconvolved
		endif
	else		// these waves are set to non nan numbers in sq_applyDCmarkers
		wave/z DCregion2Start = root:diagnostics:DCregion2Start
		if (!WaveExists(DCregion2Start) )		// assume if one is created so have them all
			return 1	// assume we have DC marker subtracted
		else
			tempWave=maskwave * DCregion2Start
			Wavestats/q/m=1 tempWave		//1.53J
			// we only test for one wave but in theory we should test all waves
			if (num !=V_npnts)
				return 0 	// we haven't dc markered
			else
				return 1	// we have applied dc markers
			endif
		endif
	endif

End


//1.53N			
Function sq_NoDCPreprocPToF(index_pos, ePToFflag)
wave index_pos
variable ePToFflag

	wave series_index = root:index:series_index

	variable idex, sPos, totolnum, num

	totolnum=numpnts(series_index)
	num = numpnts(index_pos)
	
	for(idex=0;idex<num;idex+=1)
		sPos=series_index[index_pos[idex]]		
	
		if (ePToFflag)  		// waves are set to non -nan sq_preProcessEPToF
//			wave/z EPToF_denoise =  root:diagnostics:EPToF_denoise
//			wave/z EPToF_sharpening = root:diagnostics:EPToF_sharpening
			wave/z EPToF_testregion = root:diagnostics:EPToF_testregion
			wave/z deconvolveType = root:diagnostics:deconvolveType
//			if (!waveExists(EPToF_denoise) || !waveExists(EPToF_sharpening) || !waveExists(EPToF_testregion) || !waveExists(deconvolveType))
			if (!waveExists(EPToF_testregion) || !waveExists(deconvolveType))
//				make/o/n=(numpnts(series_index))  root:diagnostics:EPToF_denoise=nan		
//				make/o/n=(numpnts(series_index))  root:diagnostics:EPToF_sharpening=nan		
				make/o/n=(numpnts(series_index))  root:diagnostics:EPToF_testregion=nan		
				make/o/n=(numpnts(series_index))  root:diagnostics:deconvolveType=nan		
//				wave/z EPToF_denoise = root:diagnostics:EPToF_denoise
//				wave/z EPToF_sharpening = root:diagnostics:EPToF_sharpening
				wave/z EPToF_testregion = root:diagnostics:EPToF_testregion
				wave/z deconvolveType = root:diagnostics:deconvolveType
			endif
//			EPToF_denoise[sPos]=nan		//1.53J
//			EPToF_sharpening[sPos]=nan
			EPToF_testregion[sPos]=nan
			deconvolveType[sPos]=nan
		else		// these waves are set to non nan numbers in sq_applyDCmarkers
			wave/z DCregion1Start = root:diagnostics:DCregion1Start
			if (!WaveExists(DCregion1Start) )
				make/o/n=(totolnum) root:diagnostics:DCregion1Start/wave=DCregion1Start
				make/o/n=(totolnum) root:diagnostics:DCregion1Stop/wave=DCregion1Stop
				make/o/n=(totolnum) root:diagnostics:DCregion2Start/wave=DCregion2Start
				make/o/n=(totolnum) root:diagnostics:DCregion2Stop/wave=DCregion2Stop		
			endif
			DCregion1Start[sPos]=nan		//1.53J
			DCregion1Stop[sPos]=nan
			DCregion2Start[sPos]=nan
			DCregion2Stop[sPos]=nan
		endif
	endfor
end			


Function sq_MSPlot_F43vsF44(f43,f44, NewPlotName) 
wave f43,f44
string NewPlotName

	nvar ms0_graphOutputType = root:panel:ms0_graphOutputType		// 1 - new, 2 = multiple, 3 = append, 4 = update

	if(ms0_graphOutputType<4)		// if update we do nothing, not even bring a graph to the top window
		
		// bring graph to front (for multiple graphs do nothing for now)
		if (ms0_graphOutputType==1)
			display/N=$NewPlotName as NewPlotName
			// sally Ng triangle lines
			make/o/n=100 root:panel:SallyLineX/wave=SallyLineX
			make/o/n=100 root:panel:SallyLineLeft/wave=SallyLineLeft
			make/o/n=100 root:panel:SallyLineRight/wave=SallyLineRight
			
			SallyLineX = p/99 + .02
			SallyLineLeft=(-6.0204)*SallyLineX+0.4154
			SallyLineRight=(-1.8438)*SallyLineX+0.3319
		
			appendtograph/L=f44/B=f43 SallyLineLeft vs SallyLineX
			appendtograph/L=f44/B=f43 SallyLineRight vs SallyLineX
			SetAxis f43 0,0.4
			SetAxis f44 0,0.2
			ModifyGraph lstyle($NameOfWave(SallyLineLeft))=7,lsize($NameOfWave(SallyLineLeft))=2
			ModifyGraph lstyle($NameOfWave(SallyLineRight))=7,lsize($NameOfWave(SallyLineRight))=2
			ModifyGraph rgb($NameOfWave(SallyLineLeft))=(0,15872,65280),rgb($NameOfWave(SallyLineRight))=(65280,0,0)
		elseif(ms0_graphOutputType==3)
			DoWindow/F $NewPlotName
		endif
						
		appendtograph/W=$NewPlotName/L=f44/B=f43 f44 vs f43		// add trace for new, multiple and append
			
		SetAxis/A/E=3 f43
		SetAxis/A/E=3 f44
		Label f43 "f43"
		Label f44 "f44"
		ModifyGraph mode($NameOfWave(f44))=3,marker($NameOfWave(f44))=8,rgb($NameOfWave(f44))=(26112,52224,0)				
		ModifyGraph freePos(f43)=0,freePos(f44)=0
		ModifyGraph freePos(f43)=0,freePos(f44)=0
		ModifyGraph lblPos=50,lblLatPos=0
		SetAxis f43 0,0.3
		SetAxis f44 0,0.3
	endif

End


Function sq_MSPlot_f44vsf60(f44,f60, NewPlotName) 
wave f44,f60
string NewPlotName

	nvar ms0_graphOutputType = root:panel:ms0_graphOutputType		// 1 - new, 2 = multiple, 3 = append, 4 = update

	if(ms0_graphOutputType<4)		// if update we do nothing, not even bring a graph to the top window
		
		// bring graph to front (for multiple graphs do nothing for now)
		if (ms0_graphOutputType==1)
			display/N=$NewPlotName as NewPlotName
			// Mike background lines
			make/o/n=2 root:panel:MikeLineMinX/wave=MikeLineMinX
			make/o/n=2 root:panel:MikeLineMinY/wave=MikeLineMinY
			make/o/n=2 root:panel:MikeLineX/wave=MikeLineX
			make/o/n=2 root:panel:MikeLineLeft/wave=MikeLineLeft
			make/o/n=2 root:panel:MikeLineRight/wave=MikeLineRight
			MikeLineMinX = {0.003, 0.003}
			MikeLineMinY= {0.05, 0.25}			
			MikeLineLeft= {0.01, 0.01}			
			MikeLineRight= {0.04, 0.01}			
			appendtograph/L=f44/B=f60 MikeLineMinY vs MikeLineMinX
			appendtograph/L=f44/B=f60 MikeLineMinY vs MikeLineLeft
			appendtograph/L=f44/B=f60 MikeLineMinY vs MikeLineRight
			ModifyGraph lstyle($NameOfWave(MikeLineMinY))=7,lsize($NameOfWave(MikeLineMinY))=2,rgb($NameOfWave(MikeLineMinY))=(30000,30000,30000)
			ModifyGraph rgb(MikeLineMinY#1)=(0,0,0),rgb(MikeLineMinY#2)=(0,0,0)
		elseif(ms0_graphOutputType==3)
			DoWindow/F $NewPlotName
		endif
						
		appendtograph/W=$NewPlotName/L=f44/B=f60 f44 vs f60		// add trace for new, multiple and append
			
		SetAxis/A/E=3 f44
		SetAxis/A/E=3 f60
		Label f44 "f44"
		Label f60 "f60"
		ModifyGraph mode($NameOfWave(f44))=3,marker($NameOfWave(f44))=8,rgb($NameOfWave(f44))=(26112,52224,0)				
		ModifyGraph freePos(f44)=0,freePos(f60)=0
		ModifyGraph freePos(f44)=0,freePos(f60)=0
		ModifyGraph lblPos=50,lblLatPos=0
		SetAxis f44 0,0.25
		SetAxis f60 0,0.05
	endif

End

Function sq_RecreateFastMSRunWithinCycle(FastKey, FastModeAvgTimeSec, fastMSRunWithinCycle, fastMSTimeWithinCycle, closedStart, closedStop)
wave FastKey, FastModeAvgTimeSec,, fastMSRunWithinCycle, fastMSTimeWithinCycle
variable closedStart, closedStop

	variable idex, num, fastmodecount, numSoFar=0
	num = numpnts(FastKey)
	idex=0
	fastmodecount=0
	fastMSRunWithinCycle=nan
	fastMSTimeWithinCycle=nan
	
	do 
		if (  numtype(fastkey[idex])!=0)
			fastMSRunWithinCycle[idex]=nan
			fastMSTimeWithinCycle[idex]=nan
			idex+=1
		elseif(fastkey[idex] == 2)		// at start of cycle
			fastmodecount=0
			fastMSRunWithinCycle[idex,idex+closedStart-1 ] = p - idex
			fastMSTimeWithinCycle[idex,idex+closedStart-1 ] = (p - idex)*FastModeAvgTimeSec[p]
			idex+=closedStart  // go at least the first fast closed number of points in cycles
			fastmodecount+=closedStart
			do 
				fastMSRunWithinCycle[idex]=fastmodecount
				fastMSTimeWithinCycle[idex]=(fastmodecount)*FastModeAvgTimeSec[idex]
				idex+=1
				fastmodecount+=1
			while (numtype(fastkey[idex])==0 &&  fastkey[idex]==0  && idex<num)	// get past all fast open
			if ( idex==num)  // we are at the end
				fastMSRunWithinCycle[idex-1]=fastmodecount-1
				fastMSTimeWithinCycle[idex-1]=(fastmodecount-1)*FastModeAvgTimeSec[idex-1]
			endif 
			// we have closedStop many fast closed to get through
			numSoFar = fastmodecount
			do 
				fastMSRunWithinCycle[idex]=fastmodecount
				fastMSTimeWithinCycle[idex]=(fastmodecount)*FastModeAvgTimeSec[idex]
				idex+=1
				fastmodecount+=1
			while (numtype(fastkey[idex])==0 &&  fastkey[idex]==2  && (idex-numSoFar)<closedStop && idex<num-1)	// get past all fast open
			if ( idex==num-1)  // we are at the end
				fastMSRunWithinCycle[idex]=fastmodecount-1
				fastMSTimeWithinCycle[idex]=(fastmodecount-1)*FastModeAvgTimeSec[idex]
			endif 
			if ( (idex-numSoFar)==closedStop )		// is previous run a fast closed, it first within a cycle?
				fastMSRunWithinCycle[idex]=fastmodecount
				fastMSTimeWithinCycle[idex]=fastmodecount*FastModeAvgTimeSec[idex]
				fastmodecount=0
			endif
		endif
	while(idex<num)

End


// modified in 1.57A to the full size of InfoVal   for backwards compatibility
Function sq_GetMajorFileVersion(currentFullPath)
string currentFullPath

	STRUCT HDF5DataInfo di	// Defined in HDF5 Browser.ipf.
	InitHDF5DataInfo(di)	// Initialize structure.

	variable fileID
	HDF5MakeHyperslabWave("root:slab", 2)	// In HDF5 Browser.ipf
	wave slab = root:slab
	slab[0][%Start] = 0	// Start at zero for dimensions 0
	slab[1][%Start] =0 	// Start at 100 for dimensions 1
	slab[][%Stride] = 1	// Use a stride of 1 for all dimensions
	
	slab[0][%Count] = 1	// Load 1 blocks of dimension 0
	slab[1][%Count] = 100	// Load 10 blocks of dimension 1		// this could be smaller... we only need col 66
	
	slab[0][%Block] = 1	// Set block size for dimension 0 to 1
	slab[1][%Block] = 1 // Set block size for dimension 1 to 10
	
	HDF5OpenFile/z/r/p=HdfDirPath fileID as currentFullPath
	if (V_Flag)
		Abort "There is something wrong with the file "+	currentFullPath+" Try to open it in the HDF5 browser or delete??"
	endif
	HDF5DatasetInfo(fileID , "InfoVal" , 0 , di ) 
	slab[1][%Count] = di.dims[1]	// Load 10 blocks of dimension 1		// this could be smaller... we only need col 66	
	
	hdf5LoadData/slab=slab/n=InfoVal/o/q/z fileID,"InfoVal"
	wave/z InfoVal=root:InfoVal
		HDF5CloseFile fileID

	if(!waveexists(InfoVal))
		HDF5CloseFile fileID
		Abort "// File "+currentFullPath+" does not contain a 'InfoVal' data set & thus can't be indexed - Aborting from sq_GetMajorFileVersion"
	endif

	variable version = InfoVal[0][66]
	Killwaves/z InfoVal, slab
	
	return version

End


// modified in 1.57A
Function sq_GetDAQFileVersion(currentFullPath)
string currentFullPath

	variable fileID
	STRUCT HDF5DataInfo di	// Defined in HDF5 Browser.ipf.
	InitHDF5DataInfo(di)	// Initialize structure.

	HDF5MakeHyperslabWave("root:slab", 2)	// In HDF5 Browser.ipf
	wave slab = root:slab
	slab[0][%Start] = 0	// Start at zero for dimensions 0
	slab[1][%Start] =0 	// Start at 100 for dimensions 1
	slab[][%Stride] = 1	// Use a stride of 1 for all dimensions
	
	slab[0][%Count] = 1	// Load 1 blocks of dimension 0
	slab[1][%Count] = 100	// Load 10 blocks of dimension 1		// this could be smaller... we only need col 66
	
	slab[0][%Block] = 1	// Set block size for dimension 0 to 1
	slab[1][%Block] = 1 // Set block size for dimension 1 to 10
	
	HDF5OpenFile/z/r/p=HdfDirPath fileID as currentFullPath
	if (V_Flag)
		Abort "There is something wrong with the file "+	currentFullPath+" Try to open it in the HDF5 browser or delete??"
	endif
	HDF5DatasetInfo(fileID , "InfoVal" , 0 , di ) 
	slab[1][%Count] = di.dims[1]	// Load 10 blocks of dimension 1		// this could be smaller... we only need col 66	
	
	hdf5LoadData/slab=slab/n=InfoVal/o/q/z fileID,"InfoVal"
	wave/z InfoVal
	HDF5CloseFile fileID

	if(!waveexists(InfoVal))
		HDF5CloseFile fileID
		Abort "// File "+currentFullPath+" does not contain a 'InfoVal' data set & thus can't be indexed - Aborting from sq_GetMajorFileVersion"
	endif

	NewDataFolder/o root:diagnostics
	variable/g root:diagnostics:DaqVersionMajorVar = InfoVal[0][66]			// ToF-AMS DAQ Version Major
	variable/g root:diagnostics:DaqVersionMinorVar  = InfoVal[0][67]			// ToF-AMS DAQ Version Minor
	variable/g root:diagnostics:DaqVersionFixVar  = InfoVal[0][68]			// ToF-AMS DAQ Version Fix
	Killwaves/z InfoVal, slab
	
End


// code by Florian  //1.54A
Function sq_EPToFMake2DSequenceInv([osFactor,overwrite])
	Variable osFactor
	Variable overwrite
	
	Variable num = 127
	osFactor = ParamIsDefault(osFactor) ? 1 : osFactor
	overwrite = ParamIsDefault(overwrite) ? 0 : overwrite
	
	//Try to find out if we actually need to do anything
	If (WaveExists(root:PToF:ePToF_Inv2Dseq) && !overwrite)
		//safetycheck, confirm we have the right dimensions
		If (DimSize(root:PToF:ePToF_Inv2Dseq, 0) == osFactor*num && DimSize(root:PToF:ePToF_Inv2Dseq, 1) == osFactor*num)
			Return 0
		Endif
	Endif		
		
	sq_EPToFMakeSequenceInv()
	Wave /I ePToF_seq127 = root:PToF:ePToF_seq127	
	
	//make this an I8 wave as we only have -1, 0 and 1
	//maybe this is unnecessary, I guess I8 is promoted to FP32 upon multiplication with FP32
	Make /O /Y=0x08 /N=(osFactor*num,osfactor*num) root:PToF:ePToF_Inv2Dseq
	Wave /I /Z ePToF_Inv2Dseq = root:PToF:ePToF_Inv2Dseq
	//We need the wave to be mostly zeroes for any oversampling factor > 1
	fastop ePToF_Inv2Dseq = 0
	
	Variable row, col, n
	
	//only fill in the values we need
	For (n=0;n<osFactor;n+=1)
		For (row=0;row<num;row+=1)
			For (col=0;col<num;col+=1)
				ePToF_Inv2Dseq[row*osFactor+n][col*osFactor+n] = ePToF_seq127[mod(osFactor*num-row+col,127)] ? 1 : -1  //1.60X
				//                                                                ^																   |
				//  this offset 2*127 is needed so we don't get negative indices,
				//  the modulo operation takes care that it doesn't make
				//  a difference for indices that wouldn't be negative
				Endfor
		Endfor
	Endfor
	
End


// code by Florian  //1.54A
//Function sq_EPToFFastDeconvolve1D(OneDdata, osFactor, deconvolved1DData)
//	wave OneDdata
//	variable osFactor		// oversampling factor
//	wave deconvolved1DData
//	
////1.59D to speed things up
////	sq_EPToFMake2DSequenceInv(osFactor = OsFactor)
////	Wave /I ePToF_Inv2Dseq = root:PToF:ePToF_Inv2Dseq	// 2D inverse sequence (created in sq_EPToFMake2DSequenceInv)
//	
////	Variable pnts = (numPnts(OneDdata)/osFactor)  // should be 127   //1.59D to speed things up
////
////	if (pnts != 127)
////		abort "The oversampling factor seems to be incorrect.  Value sent to function is "+num2str(osFactor)+" data wants "+num2str(numPnts(OneDdata)/127)+" aborting from sq_EPToFDeconvolve1D"
////	endif	
////	Redimension/N=(numPnts(OneDdata)) deconvolved1DData
//	
//	//deconvolve the data by multiplying 2D inversion matrix with the raw data
//	MatrixOp /O deconvolved1DData = ePToF_Inv2Dseq x OneDdata	
//End


// Does the conversion from  mv*sampling interval (or bits*sampling interval) to mv*ns (or bits*ns)
Function sq_correctSamplingTimeUnit(index_pos,datawav, [nSecMSsamplingIntervalVal])			//1.57K  added optional parameter
	wave datawav, index_pos
	variable nSecMSsamplingIntervalVal	
	
	if (! ParamIsDefault(nSecMSsamplingIntervalVal) && nSecMSsamplingIntervalVal>0)
		multithread datawav*=nSecMSsamplingIntervalVal
	else
	 	wave series_index = root:index:series_index
		wave/z nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.55A
		if (!WaveExists(nSecMSsamplingInterval) ||  !waveMax(nSecMSsamplingInterval) >0 || numpnts(nSecMSsamplingInterval)==0  ) //1.55G
			wave series_index = root:index:series_index
			make/o/n=(numpnts(series_index)) root:diagnostics:nSecMSsamplingInterval=1		// default - old card always at 1ns
			wave nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.55A
		endif
		datawav*=(index_pos[p]<0 ? 0 : nSecMSsamplingInterval[series_index[index_pos[p]]])
	endif
End


//1.55 M  Not used yet.
//Function sq_AMSSize(w,Daero) : FitFunc
//	Wave w
//	Variable Daero
//
//	//CurveFitDialog/ These comments were created by the Curve Fitting dialog. Altering them will
//	//CurveFitDialog/ make the function less convenient to work with in the Curve Fitting dialog.
//	//CurveFitDialog/ Equation:
//	//CurveFitDialog/ f(DAero) = Vgaslens + (Vgasexit - Vgaslens) / (1 + (Daero/Dd)^b)
//	//CurveFitDialog/ End of Equation
//	//CurveFitDialog/ Independent Variables 1
//	//CurveFitDialog/ Daero
//	//CurveFitDialog/ Coefficients 4
//	//CurveFitDialog/ w[0] = Vgaslens
//	//CurveFitDialog/ w[1] = Vgasexit
//	//CurveFitDialog/ w[2] = Dd
//	//CurveFitDialog/ w[3] = b
//
//	return w[0] + (w[1] - w[0]) / (1 + (Daero/w[2])^w[3])
//End


//1.44E
Function sq_Kill_ms_mats()
	string df = GetDataFolder(1)
	SetDataFolder root:ms_mats
	Killwaves/z/a
	SetDataFolder $df
End


//1.55M
Function sq_checkSamplingTimeVals(todo)
wave todo

	make/FREE/n=(0) mymask
	sq_makeMaskFromTodofindRun(mymask,todo)
	
	wave/wave TimeWaves=sq_GetModifiedTimes()
	wave TimeMSOpen = TimeWaves[0]
	wave TimeMSClosed = TimeWaves[1]
	wave TimePToF = TimeWaves[2]

	make/FREE/n=(numpnts(mymask)) myMaskClosed, ClosedModified
	fastop myMaskClosed =TimeMSClosed/mymask

	if (WaveMin(myMaskClosed)<=0)
		killwaves/z samptimeClosedModified

		wavestats/q/m=1 myMaskClosed		//1.56K
		DoWindow/F TimingProblemTable
		if (!V_flag)
			edit/N=TimingProblemTable root:diagnostics:TimeMSOpen, root:diagnostics:TimeMSClosed, root:diagnostics:TimeAcquiringMSOpenInRun, root:diagnostics:TimeAcquiringMSClosedInRun, root:diagnostics:FastKey as "TimingProblemTable"
		endif
		ModifyTable/W=TimingProblemTable selection=(V_minLoc, 0 ,V_minLoc, 0 ,V_minLoc, 0 ), topLeftCell=(V_minLoc , 0)
		abort "There is a problem calculating the errors with the time values in MS open and MS closed.  Aborting from sq_checkSamplingTimeVals"	
	endif

	killwaves/z samptimeClosedModified
	killwaves/z Timewaves

End


//1.60N
Function sq_ChangeFastClosedTime(fm_TimeClosedForErrs)
wave fm_TimeClosedForErrs

	wave/z blacklist = root:blacklist
	if (waveExists(blacklist) && numpnts(blacklist)>0)
		wave all = root:all
		make/free maskwave
		sq_makeMaskFromTodofindRun(maskwave,all)
		fm_TimeClosedForErrs/=maskwave
	endif
	fm_TimeClosedForErrs = fm_TimeClosedForErrs[p]==0 ? nan :  fm_TimeClosedForErrs[p]
	sq_InterpolateWave(fm_TimeClosedForErrs, fm_TimeClosedForErrs, 0)	
	if (waveExists(blacklist) && numpnts(blacklist)>0)
		fm_TimeClosedForErrs/=maskwave
	endif
End


//1.59F
// a function to generate or retrieve 'modified time' waves
// these waves are needed when one wants to user MS closed when 
// closed wasn't measured due to fastopen or ePToF only runs.
// purposes include averaging in the run dimension and
// generating errors.
// Generates two waves if they don't already exist:
// root:diagnostics:fastSamptimeClosedModified
// root:diagnostics:ePToFSampTimeClosedModified
Function/wave sq_GetModifiedTimes()

	wave/z ePToF_enabled=root:diagnostics:ePToF_enabled 
	wave/z FastKey =  root:diagnostics:FastKey		

	wave/z TimeMSOpen=root:diagnostics:TimeAcquiringMSOpenInRun	// root:diagnostics:TimeMSOpen		// 1.48E		//1.53N
	if (!WaveExists(TimeMSOpen) || ! (waveMax(TimeMSOpen) >=0))		//1.55B
		wave TimeMSOpen=root:diagnostics:TimeMSOpen		// 1.48E		//1.53N
	endif

	wave/z TimePToF=root:diagnostics:TimeAcquiringPToFInRun // root:diagnostics:TimePToFSec		// 1.48E		//1.53N
	if (!WaveExists(TimePToF)  ||  ! (waveMax(TimePToF) >=0))  	//1.55B
		wave TimePToF=root:diagnostics:TimePToFSec		// 1.48E		//1.53N
	endif

	wave/z TimeMSClosed=root:diagnostics:TimeAcquiringMSClosedInRun  
	if (!WaveExists(TimeMSClosed)  ||  ! (waveMax(TimeMSClosed) >=0)) 
		wave TimeMSClosed=root:diagnostics:TimeMSClosed	
	endif

	// if we have fast mode data
	if (waveExists(FastKey) && waveMax(FastKey)>=1)	
		wave/z fm_TimeClosedForErrs=root:diagnostics:fm_TimeClosedForErrs   //1.61F 
		if (waveExists(fm_TimeClosedForErrs) && numpnts(fm_TimeClosedForErrs) == numpnts(FastKey) )
			TimeMSClosed = fm_TimeClosedForErrs
		endif			
		duplicate/o TimeMSClosed root:diagnostics:fastsamptimeClosedModified/wave=fastsamptimeClosedModified
			sq_ChangeFastClosedTime(fastsamptimeClosedModified)
//		wave/z fastSamptimeClosedModified = root:diagnostics:fastSamptimeClosedModified
//		if (!WaveExists(fastSamptimeClosedModified) )
//			wave/z fm_TimeClosedForErrs = root:diagnostics:fm_TimeClosedForErrs		//1.60N	// possibly generated in fm_SaveTimeAvg if averaged spectra
////			wave FastModeAvgTimeSec=root:diagnostics:FastModeAvgTimeSec 
//			duplicate/o TimeMSClosed root:diagnostics:fastsamptimeClosedModified/wave=fastsamptimeClosedModified
//			fm_ChangeFastClosedTimeInFastO(fastsamptimeClosedModified, FastKey)			
////			if (!WaveExists(fm_TimeClosedForErrs))
////				fastsamptimeClosedModified = (FastKey[p]==0 && TimeMSClosed[p]== 0) ? FastModeAvgTimeSec[p] : TimeMSClosed[p]
////			else
////				fastsamptimeClosedModified = (FastKey[p]==0 && TimeMSClosed[p]== 0) ? max(fm_TimeClosedForErrs[p], FastModeAvgTimeSec[p]) : TimeMSClosed[p]
////			endif			
//		endif
		wave TimeMSClosed = fastSamptimeClosedModified	
	endif
	// if we have ePToF data
	if (waveExists(ePToF_enabled) && waveMax(ePToF_enabled)>=1)		// for cases where we have ePToF and no MS closed
		duplicate/o TimeMSClosed root:diagnostics:ePToFSampTimeClosedModified/wave=ePToFSampTimeClosedModified
		sq_ChangeFastClosedTime(ePToFSampTimeClosedModified)
//		wave/z ePToFsamptimeClosedModified = root:diagnostics:ePToFSampTimeClosedModified
//		if (!WaveExists(ePToFsamptimeClosedModified))
//			wave/z TimePToF =root:diagnostics:TimeAcquiringPToFInRun 
//			if (!WaveExists(TimePToF) )  	
//				wave/z TimePToF=root:diagnostics:TimePToFSec	
//			endif
//			duplicate/o TimeMSClosed root:diagnostics:ePToFsamptimeClosedModified/wave=ePToFsamptimeClosedModified
//			ePToFsamptimeClosedModified = (ePToF_enabled[p]==1 && TimeMSClosed[p]== 0) ? TimePToF[p] : TimeMSClosed[p]
//		endif
		wave TimeMSClosed = ePToFsamptimeClosedModified
	endif		
		
	make/o/wave TimeWaves
	TimeWaves[0] = TimeMSOpen
	TimeWaves[1] = TimeMSClosed
	TimeWaves[2] = TimePToF
	return TimeWaves
End


//1.59
Function/wave sq_GetDAQTimes()

	wave/z TimeMSOpen=root:diagnostics:TimeAcquiringMSOpenInRun	
	wave/z TimeMSClosed=root:diagnostics:TimeAcquiringMSClosedInRun
	if (!WaveExists(TimeMSOpen) || waveMax(TimeMSOpen)<0)
		wave/z TimeMSOpen=root:diagnostics:TimeMSOpen	
	endif
	wave/z TimeMSClosed=root:diagnostics:TimeAcquiringMSClosedInRun
	if (!WaveExists(TimeMSClosed)  || waveMax(TimeMSClosed)<0)
		wave/z TimeMSClosed=root:diagnostics:TimeMSClosed
	endif
	wave/z TimePToF=root:diagnostics:TimeAcquiringPToFInRun
	if (!WaveExists(TimePToF)  || waveMax(TimePToF)<0)
		wave/z TimePToF=root:diagnostics:TimePToFSec
	endif

	make/o/free/wave TimeWaves
	TimeWaves[0] = TimeMSOpen
	TimeWaves[1] = TimeMSClosed
	TimeWaves[2] = TimePToF
	return TimeWaves

End


//1.55L
Function/s PToFDataSetForMS_returnMaxCol(dataStr)
string dataStr
// variable ms0_dataType

	string datastrlist
	variable var
	
	wave/z/t PToFDataSetNames =  root:PToF:SPToFDataSetNames
	wave/i PToFDataSetMaxmz= root:PToF:SPToFDataSetMaxmz
	if (!WaveExists(PToFDataSetNames) || !WaveExists(PToFDataSetMaxmz))
		abort "There is something wrong with the selection of the data set  Aborting from PToFDataSetForMS_returnMaxCol"
	else	
		var = sq_findStr(PToFDataSetNames,ReplaceString("SPToF", dataStr, ""),1) 	// exact match
		if (var<0)
			abort "There is something wrong with the selection of the data set  Aborting from PToFDataSetForMS_returnMaxCol"
		endif
		return num2str(PToFDataSetMaxmz[var])		//1.57C
	endif
	
end


//1.57C This was named PToF_updateMSStickList
Function sq_updateMSLists()

	nvar/z ePToFExists = root:diagnostics:ePToFExists
	//1.14K 
	string/g root:panel:MSStickList ="Diff;Open;Closed;"
	string/g root:panel:MSStickDataList = "MSSDiff_p;MSSOpen_p;MSSClosed_p;"
	string/g root:panel:MSRawList ="Diff;Open;Closed;"
	string/g root:panel:MSTimeAvgList ="3;1;2;"
	string/g root:panel:MSPrefixList ="D;O;C;"

	svar MSStickList = root:panel:MSStickList
	svar MSStickDataList = root:panel:MSStickDataList
	svar MSRawList = root:panel:MSRawList
	svar MSTimeAvgList = root:panel:MSTimeAvgList
	svar MSPrefixList = root:panel:MSPrefixList

	wave/t/z data_index =  root:index:data_index
	if (!WaveExists(data_index))
		return 0	
	endif
	MSStickList=""
	MSStickDataList=""
	MSRawList=""
	MSTimeAvgList=""
	MSPrefixList=""
	
	variable OpenBool, ClosedBool, DiffBool, PToFBool
	variable idex, num, rawFlag
	string str
	OpenBool = sq_findStr(data_index,"MSOpen",0)>=0		// 2 = match part
	ClosedBool = sq_findStr(data_index,"MSClosed",0)>=0
	DiffBool = sq_findStr(data_index,"MSSDiff",0)>=0
	PToFBool = sq_findStr(data_index,"ePToFSum",0)>=0
	
	if (DiffBool)
		MSStickList+= "Diff;"
		MSStickDataList += "MSSDiff_p;"
		MSRawList+= "MSDiff_p;"
		MSTimeAvgList+= "3;"		// t_step=TimeMSOpen[p1]+TimeMSClosed[p1]
		MSPrefixList += "D;"
	endif
	if (OpenBool)
		MSStickList+= "Open;"
		MSStickDataList += "MSSOpen_p;"
		MSRawList+= "MSOpen_p;"
		MSTimeAvgList+= "1;"		// TimeMSOpen[p1]
		MSPrefixList += "O;"
	endif
	if (ClosedBool)
		MSStickList+= "Closed;"
		MSStickDataList += "MSSClosed_p;"
		MSRawList+= "MSClosed_p;"
		MSTimeAvgList+= "2;"		// TimeMSClosed[p1]
		MSPrefixList += "C;"
	endif
	if (PToFBool && NVar_exists(ePToFExists) && ePToFExists )
		MSStickList+= "ePToFSum;ePToFSumDiff;"
		MSStickDataList += "MSSePToFSum_p;MSSePToFSumDiff_p;"
		rawFlag = sq_findStr(data_index,"MSePToFSum",0)>=0
		
		if (rawFlag)
			MSRawList+= "MSePToFSum_p;MSePToFSumDiff_p;"
		else
			MSRawList+= ";;"
		endif
		MSTimeAvgList+= "4;4;"		// TimePToFSec[p1]
		MSPrefixList += "s;f;"		// sum ePToF, f = diff of sum ePTOF
	endif
//	The exceptions are for Fast mode data.  Then we use t_step=FastModeAvgTimeSec[p1]
// and for ePToFSumDiff MSSePToFSumDiff_p	
//  ptof_stick_v and ptof
	
	wave/t/z PToFDataSetNames =  root:PToF:PToFDataSetNames  //1.21G
	if (WaveExists(PToFDataSetNames))
//		for(idex=0;idex<numpnts(PToFDataSetNames);idex+=1)
//			MSStickList+=PToFDataSetNames[idex]+";"
//			MSStickDataList +=  "SPToF_"+PToFDataSetNames[idex]+";"
//			MSRawList+= "PToF_"+PToFDataSetNames[idex]+";"
//			MSTimeAvgList+= "4;"		// TimePToFSec[p1]
//			MSPrefixList += num2str(idex)+";"  // 1.21G
//		endfor
	endif
		
	if (strlen(WinList("Ams_panel", ";", ""))>0 )
		nvar ms0_dataType = root:panel:ms0_dataType
		PopupMenu ms0_dataType,mode=1,popvalue=stringFromList(ms0_dataType-1,MSStickList), value= #"root:panel:MSStickList", win = ams_panel
	endif

End


//1.55L for issues with fast mode found by Ed and old versions of DAQ
Function sq_FixFastModeTimesDAQ34()

	wave FastKey = root:diagnostics:FastKey
	wave FastModeAvgTimeSec = root:diagnostics:FastModeAvgTimeSec
	wave TimeAcquiringMSOpenInRun = root:diagnostics:TimeAcquiringMSOpenInRun
	wave TimeAcquiringMSClosedInRun = root:diagnostics:TimeAcquiringMSClosedInRun
	
	make/free/o/n=(numpnts(FastKey)) tempKey
	make/free/o/n=(numpnts(FastKey)) tempSum
	
	tempSum = TimeAcquiringMSOpenInRun+TimeAcquiringMSClosedInRun
	
	tempKey = FastKey[p]>=0 && tempSum[p] !=FastModeAvgTimeSec[p]
	
	if (sum(tempKey) !=0)		// we have problems.
		TimeAcquiringMSClosedInRun = FastKey[p] == 2 ? FastModeAvgTimeSec[p] : TimeAcquiringMSClosedInRun[p]
		TimeAcquiringMSOpenInRun = FastKey[p] == 0 ? FastModeAvgTimeSec[p] : TimeAcquiringMSOpenInRun[p]
	endif
	
//	sq_makeTodoallMS()

End


Function sq_ePToF_SetDeconvolveType(run)
variable run

	nvar/z deconvolveMike = root:panel:deconvolveMike
	if (!Nvar_exists(deconvolveMike))
		variable/g root:panel:deconvolveMike
		nvar deconvolveMike = root:panel:deconvolveMike
	endif	
	nvar deconvolveJoel = root:diagnostics:deconvolveJoel
	nvar deconvolve = root:diagnostics:deconvolve
	nvar ePToF_postmatrixInvDC = root:diagnostics:ePToF_postmatrixInvDC
	ePToF_postmatrixInvDC=1
	
	if (! sq_doesPToFDataExist(run))
		return nan
	elseif(! sq_isRunePToF(run))
		return -1
	elseif (deconvolveJoel)
		return 1 + ePToF_postmatrixInvDC
	elseif (deconvolveMike)
		return 3
//	elseif(deconvolve)
//		return 4 + ePToF_demux_adaptiveDenoise
	else		// do not deconvolve
		return 0
	endif	
	
End

	
Function sq_isRunePToF(run)
variable run
	
	variable pos
	wave/z ePToF_oversampling = root:diagnostics:ePToF_oversampling
	wave/z ePToF_enabled = root:diagnostics:ePToF_enabled
	if ( WaveExists(ePToF_oversampling) && WaveExists(ePToF_enabled)   )  
		wave rn_series = root:index:rn_series
		pos = sq_findRun(rn_series,run)
		return ePToF_enabled[pos]
	endif
	return 0
		
End


//1.57C
Function/wave sq_FindAdjacentRunsWithNoData(todowave, dataStr)
wave/i todowave
string dataStr

	wave squirrel_index = root:index:squirrel_index
	wave series_index = root:index:series_index
	wave rn_series = root:index:rn_series 
	variable idex, num, var,first, last, runFirst, runLast
	string firstStr, lastStr
	
	var = FindDimLabel(squirrel_index, 2, dataStr)
	if (var<0)
		abort "Could not find the data set "+dataStr+" in the squirrel_index.  Aborting from FindAdjacentRunsWithNoDataSet"
	endif
	
	num =dimsize(squirrel_index,0)
	
	make/free/o/n=(num)  DataSetCol0_index, DataSetCol0_series
	
	make/o/n=0 AdjacentMStodo
	
	make/o todowavemask
	
	sq_makeMaskFromTodofindRun(todowavemask,todowave)
	
	DataSetCol0_index = squirrel_index[p][0][var]
	
	for(idex=0;idex<num;idex+=1)		//1.60C
		DataSetCol0_series[series_index[idex]] = DataSetCol0_index[idex]
	endfor  // MSSClosedCol0
// 	DataSetCol0_series = series_index[DataSetCol0_index[p]]
	// MSSClosedCol0
	
	DataSetCol0_series = DataSetCol0_series[p] >0 ? 1 : nan
	
	for(idex=0;idex<num;idex+=1)
		if (todowavemask[idex] == 1)		// run in todo wave
			Last = gen_FindLast(DataSetCol0_series, idex)
			First = gen_FindFirst(DataSetCol0_series, idex)
			
			if (First==-1)
				runFirst = rn_series[num-1]
			elseif(first<num)
				runFirst = rn_series[First]
			else		//1.60B
				runFirst=nan
			endif
			if (Last==-1)
				runLast= rn_series[0]
			else
				runLast = rn_series[Last]
			endif
			
			sprintf firstStr, "%u",runFirst
			sprintf lastStr, "%u",runLast
					
			sq_create_todo(firstStr+" or "+lastStr+" or AdjacentMStodo","AdjacentMStodo")
		endif
		
	endfor
	
	killwaves/z todowavemask
	return AdjacentMStodo

End


Function sq_FillInMSClosedPToFOnly(preproc, rawflag)
wave preproc
variable rawFlag
			
	wave AdjacentMStodo =  sq_FindAdjacentRunsWithNoData(preproc, "MSClosed")		// first, enlarge our todo wave to include at least some MS closed runs
	sq_create_todo(NameofWave(preproc) +" or AdjacentMStodo","AdjacentMStodo")		// make sure our original todo runs are included in this todo
	if (rawflag)		//1.20K1
		squirrel_fetch(AdjacentMStodo,sq_FindBlanksFetch,"min_cl:0;max_cl:1","MSClosed_p")		// generates fillblank_todo and fillblank_blanks
	else
		squirrel_fetch(AdjacentMStodo,sq_FindBlanksFetch,"min_cl:0;max_cl:1","MSSClosed_p")		// generates fillblank_todo and fillblank_blanks
	endif
	wave /z/i fillblank_todo,fillblank_blanks
	if (waveexists(fillblank_todo) && numpnts(fillblank_todo)>0)	// april 2014 bug  //1.53M
//		wave/z allFastOpen = root:allFastOpen		/1.60K
//		if (WaveExists(allFastOpen))
//			sq_create_todo("fillblank_todo and not allFastOpen","fillblank_todo")		// make sure our original todo runs are included in this todo
//		endif
		if (rawflag)
			squirrel_fetch(fillblank_todo,sq_fillblanks,"dest:MSClosed_p;fill_id:fillblank_blanks;hz_op:0;","MSClosed_p")
		else
			squirrel_fetch(fillblank_todo,sq_fillblanks,"dest:MSSClosed_p;fill_id:fillblank_blanks;hz_op:0;","MSSClosed_p")
		endif
	endif
	killwaves/z AdjacentMStodo

End


//1.57D
Function sq_ReturnePToFFlags(ePToF_flag, ePToF_OS, numPToFBins, firstRunPos, todo)
variable &ePToF_flag, &ePToF_OS, &numPToFBins, &firstRunPos
wave todo

	wave rn_series = root:index:rn_series
	wave ePToF_enabled = root:diagnostics:ePToF_enabled
	wave ePToF_oversampling = root:diagnostics:ePToF_oversampling
	wave ptofNumSpectraPerChop = root:diagnostics:ptofNumSpectraPerChop

	firstRunPos = sq_findRun(rn_series,todo[0])		//1.53M
	if (ePToF_enabled[firstRunPos]>0  && ePToF_oversampling[firstRunPos]>0 && abs(ePToF_enabled[firstRunPos])>0)		   		//1.55B			
		ePToF_flag = 1
		ePToF_OS = ePToF_oversampling[firstRunPos]
		 if (ePToF_OS<0)
			abort "There seems to be a problem with the ePToF settings for run "+num2istr(todo[0])+" aborting from ReturnePToFFlags"		
		endif
	else
		ePToF_flag = 0
		ePToF_OS = 0
	endif

	numPToFBins = ptofNumSpectraPerChop[firstRunPos]
	
End


Function sq_updatePrefix()

	nvar IntermFilePrefix_ck =  root:panel:IntermFilePrefix_ck
	svar/z IntermPrefixExpFileName = root:panel:IntermPrefixExpFileName
	if (IntermFilePrefix_ck && sVar_Exists(IntermPrefixExpFileName) &&  !stringmatch(IntermPrefixExpFileName, SQUIRREL_PROC_PREF))
		TitleBox load_ShowPrefix, disable = 0
		TitleBox load_FilePrefixTitle, disable = 0
		CheckBox load_FilePrefix, disable=1
	else
		TitleBox load_ShowPrefix, disable = 1
		TitleBox load_FilePrefixTitle, disable = 1
		CheckBox load_FilePrefix, disable=0
	endif
End


//1.57E
Function fm_SaveTimeAvg(index_pos,source,dataname)
	wave index_pos,source
	string dataname

	wave series_index=root:index:series_index	
	wave/z fm_TimeClosedForErrs = root:diagnostics:fm_TimeClosedForErrs
	wave/z FastModeAvgTimeSec = root:diagnostics:FastModeAvgTimeSec

	variable idex, numAcorn, numRuns, currentRunIndex
	numRuns = numpnts(series_index)
	
	if (!WaveExists(fm_TimeClosedForErrs)) 
		wave TimeAcquiringMSClosedInRun = root:diagnostics:TimeAcquiringMSClosedInRun
		wave TimeAcquiringMSOpenInRun = root:diagnostics:TimeAcquiringMSOpenInRun
		make/o/n=(numRuns)  root:diagnostics:fm_TimeClosedForErrs/wave = fm_TimeClosedForErrs
		fastop fm_TimeClosedForErrs = TimeAcquiringMSClosedInRun
	endif
	
	numAcorn = numpnts(index_pos)
	for(idex = 0;idex<numAcorn;idex+=1)
		if (index_pos[idex]>=0)		//1.58G
			currentRunIndex =series_index[index_pos[idex]]
			fm_TimeClosedForErrs[currentRunIndex] = FastModeAvgTimeSec[currentRunIndex]*numAcorn  // number of points we are averaging
		endif
	endfor
End


// commented out in 1.59F  all time changes are now performed in sq_GetModifiedTimes() and fm_SaveTimeAvg
// new in 1.58d
// changes values in fm_TimeClosedForErrs at fast open runs to be equal to the amount of time in the next fast closed cycle
//Function ePToF_ChangeFastClosedTime(ePToF_TimeClosedForErrs, ePToF_enabled, samptimeOpen)
//wave ePToF_TimeClosedForErrs, ePToF_enabled, samptimeOpen
//
//	wave ptofNumSpectraPerChop=root:diagnostics:ptofNumSpectraPerChop
//	ePToF_TimeClosedForErrs = (ePToF_enabled[p]>0) && ptofNumSpectraPerChop[p]>0 ? nan : ePToF_TimeClosedForErrs[p]
//	sq_InterpolateWave(ePToF_TimeClosedForErrs, ePToF_TimeClosedForErrs, 0)	
//End


// commented out in 1.59F all time changes are now performed in sq_GetModifiedTimes()
// changes values in fm_TimeClosedForErrs at fast open runs to be equal to the amount of time in the next fast closed cycle
//Function fm_ChangeFastClosedTimeInFastO(fm_TimeClosedForErrs, FastKey)
//wave fm_TimeClosedForErrs, FastKey
//
////	fm_TimeClosedForErrs = FastKey[p] = 0 ? nan : fm_TimeClosedForErrs[p]	
//	wave rn_series =  root:index:rn_series
//	wave FMS_EndRuns =  root:index:FMS_EndRuns
//	wave FMS_StartRuns =  root:index:FMS_StartRuns 
//	wave FastClosedCycles =  root:index:FMS_ClosedCycles		// 4 columns: startRun, Run position, endRun, enRunPos
//	wave FastModeAvgTimeSec = root:diagnostics:FastModeAvgTimeSec
//
//	wave/z blacklist = root:blacklist
//	
//	variable idex, num, pos, run
//	variable numClosedCycles=dimsize(FastClosedCycles,0)
//	
//	num = numpnts(fm_TimeClosedForErrs)
//	make/o/n=(num)  maskwave
////	make/o/n=(num) /free FMSClosedStartRun = FastClosedCycles[][0] 
//	make/o/n=(numClosedCycles) /free FMSClosedStartPos = FastClosedCycles[p][1] 
////	make/o/n=(num) /free FMSClosedStopRun = FastClosedCycles[][2] 
//	make/o/n=(numClosedCycles) /free FMSClosedStopPos = FastClosedCycles[p][3] 
//	
//	duplicate/o/free FastModeAvgTimeSec FastModeTime
//
//	if (waveExists(blacklist) && numpnts(blacklist)>0)
//		sq_makeMaskFromTodofindRun(maskwave,blacklist)
//		blacklist = blacklist[p]==1 ? 1 : 0		// turns nans into 0s
//		duplicate/o/free FastModeAvgTimeSec FastModeTime
//		FastModeTime*=blacklist
//	endif
//
//	for(idex=0;idex<numClosedCycles-1;idex+=1)
//		fm_TimeClosedForErrs[FMSClosedStopPos[idex],FMSClosedStartPos[idex+1]] = fm_TimeClosedForErrs[FMSClosedStopPos[idex]]
//	endfor
//	fm_TimeClosedForErrs[FMSClosedStopPos[numClosedCycles-1],] = fm_TimeClosedForErrs[FMSClosedStopPos[numClosedCycles-2]]
//	
//	killwaves/z maskwave
//
//End


Function sq_populate_ePTOFDCMarkerGr()

	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:panel:
	wave  PToF_DCgr_regionY, PToF_DCgr_displayX, PToF_DCgr_displayY, PToF_DCgr_oneMz
	
	AppendToGraph/R PToF_DCgr_regionY vs PToF_DCgr_displayX
	AppendToGraph/R PToF_DCgr_displayY vs PToF_DCgr_displayX
	AppendToGraph PToF_DCgr_oneMz vs PToF_DCgr_displayX
	SetDataFolder fldrSav0
	ModifyGraph mode(PToF_DCgr_regionY)=7,mode(PToF_DCgr_displayY)=1,mode(PToF_DCgr_oneMz)=4
	ModifyGraph lSize(PToF_DCgr_displayY)=2
	ModifyGraph rgb(PToF_DCgr_regionY)=(52224,52224,0),rgb(PToF_DCgr_displayY)=(0,0,0)
	ModifyGraph rgb(PToF_DCgr_oneMz)=(52224,17408,0)	
	ModifyGraph hbFill(PToF_DCgr_regionY)=5

	ModifyGraph tick(right)=3
	ModifyGraph zero(left)=1
	ModifyGraph nticks(right)=0,nticks(bottom)=9	
	ModifyGraph minor(bottom)=1
	ModifyGraph margin(right)=7
	ModifyGraph marker(PToF_DCgr_oneMz)=8
	Label bottom "PToF bins in time, s"
	Label left "PToF sticks, dS/dPToF (Hz)\rChopper ignored"
	SetAxis/A/E=0 left
	SetAxis/A/E=3 bottom
	ShowInfo
	Legend/C/N=text1/J/X=0.62/Y=-0.63 "\\s(PToF_DCgr_displayY) 10, 100, 1000nm\r\\s(PToF_DCgr_regionY) PToF_DCgr_regionY"
//	AppendText "\\s(PToF_DCgr_confidLim) PToF_DCgr_confidLim"
	ShowTools/A
	SetDataFolder $fldrSav0
End


Function ePToF_PrefilterGr()
	PauseUpdate; Silent 1		// building window...
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:panel:
	wave DCgr_demuxPrefilterYwave, DCgr_demuxPrefilterXwave,DCgr_demuxPrefilterYpt,DCgr_demuxPrefilterXpt
	AppendToGraph/L=PrefilterLeft/B=prefilterBottom DCgr_demuxPrefilterYwave vs DCgr_demuxPrefilterXwave
	AppendToGraph/L=PrefilterLeft/B=prefilterBottom DCgr_demuxPrefilterYpt vs DCgr_demuxPrefilterXpt
	SetDataFolder fldrSav0
	ModifyGraph margin(left)=32,margin(bottom)=32,margin(top)=4,margin(right)=4
	ModifyGraph mode(DCgr_demuxPrefilterYwave)=7,mode(DCgr_demuxPrefilterYpt)=3
	ModifyGraph marker(DCgr_demuxPrefilterYpt)=8
	ModifyGraph rgb(DCgr_demuxPrefilterYwave)=(0,39168,0),rgb(DCgr_demuxPrefilterYpt)=(0,0,0)
	ModifyGraph hbFill(DCgr_demuxPrefilterYwave)=5
	ModifyGraph useNegPat(DCgr_demuxPrefilterYwave)=1
	ModifyGraph hBarNegFill(DCgr_demuxPrefilterYwave)=5
	ModifyGraph lblPos=32
	ModifyGraph lblLatPos(PrefilterLeft)=1,lblLatPos(prefilterBottom)=-8
	ModifyGraph freePos(PrefilterLeft)={0,prefilterBottom}
	ModifyGraph freePos(prefilterBottom)={0,PrefilterLeft}
	Label PrefilterLeft "Smooth scalar"
	Label prefilterBottom "Max Peak/ECL"
End


Function sq_nSecMSsamplingIntervalConst()

	variable Val
	wave/z nSecMSsamplingInterval =  root:diagnostics:nSecMSsamplingInterval		//1.55A
	wave/z series_index =  root:index:series_index	
	
	if (!WaveExists(nSecMSsamplingInterval) ||  !waveMax(nSecMSsamplingInterval) >0 ) //1.55G
		make/o/n=(numpnts(series_index)) root:diagnostics:nSecMSsamplingInterval=1		// default - old card always at 1ns
		return 1
	else
		Val = WaveMin(nSecMSsamplingInterval)
		if (Val == WaveMax(nSecMSsamplingInterval) )
			return Val
		else
			return nan					
		endif
	endif
	
End


Function sq_createTableTimeWaves()

	string df = GetDataFolder(1)
	SetDataFolder root:diagnostics
	string wlist = WaveList("*time*", ";", "DIMS:1" )
	variable idex
	Edit root:index:t_series, root:index:rn_series as "TimeTable"		//1.59A
	for (idex=0;idex<itemsInList(wlist);idex+=1)
		appendtotable $stringFromList(idex, wlist, ";")
	endfor
	SetDataFolder df
End


Function sq_TodoHasPToF(todo, [PToFFlag])
wave todo
variable PToFFlag

	wave/z allPToF = root:allPToF
	wave/z ePToF_oversampling = root:diagnostics:ePToF_oversampling
	wave/z ePToF_enabled =  root:diagnostics:ePToF_enabled
	wave/z ptofNumTimesThrough = root:diagnostics:ptofNumTimesThrough

	if (!WaveExists(allPToF) || numpnts(allPToF)==0 )
		return 0
	endif
	
	make/free/o/n=(numpnts(ePToF_enabled)) mask
	sq_makeMaskFromTodofindRun(mask,todo)	

	if (ParamIsDefault(PToFFlag))
		mask *= (ptofNumTimesThrough[p]>0)	
	elseif (PToFFlag)
		mask *= (ptofNumTimesThrough[p]>0) * (ePToF_enabled[p]==0)  // * (ePToF_oversampling[p]<=0) 		// joel doesn't change ePToF_oversampling for regular PToF
	else		// ePToF
		mask *= (ptofNumTimesThrough[p]>0) * (ePToF_enabled[p]==1) * (ePToF_oversampling[p]>0)
	endif
	
	return WaveMax(mask)>0		
	
End


Function sq_PToFePToF_Tool() 

	DoWindow/F PToFePToF_Tool
	if (V_flag)
		return 0
	endif

	nvar/z ePToFExists = root:diagnostics:ePToFExists
	variable ePToFFlag = NVar_exists(ePToFExists) && ePToFExists

	variable Voffset, ePToFOffset
	PauseUpdate; Silent 1		// building window...
	NewPanel/N=PToFePToF_Tool /W=(175,95,895,615+ePToFFlag*120) as "PToFePToF_Tool"
	ShowTools/A
	SetDrawLayer UserBack
	SetDrawEnv fsize= 14,fstyle= 1
	DrawText 3,20,"PToF and ePToF Preview and Parameter Setting Tool"
	TitleBox PToFINtro pos={5,18},variable=root:panel:PToFInfo,frame=0, fsize=10

	GroupBox DCgr_rungroup,pos={5,141},size={342,70},title="Info for current run or todo"
	TitleBox DCgr_NumTimesThruPToF,pos={160,96},size={26,13},fSize=10,frame=0
	TitleBox DCgr_NumTimesThruPToF,variable= root:panel:PToF_DCgr_RunInfo
	SetVariable DCgr_RunNumber,pos={28,96},size={130,16},proc=sq_PToF_DCGr_setVar_Run,title="Run number"
	SetVariable DCgr_RunNumber,fSize=10,format="%g"
	SetVariable DCgr_RunNumber,value=root:panel:PToF_DCgr_runNumber
	PopupMenu ams_todolist_pop,pos={28,116},size={148,21},bodyWidth=120,proc=sq_PToFDC_PopMenuProc,title="Todo"
	PopupMenu ams_todolist_pop,fSize=10,size={145.00,19.00}
	PopupMenu ams_todolist_pop,mode=8,popvalue="select",value= #"root:panel:sq_toDoList+\"Get List;\"\t"
	Button DCgr_prev_runNumber,pos={247,93},size={100,20},fsize=10,proc=sq_PrevNextInTodoButtonProc,title="Quick prev in todo"
	Button DCgr_next_runNumber,pos={247,115},size={100,20},fsize=10,proc=sq_PrevNextInTodoButtonProc,title="Quick next in todo"
	CheckBox DCgr_SingleRun,pos={10,97},size={16,14},proc=sq_ck_PToF_SingleRunTodo,title=""
	CheckBox DCgr_SingleRun,value= 0,mode=1
	CheckBox DCgr_Todo,pos={10,118},size={16,14},proc=sq_ck_PToF_SingleRunTodo,title=""
	CheckBox DCgr_Todo,value= 1,mode=1

	ValDisplay DCgr_tstep,pos={10,192},size={138,14},bodyWidth=65,title="PToF t step (s)"
	ValDisplay DCgr_tstep,fSize=10,format="%1.4e",limits={0,0,0},barmisc={0,1000},disable=2
	ValDisplay DCgr_tstep,value= #"root:panel:PToF_DCgr_tstep"
	ValDisplay DCgr_numBins,pos={226,174},size={100,14},title="# of PToF bins"
	ValDisplay DCgr_numBins,fSize=10,format="%g",limits={0,0,0},barmisc={0,1000},disable=2
	ValDisplay DCgr_numBins,value= #"root:panel:PToF_DCgr_numBins"
	ValDisplay DCgr_minMz,pos={148,175},size={75,14},title="Min m/z",fSize=10
	ValDisplay DCgr_minMz,format="%g",limits={0,0,0},barmisc={0,1000},disable=2
	ValDisplay DCgr_minMz,value= #"root:panel:PToF_DCgr_minMz"
	ValDisplay DCgr_maxMz,pos={148,193},size={75,14},title="Max m/z",fSize=10
	ValDisplay DCgr_maxMz,format="%g",limits={0,0,0},barmisc={0,1000},disable=2
	ValDisplay DCgr_maxMz,value= #"root:panel:PToF_DCgr_maxMz"
	ValDisplay DCgr_DurationOfPToF,pos={224,191},size={120,14},fsize=10,title="PToF duration (s)"
	ValDisplay DCgr_DurationOfPToF,format="%0.3f",fStyle=0
	ValDisplay DCgr_DurationOfPToF,limits={0,0,0},barmisc={0,1000},disable=2
	ValDisplay DCgr_DurationOfPToF,value= #"root:panel:PToF_DCMarkerDuration"
	ValDisplay DCgr_ePToF_OSSetting,pos={10,156},size={230,14},title="ePToF oversampling (nan for non ePToF)"
	ValDisplay DCgr_ePToF_OSSetting,limits={0,0,0},barmisc={0,1000},disable=2, fsize=10
	ValDisplay DCgr_ePToF_OSSetting,value= #"root:panel:PToF_ePToF_Mulitplier"
	TitleBox DCgr_step1Info,pos={5,80},size={158,43},fSize=12,frame=0,fStyle=1
	TitleBox DCgr_step1Info,variable= root:panel:PToF_DCgr_Info2
	ValDisplay DCgr_t0,pos={10,173},size={121,44},bodyWidth=65,disable=2,title="PToF t0 (s)"
	ValDisplay DCgr_t0,fSize=10,format="%1.4e",limits={0,0,0},barmisc={0,1000},disable=2
	ValDisplay DCgr_t0,value= #"root:panel:PToF_DCgr_t0"

	sq_PToF_panelsection()

	if (ePToFFLag)
		ePToFOffset=215
		sq_ePToF_panelSection(ePToFOffset)
		Voffset=340
	else
		Voffset=220
	endif
	
	sq_PToF_calcsection(Voffset)
End


Function sq_PToF_panelsection()

	TitleBox PToF_step1a,pos={359.00,93.00},size={237.00,15.00},fSize=12,frame=0
	TitleBox PToF_step1a,fStyle=0,variable= root:panel:DCgr_PToF_step1
	GroupBox PToF_group,pos={355.00,79.00},size={355.00,134.00},title="DC marker settings for single slit PToF"
	CheckBox PToF_BinUnits_ck,pos={363.00,127.00},size={263.00,13.00},title="Use PToF bin # as units - if unchecked, s units are used"
	CheckBox PToF_BinUnits_ck,fSize=10,variable= root:panel:ptof_dcUseBinNumUnits

	SetVariable PToF_cor3_dc1,pos={362.00,142.00},size={94.00,15.00},bodyWidth=30,title="Region 1 start"
	SetVariable PToF_cor3_dc1,help={"Position of DC marker 1 (begin region 1)"}
	SetVariable PToF_cor3_dc1,fSize=10
	SetVariable PToF_cor3_dc1,limits={0,inf,0},value= root:panel:cor3_dcMarker1
	SetVariable PToF_cor3_dc2,pos={361.00,158.00},size={95.00,15.00},bodyWidth=30,title="Region 1 stop"
	SetVariable PToF_cor3_dc2,help={"Position of DC marker 2 (end region 1)"}
	SetVariable PToF_cor3_dc2,fSize=10
	SetVariable PToF_cor3_dc2,limits={0,inf,0},value= root:panel:cor3_dcMarker2
	SetVariable PToF_cor3_dc3,pos={461.00,142.00},size={94.00,15.00},bodyWidth=30,title="Region 2 start"
	SetVariable PToF_cor3_dc3,help={"Position of DC marker 3 (begin region 2)"}
	SetVariable PToF_cor3_dc3,fSize=10
	SetVariable PToF_cor3_dc3,limits={-inf,inf,0},value= root:panel:cor3_dcMarker3
	SetVariable PToF_cor3_dc4,pos={460.00,159.00},size={95.00,15.00},bodyWidth=30,title="Region 2 stop"
	SetVariable PToF_cor3_dc4,help={"Position of DC marker 4 (end region 2)"}
	SetVariable PToF_cor3_dc4,fSize=10
	SetVariable PToF_cor3_dc4,limits={-inf,inf,0},value= root:panel:cor3_dcMarker4
	Button PToF_buttonUpdate,pos={636.00,126.00},size={70.00,18.00},proc=sq_PToF_DCGr_butt_plotDC,title="Plot Regions"
	Button PToF_buttonUpdate,fSize=10
	TitleBox PToF_Help,pos={360.00,111.00},size={335.00,12.00},fSize=10,frame=0
	TitleBox PToF_Help,fStyle=0,variable= root:panel:PTof_DC_gr_info
	SetVariable cor3_region1OnlyMz,pos={360.00,179.00},size={285.00,15.00},bodyWidth=195,title="Region 1 only m/zs"
	SetVariable cor3_region1OnlyMz,help={"m/z channels that only use DC region 1 in PToF mode."}, proc=sq_PToFRegion1UserOption		//1.59E
	SetVariable cor3_region1OnlyMz,fSize=10,value= root:panel:cor3_region1channels
	SetVariable cor3_region2OnlyMz,pos={360.00,195.00},size={285.00,15.00},bodyWidth=195,title="Region 2 only m/zs"
	SetVariable cor3_region2OnlyMz,help={"m/z channels that only use DC region 2 in PToF mode."}
	SetVariable cor3_region2OnlyMz,fSize=10,value= root:panel:cor3_region2channels
	CheckBox PToF_Region1OnlyMzs,pos={572.00,148.00},size={132.00,24.00},proc=sq_PToF_Region1Check,title="Use Region 1 only for all\rm/zs not in Region 2 only."
	CheckBox PToF_Region1OnlyMzs,fSize=10,variable= root:panel:ptof_dcRegion1Allnot2
End


//1.59A
Function sq_PToFRegion1UserOption(sva) : SetVariableControl
	STRUCT WMSetVariableAction &sva

	switch( sva.eventCode )
		case 1: // mouse up
		case 2: // Enter key
		case 3: // Live update
			Variable dval = sva.dval
			String sval = sva.sval
			nvar ptof_dcRegion1Allnot2 = root:panel:ptof_dcRegion1Allnot2		//1.59E
			ptof_dcRegion1Allnot2=0
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


Function sq_PToF_calcsection(Voffset)
variable Voffset

	SetVariable DCgr_setvarMz,pos={450,Voffset},size={189,16},bodyWidth=50,proc=sq_PToF_DCGr_SetVar_mz,title="Step 3. Display this m/z"
	SetVariable DCgr_setvarMz,fSize=12,fStyle=1,value= root:panel:PToF_DCgr_mzChoice
	Button DCgr_Calculate,pos={4,Voffset},size={410,20},proc=DC_RecalcDeconvlButtonProc,title="Step 2. Calculate or recalculate all m/z for run or todo with Step 1. settings"
	Button DCgr_Calculate,fColor=(65280,43520,0)
	Display/W=(5,25+Voffset,710,300+Voffset)/HOST=# 
	RenameWindow #,DCMarkerGr	
	sq_populate_ePTOFDCMarkerGr() 
	SetActiveSubwindow ##
End


Function sq_ePToF_panelsection(ePToFOffset)
variable ePToFOffset

	GroupBox ePToF_group,pos={5,1+ePToFOffset},size={705,125}
	
	TitleBox ePToF_step1,pos={10,3+ePToFOffset},size={246,13},fSize=12,frame=0,fStyle=1
	TitleBox ePToF_step1,variable=root:panel:DCgr_ePToF_step1

	CheckBox ePToF_DeconvolveNone,pos={10,21+ePToFOffset},size={102,14},proc=sq_DeconvolveCheckProc,title="Don't deconvolve"
	CheckBox ePToF_DeconvolveNone,fSize=12,variable= root:panel:deconvolveNone,mode=1
	CheckBox ePToF_DeconvolveJoel,pos={10,38+ePToFOffset},size={124,14},proc=sq_DeconvolveCheckProc,title="Simple matrix inversion"
	CheckBox ePToF_DeconvolveJoel,fSize=12,variable= root:panel:deconvolveJoel,mode=1
	CheckBox ePToF_DeconvolveMike,pos={10,86+ePToFOffset},size={307,14},proc=sq_DeconvolveCheckProc,title="Tofwerk deconvolution (different smoothings for different m/zs)"
	CheckBox ePToF_DeconvolveMike,fSize=12,variable= root:panel:deconvolveMike,mode=1
	SetVariable ePToF_smoothSetVar,pos={25,54+ePToFOffset},size={460,15},bodyWidth=50,title="Lo pass filter then smooth by this factor (<1 mean no filtering smoothing, applied to all m/z)"
	SetVariable ePToF_smoothSetVar,limits={-1,500,1},value= root:panel:DCgr_smoothVar, fsize=10
	SetVariable ePToF_TestRegionSetvar,pos={25,70+ePToFOffset},size={351,15},bodyWidth=50,title="Baseline (BL) region (fraction of ending bins which should be noise)"
	SetVariable ePToF_TestRegionSetvar,limits={0,1,0.01},value= root:panel:PToF_ePToF_TestRegion, fsize=10
	CheckBox ePToF_SumDiffScal,pos={25,106+ePToFOffset},size={310,14},title="ePToFSumDiff Scaling (scaling will happen during preprocess & is not shown here)"
	CheckBox ePToF_SumDiffScal,fSize=10,variable= root:panel:PToF_DCgr_ePToFSumDiffScaling

	Button TWbutt_TWEPToF_Gr,pos={380,10+ePToFOffset},size={320,20},proc=TW_grButtonProc,title="Details of Tofwerk deconvolution of DAQ sticks, one run or todo"
	Button TWbutt_TWEPToF_Gr,fSize=10

End	


Function sq_ePToFWaveNote(wlist)
string wlist

	string str, wnote
	variable idex, isEPTOF

	svar todoStr=root:panel:sq_toDoWvNm
	nvar tof1_ugconv=root:panel:tof1_ugconv		//ug/m3
	nvar tof0_corrop=root:panel:tof0_corrop		// AB correction
	nvar tof1_norm=root:panel:tof1_norm		// normalize to MS
	nvar tof0_gppp=root:panel:tof0_gppp		// gp pp boundary
	nvar tof0_fragAirIs0 = root:panel:tof0_fragAirIs0		// nonzero frag air
	nvar tof1_datatype=root:panel:tof1_datatype		// X vs ToF or diameter
	nvar deconvolveNone = root:panel:deconvolveNone
	nvar deconvolve = root:panel:deconvolve
	nvar deconvolveJoel = root:panel:deconvolveJoel
	nvar/z deconvolveMike = root:panel:deconvolveMike
	if (!Nvar_exists(deconvolveMike))
		variable/g root:panel:deconvolveMike
		nvar deconvolveMike = root:panel:deconvolveMike
	endif	
	
//	nvar ePToF_demux_adaptiveDenoise = root:panel:ePToF_demux_adaptiveDenoise
	nvar ePToF_postmatrixInvDC = root:panel:ePToF_postmatrixInvDC
	ePToF_postmatrixInvDC=1  // we do DC marker separately
	nvar PToF_ePToF_testRegion = root:panel:PToF_ePToF_testRegion
//	nvar PToF_ePToF_sharpening = root:panel:PToF_ePToF_sharpening
//	nvar PToF_ePToF_denoise = root:panel:PToF_ePToF_denoise
//	nvar DCgr_ck_alsoSmooth = root:panel:DCgr_ck_alsoSmooth
	nvar DCgr_smoothVar = root:panel:DCgr_smoothVar
//	nvar ePToF_demux_ECLulim =root:panel:ePToF_demux_ECLulim
//	nvar ePToF_demux_BLMax =root:panel:ePToF_demux_BLMax
//	nvar ePToF_demux_DNulim =root:panel:ePToF_demux_DNulim
//	nvar ePToF_demux_DNMax =root:panel:ePToF_demux_DNMax
	
	nvar tof0_d_saved=root:panel:tof0_d_saved
	nvar tof0_d_reg=root:panel:tof0_d_reg
	nvar tof0_d_custom=root:panel:tof0_d_custom
	svar tof0_d_cus_Val=root:panel:tof0_d_cus_Val
	nvar tof0_d_reg_min=root:panel:tof0_d_reg_min		
	nvar tof0_d_reg_max=root:panel:tof0_d_reg_max	
	nvar tof0_d_reg_n=root:panel:tof0_d_reg_n	

	nvar/z PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	if (!Nvar_exists(PToF_DCgr_IsEPToF))
		variable/g root:panel:PToF_DCgr_IsEPToF
		nvar PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	endif
	
	if (stringmatch(WinName(0,64), "PToFePToF_Tool") )
		sq_DCGr_UpdateRunNumParams()			// sets PToF_DCgr_IsEPToF
		isEPTOF = PToF_DCgr_IsEPToF
	else
		wave todo = $"root:"+todoStr
		isEPTOF = sq_TodoHasPToF(todo, PToFFlag=0)  //1.59C
	endif
	
	wnote = ""
	wnote += "todoStr:"+todoStr+"/"
	wnote += "ugconv:"+num2str(tof1_ugconv)+"/"		//ug/m3
	wnote += "ABcorr:"+num2str(tof0_corrop)+"/"	// AB correction
	wnote += "MSnorm:"+num2str(tof1_norm)+"/"	// normalize to MS
	wnote += "gppp:"+num2str(tof0_gppp)+"/"		// gp pp boundary
	wnote += "fragAirIs0:"+num2str(tof0_fragAirIs0)+"/"	// nonzero frag air
		
	wnote += "Xaxis:"+SelectString(tof1_datatype==1, "XvsToF", "dXdlogDa" )+"/"	// nonzero frag air of1_datatype=root:panel:tof1_datatype		// X vs ToF or diameter
	if (tof1_datatype)
		if (tof0_d_saved)		// as saved
			wnote += "diameterBase:0/"
		elseif(tof0_d_reg)		// evenly spaced bins
			wnote += "diameterBase:1/"
			wnote += "diameterBaseN:"+num2str(tof0_d_reg_n)+"/"
			wnote += "diameterBaseMin:"+num2str(tof0_d_reg_min)+"/"
			wnote += "diameterBaseMax:"+num2str(tof0_d_reg_max)+"/"
		else					// custom wave
			wnote += "diameterBase:2/"
			wnote += "diameterBaseWave:"+tof0_d_cus_Val+"/"
		endif

	endif
	if (!isEPTOF)
		wnote += "ePToF:0/"	// PToF not ePToF			
//		if (DCgr_smoothVar>1)		//1.59D
//			wnote += "smooth:"+num2str(DCgr_smoothVar)+"/"	// PToF not ePToF			
//		endif
	else		// ePToF
		wnote += "ePToF:1/"	//  ePToF			
		sprintf str, "%0.2f", PToF_ePToF_testRegion
		wnote += "ePToFtestRegion:"+str+"/"			// really only valid of deconvolved with matrix subtraction	
		if (DCgr_smoothVar>1)		//1.59D
			wnote += "smooth:"+num2str(DCgr_smoothVar)+"/"	// PToF not ePToF			
		endif
		if (deconvolveNone)
			wnote += "deconvolve:0/"	//  ePToF			
		elseif(deconvolveJoel)
			wnote += "deconvolve:1/"	//  ePToF
			wnote += "subtractDC:"+num2str(ePToF_postmatrixInvDC)+"/"	// PToF not ePToF		
		elseif(deconvolveMike)		//1.57Z1
			wnote += "deconvolve:3/"	//  ePToF
		endif
	endif
		
	for (idex=0;idex<itemsInList(wlist);idex+=1)
		wave w = $stringFromList(idex, wlist, "/")
		Note/K w, wnote
	endfor
	
End


Function sq_ePToF_2DsmoothCol(wave2D, smoothVar)		// 2D
wave wave2D
variable smoothVar

	variable idex, num
	for (idex=0;idex<dimsize(wave2D,1);idex+=1 )
		matrixOp/o OneCol =Col(wave2D,idex)
		filterfir/lo={0,min(0.5,1/2),7} OneCol		//1.59D
		Smooth/M=0/MPCT=50 smoothVar, OneCol
		wave2D[][idex]=OneCol[p]
	endfor
	killwaves/z OneCol	
End


// check if all values in the todo wave are the same. 		
Function sq_PToF_DC_Same(PToFtodo, UseBinNumUnits, dc1, dc2, dc3, dc4,seriesPos )
wave PToFtodo
variable &UseBinNumUnits, &dc1, &dc2, &dc3, &dc4, seriesPos

	variable num

	wave/z/i PToFDC_Reg1_Start = root:diagnostics:PToFDC_Reg1_Start
	wave/z/i PToFDC_Reg1_Stop = root:diagnostics:PToFDC_Reg1_Stop
	wave/z/i PToFDC_Reg2_Start = root:diagnostics:PToFDC_Reg2_Start
	wave/z/i PToFDC_Reg2_Stop = root:diagnostics:PToFDC_Reg2_Stop
	wave/z/i PToFDC_BinNumFlag = root:diagnostics:v
	wave/z/t PToFDC_Reg1Only = root:diagnostics:PToFDC_Reg1Only
	wave/z/t PToFDC_Reg2Only = root:diagnostics:PToFDC_Reg2Only

	nvar cor3_dcmarker1 =root:panel:cor3_dcmarker1
	nvar cor3_dcMarker2 =root:panel:cor3_dcMarker2
	nvar cor3_dcmarker3 =root:panel:cor3_dcmarker3
	nvar cor3_dcmarker4 =root:panel:cor3_dcmarker4
	nvar ptof_dcUseBinNumUnits = root:panel:ptof_dcUseBinNumUnits
	string reg1Str, reg2str
	
	if (WaveExists(PToFDC_Reg1_Start))		// assume that if one is missing, all are
		num = numpnts(PToFDC_Reg1_Start)
		make/i/o/n=(num)/FREE tempFlag, wave1, wave2, wave3, wave4, wave5, wave6, wave7
		sq_makeMaskFromTodofindRun(tempFlag,PToFtodo)
		// check if all values in the todo wave are the same. 		
		dc1=PToFDC_Reg1_Start[seriesPos]
		dc2=PToFDC_Reg1_Stop[seriesPos]
		dc3=PToFDC_Reg2_Start[seriesPos]
		dc4=PToFDC_Reg2_Stop[seriesPos]
		UseBinNumUnits=PToFDC_BinNumFlag[seriesPos]
		reg1Str=PToFDC_Reg1Only[seriesPos]
		reg2str=PToFDC_Reg2Only[seriesPos]
	 
		wave1 	=  (tempFlag[p]==1 && dc1!=PToFDC_Reg1_Start[p])?  1 : 0
		wave2 	=  (tempFlag[p]==1 && dc2!=PToFDC_Reg1_Stop[p])?  1 : 0
		wave3 	=  (tempFlag[p]==1 && dc3!=PToFDC_Reg2_Start[p])?  1 : 0
		wave4 	=  (tempFlag[p]==1 && dc4!=PToFDC_Reg2_Stop[p])?  1 : 0
		wave5 	=  (tempFlag[p]==1 && UseBinNumUnits!=PToFDC_BinNumFlag[p]) ?  1 : 0
	
		wave6 	= (tempFlag[p]==1 && !stringmatch(reg1Str,PToFDC_Reg1Only[p]) ) ?  1 : 0
		wave7 	= (tempFlag[p]==1 && !stringmatch(reg2Str,PToFDC_Reg2Only[p]) ) ?  1 : 0

		return (sum(wave1) + sum(wave2) + sum(wave3) + sum(wave4) + sum(wave5) + sum(wave6) +sum(wave7) )
	else		// just use values that are in the panel
		dc1=cor3_dcmarker1
		dc2=cor3_dcMarker2
		dc3=cor3_dcmarker3
		dc4=cor3_dcmarker4
		UseBinNumUnits=ptof_dcUseBinNumUnits
		return nan
	endif
	
End


// used for adding DC markers to graph.  We first check to see that all runs in todo have been processed the same
Function sq_PToF_ePToFDevonv_Same(PToFtodo, dc3, dc4, seriesPos )
wave PToFtodo
variable &dc3, &dc4, seriesPos

//	wave/z EPToF_denoise = root:diagnostics:EPToF_denoise
//	wave/z EPToF_sharpening = root:diagnostics:EPToF_sharpening
	wave/z EPToF_testregion = root:diagnostics:EPToF_testregion
	wave/z deconvolveType = root:diagnostics:deconvolveType

	wave ptof_dcMarkersPtWave = root:panel:ptof_dcMarkersPtWave
	wave ptofNumSpectraPerChop = root:diagnostics:ptofNumSpectraPerChop
	nvar PToF_ePToF_TestRegion = root:panel:PToF_ePToF_TestRegion
	
	variable num, denoise, sharpening, testregion, deconvolveT

	sq_dcMarkersExamine_ePToF(seriesPos)
	dc3=ptof_dcMarkersPtWave[2]
	dc4=ptof_dcMarkersPtWave[3]
	
	if (WaveExists(deconvolveType))		// assume that if one is missing, all are
		num = numpnts(deconvolveType)
		make/i/o/n=(num)/FREE tempFlag, wave3, wave4
		sq_makeMaskFromTodofindRun(tempFlag,PToFtodo)

//		denoise=EPToF_denoise[seriesPos]
//		sharpening=EPToF_sharpening[seriesPos]
		testregion=EPToF_testregion[seriesPos]
		deconvolveT=deconvolveType[seriesPos]
		if (numtype(deconvolveT)==0)
	//		wave1 	=  (tempFlag[p]==1 && denoise!=EPToF_denoise[p])?  1 : 0
	//		wave2 	=  (tempFlag[p]==1 && sharpening!=EPToF_sharpening[p])?  1 : 0
			wave3 	=  (tempFlag[p]==1 && testregion!=EPToF_testregion[p])?  1 : 0
			wave4 	=  (tempFlag[p]==1 && deconvolveT!=deconvolveType[p])?  1 : 0
		else
			wave3 	=  (tempFlag[p]==1 && numtype(EPToF_testregion[p]) !=2  )
			wave4 	=  (tempFlag[p]==1 && numtype(deconvolveType[p]) !=2  )
		endif
//		return (sum(wave1) + sum(wave2) + sum(wave3) + sum(wave4)  )
		return ( sum(wave3) + sum(wave4)  )
	else		// just use values that are in the panel
		return nan
	endif
	
End


Function sq_DeconvolveCheckProc(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar PToF_DCgr_IsEPToF = root:panel:PToF_DCgr_IsEPToF
	nvar deconvolveNone = root:panel:deconvolveNone
	nvar deconvolve = root:panel:deconvolve
	nvar deconvolveJoel = root:panel:deconvolveJoel
	nvar deconvolveMike = root:panel:deconvolveMike
//	nvar ePToF_demux_adaptiveDenoise = root:panel:ePToF_demux_adaptiveDenoise
	nvar PToF_ePToF_TestRegion = root:panel:PToF_ePToF_TestRegion
//nvar DCgr_ck_alsoSmooth = root:panel:DCgr_ck_alsoSmooth

	string wStr, ePToFWinList, ePToFPrefixList, ePToFPrefixStr, allWinList =WinList("*", ";", "WIN:65")

	variable idex, HdfTab,which 
	
	which= WhichListItem(stringFromList(1,ctrlName, "_" ), "DeconvolveNone;DeconvolveJoel;_DeconvolveRich;DeconvolveMike")

	ePToFWinList ="ams_panel;ams_panel;PToFePToF_Tool;" 
	ePToFPrefixList ="loadepD_;tof0ePToF_;ePToF_;" 

	deconvolveNone = (which == 0)
	deconvolveJoel = (which == 1)
	deconvolve	 = (which == 2)		// Rich
	deconvolveMike = (which == 3)

	ControlInfo/w=ams_panel load_preprocessTab
	HdfTab=V_Value
	
	ControlInfo/w=ams_panel ams_tab
	
	variable TopWinTWflag = stringmatch("TWEPToF_gr",WinName(0,65))

	wStr="ams_panel"
	ePToFPrefixStr="loadepD_"
	SetVariable $ePToFPrefixStr+"TestRegionSetVar", win =$wStr, disable = SelectNumber(V_Value==0 && HdfTab==2, 1,  2*(which == 0))
	SetVariable $ePToFPrefixStr+"smoothSetVar", win =$wStr,  disable = SelectNumber(V_Value==0 && HdfTab==2, 1,  2*(which == 3))
	Checkbox $ePToFPrefixStr+"SumDiffScal", win =$wStr,  disable = SelectNumber(V_Value==0 && HdfTab==2, 1,  2*(which != 3))
	ePToFPrefixStr="tof0ePToF_"
	SetVariable $ePToFPrefixStr+"TestRegionSetVar", win =$wStr, disable = SelectNumber(V_Value==3 && !TopWinTWflag, 1,  2*(which == 0))
	SetVariable $ePToFPrefixStr+"smoothSetVar", win =$wStr,  disable = SelectNumber(V_Value==3 && !TopWinTWflag, 1,  2*(which == 3))
	Checkbox $ePToFPrefixStr+"SumDiffScal", win =$wStr,  disable = SelectNumber(V_Value==3 && !TopWinTWflag,1,  2*(which != 3))
	wStr="PToFePToF_Tool"
	ePToFPrefixStr="ePToF_"
	SetVariable/Z $ePToFPrefixStr+"TestRegionSetVar", win =$wStr, disable = 2*(which == 0)
	SetVariable/Z $ePToFPrefixStr+"smoothSetVar", win =$wStr,   disable = 2*(which == 3)
	Checkbox/Z $ePToFPrefixStr+"SumDiffScal", win =$wStr,  disable = 2*(which != 3)
	
End


Function/s sq_findePToFDeconvType(todo)
wave todo

	wave rn_series = root:index:rn_series
	variable dc3, dc4, pos, numdiff, var
	string DeconStr=""
	pos = sq_findRun(rn_series,todo[0])
	numDiff = sq_PToF_ePToFDevonv_Same(todo, dc3, dc4, pos )
	if (numDiff >0)
		DeconStr=" NONSAME DECON!"	
	else
		wave deconvolveType = root:diagnostics:deconvolveType
		var=limit(deconvolveType[pos], 0, 4)
		DeconStr=StringFromList(var,  " Not decon; Matrix inv; Matrix inv; TW decon; Rich demux")	
	endif
	return DeconStr
	
End


Function/s sq_setTof0_PToFePToFtitle(todo)
wave todo

	string returnStr=""
	svar tof0_PToFePToFtitle = root:panel:tof0_PToFePToFtitle		//1.59D
	if ( WaveExists(todo) && numpnts(todo)>0 )	//1.57n	
		variable hasPToF = sq_TodoHasPToF(todo, PToFFlag=1)  //1.59C)
		variable hasEPToF = sq_TodoHasPToF(todo,PToFFlag=0)  //1.59C)
		svar tof0_PToFePToFtitle = root:panel:tof0_PToFePToFtitle
		tof0_PToFePToFtitle="ePToF:"+selectstring(hasEPToF, "N", "Y")+"\r"
		if (hasEPToF)
			tof0_PToFePToFtitle+=  "Preproc."+sq_findePToFDeconvType(todo)  // " Preproc:"+
		endif			
		if (hasPToF)
			tof0_PToFePToFtitle+="\rPToF:"+selectstring(hasPToF, "N", "Y") 		
		endif

		returnStr = tof0_PToFePToFtitle
	else
		tof0_PToFePToFtitle=returnStr
	endif

	variable NeedToDeconvolve = strsearch(tof0_PToFePToFtitle, "Not decon", 0) >=0
	if (strsearch(tof0_PToFePToFtitle, "Not decon", 0) >=0)
		GroupBox tof0ePToF_DeconGroup labelBack=(65535,65534,49151), win=AMS_Panel
	else
		GroupBox tof0ePToF_DeconGroup labelBack=0, win=AMS_Panel
	endif
	
	sq_HideEPToFControls(NeedToDeconvolve)

	return returnStr
End


Function sq_ePToFfromDAQ(index_pos,paramOld,acorn,n_acorns)
	wave index_pos
	string paramOld
	variable acorn,n_acorns

	wave source=$stringbykey("acorn_0",paramOld)
	variable ePToF_flag = numberbykey("ePToF_flag",paramOld)	

	string paramStr = ""
	paramStr+="hz_op:1;"			// variable hz_op=numberbykey("hz_op",paramStrstr)
	paramStr+="hdf_op:0;"			// variable hdf_op=0 // numberbykey("hdf_op",paramStrstr)  
	paramStr+="duty_op:1;"			// variable duty_op=numberbykey("duty_op",paramStrstr)
	paramStr+="applyDC:0;"			// variable applyDC=0		// numberbykey("applyDC",paramStrstr)==1
	paramStr+="ePToF_flag:1;"		// 	variable ePToF_flag=numberbykey("ePToF_flag",paramStrstr)==1
	paramStr+="ePToF_OS:2;"		// 	variable ePToF_OS=numberbykey("ePToF_OS",paramStrstr)
	paramStr+="collapsePToF_op:0;"			// variable collapsePToF_op=numberbykey("collapsePToF_op",paramStrstr)
	paramStr+="collapsePToF_Avg:0;"			// variable collapsePToF_Avg=numberbykey("collapsePToF_Avg",paramStrstr)
	paramStr+="timeweight:4;"	
	sq_insert_Matrix(index_pos,paramStr,acorn,n_acorns)

// we now have a PToF matrix, acorn_0,  nicely set up 	
	nvar chopper_duty = root:diagnostics:chopper_duty
	nvar cor3_chamber = root:panel:cor3_chamber
	wave ePToF_oversampling = root:diagnostics:ePToF_oversampling		//1.60M
	variable pos = WaveMax(index_pos)
	wave series_index = root:index:series_index
	pos = series_index[pos]		//1.60M
	
		
	paramStr =""
	paramStr ="acorn_0:"+stringbykey("acorn_0",paramOld)+";"
	paramStr+="ePToF_flag:"+num2str(ePToF_flag)+";"	
	paramStr+="PostAvgFlag:1;"	
	paramStr+="osFactor:"+num2istr(ePToF_oversampling[pos])+";"
	paramStr+="lc:"+num2str(cor3_chamber)+";"
	paramStr+="chop_duty:"+num2str(chopper_duty)+";" 
	paramStr+="ug_op:0;"
	paramStr+="filter_op:0;"
	paramStr+="product_type:6;"
	paramStr+="d_base:;"
	paramStr+="t_base:;"
	paramStr+="dlog_op:0;"
	paramstr+="frag_exclude:;" 
	paramstr+="fraglist:all;" 
	paramstr+="speclist:all;" 
	paramstr+="hz_op:0;"
	paramStr+="timeweight_op:4;"
	paramStr+="destlist:temp_PToFmatrix;"
	paramStr+="ignoreChop:1;"	// ignore = 0 means we use(1/chop_duty)*ChopperFreq  ignore = 1 means 1
	paramStr+="daqPToFStick:0;"	

	sq_MS_concentration(index_pos,paramStr,acorn,n_acorns)
	
End


Function sq_URLButton(ba) : ButtonControl			//1.157Z2
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			string urlStr
			strswitch(ba.ctrlName)
				case "ams_url_FAQ":	
					urlStr = "http://cires1.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software"
					break
				case "fDiag_butt_ceWebLink":	
					urlStr = "http://cires1.colorado.edu/jimenez/Papers/2011_AST_Middlebrook_CE.pdf"
					break
				case "fDiag_butt_PieberWebLink":	
					urlStr = "http://pubs.acs.org/doi/abs/10.1021/acs.est.6b01035"
					break
				case "ImpAm_PaperRef1":
					urlStr = "http://cires1.colorado.edu/jimenez/Papers/ac071150w_published_complete.pdf"
					break
				case "ImpAm_PaperRef":
					urlStr = "http://www.atmos-chem-phys.net/15/253/2015/acp-15-253-2015.pdf"
					break
				case "sq_CEpaperURL_buttonProc":
					urlStr = "http://cires.colorado.edu/jimenez/Papers/2011_AST_Middlebrook_CE.pdf"
					break
				case "sq_butt_exportDBUMRWebsite":
					urlStr = "http://cires.colorado.edu/jimenez-group/AMSsd/"
					break
				case "sq_butt_exportDBUMRwiki":
					urlStr = "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Exporting_Results_to_the_AMS_Unit_Mass_Resolution_Data_Base"
					break
				case "sq_butt_exportDBHRWebsite":		// HR
					urlStr = "http://cires.colorado.edu/jimenez-group/HRAMSsd/"
					break
				case "sq_butt_exportDBHRwiki":		// HR
					urlStr = "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Exporting_Results_to_the_AMS_HR_Mass_Resolution_Data_Base"
					break
				case "sq_CEHelpButtonProc":	
					urlStr = "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Composition_Dependent_Collection_Efficiency_.28CE_Panel.29"
					break
				case "fDiag_butt_PieberWebLink":	
					urlStr = "http://pubs.acs.org/doi/abs/10.1021/acs.est.6b01035"
					break
				case "fc_butt_wikiHelp":
					urlStr = "http://cires.colorado.edu/jimenez-group/wiki/index.php/Field_Data_Analysis_Guide#Make_campaign_specific_adjustments_to_fragmentation_table"
					break
				case "buttonEPToFQs": //1.60Q
					urlStr = "http://cires1.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Working_with_ePToF_data"
					break
// pika urls
				case "HRGen_butt_LatestVersion":
					urlStr = "http://cires.colorado.edu/jimenez-group/ToFAMSResources/ToFSoftware/index.html#Analysis3"
					break
				case "HRGen_butt_FAQs":
					urlStr = "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software"
					break
				case "buttonUrlMiddlebrook":
					urlStr = "http://cires.colorado.edu/jimenez/Papers/2011_AST_Middlebrook_CE.pdf"
					break
				case "ceHelp":
					urlStr = "http://cires.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software#Composition_Dependent_Collection_Efficiency_.28HR_CE_panel.29"
					break
				case "ButtonDeCarloPaper":		// on credits panel
					urlStr = "http://cires1.colorado.edu/jimenez/Papers/DeCarlo_HRToFAMS_complete_published.pdf"
					break
				case "ButtonAiken1Paper":
					urlStr = "http://cires1.colorado.edu/jimenez/Papers/ac071150w_published_complete.pdf"		// EST
					break					
				case "ButtonAiken2Paper":
					urlStr = "http://cires.colorado.edu/jimenez/Papers/2008_EST_Aiken_Elemental_App_Pub_Complete.pdf"		// analytic chemistry
					break
				case "ButtonPaperListingWebSite":
					urlStr = "http://cires1.colorado.edu/jimenez/ams-papers.html"		// analytic chemistry
					break
				case "fami_HerringPAHpaper":
					urlStr = "http://www.tandfonline.com/doi/pdf/10.1080/02786826.2015.1101050"	// analytic chemistry
					break
				default 	:	// "ams_url":			// version web site	
					urlStr ="http://cires1.colorado.edu/jimenez-group/wiki/index.php/ToF-AMS_Analysis_Software"
			endswitch
			browseurl /z urlstr

			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


Function sq_ePToF_InfoButtonProc(ControlName): ButtonControl
string ControlName

	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	sq_pop_toDoList("ams_todolist_pop",nan,sq_toDoWvNm) 

End


Function sq_EPToFScaling(source, ePToFSumDiff, AcornMx, index_pos, killFlag [AvgFlag])	
wave source, ePToFSumDiff, AcornMx, index_pos
variable killFlag, AvgFlag

	wave series_index = root:index:series_index
	variable idex, IsAvg, maxmz=dimsize(ePToFSumDiff,1), runs = dimsize(ePToFSumDiff,0)
	make/o/n=(maxmz) ScalarMS
	make/o/n=(maxmz) DeconIntegrated  // DeconSumMS
	make/o/n=(maxmz)  PTOFTime // keep as is, don't change to twPToFtime // DeconSumMS
	make/free/o/n=12 DVa_wave
	IsAvg =  !ParamIsDefault(AvgFlag) && AvgFlag

	if (IsAvg)
		make/o/n=(runs, maxmz) root:TWePTOF:AvgDeconvScalMz/wave=AvgDeconvScalMz
	endif

	if (dimsize(ePToFSumDiff,0) != dimsize(source,0))
		print  "// Something is wrong when I try to scale.  Dims of ePToFSumDiff is "+num2str(dimsize(ePToFSumDiff,0))+" and of ePToF is "+ num2str(dimsize(source,0))
		abort "Something is wrong when I try to scale.  Dims of ePToFSumDiff is "+num2str(dimsize(ePToFSumDiff,0))+" and of ePToF is "+ num2str(dimsize(source,0))
	endif
	
	for(idex=0;idex<runs;idex+=1)
		if (index_pos[idex]<0)
			continue
		else
			sq_GetPToFParams(DVa_wave,  series_index[index_pos[idex]])
			PToFtime = DVa_wave[%t0] + p*DVa_wave[%step]		
			MatrixOp/o MSAvg = row(ePToFSumDiff, idex)
			Redimension/n=(maxmz) MSAvg
			ImageTransform/PTYP=(2)/P=(idex) GetPlane source		//1.57N 1.53D the /PTYP=(2) YZ plane
			wave M_ImagePlane    // (numbins, maxMz) 
			TWDoScaling(MSAvg, M_ImagePlane, PTOFTime,ScalarMS,DeconIntegrated, series_index[index_pos[idex]])
			if (IsAvg)
				AvgDeconvScalMz[idex][0, Numpnts(ScalarMS)-1]=ScalarMS[q]		//1.59D  If user selected max mz = 200 say
			else
				AcornMx[idex][%scalar][0, Numpnts(ScalarMS)-1]= ScalarMS[r]		// AcornMx is runs x mz x 4
			endif
			source[idex][][] *= ScalarMS[r]
		endif
	endfor

	if (killflag)
		killwaves/z MSAvg, M_ImagePlane, DVa_wave, ScalarMS, DeconIntegrated, DVa_wave, PTOFTime
	endif
End


Function sq_PreProcessTab(ctrlName, tab) : TabControl
	string ctrlName
	variable tab
	
	variable cont_disp,tab_1,idex,num
	string cont_list, cont_item
	
	controlinfo /w=ams_panel load_PreProcessTab
	tab_1=v_value
	
	cont_list=controlnamelist("")
	num=itemsinlist(cont_list)
	for (idex=0;idex<num;idex+=1)
		cont_item=stringfromlist(idex,cont_list)
		strswitch (cont_item[0,4])
			case "loadm":	
				cont_disp=tab!=0
				break
			case "loadp":	// same as hdf index
				cont_disp=tab!=1
				break
			case "loade": 	// Corrections tab, no subtab
				cont_disp=tab!=2
				break
			case "load_": 
				continue
			default:
				continue
		endswitch
		controlinfo $cont_item	//	 /w=ams_pane/
		switch (abs(v_flag))
			case 2:
				checkbox  $cont_item disable=cont_disp
				break
			case 5:
				setvariable $cont_item disable=cont_disp
				break
			case 9:
				groupbox $cont_item disable=cont_disp
				break
			case 10:
				titlebox $cont_item disable=cont_disp
				break
		endswitch

	endfor

End


Function sq_GetIndexNotDoneYet()

	if (!DataFolderExists("root:diagnostics"))
		abort " This functionality is not available until you press the Get Index button - Aborting from sq_GetIndexNotDoneYet"
	endif
	wave/z rn_series = root:index:rn_series
	if (!WaveExists(rn_series) || numpnts(rn_series)==0)
		abort " This functionality is not available until you press the Get Index button - Aborting from sq_GetIndexNotDoneYet"
	endif
	
End	


Function sq_iterateOverList(todo, TodoList, numList, paramStr, DataSetStr, sqfunc)
wave todo
string TodoList, paramStr, DataSetStr
funcref squirrel_proto sqfunc 
variable numList

	nvar ams_sqprog	= root:panel:ams_sqprog		// major but progress bar  1.52O
	variable idex, ePToF_flag, ePToF_OS, numPToFBins, firstRunPos
	string multipleOpStr=""
	variable checkeEPToFflag = numberbykey("checkeEPToFflag",paramstr) 
	variable checkePToFSumflag = numberbykey("checkePToFSumflag",paramstr) 
	variable MSSStickflag = numberbykey("MSSStickflag",paramstr) 
	wave squirrel_index = root:index:squirrel_index
	variable m
	
	sq_ams_stat_upd("Iterating....")	
	for (idex=0;idex<numList;idex+=1)		//for each PToF group
		ams_sqprog=100*( idex/numList)		//1.52O5
		sq_create_todo(NameofWave(todo)+" and "+stringfromList(idex, TodoList),"GroupTodo_tmp")
		wave GroupTodo_tmp = root:GroupTodo_tmp
		if (numpnts(GroupTodo_tmp) >0 )
		
			// special case for ePToF
			if (checkeEPToFflag)
				sq_ReturnePToFFlags(ePToF_flag, ePToF_OS, numPToFBins, firstRunPos, GroupTodo_tmp)		//1.57D
				if (!ePToF_flag)
					continue
				endif
			endif
			m=sq_findMaxMinMz(GroupTodo_tmp, 1, 0)
			if (numtype(m) !=0 || m<0 || m>1e8)		// 1e8 is arbitrary
				abort "The maximum Mz of "+num2str(m)+" seems incorrect.  Aborting from sq_iterateOverList" 
			endif		//1.60L

			if (MSSStickflag)
				paramStr+="maxMz:"+num2str(m)+";"
			endif
			squirrel_fetch(GroupTodo_tmp, sqfunc, paramStr, DataSetStr)				
			
			// special case for ePToF
			if (checkeEPToFflag && ePToF_flag && checkePToFSumflag)	// do sum then diff				
				if ( FindDimLabel(squirrel_index, 2, "MSClosed_p") >=0 )		// in case we have MS closed   could give problems when only part of MSClosed was preprocessed
					sq_FillInMSClosedPToFOnly(GroupTodo_tmp,1) 					
					squirrel_fetch(GroupTodo_tmp,sq_diffcalc,"multiplyFactor:"+num2str(1/127)+";hdf_op:1;raw:1;dest:MSePToFSumDiff_p","MSePToFSum_p;MSClosed_p")	// multiply by 2 because of half duty cycle
				endif
			endif
		endif				
	endfor   

	ams_sqprog=100*(1)		//1.60L

	killwaves/z GroupTodo_tmp, tempPToFTodoPp
End


//1.59
Function sq_FileIndexTable(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
	PauseUpdate; Silent 1		// building window...
	DoWindow/F FileIndexTable
	if (V_flag)
		return 0
	endif
	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:index:
	wave file_index
	Edit/W=(40,60,700,260)/N=FileIndexTable file_index as "FileIndexTable"
	ModifyTable format(Point)=1,width(file_index)=572
	SetDataFolder fldrSav0
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End


// a function for users to autmatically set specific ions for either the mz calibration or the HR peak shape
// typeStr should either be mzFitting or hrPeakShape
// sample usage:
// sq_UseTheseIonsForMassTable("HR_PeakShape", "CH;O2;CO2;C6H6", 1)
// sq_UseTheseIonsForMassTable("mzFitting", "N+;O+;CO2+;C6H6+", 0)
Function sq_UseTheseIonsForMassTable(typeStr, HRionList, UseOnlyTheseHRIons)
string typeStr, HRionList
variable UseOnlyTheseHRIons

	string ionStr, BigListPosList="", tmpStr
	variable idex, kdex,numIons, bigListPos, smallListPos, HrIonMass
	
	if (WhichListItem(typeStr, "mzFitting;HR_PeakShape;")<0)
		abort "Could not determine which table of HR ions you wanted to change.  It must either be mzFitting or HRPeakShape.  Aborting from sq_UseTheseIonsForMassTable"
	endif

	wave/d/z ExactMassWave_All = root:HR:ExactMassWave_All
	wave/t/z ExactMassText_All = root:HR:ExactMassText_All
	if (!WaveExists(ExactMassText_All) || !WaveExists(ExactMassWave_All))
		abort "Could not proceed because the HR ion waves root:HR:ElementIonMass, root:HR:ElementIonName are not present.  Aborting from sq_UseTheseIonsForMassTable"
	endif

	numIons = itemsInList(HRionList)
	for(idex=0;idex<numIons;idex+=1)
		tmpStr = stringFromList(idex, HRionList)
		ionStr = ReplaceString("+", tmpStr,"")
		FindValue/Z/TEXT=(ionStr)/TXOP=5 ExactMassText_All	
		if (V_Value<0)
			abort "Could not proceed because the HR ion "+ionStr+" is not present in the wave root:HR:ElementIonName.  Aborting from sq_UseTheseIonsForMassTable"
		endif
		BigListPosList += num2str(V_Value)+";"
	endfor 

	strswitch(typeStr)
	case "mzFitting": 
		dfref df= root:mzFitting:
		if (DataFolderRefStatus(df)==0)
			abort "The folder root:mzFitting: does not yet exist. Aborting from sq_UseTheseIonsForMassTable"
		endif
		SetDataFolder df
		wave SpecType = mz_SpecType
		wave/t Name = mz_Name
		wave Mass = mz_Mass
		wave Delta = mz_DeltaNum
		make/free/wave moreWaves = {root:mzFitting:mz_Graph}
		break
	case "HR_PeakShape": 
		dfref df= root:HR_PeakShape:
		if (DataFolderRefStatus(df)==0)
			abort "The folder root:HR_PeakShape: does not yet exist. Aborting from sq_UseTheseIonsForMassTable"
		endif
		SetDataFolder df
		wave SpecType = root:GaussFits:GFMask
		wave/t Name = root:GaussFits:GFName
		wave Mass = root:GaussFits:GFMass
		wave Delta = root:GaussFits:GFDeltaNum
		make/free/wave moreWaves = {root:HR_PeakShape:PW_VmodeMask,root:HR_PeakShape:PW_WmodeMask,root:HR_PeakShape:PW_Graph,root:GaussFits:GFComments}
		break
	endswitch

	if (UseOnlyTheseHRIons)
		SpecType=0
	endif
	
	numIons = itemsInList(HRionList)
	for(idex=0;idex<numIons;idex+=1)
		ionStr = stringFromList(idex, HRionList) + selectString(Stringmatch(typeStr, "mzFitting"),"", "", "+") 
		bigListPos = str2num(stringFromList(idex, BigListPosList))
		FindValue/Z/TEXT=(ionStr)/TXOP=5 Name	
		if (V_Value<0)	// ion is not in list... figure out where to add it, best to add it in increasing mass order
			HrIonMass = ExactMassWave_All[bigListPos]
			smallListPos = Ceil(binarySearchInterp(Mass,HrIonMass))			
			if (numtype(smallListPos)==0	)	// we have a real number
//				smallListPos = floor(V_Value)
			elseif (HrIonMass<WaveMin(Mass))
				smallListPos=-1
			else 		// (HrIonMass>WaveMax(Mass))
				smallListPos=numpnts(Mass)-1
			endif
			
			insertpoints smallListPos, 1, Name, Mass,SpecType,Delta
			for(kdex=0;kdex<numpnts(moreWaves); kdex+=1)
				wave w = morewaves[kdex]
				insertpoints smallListPos+1, 1, w					
			endfor
		else	// already in list
			smallListPos = floor(V_Value)
		endif
		
		SpecType[smallListPos]=2		// default to closed
		Name[smallListPos]=ionStr		
		Mass[smallListPos]=ExactMassWave_All[bigListPos]	
		Delta[smallListPos]= ( smallListPos==numpnts(Delta)-1 ?  Delta[smallListPos-1] : Delta[smallListPos+1]  )
		for(kdex=0;kdex<numpnts(moreWaves); kdex+=1)
			wave w = morewaves[kdex]
			if (WaveType(w)!=0)		// not a text wave
				w[smallListPos]=1
			endif
		endfor
	
	endfor 

End


//1.59E
Function sq_HideEPToFControls(hideflag)
variable hideflag

	ControlInfo/w=ams_panel ams_Tab 
	if (V_Value==3)
		CheckBox tof0ePToF_DeconvolveNone, win=ams_panel, disable= !hideFlag 	
		CheckBox tof0ePToF_DeconvolveJoel, win=ams_panel,disable= !hideFlag 	
		CheckBox tof0ePToF_DeconvolveMike, win=ams_panel, disable= !hideFlag 	
		SetVariable tof0ePToF_smoothSetVar, win=ams_panel, disable= !hideFlag 	
		CheckBox tof0ePToF_SumDiffScal, win=ams_panel, disable= !hideFlag 	
		SetVariable tof0ePToF_TestRegionSetvar, win=ams_panel, disable= !hideFlag 	
	endif
End


//1.59E
// return imaginary is way to return two values
// used in sq_FindHRPToFEdges
Function/c sq_GetDvaFromPToFBins(bstart, bstop, runPos)		
variable bstart, bstop, runPos

	nvar cor3_chamber = root:panel:cor3_chamber
	variable dvaStart, dvaStop
	
	make/free DVa_wave
	sq_GetPToFParams(DVa_wave, runPos)
	
	dvaStart = sq_ptof2dva(cor3_chamber,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx], DVa_wave[%t0]+((bstart-0.5)*DVa_wave[%step])) 
	dvaStop =  sq_ptof2dva(cor3_chamber,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx], DVa_wave[%t0]+((bstop+0.5)*DVa_wave[%step])) 
	
	// for when DVa returns inf
	dvaStart = numtype(dvaStart) ?  0  : dvaStart
	dvaStop = numtype(dvaStop) ?  0 : dvaStop
	
	variable/C ret =cmplx(dvaStart,dvaStop)

	return ret

End


// 1.59E
// used in HR_butt_MS_Calc, by default only for non-ePToF, HR purposes
Function/c sq_FindHRPToFEdges(StartBin, StopBin, runPos)
variable StartBin, StopBin, runPos

	variable/c sizeEdges = sq_GetDvaFromPToFBins(StartBin, StopBin, runPos)	
	return sizeEdges
End


//1.59E
Function sq_butt_allSavedParams(ba) : ButtonControl
	STRUCT WMButtonAction &ba

	switch( ba.eventCode )
		case 2: // mouse up
			DoWindow/F AllSavedParams
			if (V_flag)
				return 0
			endif
			PauseUpdate; Silent 1		// building window...
			String fldrSav0= GetDataFolder(1)
			SetDataFolder root:diagnostics:
			wave ParValText,ComParValText,InfoValText			
			Edit/N=AllSavedParams/W=(42,49.25,768.75,435.5) ParValText,ComParValText,InfoValText as "AllSavedParams"
			ModifyTable format(Point)=1,width(Point)=38,width(ParValText)=297,width(ComParValText)=203
			ModifyTable width(InfoValText)=165
			SetDataFolder fldrSav0			
		break
		case -1: // control being killed
			break
	endswitch

	return 0
End


// Moved from PK_peakShape 1.20
Function gen_SanityTodoWaveExists()

	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	wave todo = $"root:"+sq_toDoWvNm
	if ( !waveexists(todo)  || numpnts(todo)==0)	//^
		Abort " Either the todo wave was not found or was of zero length - aborting from gen_SanityTodoWaveExists"
	endif
End


// Moved from PK_peakShape 1.20
// case sensitive!!, returns truth or false
Function gen_isListAsubsetListB(listA, listB)
string listA, listB

	variable idex, numA, result
	
	result = 1
	numA = itemsInLIst(listA)
	for (idex=0;idex<numA;idex+=1)
		result*= WhichListItem(StringFromList(idex, listA), listB)	>=0
	endfor
	
	return result

End


// Moved from PK_peakShape 1.20
// a generic pop menu function that will only display values that are in the chosen todo wave (is
Function sq_ShowOnlyForThisTodoPopMenu(ctrlName,popNum,popStr) : PopupMenuControl
	String ctrlName
	Variable popNum
	String popStr
	
	variable idex, num
	string str, dfstr, traceList = TraceNameList("", ";", 1)	
	
	dfstr = ctrlName[strsearch(ctrlName, "DF_", 0)+3, strlen(ctrlName)]		// presumes control has name *_DF_HR_PeakShape
	dfstr=selectString(DataFolderExists("root:"+dfstr), "", dfstr )
	wave/z todo_mask = $"root:"+dfstr+":todo_mask"
	if (!WaveExists(todo_mask))
		make/o $"root:"+dfstr+":todo_mask"/Wave=todo_mask
	endif
	Wave/z todo = $"root:"+popStr
	if (!WaveExists(todo))
		abort "Could not find the todo wave selected"
	endif

  	sq_makeMaskFromTodofindRun(todo_mask,todo) 	

	num = itemsInList(traceList)
	for (idex=0;idex<num;idex+=1)
		str =stringfromList(idex, TraceList) 
		ModifyGraph zmrkSize($str)={todo_mask,0,3,1,10}
	endfor

End


Function gen_setDimLabelFromTextwave(dim, HRMx, TextWave)
variable dim
wave HRMx
wave/t TextWave
	
	variable idex, num=numpnts(TextWave)
	
	if (dimsize(HRMx, dim) != num )
		abort "There are different number of points in these waves "+NameOfWave(HRMx)+" and " +NameOfWave(TextWave)+" Cannot set dims.  Aborting from gen_setDimLabelFromTextwave" 
	endif
	
	for (idex=0;idex<num;idex+=1)
		SetDimLabel dim, idex, $TextWave[idex],  HRMx
	endfor

End


//1.60K
Function sq_initializeDeconvolveRadio()
	
	nvar deconvolveNone = root:panel:deconvolveNone
	nvar deconvolve = root:panel:deconvolve
	nvar deconvolveJoel = root:panel:deconvolveJoel
	nvar deconvolveMike = root:panel:deconvolveMike

	string CtrlName=""
	if (deconvolveNone)
		CtrlName="DeconvolveNone"
	elseif(deconvolveJoel)
		CtrlName="DeconvolveJoel"
	elseif(deconvolveMike)
		CtrlName="DeconvolveMike"
	endif
	if (strlen(CtrlName)>0)
		sq_DeconvolveCheckProc("x_"+CtrlName,1)
	endif	
End


//1.60S Addition 
//Function/S gen_AddOrRemoveChar(Str, char, [,none])
//	String Str, char
//	Variable none
//	
//	if (ParamIsDefault(none))		// Put colon on end
//		if (!stringmatch(str, "*"+char))
//			str += char
//		endif
//	else						// Take colon off end
//		if (stringmatch(str, "*"+char))
//			String endstr=""
//			Variable n
//			for (n=0; n<ItemsInList(str, char); n+=1)
//				endstr  += StringFromList(n, str, char)
//				if (n<(ItemsInList(str, char) - 1))
//					endstr += char
//				endif
//			endfor
//			str = endstr
//		endif
//	endif
//
//	return str
//
//End

//1.60Y
// returns emptyString if Str is ""
// returns Str if Char is ""
Function/S gen_AddOrRemoveLastChar(Str,char, addFlag)
	String Str, char
	Variable addFlag
	
	if (strlen(Str) == 0)
		return Str
	endif
	
	if (addFlag)
		if (stringmatch(str, "*"+char))
			return Str
		else
			return Str+char
		endif
	else
		if (stringmatch(str, "*"+char))
			Str = Str[0,strlen(Str)-2]
			return Str
		else
			return Str
		endif
	endif
	
End



// additions in 1.60T
Function/S gen_DoSaveFileDialog(msg,FilenameStr)
string msg, FilenameStr
	Variable refNum
	String message = "Select the folder and the file name that will contain the 2D raw spectra"
	String outputPath
	String fileFilters = "Data Files (*.*);"
	fileFilters += "All Files:.*;"
	Open /D /F=fileFilters /M=message refNum as FilenameStr
	outputPath = S_fileName	
	return outputPath		// Will be empty if user canceled
End



// New in 1.60Z
Function sq_PartialFastCycle(partialFirstTodo,source, deststr)
wave/i partialFirstTodo
wave source
string deststr

	variable maxFill = 500		// 1.51F an arbitrary number of the maximum number of runs we will fill in in one hdf write
	variable mycount = numpnts(partialFirstTodo)
	variable j, numCol = dimsize(source,1)
	variable nRuns = min(maxFill, myCount)
	wave run_index = root:index:run_index
		
	make/free/o/n=(nRuns)  fillblank_pos			

	for (j=0;j<mycount;j+=1)	// for each run in this acorn
		findvalue /i=(partialFirstTodo[j])/s=(max(fillblank_pos[max(0,j-1)],0)) run_index		// JDA fix in 1.42A, // fix in 1.58G
		if (v_value==-1)
			findvalue /i=(fillblank_pos[j]) run_index
		endif
		fillblank_pos[j]=v_value
	endfor

	make/free/o/n=(nRuns,numCol) fillblank_tmp =source[0][q]
//	sq_vet_blanks(fillblank_pos, fillblank_tmp, partialFirstTodo)
	if (numpnts(fillblank_pos)>0)
		//1.14M  Raw spectra or UMR
		squirrel_hdf_write(fillblank_pos, fillblank_tmp, deststr)
	endif

End


// New in 1.60Z
Function sq_FillBlanksPartialCycles(dataSet, FirstOrLast)
string dataSet
variable FirstOrLast

	Wave FMS_StartRuns = root:index:FMS_StartRuns
	Wave FMS_EndRuns = root:index:FMS_EndRuns
	Wave FMS_StartTypes = root:index:FMS_StartTypes
	Wave FMS_EndTypes = root:index:FMS_EndTypes
	Wave allFastClosed = root:allFastClosed
	string destStr = "PartialTemp_"+dataSet+"_d"
	string paramstr =  "dest:"+destStr
	variable numC = dimsize(FMS_StartRuns,0)-1

//	create a todo of edge non-nan closed
	if (FirstOrLast)
		if (FMS_StartTypes[0] != 0)
			return 0
		endif
		sq_create_todo(num2istr(allFastClosed[0]),"tempEdgeClosed")
		sq_create_todo(num2istr(FMS_StartRuns[0][0])+"-"+num2istr(FMS_EndRuns[0][0])+" and allFastOpen" ,"tempPartialTodo")
	else
		if (FMS_EndTypes[numC] != 0)
			return 0
		endif
		sq_create_todo(num2istr(allFastClosed[numpnts(allFastClosed)-1]),"tempEdgeClosed")
		sq_create_todo(num2istr(FMS_StartRuns[numC][0])+"-"+num2istr(FMS_EndRuns[numC][0])+" and allFastOpen" ,"tempPartialTodo")
	endif	
	wave tempEdgeClosed
	wave tempPartialTodo

	if (numpnts(tempEdgeClosed)==0 ||numpnts(tempPartialTodo)==0  )
		return 0
	endif
	
	// make sure we get the correct data
	killwaves/z $destStr
	wave/z data = $destStr
	if (WaveExists(data))
		abort "Could not proceed"
	endif
	squirrel_fetch(tempEdgeClosed,sq_dump2memory,paramstr,dataSet)
	wave data = $destStr
	
	sq_PartialFastCycle(tempPartialTodo,data, dataSet)

	killwaves/z data, tempEdgeClosed, tempPartialTodo

End


// New in 1.60Z
Function sq_completePartialFastCycles(todo, dataSet)
wave todo
string dataSet

	variable minRun = WaveMin(todo)
	variable maxRun = WaveMax(todo)

	Wave/z FMS_StartRuns = root:index:FMS_StartRuns
	Wave/z FMS_EndRuns = root:index:FMS_EndRuns

	if (!WaveExists(FMS_StartRuns) || !WaveExists(FMS_StartRuns) )
		return 0
	endif
	if (minRun <= FMS_EndRuns[0][0])
		sq_FillBlanksPartialCycles(dataSet, 1)
	endif
	
	if (maxRun >= FMS_StartRuns[dimsize(FMS_StartRuns,0)-1][0])
		sq_FillBlanksPartialCycles(dataSet, 0)
	endif
End

Function gen_DrawVertLines(XaxisLines, gname)
wave XaxisLines
string gname

	variable idex, num = numpnts(XaxisLines)
	
	DoWindow/F $gname
	if (!V_flag)
		return 0
	endif
	DrawAction/W=$gname getgroup=$gname, delete, begininsert	
	SetDrawEnv/W=$gname gstart,gname= $gname
	for (idex=0;idex<num;idex+=1)
		SetDrawEnv/W=$gname xcoord= bottom
		DrawLine/W=$gname XaxisLines[idex],0,XaxisLines[idex],1
	endfor
	SetDrawEnv/W=$gname gstop	
	DrawAction/W=$gname endinsert

End


//& A find value function that isn't spoofed by nan's
Function sq_getRunPos(run)
variable run
	wave rn_series = root:index:rn_series
	return sq_findRun(rn_series,run)
End


Function gen_SetDimLabels(w, dimN, list)
wave w
variable dimN 
string list
		
	variable maxN = dimsize(w,dimN)
	variable idex, maxList = itemsInList(list) 
	for(idex = 0;idex<Min(maxN, maxList); idex+=1)
		SetDimLabel dimN,idex, $stringFromList(idex, list), w
	endfor	
End


Function gen_getWinLTRB(str, LTRB)
string str
wave LTRB

	GetWindow/Z $str wsizeRM
	if (V_flag)
		return 0
	else		
		gen_SetDimLabels(LTRB, 0, "l;t;r;b")		
		LTRB[%l]=V_left
		LTRB[%t]=V_top
		LTRB[%r]=V_right
		LTRB[%b]=V_bottom		
	endif
	
End


Function gen_MoveIt(str1, str2)  // move window str1 to be to the right of window str2
string str1, str2	
	
	make/o/free/i/n=4 LTRB1=0, LTRB2=0
	
	if (gen_getWinLTRB(str1, LTRB1))
		return 0
	endif
	if (gen_getWinLTRB(str2, LTRB2))
		return 0
	endif
	
	variable factor

	if (WinTYpe(str2)==7)
		#if (IgorVersion()>=7)
			factor = ScreenResolution/panelResolution(str2)
			LTRB2/=factor
		#endif
	endif
	
	if (WinTYpe(str1)==1)
		#if (IgorVersion()>=7)
			LTRB1/=ScreenResolution/panelResolution(str1)
		#endif
	endif

	Dowindow/F $str1
	Dowindow/F $str2
	if (IgorVersion() <7)
		MoveWindow/W=$str1 factor*LTRB2[%r],factor*LTRB2[%t],factor*(LTRB2[%r]+(LTRB1[%r]-LTRB1[%l])),factor*(LTRB2[%t]+(LTRB1[%b]-LTRB1[%t])) // left, top, right, bottom
	else
		MoveWindow/W=$str1 factor*LTRB2[%r],factor*LTRB2[%t],-1,-1 // left, top, right, bottom
	endif
End

