#pragma TextEncoding = "Windows-1252"
#pragma rtGlobals=3		// Use modern global access method.
//#pragma version=1.17d// decided to not use pragma but a string constant 

//ToF-AMS data processing kit for ToF-AMS analysis Toolkit
//Copyright (C) 2005, 2006, 2007,2008, 2009,2010,2011, 2012, 2013, 2014, 2015, 2016, 2017
//James Allan (SEAES, University of Manchester, UK; DIAC, NCAS, UK)
//Jonathan Crosier (SEAES, University of Manchester, UK)
//Edward Dunlea (CIRES, University of Colorado at Boulder, CO, USA)
//Donna Sueper (CIRES, University of Colorado at Boulder, CO, USA; Aerodyne Research Inc., MA, USA)
//
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

///////////////////////////////////////////////////////////////////////////////
// CURRENT STATUS
// see Read me file for details.


Function mz_createGlobalsMzCalibration()
 
	wave series_index=root:index:series_index
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	wave todowave = $"root:"+sq_toDoWvNm
	
	variable idex, numMasses, numRuns
	string tempStr, MassStr
	
	numRuns = numpnts(series_index) 
	NewDataFolder/o root:mzFitting
	
	wave/z mz_Mass = root:mzFitting:mz_Mass
	if (!WaveExists(mz_mass))
		mz_makeMzCal_Waves()
		wave mz_Mass = root:mzFitting:mz_Mass
	endif
	
	numMasses = numpnts(mz_Mass) 
	
	wave/z OneRunFitTime = root:mzFitting:OneRunFitTime
	
	if (!WaveExists(OneRunFitTime))
	
		make/o/n=(numMasses) root:mzFitting:OneRunFitTime		//^ values of peak (fitted) centers, in time space
		make/o/n=(numMasses) root:mzFitting:OneRunLoggedTime	//^ time using logging values
		make/o/n=(numMasses) root:mzFitting:OneRunPowerFit		//^ power fit of OneRunFitTime
	
		make/o/n=(numMasses) root:mzFitting:OneRunAccuracyMass   //^ difference between fit and actual
		make/o/n=(numMasses) root:mzFitting:OneRunAccuracyTime   //^ difference between fit and actual
	
		make/o/n=(100) root:mzFitting:OneRunPowerFitDisplayX		//^ more granular display of power fit of OneRunFitTime
		make/o/n=(100) root:mzFitting:OneRunPowerFitDisplayY		//^ more granular display ofower fit of OneRunFitTime
	
		make/o/n=(numMasses) root:mzFitting:OneRun_deltaTSquared
		make/o/n=(numMasses) root:mzFitting:OneRun_deltaTSquared_fit   // fit of delta_t_squared_FWHM to mass
			
		make/o/n=(numMasses) root:mzFitting:OneRunDisplayPC_GaussFit=1e5  //^ display peak center for each mass
		make/o/n=(numMasses) root:mzFitting:OneRunDisplayPC_Fit=1e5  //^ display peak center for each mass
		make/o/n=(numMasses) root:mzFitting:OneRunDisplayPC_Log=1e5  //^ arbitrary
	
		make/o/n=(0) root:mzFitting:OneRunRawSpectra
	
		make/o/n=(30) root:mzFitting:ppmGuidelinesTop
		make/o/n=(30) root:mzFitting:ppmGuidelinesBottom
		make/o/n=(30) root:mzFitting:ppmGuidelinesMz
		wave ppmGuidelinesTop = root:mzFitting:ppmGuidelinesTop
		wave ppmGuidelinesBottom = root:mzFitting:ppmGuidelinesBottom
		wave ppmGuidelinesMz = root:mzFitting:ppmGuidelinesMz
		ppmGuidelinesMz = (p+1)*10
		
	endif
	
	for (idex=0;idex<6;idex+=1)		// create them all in case they may be used later.
		make/o/n=(41) $( "root:mzFitting:fit_gauss_Y_"+num2str(idex) )		// we fit points and want a 10 pt resolution - first ftp*10 + last point
		make/o/n=(41) $( "root:mzFitting:fit_gauss_X_"+num2str(idex)  )
	endfor

	make/o/n=(0) root:mzFitting:OneRunRawSpectra				//^ raw spectra from one run

	for (idex=0;idex<numMasses;idex+=1)
		sprintf MassStr "%1.2f", mz_Mass[idex]
		MassStr = ReplaceString(".",MassStr,"_")			
		make/o/n=(numRuns) $"root:mzFitting:Accuracy_"+MassStr
	endfor

	sq_initializeGlobalNVar("root:mzFitting:mz_OrigSlopeVar", nan)  
	sq_initializeGlobalNVar("root:mzFitting:mz_OrigInterceptVar", nan)  
	sq_initializeGlobalNVar("root:mzFitting:mz_OrigPowerVar", nan)
	sq_initializeGlobalNVar("root:mzFitting:mz_FitSlopeVar", nan)
	sq_initializeGlobalNVar("root:mzFitting:mz_FitInterceptVar", nan)
	sq_initializeGlobalNVar("root:mzFitting:mz_FitPowerVar", nan)
	sq_initializeGlobalNVar("root:mzFitting:mz_RatioSlopeVar", nan)
	sq_initializeGlobalNVar("root:mzFitting:mz_RatioInterceptVar", nan)
	sq_initializeGlobalNVar("root:mzFitting:mz_RatioPowerVar", nan)

	sq_initializeGlobalNVar("root:mzFitting:FilterThresholdPercentVar", 1)
	sq_initializeGlobalNVar("root:mzFitting:FilterThresholdNumRemoved", 0)
	sq_initializeGlobalNVar("root:mzFitting:FilterNumNans", nan)

	sq_initializeGlobalNVar("root:mzFitting:KeepPowerParamConstant", 0)

	sq_initializeGlobalNVar("root:mzFitting:gaussGood", 0) 
	sq_initializeGlobalNVar("root:mzFitting:gaussBad", 0)
	sq_initializeGlobalNVar("root:mzFitting:NoRawSpectra", 0)
		
	sq_initializeGlobalNVar("root:mzFitting:mz_viewManySleepSec", 0)
	
	sq_initializeGlobalNVar("root:mzFitting:ResolutionAvgVMode",nan)
	sq_initializeGlobalNVar("root:mzFitting:ResolutionStdVMode",nan)
	sq_initializeGlobalNVar("root:mzFitting:ResolutionAvgWMode",nan)
	sq_initializeGlobalNVar("root:mzFitting:ResolutionStdWmode",nan)
//	sq_initializeGlobalNVar("root:mzFitting:t_ionAvg",nan)  1.61G
//	sq_initializeGlobalNVar("root:mzFitting:t_ionStd",nan)  1.61G

	sq_initializeGlobalNVar("root:mzFitting:mz_checkMz_MS", 1)
	sq_initializeGlobalNVar("root:mzFitting:mz_checkMz_PToF", 0)

	sq_initializeGlobalSVar("root:mzFitting:mz_runModeStr", "")	
	sq_initializeGlobalSVar("root:mzFitting:FitNotDisplayed","")

	sq_initializeGlobalNVar("root:mzFitting:mz_LiveUpdate",0)		//1.59D  changed default
	
	sq_initializeGlobalNVar("root:mzFitting:mz_UsePreviousRunParams",0)
	sq_initializeGlobalNVar("root:mzFitting:mz_RegionScalar",1)
	
	sq_initializeGlobalNVar("root:mzFitting:mz_spectraType",2)	//	1.51C

	sq_initializeGlobalNVar("root:mzFitting:PowerConstant", 0.5)		// 1.51H	

	variable/g root:mzFitting:mz_CurrentRunNum
	nvar mz_CurrentRunNum= root:mzFitting:mz_CurrentRunNum
	mz_CurrentRunNum = todowave[0]
	
	string/g root:mzFitting:mz_SpecTypeStr
	svar mz_SpecTypeStr =  root:mzFitting:mz_SpecTypeStr
	mz_SpecTypeStr ="Spec Type: 0 = Don't Use\r"
	mz_SpecTypeStr +="1=Diff,2=Closed,3=Open,4=PToF\r"		//1.49A
	mz_SpecTypeStr +="Delta: Fit 2*Delta+1 points\r"
	mz_SpecTypeStr +="Plot: 0 = Don't Show, 1 = Show"

	//1.50C
	sq_initializeGlobalNVar("root:mzFitting:ShowPpmGraph",1)
	sq_initializeGlobalNVar("root:mzFitting:ShowResolutionGraph",1)
	sq_initializeGlobalNVar("root:mzFitting:ShowParamGraph",1)  //1.61G

	sq_initializeGlobalSVar("root:mzFitting:FitNotDisplayed","")		//1.52O
	sq_initializeGlobalSVar("root:mzFitting:mz_FitMassList","")		//1.52O
	sq_initializeGlobalNVar("root:mzFitting:OpenOnlyFlag",1)			//1.52O

	sq_initializeGlobalNVar("root:mzFitting:mz_smoothFinalParamsVar", 0)  //1.21G

	mz_InitializeMzCalibration()

End


//^  create and set mzCal Mass values in mzFitting folder - assumes folder exists.  Set default values for choosing which to user for m/z fitting
Function mz_makeMzCal_Waves()
	
	NewDataFolder/O root:mzFitting
	make/o/n=30 root:mzFitting:mz_Mass
	make/t/o/n=30 root:mzFitting:mz_Name
	make/o/n=30 root:mzFitting:mz_SpecType
	make/o/n=30 root:mzFitting:mz_DeltaNum
	make/o/n=30 root:mzFitting:mz_Graph
	wave mz_Mass=root:mzFitting:mz_Mass
	wave/t mz_Name=root:mzFitting:mz_Name
	wave mz_SpecType=root:mzFitting:mz_SpecType
	wave mz_DeltaNum=root:mzFitting:mz_DeltaNum
	wave mz_Graph=root:mzFitting:mz_Graph
	
	//^ list compiled by Peter.. Donna added a few.
	//^ 1 = Diff;       2 = Closed;        3 = Open;        4 = PToF;     0 = Don't Use
//	mz_Mass[n]=12;				mz_Name[n]="C+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;		
//	mz_Mass[n]=14.00306988;	mz_Name[n]="N+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;
//	mz_Mass[n]=15.99491978;	mz_Name[n]="O+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;
//	mz_Mass[n]=18.010565;		mz_Name[n]="H2O+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;
//	mz_Mass[n]=28.0060997;		mz_Name[n]="N2+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;
//	mz_Mass[n]=31.98983002;	mz_Name[n]="O2+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;
//	mz_Mass[n]=39.96239853;	mz_Name[n]="Ar+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=2;	mz_Graph[n]=1;
//	mz_Mass[n]=91.05477142;	mz_Name[n]="C7H7+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=3;	mz_Graph[n]=1;
//	mz_Mass[n]=91.47509766;	mz_Name[n]="W(183)++";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=3;	mz_Graph[n]=1;
//	mz_Mass[n]=149.02387;		mz_Name[n]="C8H5O3+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=4;	mz_Graph[n]=1;
//	mz_Mass[n]=181.948; 		mz_Name[n]="W(182)+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=5;	mz_Graph[n]=1;
//	mz_Mass[n]=183.950;		mz_Name[n]="W(184)+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=5;	mz_Graph[n]=1;
//	mz_Mass[n]=185.954;		mz_Name[n]="W(186)+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=5;	mz_Graph[n]=1;
//	mz_Mass[n]=279.15963;		mz_Name[n]="C16H23O4+";	mz_SpecType[n]=0;	 mz_DeltaNum[n]=7;	mz_Graph[n]=1;
//
//
// updated in 1.50B
	variable n=0

	mz_Mass[n]=12.00000000;	mz_Name[n]="C+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;	
	mz_Mass[n]=13.00782503;	mz_Name[n]="CH+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=14.00307401;	mz_Name[n]="N+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=15.99491462;	mz_Name[n]="O+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=17.00273965;	mz_Name[n]="OH+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=18.01056469;	mz_Name[n]="H2O+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=25.00782503;	mz_Name[n]="C2H+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=28.00614801;	mz_Name[n]="N2+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=31.98982924;	mz_Name[n]="O2+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=38.01565006;	mz_Name[n]="C3H2+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=39.02347510;	mz_Name[n]="C3H3+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=39.96238312;	mz_Name[n]="Ar+";			mz_SpecType[n]=2;	 mz_DeltaNum[n]=6;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=43.98982924;	mz_Name[n]="CO2+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=6;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=47.96698535;	mz_Name[n]="SO+";			mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=50.01565006;	mz_Name[n]="C4H2+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=57.07042529;	mz_Name[n]="C4H9+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=62.01565006;	mz_Name[n]="C5H2+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=63.96189997;	mz_Name[n]="SO2+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=77.03912516;	mz_Name[n]="C6H5+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=79.95681460;	mz_Name[n]="SO3+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=91.05477522;	mz_Name[n]="C7H7+";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=91.47511210;	mz_Name[n]="W183++";		mz_SpecType[n]=0;	 mz_DeltaNum[n]=5;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=149.02386903;	mz_Name[n]="C8H5O3+";	 	mz_SpecType[n]=2;	 mz_DeltaNum[n]=6;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=181.94820500;	mz_Name[n]="W182+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=8;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=183.95093230;	mz_Name[n]="W184+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=8;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=185.95436200;	mz_Name[n]="W186+";		mz_SpecType[n]=2;	 mz_DeltaNum[n]=8;		mz_Graph[n]=1;	n+=1;
	mz_Mass[n]=279.15963422;	mz_Name[n]="C16H23O4+";	mz_SpecType[n]=0;	 mz_DeltaNum[n]=12;		mz_Graph[n]=1;	n+=1;
//1.52O
	deletepoints n, 30, mz_Mass,mz_Name,mz_SpecType,mz_DeltaNum,mz_Graph

End


//^  Creates & sets waves to nan
//^ Significantly reorganized, with the createGlobals function.  Now allows users to 'update' 
//^ and not reset to nan ever time the panel is called.
//^ A cleaner way to do this is with strings....
Function mz_initializeMzCalibration()

	wave rn_series = root:index:rn_series
	wave mz_Mass = root:mzFitting:mz_Mass
	variable idex, numRuns, numOldRuns, numNewRuns, numMasses
	string MassStr
	
	numRuns =  numpnts(rn_series)
	numMasses = numpnts(mz_Mass)
	
	wave/z mz_FitIntercept = root:mzFitting:mz_FitIntercept

	if (waveExists(mz_FitIntercept)==0)		//assume if one is missing, all are
		
		make /o/n=(numRuns) root:mzFitting:mz_FitIntercept=nan
		make /o/n=(numRuns) root:mzFitting:mz_FitSlope=nan
		make /o/n=(numRuns) root:mzFitting:mz_FitPower=nan
		make /o/n=(numRuns) root:mzFitting:mz_FitChiSq=nan
	
		make /o/n=(numRuns) root:mzFitting:mz_RatioIntercept=nan
		make /o/n=(numRuns) root:mzFitting:mz_RatioSlope=nan
		make /o/n=(numRuns) root:mzFitting:mz_RatioPower=nan
		make /o/n=(numRuns) root:mzFitting:FitFilterKey=nan
	
		make /o/n=(numRuns) root:mzFitting:mz_ToFTypeDisplayKey=1
		make /o/n=(numRuns) root:diagnostics:mzPower=0.5		// we will use it later
			
		make /o/n=(numRuns) root:mzFitting:t_ion=nan
		make /o/n=(numRuns) root:mzFitting:Resolution=nan
		make /o/n=(numRuns) root:mzFitting:ppmStd=nan
		make/o/n=(numRuns) root:mzFitting:deltaTSquared_Chisq
	
		make/o/n=(numRuns,2) root:mzFitting:deltaTSquared_coefs		// intercept and slope of delta_t_squared_fit
	
		make/o/n=(numRuns, numMasses) root:mzFitting:AllRunsMassSigma=nan
		make/o/n=(numRuns, numMasses) root:mzFitting:AllRunsAccuracyTime=nan
		make/o/n=(numRuns, numMasses) root:mzFitting:AllRunsAccuracyMass=nan

	else		//^ we are not starting from scratch

		numOldRuns = numpnts(mz_FitIntercept)
		numNewRuns = numRuns - numOldRuns
		
		wave mz_FitSlope = root:mzFitting:mz_FitSlope
		wave mz_FitPower = root:mzFitting:mz_FitPower
		wave mz_FitChiSq =root:mzFitting:mz_FitChiSq

		wave mz_RatioIntercept = root:mzFitting:mz_RatioIntercept
		wave mz_RatioSlope = root:mzFitting:mz_RatioSlope
		wave mz_RatioPower = root:mzFitting:mz_RatioPower
		wave FitFilterKey = root:mzFitting:FitFilterKey

		wave  mz_ToFTypeDisplayKey = root:mzFitting:mz_ToFTypeDisplayKey
		wave/z mzPower = root:diagnostics:mzPower	
		if (WaveExists(mzPower)==0)			//1.57J
	//		duplicate/o mzSlope root:diagnostics:mzPower
			make/n=(numRuns) root:diagnostics:mzPower/wave=mzPower
			mzPower=.5
		endif	

		wave t_ion = root:mzFitting:t_ion
		wave Resolution = root:mzFitting:Resolution
		wave ppmStd = root:mzFitting:ppmStd
		wave deltaTSquared_Chisq = root:mzFitting:deltaTSquared_Chisq

		wave deltaTSquared_coefs =  root:mzFitting:deltaTSquared_coefs		// intercept and slope of delta_t_squared_fit

		wave AllRunsMassSigma = root:mzFitting:AllRunsMassSigma
		wave AllRunsAccuracyTime = root:mzFitting:AllRunsAccuracyTime
		wave AllRunsAccuracyMass = root:mzFitting:AllRunsAccuracyMass

		if (numNewRuns>0)		// 1.43A this entire if statement added because indexing isn't nice outside the numpts in wave
		
	//		wave mz_FitIntercept = root:mzFitting:mz_FitIntercept  // already declared
			InsertPoints numOldRuns,numNewRuns, mz_FitIntercept, mz_FitSlope, mz_FitPower, mz_FitChiSq
			mz_FitIntercept[numOldRuns,]=nan
			mz_FitSlope[numOldRuns,]=nan
			mz_FitPower[numOldRuns,]=nan
			mz_FitChiSq[numOldRuns,]=nan

			InsertPoints numOldRuns,numNewRuns, mz_RatioIntercept, mz_RatioSlope, mz_RatioPower, FitFilterKey
			mz_RatioIntercept[numOldRuns,]=nan
			mz_RatioSlope[numOldRuns,]=nan
			mz_RatioPower[numOldRuns,]=nan
			FitFilterKey[numOldRuns,]=nan
		
			InsertPoints numOldRuns,numNewRuns, mz_ToFTypeDisplayKey, mzPower
			mz_ToFTypeDisplayKey[numOldRuns,]=1
			mzPower[numOldRuns,]= 0.5
	
			InsertPoints numOldRuns,numNewRuns, t_ion, Resolution, ppmStd, deltaTSquared_Chisq
			t_ion[numOldRuns,]=nan
			Resolution[numOldRuns,]=nan
			ppmStd[numOldRuns,]=nan
			deltaTSquared_Chisq[numOldRuns,]=nan

			InsertPoints/M=0 numOldRuns,numNewRuns, deltaTSquared_coefs
			deltaTSquared_coefs[numOldRuns,][]=nan
		
			InsertPoints/M=0 numOldRuns,numNewRuns, AllRunsMassSigma, AllRunsAccuracyTime, AllRunsAccuracyMass
			AllRunsMassSigma[numOldRuns,][]=nan
			AllRunsAccuracyTime[numOldRuns,][]=nan
			AllRunsAccuracyMass[numOldRuns,][]=nan

			for (idex=0;idex<numMasses;idex+=1)
				sprintf MassStr "%1.2f", mz_Mass[idex]
				MassStr = ReplaceString(".",MassStr,"_")			
				make/o/n=(numRuns) $"root:mzFitting:Accuracy_"+MassStr
			endfor

		endif // we have more runs than when we last calculated
			
	endif // we already had the waves above created

	wave OneRun_deltaTSquared = root:mzFitting:OneRun_deltaTSquared
	wave OneRun_deltaTSquared_fit = root:mzFitting:OneRun_deltaTSquared_fit 
	wave deltaTSquared_Chisq = root:mzFitting:deltaTSquared_Chisq 
	wave deltaTSquared_coefs = root:mzFitting:deltaTSquared_coefs
	OneRun_deltaTSquared=nan
	OneRun_deltaTSquared_fit=nan
	deltaTSquared_Chisq=nan
	deltaTSquared_coefs=nan

	wave OneRunPowerFitDisplayX = root:mzFitting:OneRunPowerFitDisplayX
	wave OneRunPowerFitDisplayY = root:mzFitting:OneRunPowerFitDisplayY
	OneRunPowerFitDisplayY = nan
	WaveStats/q/m=1	mz_Mass 
	OneRunPowerFitDisplayX =(V_max/100)*(p+1)
	
	wave OneRunFitTime = root:mzFitting:OneRunFitTime
	wave OneRunLoggedTime = root:mzFitting:OneRunLoggedTime
	wave OneRunPowerFit = root:mzFitting:OneRunPowerFit	
	OneRunFitTime=nan
	OneRunLoggedTime=nan
	OneRunPowerFit=nan

	//1.50B
	wave/z OneRunDisplayPC_GaussFit = root:mzFitting:OneRunDisplayPC_GaussFit
	if (!WaveExists(OneRunDisplayPC_GaussFit))
		duplicate/o OneRunFitTime root:mzFitting:OneRunDisplayPC_GaussFit
	endif

	wave OneRunAccuracyMass = root:mzFitting:OneRunAccuracyMass
	wave OneRunAccuracyTime = root:mzFitting:OneRunAccuracyTime 
	OneRunAccuracyMass = nan
	OneRunAccuracyTime = nan
			
	nvar ResolutionAvgVMode = root:mzFitting:ResolutionAvgVMode
	nvar ResolutionStdVMode = root:mzFitting:ResolutionStdVMode
	nvar ResolutionAvgWMode = root:mzFitting:ResolutionAvgWMode
	nvar ResolutionStdWmode = root:mzFitting:ResolutionStdWmode
//	nvar t_ionAvg = root:mzFitting:t_ionAvg
//	nvar t_ionStd = root:mzFitting:t_ionStd
	ResolutionAvgVMode=nan
	ResolutionStdVMode=nan
	ResolutionAvgWMode=nan
	ResolutionStdWmode = nan
//	t_ionAvg=nan
//	t_ionStd=nan

End


Function mz_calibrationPanel() // rearranged in   //1.61G

	PauseUpdate; Silent 1		// building window...
	NewPanel/N=SQ_MzCalibration_Panel /W=(308,112,1220,710) as "SQ_MzCalibration_Panel"
	ModifyPanel fixedSize=1
	SetDrawLayer UserBack
	SetDrawEnv linethick= 2,linefgc= (0,0,52224),fillpat= 0
	DrawRect 2,198,477,595
	SetDrawEnv linethick= 2,linefgc= (65280,43520,32768),fillpat= 0
	DrawRect 480,337,905,570
	SetDrawEnv linethick= 2,linefgc= (52224,0,41728),fillpat= 0
	DrawRect 480,2,905,335
	SetDrawEnv linethick= 2,linefgc= (0,52224,0),fillpat= 0
	DrawRect 2,23,477,195
	SetDrawEnv linethick= 2,linefgc= (0,52224,0),fillpat= 0
	DrawRect 480,570,885,595
	
	SetDrawEnv fstyle= 1
	DrawText 4,19,"Power Fit: sample number = intercept + slope*(mass^power)"
	SetDrawEnv fstyle= 1
	DrawText 8,41,"Step 1. Choose m/z fitting settings by editing values in the table and checkboxes."
	SetDrawEnv fstyle= 1
	DrawText 8,217,"Step 2. Find, view results for one run.  Repeat steps 1, 2 until accuracy values are low."
	SetDrawEnv fstyle= 1
	DrawText 484,21,"Step 3. Using Step 1 settings, find m/z parameters for all runs in todo wave."
	SetDrawEnv fstyle= 1
	DrawText 486,356,"Step 4, 5. View, perhaps modify parameters."
	SetDrawEnv fstyle= 1
//	DrawText 375,22,"Step 5. (Optional) View results."
//	SetDrawEnv fstyle= 1
	DrawText 482,591,"Step 6. (Rare) Declare separate params for open/closed."
	DrawText 230,595,"Black=Data, Red=Gauss Fit, Gold=Power Fit"
	
	DefineGuide UGH0={FT,229},UGH1={FT,343},UGH2={FT,463},UGH3={FT,139},UGH4={FT,192}
	DefineGuide UGV0={FL,10},UGV1={FL,162},UGV2={FL,314},UGV3={FL,458},UGV4={FL,486}

	Button button_mz_FittingChoicesTable,pos={460,40},size={14,50},fsize=10,proc=sq_butt_PopThis,title="p\ro\rp"
	Button button_mz_FittingChoicesTable,fColor=(56576,56576,56576)
	Button button_RevertMassSpecOpen,pos={136,166},size={27,30},fsize=8,proc=mz_butt_RevertmzCal_Spec,title="<- \rDo it"

	Button button_Mz_paramGraph,pos={886.00,358.00},size={14.00,60.00},proc=mz_butt_paramGraph,title="p\ro\rp"
	Button button_Mz_paramGraph,fSize=10,fColor=(56576,56576,56576)
	Button button_paramTable,pos={886.00,491.00},size={15.00,70.00},proc=mz_butt_FitParamTable,title="T\ra\rb\rl\re"
	Button button_paramTable,fSize=10

	Button button_mz_copyMzTable pos={460,92}, size={14,55}, title="C\ro\rp\ry",fsize=10, proc=mz_butt_copyMzTable 		//1.44B
	Button button_mz_loadMzTable pos={460,146}, size={14,55},  title="L\ro\ra\rd",fsize=10, proc=mz_butt_loadMzTable 		//1.44B

	PopupMenu popup_MzSelectMasses,pos={4,172},size={130,24},fsize=8		//,proc=sq_pop_toDoList 1.43 A fix
	PopupMenu popup_MzSelectMasses,mode=1,bodyWidth= 130,popvalue="Set to defaults",value= #"\"Set to defaults;Set all Spec Type=Closed;Set all Spec Type=Open;Set all Spec Type=PToF\""		//1.49A
	SetVariable setvar_regiontolook,pos={8,154},size={130,16},fsize=10,title="Peak search factor"
	SetVariable setvar_regiontolook,limits={0.1,10,0.1},value= root:mzFitting:mz_RegionScalar
	CheckBox check_ConstantPower,pos={4,110},size={89,14},title="Power param.="
	CheckBox check_ConstantPower,fSize=10
	CheckBox check_ConstantPower,variable= root:mzFitting:KeepPowerParamConstant
	SetVariable setvar_powerConstant,pos={96,110},size={65,16},title=" ",fSize=10
	SetVariable setvar_powerConstant,format="%0.6f"
	SetVariable setvar_powerConstant,limits={0.1,10,0.001},value= root:mzFitting:PowerConstant
	CheckBox checkMz_MS,pos={4,92},size={34,14},proc=mz_ck_checkMSPToF,title="MS"
	CheckBox checkMz_MS,fSize=10,variable= root:mzFitting:mz_checkMz_MS,mode=1
	CheckBox checkMz_PToF,pos={49,92},size={107,14},proc=mz_ck_checkMSPToF,title="PToF (sum all bins)"
	CheckBox checkMz_PToF,fSize=10,fStyle=0
	CheckBox checkMz_PToF,variable= root:mzFitting:mz_checkMz_PToF,mode=1
	CheckBox check_UsePrevRun,pos={4,126},size={142,14},title="Use previous run's params"
	CheckBox check_UsePrevRun,fSize=10
	CheckBox check_UsePrevRun,variable= root:mzFitting:mz_UsePreviousRunParams
	CheckBox checkMz_UsePreprocessed,pos={4,141},size={86,14},proc=mz_ck_checkMSPToF,title="Use \"_p\" data"
	CheckBox checkMz_UsePreprocessed,fSize=10
	CheckBox checkMz_UsePreprocessed,variable= root:mzFitting:mz_UsePreProcessed

	TitleBox title_moreThanSixGraphs,pos={12,579},size={161,13},fsize=10, variable=root:mzFitting:FitNotDisplayed
	TitleBox title_moreThanSixGraphs,frame=0

	// Fit one run controls
	Button button_FitThisRun,pos={8,242},size={120,20},proc=mz_butt_FitThisRun,title="Find fit for one run"
	Button button_FitThisRun,help={"Calculate and display the logged and fitted mz parameters,"}
	Button button_FitThisRun,fColor=(65280,49152,16384)
	Button button_Mz_FitOneMassGraph,pos={460,347},size={14,60},fsize=10,proc=sq_butt_PopThis,title="p\ro\rp"
	Button button_Mz_FitOneMassGraph,fColor=(56576,56576,56576)
	Button button_Mz_DeltaTSquaredGraph,pos={132,267},size={14,60},fsize=10,proc=sq_butt_PopThis,title="p\ro\rp"		//1.42C fix
	Button button_Mz_DeltaTSquaredGraph,fColor=(56576,56576,56576)										//1.42C fix
	SetVariable setvar_CurrentRunNum,pos={8,221},size={110,16},fsize=10,proc=mz_SetVar_RunNum,title="Run #"
	SetVariable setvar_CurrentRunNum,help={"Enter the run number to view specific values for the logging and fit parameters."}
	SetVariable setvar_CurrentRunNum,format="%u"
	SetVariable setvar_CurrentRunNum,value= root:mzFitting:mz_CurrentRunNum

	GroupBox group_FitVals,pos={149,216},size={94,63},fsize=10,title="Fit values",fStyle=1, fcolor=(1,1,1)
	GroupBox group_DaqVals,pos={148,280},size={94,67},fsize=10,title="Daq values",fStyle=1, fcolor=(1,1,1)
	SetVariable setvar_OrigIntercept,pos={151,296},size={88,16},fsize=10,title="intercept"
	SetVariable setvar_OrigIntercept,help={"Displays the original m/z intercept value."}
	SetVariable setvar_OrigIntercept,format="%1.2f"
	SetVariable setvar_OrigIntercept,limits={0,inf,0},value= root:mzFitting:mz_OrigInterceptVar,noedit= 1
	SetVariable setvar_OrigPower,pos={151,328},size={88,16},fsize=10,title="power"
	SetVariable setvar_OrigPower,help={"Displays the original m/z power (exponent) value."}
	SetVariable setvar_OrigPower,format="%1.5f"
	SetVariable setvar_OrigPower,limits={0,inf,0},value= root:mzFitting:mz_OrigPowerVar,noedit= 1
	SetVariable setvar_OrigSlope,pos={151,312},size={88,16},fsize=10,title="slope"
	SetVariable setvar_OrigSlope,help={"Displays the original m/z slope value."}
	SetVariable setvar_OrigSlope,format="%1.2f"
	SetVariable setvar_OrigSlope,limits={0,inf,0},value= root:mzFitting:mz_OrigSlopeVar,noedit= 1
	SetVariable setvar_FitIntercept,pos={151,231},size={88,16},fsize=10,title="intercept"
	SetVariable setvar_FitIntercept,help={"Displays the fitted m/z intercept value."}
	SetVariable setvar_FitIntercept,format="%1.2f"
	SetVariable setvar_FitIntercept,limits={0,inf,0},value= root:mzFitting:mz_FitInterceptVar,noedit= 1
	SetVariable setvar_FitSlope,pos={151,246},size={88,16},fsize=10,title="slope"
	SetVariable setvar_FitSlope,help={"Displays the fitted m/z slope value.."}
	SetVariable setvar_FitSlope,format="%1.2f"
	SetVariable setvar_FitSlope,limits={0,inf,0},value= root:mzFitting:mz_FitSlopeVar,noedit= 1
	SetVariable setvar_FitPower,pos={151,260},size={88,16},fsize=10,title="power"
	SetVariable setvar_FitPower,help={"Displays the fitted m/z power (exponent) value."}
	SetVariable setvar_FitPower,format="%1.5f"
	SetVariable setvar_FitPower,limits={0,inf,0},value= root:mzFitting:mz_FitPowerVar,noedit= 1

	// fit todo wave controls
	Button button_BeginMzFitting,pos={490,50},size={310,20},proc=mz_butt_BeginMzFitting,title="Find fits for m/z parameters for all runs in todo wave"
	Button button_BeginMzFitting,help={"Pressing this button will begin the mz calibration routine for all runs."}
	Button button_BeginMzFitting,fsize=10,fStyle=0,fColor=(65280,49152,16384)
	Button button_SetToNan,pos={680,18},size={70,32},fsize=10,proc=mz_butt_SetParamsToNan, title="Set params =\rnan in todo"
	Button button_Mz_PpmGraph,pos={888,72},size={14,60},fsize=10,proc=sq_butt_PopThis,title="p\ro\rp"
	Button button_Mz_PpmGraph,fColor=(56576,56576,56576)
	Button button_Mz_CalAccuracyGraph,pos={460,218},size={14,60},fsize=10,proc=sq_butt_PopThis,title="p\ro\rp"
	Button button_Mz_CalAccuracyGraph,fColor=(56576,56576,56576)
	Button button_Mz_ResolutionGraph,pos={888,203},size={14,60},fsize=10,proc=sq_butt_PopThis,title="p\ro\rp"
	Button button_Mz_ResolutionGraph,fColor=(56576,56576,56576)
	SetVariable setvar_sleepBetweenRuns,pos={755,32},size={145,16},fsize=10,title="Sleep between runs, s"
	SetVariable setvar_sleepBetweenRuns,limits={0,60,0.5},value= root:mzFitting:mz_viewManySleepSec
	CheckBox check_LiveUpdate,pos={755,20},size={76,14},fsize=10,title="Live Update"
	CheckBox check_LiveUpdate,variable= root:mzFitting:mz_LiveUpdate
	TitleBox titlebox_mz_SpecType,pos={8,39},size={157,52},fSize=10,frame=0
	TitleBox titlebox_mz_SpecType,variable= root:mzFitting:mz_SpecTypeStr

	// Step 4,5 Filter bad params controls
	
//	SetVariable setvar_nanNum,pos={346.00,0.00},size={150.00,15.00},title="# runs where fit = nan"
//	SetVariable setvar_nanNum,help={"Indicates the number of runs with nan parameters."}
//	SetVariable setvar_nanNum,fSize=10,limits={0,inf,0},value= root:mzFitting:FilterNumNans,noedit= 1

//	Button button_paramGraph2,pos={722,554},size={40,20},fsize=10,proc=mz_butt_FitParamGraph,title="Graph"

	Button button_DeclareParamsAsOpen,pos={808.00,572.00},size={33.00,20.00},proc=Mz_butt_DeclareParamsAsOC,title="Open"
	Button button_DeclareParamsAsOpen,fSize=10
	Button button_DeclareParamsAsClosed,pos={842.00,572.00},size={40.00,20.00},proc=Mz_butt_DeclareParamsAsOC,title="Closed"
	Button button_DeclareParamsAsClosed,fSize=10
	Button button_mzEnd,pos={887.00,572.00},size={25.00,25.00},proc=sq_butt_End,title="End"
	Button button_mzEnd,fSize=10,fStyle=0

	PopupMenu popup_ToDoWave,pos={490,24},size={184,24},fsize=10,proc=mz_pop_toDoList,title="ToDo Wave"
	PopupMenu popup_ToDoWave,mode=1,bodyWidth= 120,popvalue="all",value= #"root:panel:sq_toDoList+\"Get List;\"\t"		//1.58G

	// m/z param table
	Edit/W=(150,42,459,177)/FG=(UGV1,,,UGH4)/HOST=#
	mz_populate_FittingChoicesTable()
	RenameWindow #,FittingChoicesTable
	SetActiveSubwindow ##

	// FitRunmz_Mass graph
	Display/W=(245,218,459,344)/HOST=#
	mz_populate_CalAccuracyGraph()
	RenameWindow #,CalAccuracyGraph
	SetActiveSubwindow ##

	// deltaTSquared graph
	Display/W=(10,269,132,324)/FG=(UGV0,,,UGH1)/HOST=#
	mz_populate_DeltaTSquaredGraph()
	RenameWindow #,deltaTSquaredGraph
	SetActiveSubwindow ##
	
	// param graph

	mz_individMassFitGraphs()		//1.51D changed the order so it doesn't take so long to load

	CheckBox check_PPMGraph,pos={861,55},size={45,14},proc=mz_showGraph_CheckProc,title="Show"
	CheckBox check_PPMGraph,fSize=10,variable= root:mzFitting:ShowPpmGraph
	CheckBox check_ResolutionGraph,pos={861,190},size={45,14},proc=mz_showGraph_CheckProc,title="Show"
	CheckBox check_ResolutionGraph,fSize=10
	CheckBox check_ResolutionGraph,variable= root:mzFitting:ShowResolutionGraph
	CheckBox check_ParamGraph,pos={861,343},size={45,14},proc=mz_showGraph_CheckProc,title="Show"
	CheckBox check_ParamGraph,fSize=10,variable= root:mzFitting:ShowParamGraph

	nvar ShowParamGraph = root:mzFitting:ShowParamGraph
	nvar ShowResolutionGraph = root:mzFitting:ShowResolutionGraph
	nvar ShowPpmGraph = root:mzFitting:ShowPpmGraph

	mz_showGraph_CheckProc("check_ParamGraph", ShowParamGraph)
	mz_showGraph_CheckProc("check_ResolutionGraph", ShowResolutionGraph)
	mz_showGraph_CheckProc("check_PPMGraph", ShowPpmGraph)

//	// ppmGr graph
//	Display/W=(486,72,885,198)/FG=(UGV4,,,)/HOST=#
//	mz_populate_PpmGraph()
//	RenameWindow #,ppmGraph
//	SetActiveSubwindow ##
//
//	// Resolution graph
//	Display/W=(487,202,884,328)/FG=(UGV4,,,)/HOST=#
//	mz_populate_ResolutionGraph()
//	RenameWindow #,ResolutionGraph
//	SetActiveSubwindow ##
//	
//	// RatioGraph 
//	Display/W=(486,357,881,481)/FG=(UGV4,,,)/HOST=#
//	mz_populate_ParamRatioGraph()
//	RenameWindow #,RatioGraph
//	SetActiveSubwindow ##

	mz_SetppmAxis()

End

Function mz_individMassFitGraphs()

	variable grXstart, grYstart, grXwidth, grYheight
	//^ 6 individual mass peak fitting windows, + 1 run fit window. 
	variable winX0 = 10, winY0 = 345
	variable winDelta = 3
	variable winHeight = 113, winWidth = 150
	variable winRow, winCol
	variable idex
	string numStr 
		
	wave OneRunLoggedTime = root:mzFitting:OneRunLoggedTime
	wave OneRunPowerFit = root:mzFitting:OneRunPowerFit
	wave OneRunFitTime = root:mzFitting:OneRunFitTime
	
	wave OneRunDisplayPC_GaussFit = root:mzFitting:OneRunDisplayPC_GaussFit
	wave OneRunDisplayPC_Fit = root:mzFitting:OneRunDisplayPC_Fit
	wave OneRunDisplayPC_Log = root:mzFitting:OneRunDisplayPC_Log

	wave OneRunRawSpectra = root:mzFitting:OneRunRawSpectra

	PauseUpdate //1.50C	

	for(idex=0;idex<6;idex+=1)	
	
		numStr = num2str(idex)
		winRow = floor(idex/3)
		winCol = mod(idex,3)
		grXstart = winX0 + winCol*(winWidth+winDelta)
		grYstart = winY0+winRow*(winHeight+winDelta)
		grXwidth = grXstart + winWidth
		grYheight = grYstart + winHeight
		
		// this is painful.... guides are fussy 
 		mz_IndividualMassGrPlacement(idex, grXstart, grYstart, grXwidth, grYheight)
 		
		wave/z wx = $"root:mzFitting:fit_gauss_X_"+numStr	
		wave/z wy = $"root:mzFitting:fit_gauss_Y_"+numStr					
		wy = nan

		AppendToGraph OneRunRawSpectra
		ModifyGraph rgb(OneRunRawSpectra)=(0,0,0)
		ModifyGraph mode(OneRunRawSpectra)=4,marker(OneRunRawSpectra)=19
		
		AppendToGraph OneRunDisplayPC_Log vs OneRunLoggedTime
		AppendToGraph OneRunDisplayPC_GaussFit vs OneRunFitTime
		AppendToGraph OneRunDisplayPC_Fit vs OneRunPowerFit
		ModifyGraph mode(OneRunDisplayPC_Fit)=1
		ModifyGraph mode(OneRunDisplayPC_Log)=1
		ModifyGraph mode(OneRunDisplayPC_GaussFit)=1
		ModifyGraph rgb(OneRunDisplayPC_Fit)=(39168,39168,0)
		ModifyGraph rgb(OneRunDisplayPC_Log)=(0,0,0)
		ModifyGraph rgb(OneRunDisplayPC_GaussFit)=(65280,0,0)
		ModifyGraph lsize(OneRunDisplayPC_Fit)=3
		AppendToGraph wy vs wx
		SetAxis bottom 0,1 		// to prevent it from taking a long time
		ModifyGraph margin(left)=36,margin(bottom)=36,margin(top)=7,margin(right)=7
		ModifyGraph width=108,height=72
		ModifyGraph rgb($NameofWave(wy))=(65280,22016,1024)
		ModifyGraph lsize($NameofWave(wy))=2
		RenameWindow #,$"Fit_"+numStr		// MassStr		//1.50A
	endfor

	ResumeUpdate	//1.50C
	
End


Function mz_setppmAxis()

	DoWindow SQ_mzCalibration_Panel
	if (!V_flag)
		return 0	
	endif
	
	nvar isC = root:diagnostics:isC
	string childList =  ChildWindowList("SQ_mzCalibration_Panel" )

	 if (WhichListItem("ppmGraph", childList)>=0 )	
		SetActiveSubwindow SQ_MzCalibration_Panel#ppmGraph
		if (!isC)
			SetAxis right -50,50
		else
			SetAxis right -500,500
		endif
	endif
		
	 if (WhichListItem("CalAccuracyGraph", childList)>=0 )	
		SetActiveSubwindow SQ_MzCalibration_Panel#CalAccuracyGraph
		if (!isC)
			SetAxis right -50,50
		else	
			SetAxis right -500,500
		endif
	endif
	SetActiveSubwindow #

End


//^	All the individual fit windows
Function	mz_individualMassFitGraphs()

	DoWindow/F SQ_MzCalibration_Panel
//	if (v_flag!=1)
//		Abort "Is the calibration panel window renamed? - Aborting from mz_IndividualMassFitGraphs"
//	endif
	
	wave/t mz_Name = root:mzFitting:mz_Name
	wave mz_SpecType = root:mzFitting:mz_SpecType
	wave mz_Mass = root:mzFitting:mz_Mass
	wave mz_Graph = root:mzFitting:mz_Graph
	
//	wave OneRunLoggedTime = root:mzFitting:OneRunLoggedTime
//	wave OneRunPowerFit = root:mzFitting:OneRunPowerFit
//	
//	wave OneRunDisplayPC_Fit = root:mzFitting:OneRunDisplayPC_Fit
//	wave OneRunDisplayPC_Log = root:mzFitting:OneRunDisplayPC_Log
//
//	nvar mz_checkMz_MS =root:mzFitting:mz_checkMz_MS
//	nvar mz_checkMz_PToF =root:mzFitting:mz_checkMz_PToF

	variable idex, num, numMzCal=numpnts(mz_SpecType), numMzCal_2Fit, numMzCal_2Display
	string MassList="", MassStr, MassNameList=""
		
	string/g  root:mzFitting:FitNotDisplayed = ""
	svar FitNotDisplayed = root:mzFitting:FitNotDisplayed
	
 	numMzCal_2Fit=-1	// this is kinda tricky.  We want to start counting from 0.
 	numMzCal_2Display=-1// this is kinda tricky.  We want to start counting from 0.
	
	for(idex=0;idex<numMzCal;idex+=1)		// loop through every mass in table
//		if ( mz_Graph[idex]>0 && (mz_checkMz_MS && (mz_SpecType[idex]==1 || mz_SpecType[idex]==2 || mz_SpecType[idex]==3)) || (mz_checkMz_PToF && mz_SpecType[idex]==4 )  )
		if ( mz_SpecType[idex]>0) 
			numMzCal_2Fit+=1		// The first mass to fit counts from 0.
			if ( mz_Graph[idex]>0 && numMzCal_2Display< 5 )
				numMzCal_2Display+=1						
			else		// we fit but don't display
				sprintf MassStr "%1.2f", mz_Mass[idex]
				FitNotDisplayed+= mz_Name[idex]+", "//MassStr + "="+mz_Name[idex]+" "
			endif	// display or no		
		endif	// fit this mass
	endfor	//loop through all masses
	
	if (strlen(FitNotDisplayed)>0)
		FitNotDisplayed= "Not displayed:"+FitNotDisplayed
	endif

	if (nummzCal_2Fit<3)
		Abort " At least 4 masses needed to be chosen to find a fit. - aborting from mz_IndividualMassFitGraphs"
	endif

End


Function mz_individualMassGrPlacement(nummzCal_2Fit, grXstart, grYstart, grXwidth, grYheight)
	variable numMzCal_2Fit, grXstart, grYstart, grXwidth, grYheight			

	DoWindow SQ_MzCalibration_Panel
	if (!V_flag)
		return 0
	endif
	
	SetActiveSubwindow SQ_MzCalibration_Panel
	switch (numMzCal_2Fit)	
	case 0:
		Display/W=(grXstart, grYstart, grXwidth, grYheight)/FG=(UGV0,,,UGH2)/HOST=#		// anchor left, bottom
		break
	case 1:
		Display/W=(grXstart, grYstart, grXwidth, grYheight)/FG=(UGV1,,,UGH2)/HOST=#		// anchor left, bottom
		break
	case 2:
		Display/W=(grXstart, grYstart, grXwidth, grYheight)/FG=(UGV2,,UGV3,UGH2)/HOST=#		// anchor left, right, bottom
		break
	case 3:
		Display/W=(grXstart, grYstart, grXwidth, grYheight)/FG=(UGV0,UGH2,,)/HOST=#		// anchor left, top
		break
	case 4:
		Display/W=(grXstart, grYstart, grXwidth, grYheight)/FG=(UGV1,UGH2,,)/HOST=#		// anchor left, top
		break
	case 5:
		Display/W=(grXstart, grYstart, grXwidth, grYheight)/FG=(UGV2,UGH2,UGV3,)/HOST=#		// anchor left, right, top
		break
	endswitch
	 	
End


// modified in 1.52
Function mz_butt_beginMzFitting(ctrlName) : ButtonControl
	String ctrlName
		
	wave mz_Mass=root:mzFitting:mz_Mass
	wave/T mz_Name=root:mzFitting:mz_Name
	wave mz_SpecType=root:mzFitting:mz_SpecType
	wave AllRunsAccuracyMass=root:mzFitting:AllRunsAccuracyMass

	wave OneRunFitTime=root:mzFitting:OneRunFitTime
	wave OneRunLoggedTime=root:mzFitting:OneRunLoggedTime
	wave OneRunAccuracyMass=root:mzFitting:OneRunAccuracyMass
	wave OneRunAccuracyTime=root:mzFitting:OneRunAccuracyTime

	wave AllRunsAccuracyTime=root:mzFitting:AllRunsAccuracyTime
	wave AllRunsAccuracyMass=root:mzFitting:AllRunsAccuracyMass

	wave OneRunPowerFitDisplayX=root:mzFitting:OneRunPowerFitDisplayX
	wave OneRunPowerFitDisplayY=root:mzFitting:OneRunPowerFitDisplayY
	
	wave ToFTypeVKey = root:diagnostics:ToFTypeVKey
	wave ToFTypeWKey = root:diagnostics:ToFTypeWKey
	
	wave Resolution=root:mzFitting:Resolution
	wave t_ion=root:mzFitting:t_ion

	nvar  ResolutionAvgVMode=root:mzFitting:ResolutionAvgVMode
	nvar  ResolutionStdVMode=root:mzFitting:ResolutionStdVMode
	nvar  ResolutionAvgWMode=root:mzFitting:ResolutionAvgWMode
	nvar  ResolutionStdWMode=root:mzFitting:ResolutionStdWMode
	
//	nvar  t_ionAvg=root:mzFitting:t_ionAvg
//	nvar  t_ionStd=root:mzFitting:t_ionStd

	nvar mz_checkMz_MS = root:mzFitting:mz_checkMz_MS
	nvar mz_checkMz_PToF = root:MzFitting:mz_checkMz_PToF
	nvar mz_LiveUpdate = root:mzFitting:mz_LiveUpdate
	nvar isC = root:diagnostics:isC
	
	svar todoStr=root:panel:sq_toDoWvNm
	nvar FilterNumNans = root:mzFitting:FilterNumNans
	nvar mz_spectraType = root:mzFitting:mz_spectraType

	sq_initializeGlobalNVar("root:mzFitting:mz_UsePreProcessed", 0)  		//1.17c
	nvar mz_UsePreProcessed = root:mzFitting:mz_UsePreProcessed
	string preprocSuffix = selectstring (mz_UsePreProcessed, "", "", "_p")
	
	FilterNumNans = 0
	
	variable numMasses, numRuns, idex, maxMz
	string tempStr = ""

	wave/z todo=$"root:"+todoStr			//1.44B
	if ( !waveexists(todo)  || numpnts(todo)==0)	//^
		Abort " Either the todo wave "+todoStr+ " was not found or was of zero length - Aborting from mz_butt_BeginMzFitting"
	endif
	
	ControlInfo/w=Sq_mzcalibration_panel popup_ToDoWave			//1.42E fix
	if (!stringmatch(S_Value, todoStr))
		abort "Please re-select the todo wave.  Aborting from mz_butt_beginMzFitting"
	endif

	numMasses=numpnts(mz_Mass)
	numRuns=numpnts(todo)
	
	if (numMasses!=numpnts(mz_Mass) || numMasses!=numpnts(mz_SpecType)  ) 
		Abort "When entering values into the mzCal columns, make sure that all columns are the same length.  -  Aborting from mz_butt_BeginMzFitting"
	endif

	maxMz = sq_findMaxMinMz(todo, 1, 0)		//1.52E1  find the smallest of the max mzs.  Make sure we don't request to fit a mass > smallest mz
	if (numtype(maxMz) !=0 || maxMz<0 || maxMz>1e8)		// 1e8 is arbitrary
		abort "The maximum Mz of "+num2str(maxMz)+" seems incorrect.  Aborting from mz_butt_beginMzFitting" 
	endif		//1.60L
	for (idex=0;idex<dimsize(mz_Mass,0); idex+=1)		// does not require that masses are monotonically increasing
		if (mz_SpecType[idex]>0 && mz_Mass[idex]>maxMz)
			DoAlert 1,  "Cannot include mass "+mz_Name[idex] +" in mz calibration because the the max mz value at this spectra was "+num2str(maxMz)+ ".  Select Yes to continue and not fit this mass.  Select No to abort"
			if (V_flag==2)		// user selected NO
				abort "The user chose to abort"
			else
				mz_SpecType[idex]=0
			endif 
		endif
	endfor
	
	for (idex=0;idex<numMasses;idex+=1)		// added in 1.40D
		if (mz_SpecType[idex]>0)
			tempStr +=mz_Name[idex]+";"
		endif
	endfor
	
	print "//** The m/z fitting of masses "+ tempStr+"began at "+time() 

	if (mz_LiveUpdate==0)
 		DoAlert 1, "You have deselected the Live Update option. To speed processing, the panel will close during calculations, then reopen when finished. Select yes to continue, no to abort." 
	 	if (V_flag==1)		// yes
	 		DoWindow/Hide=1  SQ_MzCalibration_Panel		// 1.42E fix OOPS  only works with Igor 6
	 		//DoWindow/K SQ_MzCalibration_Panel
	 	else
	 		return 0
	 	endif
 	endif
		 	
	mz_InitializeMzCalibration()		// redimension,  set various waves to nan		
	mz_ReSizeMzCalWaves()			// reset in case additional masses were added
	mz_IndividualMassFitGraphs()		// do graphs

 	variable SumPToFBins=1		// 1.52	

 	if (mz_checkMz_MS==1)		// MS
		sq_makeRawSpectraGroups()		//1.60S creates todo waves raw spectraXX where XX is the number of points in the raw spectra
		// We will want to do our squirrel fetches with todo waves that have the same number of points in the raw spectra to avoid
		// having to redimension things within a fetch (i.e. raw spectra points of 80,000 and 40,000)  
		string RawSpectraTodoList = waveList("RawSpectra*", ";", "")
		variable numRawList = itemsInList(RawSpectraTodoList)  
		funcref squirrel_proto sq_f=mz_Calibration
 		if (mz_spectraType==1)
//			squirrel_fetch(todo,mz_Calibration,"","MSOpen"+preprocSuffix+";MSClosed"+preprocSuffix+";")	// always perform on raw waves
			sq_iterateOverList(todo, RawSpectraTodoList, numRawList, "", "MSOpen"+preprocSuffix+";MSClosed"+preprocSuffix+";", sq_f)
	 	elseif (mz_spectraType==2)
// 			squirrel_fetch(todo,mz_Calibration,"","MSClosed"+preprocSuffix+";")	// always perform on raw waves
			sq_iterateOverList(todo, RawSpectraTodoList, numRawList, "", "MSClosed"+preprocSuffix+";", sq_f)
 		else
// 			squirrel_fetch(todo,mz_Calibration,"","MSOpen"+preprocSuffix+";")	// always perform on raw waves
			sq_iterateOverList(todo, RawSpectraTodoList, numRawList, "", "MSOpen"+preprocSuffix+";", sq_f)
 		endif
		sq_KillWavesInList(RawSpectraTodoList)	
	else		// PToF  1.52
		string PToFGrpList, PToFGrpStr
		variable numPToFGrp		
		PToFGrpList = WaveList("allPToFGrp*",";","") + WaveList("allePToFGrp*",";","")
		PToFGrpList = SortList(PToFGrpList) 
		numPToFGrp = itemsInList(PToFGrpList)
		funcref squirrel_proto sq_f=mz_Calibration

  		if (SumPToFBins)
  		  	if (FindDimlabel(root:index:squirrel_index,2,"MS_PToF")<0)
// 				squirrel_fetch(todo,sq_create_MS_PToF_fetch,"dest:MS_PToF","PToF;")	// always perform on raw waves		//1.49A
				funcref squirrel_proto sq_fCreate=sq_create_MS_PToF_fetch
				sq_iterateOverList(todo, PToFGrpList, numPToFGrp, "dest:MS_PToF", "PToF;", sq_fCreate)
 			endif
// 			squirrel_fetch(todo,mz_Calibration,"","MS_PToF;")	// always perform on raw waves
			sq_iterateOverList(todo, PToFGrpList, numPToFGrp, "", "MS_PToF;", sq_f)
 		else		// don't sum bins	
//			squirrel_fetch(todo,mz_Calibration,"","PToF;")	// always perform on raw waves
			sq_iterateOverList(todo, PToFGrpList, numPToFGrp, "", "PToF;", sq_f)
 		endif
	endif
	
	print "//** The m/z fitting ended at "+time()
	
	//^ clean up panel
	nvar mz_OrigSlopeVar = root:mzFitting:mz_OrigSlopeVar
	nvar mz_OrigInterceptVar = root:mzFitting:mz_OrigInterceptVar
	nvar mz_OrigPowerVar = root:mzFitting:mz_OrigPowerVar
	nvar mz_FitSlopeVar = root:mzFitting:mz_FitSlopeVar
	nvar mz_FitInterceptVar = root:mzFitting:mz_FitInterceptVar
	nvar mz_FitPowerVar = root:mzFitting:mz_FitPowerVar
	nvar mz_RatioSlopeVar = root:mzFitting:mz_RatioSlopeVar  
	nvar mz_RatioInterceptVar = root:mzFitting:mz_RatioInterceptVar
	nvar mz_RatioPowerVar = root:mzFitting:mz_RatioPowerVar
	
	 mz_OrigSlopeVar = nan
	 mz_OrigInterceptVar = nan
	 mz_OrigPowerVar = nan
	 mz_FitSlopeVar = nan
	 mz_FitInterceptVar = nan
	 mz_FitPowerVar = nan
	 mz_RatioSlopeVar = nan  
	 mz_RatioInterceptVar = nan
	 mz_RatioPowerVar = nan

//	nvar FilterThresholdPercentVar = root:mzFitting:FilterThresholdPercentVar    //1.61G
//	FilterThresholdPercentVar= selectnumber(FilterThresholdPercentVar>0, 1, FilterThresholdPercentVar)		// 1.43A
//	mz_setvar_EstimateFiltered("",FilterThresholdPercentVar,"","")
//	WaveStats/q t_ion
//	t_ionAvg = V_avg
//	t_ionStd = V_sdev

	duplicate/o Resolution tempwave
	
	if (!isC)
		tempwave = (Resolution)*ToFTypeVKey/ToFTypeVKey			//1.57J
		WaveStats/q tempwave
		ResolutionAvgVMode = V_avg
		ResolutionStdVMode = V_sdev
		
		tempwave = (Resolution)*ToFTypeWKey/ToFTypeWKey 	//1.57J
		WaveStats/q tempwave
		ResolutionAvgWMode = V_avg
		ResolutionStdWMode = V_sdev
	else
		WaveStats/q Resolution
		ResolutionAvgVMode = V_avg
		ResolutionStdVMode = V_sdev
	endif
	
	Killwaves/z tempwave
	KillWaves/z W_coef, W_ParamConfidenceInterval, W_sigma, myCoeffWave, myConstraintWave//^		//1.47J
	KillVariables/z V_FitOptions, V_FitError		//^

	if (mz_LiveUpdate==0)
 		DoWindow/Hide=1/F  SQ_MzCalibration_Panel		// 1.42E fix  oops only available in Igor 6
 	endif
 	
	wave/z badmz = $"root:"+todoStr + "_badmz"
	if (WaveExists(badmz) && numpnts(badmz)>0)
		DoAlert 1, "There were some runs where the m/z calibration had problems.  Do you want to display the table of bad runs?"
		if (V_flag ==1)	
			edit badmz
		endif
	endif

End


// redimension in case the user added or removed another mass in the panel's table
Function mz_reSizeMzCalWaves()	

	wave mz_Mass=root:mzFitting:mz_Mass

	wave OneRunLoggedTime=root:mzFitting:OneRunLoggedTime
	wave OneRunFitTime=root:mzFitting:OneRunFitTime
	wave OneRunPowerFit=root:mzFitting:OneRunPowerFit
	
	wave OneRunAccuracyMass=root:mzFitting:OneRunAccuracyMass
	wave OneRunAccuracyTime=root:mzFitting:OneRunAccuracyTime

	wave OneRunDisplayPC_GaussFit=root:mzFitting:OneRunDisplayPC_GaussFit
	wave OneRunDisplayPC_Fit=root:mzFitting:OneRunDisplayPC_Fit
	wave OneRunDisplayPC_Log=root:mzFitting:OneRunDisplayPC_Log
	
	wave OneRun_deltaTSquared=root:mzFitting:OneRun_deltaTSquared
	wave OneRun_deltaTSquared_fit=root:mzFitting:OneRun_deltaTSquared_fit
	
	wave AllRunsMassSigma=root:mzFitting:AllRunsMassSigma
	wave AllRunsAccuracyMass=root:mzFitting:AllRunsAccuracyMass
	wave AllRunsAccuracyTime=root:mzFitting:AllRunsAccuracyTime

	wave mz_SpecType=root:mzFitting:mz_SpecType
	wave OneRunPowerFitDisplayX=root:mzFitting:OneRunPowerFitDisplayX
	
	wave rn_series = root:index:rn_series
	
	variable idex, numMass, numForOne, numRuns
	string MassStr
	
	numMass = numpnts(mz_Mass)
	numForOne = numpnts(OneRunLoggedTime)
	numRuns = numpnts(rn_series)

	if (numForOne!=numMass)
		redimension/n=(numMass) OneRunLoggedTime, OneRunFitTime, OneRunPowerFit
		redimension/n=(numMass) OneRunAccuracyMass, OneRunAccuracyTime
		redimension/n=(numMass) OneRunDisplayPC_Fit, OneRunDisplayPC_Log
		redimension/n=(numMass) OneRun_deltaTSquared, OneRun_deltaTSquared_fit
		redimension/n=(numRuns, numMass) AllRunsMassSigma, AllRunsAccuracyMass, AllRunsAccuracyTime
	endif

	OneRunDisplayPC_GaussFit=1e5
	OneRunDisplayPC_Fit=1e5
	OneRunDisplayPC_Log=1e5
	
	Wavestats/q/m=1 mz_Mass
	OneRunPowerFitDisplayX =(V_max/100)*(p+1)

//	variable/g  root:mzFitting:OpenOnlyFlag = 1		// added in 1.38A
	nvar OpenOnlyFlag = root:mzFitting:OpenOnlyFlag

	for (idex=0;idex<numMass;idex+=1)
		OpenOnlyFlag= mod(mz_SpecType[idex],3)>0 ? 0:OpenOnlyFlag
	endfor

//	string/g root:mzFitting:mz_FitMassList="" // added in 1.40D
	svar mz_FitMassList = root:mzFitting:mz_FitMassList
	mz_FitMassList=""

//	variable/g root:mzFitting:mz_spectraType=nan// added in 1.50A
	nvar mz_spectraType = root:mzFitting:mz_spectraType

	mz_spectraType = waveMax(mz_SpecType)
	duplicate/o mz_SpecType tempWave
	tempWave = mod(mz_SpecType, mz_spectraType)
	if (waveMax(tempWave) != 0)
		killwaves/z tempwave
		abort "Please select only one type of raw spectra (Open, Closed, Diff, PToF) in the SpecTypeColumn - aborting from mz_reSizeMzCalWaves"
	endif
	killwaves/z tempwave

	for (idex=0;idex<numMass;idex+=1)
		sprintf MassStr "%1.2f", mz_Mass[idex]
		MassStr = ReplaceString(".",MassStr,"_")			
		mz_FitMassList+=MassStr+";"
		if (!Exists("root:mzFitting:Accuracy_"+MassStr))			//1.44B fix
			make/o/n=(numRuns) $"root:mzFitting:Accuracy_"+MassStr=nan
		endif
	endfor
	
End

// no longer needed in .142E because we are using sq_butt_end
Function mz_butt_end(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/K SQ_MzCalibration_Panel

End


// > squirrel fetch command that handles m/z calibration for MS data
// rearranged  in 1.44B and added the feature of making a todo wave of bad runs
Function mz_calibration(index_pos,paramstr,acorn,n_acorns)
	wave index_pos 
	string paramstr
	variable acorn
	variable n_acorns

	wave MSRaw=$stringbykey("acorn_0",paramstr)		//1.50 x
	if (strlen( stringbykey("acorn_1",paramstr))>0)		// fitting diff raw spectra
		wave MSRawClosed=$stringbykey("acorn_1",paramstr)
		MSRaw -= MSRawClosed
	endif
	variable numBins=str2num(stringbykey("numBins",paramstr))		//1.52
	
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm

	nvar mz_checkMz_MS = root:mzFitting:mz_checkMz_MS
	nvar FilterNumNans = root:mzFitting:FilterNumNans
	
	wave series_index=root:index:series_index
	wave rn_series=root:index:rn_series	
	wave mz_Mass=root:mzFitting:mz_Mass
	
	nvar mz_LiveUpdate = root:mzFitting:mz_LiveUpdate
	nvar mz_viewManySleepSec = root:mzFitting:mz_viewManySleepSec
	nvar mz_CurrentRunNum = root:mzFitting:mz_CurrentRunNum
						
	nvar gaussGood = root:mzFitting:gaussGood		//1.44B?
	nvar gaussBad = root:mzFitting:gaussBad
	nvar NoRawSpectra = root:mzFitting:NoRawSpectra
	gaussGood=0
	gaussBad=0
	NoRawSpectra=0	

	variable /g V_FitOptions=4 //& Suppress the fit window
	variable /g V_FitError=0 //& Deal with errors internally
	
	variable idex, currentRunIndex, thisAcornRows, thisAcornCols, tempVar, RawSpectraSize=dimsize(MSRaw,1) // RawSpectraSize=100000
	variable jdex
	
	variable modifyGraphLive = mz_LiveUpdate && stringmatch("SQ_Mz_Calibration_Panel;", WinList("*", ";","WIN:65") )	//1.57E
	
	thisAcornRows = dimsize(MSRaw,0)
	
	variable PToFSingleBins = 0
	
	if (acorn ==0)			// new in 1.44A, we create todo waves that has bad runs
		make /o/i/n=0 $sq_toDoWvNm+"_badmz"
		wave badmz = $sq_toDoWvNm+"_badmz"
		note badmz, "TYPE:todo;"
		make/o/n=(RawSpectraSize) root:mzFitting:OneRunRawSpectra

		if (PToFSingleBins)
			make/o/n=(numpnts(rn_series), 130) root:mzFitting:mz_FitInterceptPToFSingle=nan
			make/o/n=(numpnts(rn_series), 130) root:mzFitting:mz_FitSlopePToFSingle=nan
			make/o/n=(numpnts(rn_series), 130) root:mzFitting:mz_FitPowerPToFSingle=nan
		endif
	endif

	//1.49H

	wave OneRunRawSpectra=root:mzFitting:OneRunRawSpectra
	wave badmz = $sq_toDoWvNm+"_badmz"
			
	sq_ams_stat_upd("Fitting peaks")	
	
	numBins = dimsize(MSRaw,1)
	
	for(idex=0;idex<thisAcornRows;idex+=1) // loop to deal with each run
	
		sq_ams_prog_upd(100*(acorn+(idex/thisacornrows))/n_acorns)
		
		if (index_pos[idex]==-1)		// 1.42E fix
			continue
		endif
		
		currentRunIndex =series_index[index_pos[idex]]
		mz_CurrentRunNum = rn_series[currentRunIndex]		//^ update panel
		mz_setVar_runNum("",mz_CurrentRunNum,"","")		//^ update panel
		
		if (!PToFSingleBins)
			// matrixOp/o OneRunRawSpectra=getrow(MSRaw,idex)		//   OneRunRawSpectra= MSRaw[idex][p] n
			ImageTransform/G=(idex) getRow MSRaw 
			wave W_ExtractedRow
			duplicate/o W_ExtractedRow   root:mzFitting:OneRunRawSpectra  //1.57K  this is faster than the fastop
		//	FastOp OneRunRawSpectra= W_ExtractedRow 
			tempVar=mz_FitOneRun(currentRunIndex, 0, modifyGraphLive=modifyGraphLive)		//returns a 1 or zero depending upon if successful fit.
		else	
			for(jdex=0;jdex<numBins;jdex+=1)
				ImageTransform/beam={(idex),(jdex)} getBeam MSRaw  //  OneRunRawSpectra= MSRaw[idex][jdex][p]
				wave W_beam
				fastop root:mzFitting:OneRunRawSpectra =W_Beam
				tempVar=mz_FitOneRun(currentRunIndex, 0, PToFBinNum=jdex)		//returns a 1 or zero depending upon if successful fit.
			endfor
		endif
				
		FilterNumNans += tempVar
		 if (tempVar>0)
		 	InsertPoints numpnts(badmz), 1, badmz
		 	badmz[numpnts(badmz)-1]=mz_CurrentRunNum
		 endif
		 
		 if (mz_LiveUpdate==1)
			DoUpdate
			Sleep/s/B mz_viewManySleepSec
		else
			PauseUpdate
		endif
							
	endfor // run number loop
	
	if (acorn==n_acorns-1)
		if (numpnts(badmz)==0)
			killwaves/z badmz
		endif
		
		KillWaves/z W_coef, W_ParamConfidenceInterval, W_sigma, W_ExtractedRow//^
		KillVariables/z V_FitOptions, V_FitError		//^
	endif
			
	print "// "+num2str(gaussGood/(gaussBad+gaussGood)*100) + " % of the " + num2str(gaussBad+gaussGood) + " gaussian fits in this acorn worked"
	print "// There were "+num2str(NoRawSpectra)+" blank spectra in this acorn."

End


Function mz_adjustFitAxis(thisRunWave, index, center, range, graphIndex, plotFlag)
	wave thisRunWave
	variable index, center, range, graphIndex, plotFlag

	wave/t mz_Name = root:mzFitting:mz_Name
	
	string tempStr
	tempStr =  "Fit_"+num2str(graphIndex)

	DoWindow SQ_MzCalibration_Panel
	if (!V_flag)
		return 0
	endif
	
	SetActiveSubwindow SQ_MzCalibration_Panel#$tempStr
	
	if (plotFlag)
		setaxis bottom, center-range/2-2, center+range/2+2//^ 1.36 change 
		Label bottom mz_Name[index]
		wavestats/q/m=1/r=[ center-range/2-2, center+range/2+2] thisRunWave
		setaxis/z left, 0, 1.2*V_max	// gaussian peak centers can go higher than raw data values		//.147I set min to 0
	else
		setaxis bottom, -2,-1
		Label bottom ""
		setaxis/z left, 0, 0
	
	endif
End


//^  For one run, one mzCal mass, return peak center for OneRunFitTime and fill in AllRunsMassSigma
Function mz_getOneFitEstimate(slope, int, thisRange, currentRunIndex, jdex, mzCal_Val, mzCal_DeltaVal, OneRunLoggedTimeVal, thisRun)
	variable slope, int, thisRange, currentRunIndex, jdex, mzCal_Val, mzCal_DeltaVal, OneRunLoggedTimeVal
	wave thisRun

	nvar gaussBad = root:mzFitting:gaussBad
	nvar gaussGood = root:mzFitting:gaussGood	
	nvar V_FitError = root:V_FitError
	nvar KeepPowerParamConstant = root:mzFitting:KeepPowerParamConstant	

	wave AllRunsMassSigma=root:mzFitting:AllRunsMassSigma
	wave/t/z gauss_Constraints=root:mzFitting:gauss_Constraints		//1.44B
	if (!waveExists(gauss_Constraints) || numpnts(gauss_Constraints) != 3)
		Make/O/T/N=3 root:mzFitting:gauss_Constraints =  {"K1>0","K2>0","K3>0"}
		wave/t gauss_Constraints=root:mzFitting:gauss_Constraints
	endif
		 		
	variable  delta, localMax , returnVal, Num
	string str1
	
	num = numpnts(thisRun)
	localMax = mz_FindPValMax( OneRunLoggedTimeVal-thisRange, OneRunLoggedTimeVal+thisRange, thisRun)
	delta = mzCal_DeltaVal		//^ we always want to fit only 5.... to get the peak center
	
	if (localMax<0 || localMax > num )		// 138A fix
		nvar mz_CurrentRunNum = root:mzFitting:mz_currentRunNum
		sprintf str1, "%d" , mz_CurrentRunNum		// small bug, things can go wrong with run numbers > 1e6
		print "// Had problems with the gaus fit for run "+str1+" and mass "+num2str(mzCal_Val)
		return 0		
	endif
	
	V_FitError=0
	K0=0		// even though there is non-zero baseline we just want peak center for the moment
	// 1.44B added initial guesses to try to make it go faster
	K1=thisRun[localMax]
	K2=localMax
	K3=1	// estimate
	curveFit/NTHR=0/n/q/H="1000"/G  gauss thisRun[localMax-delta,localMax+delta]	  /C=gauss_Constraints //^ do not use flag /g because if we use inital guesses, things go bad  1.57K
	
	wave W_coef = root:W_coef					
	if (v_fiterror==0 && (W_coef[2] < localMax+delta) && (W_coef[2] >localMax-delta)  )		//1.40D fix,  we want to make sure the center of the peak is in the region we anticipate
		returnVal = W_coef[2]		//^ peak center
		AllRunsMassSigma[currentRunIndex][jdex] = W_coef[3]	//^ peakwidth
		gaussGood += 1
	 else
		returnVal=NaN
		AllRunsMassSigma[currentRunIndex][jdex] = NaN
		gaussBad += 1
	endif

	return returnVal	// goes into OneRunFitTime[j]

End	


Function mz_fittingParamTable()

	variable OpenExists, ClosedExists, PToFExists
	
	OpenExists = WaveExists(root:mzFitting:mz_FitInterceptOpen)		// could use intercept, slope or power
	ClosedExists = WaveExists(root:mzFitting:mz_FitInterceptClosed)		// could use intercept, slope or power
	PToFExists = WaveExists(root:mzFitting:mz_FitInterceptPToF)		// could use intercept, slope or power
	
	PauseUpdate; Silent 1		// building window...
	Edit/W=(36.6,66.8,602.4,285.8)/N=MzFittingParamTable root:index:rn_series  as "MzFittingParamTable"
	AppendToTable root:mzFitting:FitFilterKey
	
	AppendToTable root:diagnostics:mzInt, root:mzFitting:mz_FitIntercept 
	ModifyTable rgb(root:mzFitting:mz_FitIntercept)=(44032,29440,58880)
	if (OpenExists)
		AppendToTable root:mzFitting:mz_FitInterceptOpen
	endif	
	if (ClosedExists)
		AppendToTable root:mzFitting:mz_FitInterceptClosed
	endif
	if (PToFExists)
		AppendToTable root:mzFitting:mz_FitInterceptPToF
	endif
	AppendToTable root:diagnostics:mzSlope, root:mzFitting:mz_FitSlope
	ModifyTable rgb(root:mzFitting:mz_FitSlope)=(0,0,65280)
	if (OpenExists)
		AppendToTable root:mzFitting:mz_FitSlopeOpen
	endif	
	if (ClosedExists)
		AppendToTable root:mzFitting:mz_FitSlopeClosed
	endif
	if (PToFExists)
		AppendToTable root:mzFitting:mz_FitSlopePToF
	endif
	AppendToTable root:diagnostics:mzPower, root:mzFitting:mz_FitPower
	ModifyTable rgb(root:mzFitting:mz_FitPower)=(0,39168,0)
	if (OpenExists)
		AppendToTable root:mzFitting:mz_FitPowerOpen
	endif	
	if (ClosedExists)
		AppendToTable root:mzFitting:mz_FitPowerClosed
	endif
	if (PToFExists)
		AppendToTable root:mzFitting:mz_FitPowerPToF
	endif
	ModifyTable width(Point)=40,width(root:index:rn_series)=50, width(root:mzFitting:FitFilterKey)=50

End


Function mz_butt_fitParamTable(ctrlName) : ButtonControl
	String ctrlName
	
	DoWindow/K mzFittingParamTable
	if (V_Flag==0)
		mz_FittingParamTable()
	endif
	
End


Function mz_slider_ratioAxis(ctrlName,sliderValue,event) : SliderControl
	String ctrlName
	Variable sliderValue
	Variable event	// bit field: bit 0: value set, 1: mouse down, 2: mouse up, 3: mouse moved
	
	SetActiveSubwindow SQ_MzCalibration_Panel#RatioGraph
	setaxis/z left, 1-sliderValue/100, 1+sliderValue/100
	
	SetActiveSubwindow #

End


Function mz_butt_filterBadFitsNow(ctrlName) : ButtonControl
	String ctrlName

	nvar  FilterThresholdNumRemoved=root:mzFitting:FilterThresholdNumRemoved
	nvar  FilterThresholdPercentVar=root:mzFitting:FilterThresholdPercentVar
	nvar  FilterNumNans=root:mzFitting:FilterNumNans

	wave FitFilterKey = root:mzFitting:FitFilterKey

	wave mz_RatioIntercept=root:mzFitting:mz_RatioIntercept
	wave mz_RatioSlope=root:mzFitting:mz_RatioSlope
	wave mz_RatioPower=root:mzFitting:mz_RatioPower

	wave mz_FitIntercept=root:mzFitting:mz_FitIntercept
	wave mz_FitSlope=root:mzFitting:mz_FitSlope
	wave mz_FitPower=root:mzFitting:mz_FitPower

	wave OrigIntercept=root:diagnostics:mzInt
	wave OrigSlope=root:diagnostics:mzSlope
	wave OrigPower=root:diagnostics:mzPower

	string printStr = "// After m/z calibration fitting, "+num2str(FilterNumNans)+" many nans were replaced and "
	printStr+=num2str(FilterThresholdNumRemoved)+" many points were replaced at the ratio threshold of "+num2str(FilterThresholdPercentVar) +"% using the method :"
	
	ControlInfo/w=Sq_mzcalibration_panel popup_FillInType
	
	fastop mz_FitIntercept = FitFilterKey*mz_FitIntercept
	fastop mz_FitSlope = FitFilterKey*mz_FitSlope
	fastop mz_FitPower = FitFilterKey*mz_FitPower

	switch (V_Value)
	case 1: // Interpolate
		sq_InterpolateWaveSameMode(mz_FitIntercept,mz_FitIntercept,0)		//JDA change 1.47G
		sq_InterpolateWaveSameMode(mz_FitSlope,mz_FitSlope,0)			//JDA change 1.47G
		sq_InterpolateWaveSameMode(mz_FitPower,mz_FitPower,1)			//JDA change 1.47G
		printStr+= "Interpolate."
		break
	case 2: // Repeat Last Good Fit
		sq_RepeatLastNonNanSameMode(mz_FitIntercept,0)				//JDA change 1.47G
		sq_RepeatLastNonNanSameMode(mz_FitSlope,0)				//JDA change 1.47G
		sq_RepeatLastNonNanSameMode(mz_FitPower,1)				//JDA change 1.47G
		printStr+= "Repeat Last Good Fit."
		break
	case 3: // Use Logging
		mz_FitIntercept = (FitFilterKey[p]==1) ? mz_FitIntercept[p]: OrigIntercept[p]
		mz_FitSlope = (FitFilterKey[p]==1) ? 	mz_FitSlope[p]: OrigSlope[p]
		mz_FitPower = (FitFilterKey[p]==1) ? mz_FitPower[p]:OrigPower[p]
		printStr+= "Use Logging."
		break
	endSwitch

	fastop mz_RatioIntercept = mz_FitIntercept/OrigIntercept
	fastop mz_RatioSlope = mz_FitSlope/OrigSlope
	fastop mz_RatioPower = mz_FitPower/OrigPower
	
	print printStr
	FilterThresholdNumRemoved=0
	FilterNumNans=0
	
End


Function mz_setVar_estimateFiltered(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	wave FitFilterKey = root:mzFitting:FitFilterKey
	wave mz_RatioIntercept=root:mzFitting:mz_RatioIntercept
	wave mz_RatioSlope=root:mzFitting:mz_RatioSlope
	wave mz_RatioPower=root:mzFitting:mz_RatioPower

	svar todoStr = root:panel:sq_toDoWvNm
	wave todo = $"root:"+todoStr		//1.44B
	
	duplicate/o FitFilterKey tempWave		// added in 1.43A to 
	sq_makeMaskFromTodofindRun(tempWave,todo)
	
	nvar  FilterThresholdNumRemoved=root:mzFitting:FilterThresholdNumRemoved
	nvar  FilterNumNans=root:mzFitting:FilterNumNans		//Should remain constant
	
	FilterThresholdNumRemoved = nan
	
	variable FilterMin, FilterMax
	FilterMin = 1-varNum/100
	FilterMax = 1+varNum/100
	
	FitFilterKey = 1
	FitFilterKey = ( tempWave[p] && (mz_RatioIntercept[p]>FIlterMin) && (mz_RatioIntercept[p] < FilterMax) ) ? 	FitFilterKey[p]: nan
	FitFilterKey = ( tempWave[p] && (mz_RatioSlope[p]>FIlterMin) && (mz_RatioSlope[p] < FilterMax) ) ? 		FitFilterKey[p] :nan
	FitFilterKey = ( tempWave[p] && (mz_RatioPower[p]>FIlterMin) && (mz_RatioPower[p] < FilterMax) ) ? 		FitFilterKey[p]: nan

	WaveStats/q/m=1 FitFilterKey
	FilterThresholdNumRemoved=V_NumNans - FilterNumNans
	
	killwaves/z tempWave

End


//^ Finds peak centers for chosen mzCal Masses and does a power fit.  
//^ Raw spectra waves in OneRunRawSpectraClosed  OneRunRawSpectraOpen, and OneRunRawSpectraDiff should already be set before this is called
Function mz_fitOneRun(currentRunIndex, SingleRunFlag, [PToFBinNum, modifyGraphLive])
	variable currentRunIndex, SingleRunFlag, PToFBinNum, modifyGraphLive  // PToFBinNum added in 1.52

	variable /g V_FitOptions=4 //& Suppress the fit window
	variable /g V_FitError=0 //& Deal with errors internally
	modifyGraphLive = ParamIsDefault(modifyGraphLive)

	// use mz cal waves from diagnostics folder
	wave mzIntercept=root:diagnostics:mzInt
	wave mzSlope=root:diagnostics:mzSlope
	wave/z  mzPower=root:diagnostics:mzPower
	if (WaveExists(mzPower)==0)
		duplicate/o mzSlope root:diagnostics:mzPower/wave=mzPower
//		wave/z mzPower=root:diagnostics:mzPower
		mzPower=.5
	endif	

		
	wave mz_Mass=root:mzFitting:mz_Mass
	wave mz_SpecType=root:mzFitting:mz_SpecType
	wave mz_DeltaNum=root:mzFitting:mz_DeltaNum
	wave mz_Graph=root:mzFitting:mz_Graph
	
	wave AllRunsMassSigma=root:mzFitting:AllRunsMassSigma

	wave t_ion = root:mzFitting:t_ion
	wave Resolution = root:mzFitting:Resolution

	wave OneRun_deltaTSquared = root:mzFitting:OneRun_deltaTSquared
	wave OneRun_deltaTSquared_fit = root:mzFitting:OneRun_deltaTSquared_fit   // fit of delta_t_squared_FWHM to mass
	wave deltaTSquared_coefs = root:mzFitting:deltaTSquared_coefs // intercept and slope of delta_t_squared_fit
	
	wave AllRunsAccuracyTime=root:mzFitting:AllRunsAccuracyTime
	wave AllRunsAccuracyMass=root:mzFitting:AllRunsAccuracyMass
	
	wave mz_FitIntercept=root:mzFitting:mz_FitIntercept
	wave mz_FitSlope=root:mzFitting:mz_FitSlope
	wave mz_FitPower=root:mzFitting:mz_FitPower
	wave mz_FitChiSq=root:mzFitting:mz_FitChiSq		// info currently stored but not used

	if (!ParamIsDefault(PToFBinNum))
		wave mz_FitInterceptPToFSingle=root:mzFitting:mz_FitInterceptPToFSingle
		wave mz_FitSlopePToFSingle=root:mzFitting:mz_FitSlopePToFSingle
		wave mz_FitPowerPToFSingle=root:mzFitting:mz_FitPowerPToFSingle
	endif
	
	wave mz_RatioIntercept=root:mzFitting:mz_RatioIntercept
	wave mz_RatioSlope=root:mzFitting:mz_RatioSlope
	wave mz_RatioPower=root:mzFitting:mz_RatioPower

	wave OneRunLoggedTime=root:mzFitting:OneRunLoggedTime
	wave OneRunFitTime=root:mzFitting:OneRunFitTime
	wave OneRunPowerFit=root:mzFitting:OneRunPowerFit

	wave OneRunPowerFitDisplayX= root:mzFitting:OneRunPowerFitDisplayX		//^ more granular display of power fit of OneRunFitTime
	wave OneRunPowerFitDisplayY= root:mzFitting:OneRunPowerFitDisplayY		//^ more granular display ofower fit of OneRunFitTime

	wave OneRunRawSpectra=root:mzFitting:OneRunRawSpectra	// values should be set by calling function
	
	wave OneRunAccuracyMass=root:mzFitting:OneRunAccuracyMass
	wave OneRunAccuracyTime=root:mzFitting:OneRunAccuracyTime

	wave t_ion = root:mzFitting:t_ion
	wave Resolution = root:mzFitting:Resolution
	wave ppmStd = root:mzFitting:ppmStd
	wave deltaTSquared_Chisq = root:mzFitting:deltaTSquared_Chisq

	nvar mz_OrigSlopeVar = root:mzFitting:mz_OrigSlopeVar
	nvar mz_OrigInterceptVar = root:mzFitting:mz_OrigInterceptVar
	nvar mz_OrigPowerVar = root:mzFitting:mz_OrigPowerVar
	nvar mz_FitSlopeVar = root:mzFitting:mz_FitSlopeVar
	nvar mz_FitInterceptVar = root:mzFitting:mz_FitInterceptVar
	nvar mz_FitPowerVar = root:mzFitting:mz_FitPowerVar
	nvar mz_RatioSlopeVar = root:mzFitting:mz_RatioSlopeVar
	nvar mz_RatioInterceptVar = root:mzFitting:mz_RatioInterceptVar
	nvar mz_RatioPowerVar = root:mzFitting:mz_RatioPowerVar

	nvar mz_UsePreviousRunParams = root:mzFitting:mz_UsePreviousRunParams
	wave ppmGuidelinesMz = root:mzFitting:ppmGuidelinesMz
	wave ppmGuidelinesTop = root:mzFitting:ppmGuidelinesTop
	wave ppmGuidelinesBottom = root:mzFitting:ppmGuidelinesBottom

	nvar KeepPowerParamConstant=root:mzFitting:KeepPowerParamConstant
	nvar NoRawSpectra=root:mzFitting:NoRawSpectra

	nvar mz_checkMz_MS =root:mzFitting:mz_checkMz_MS
	nvar mz_checkMz_PToF =root:mzFitting:mz_checkMz_PToF
	
	nvar mz_LiveUpdate = root:mzFitting:mz_LiveUpdate	
	nvar OpenOnlyFlag = root:mzFitting:OpenOnlyFlag		// added in 1.38B
	nvar mz_RegionScalar = root:mzFitting:mz_RegionScalar
	svar mz_FitMassList = root:mzFitting:mz_FitMassList // added in 1.40D

	nvar PowerConstant = root:mzFitting:PowerConstant 	/// 1.49A

	wave OneRunRawSpectra =  root:mzFitting:OneRunRawSpectra
	
	wave/z W_coef = root:W_coef 
	if (!WaveExists(W_coef))
		make/o/n=0 root:W_coef 
		wave W_coef = root:W_coef 
	endif

	variable idex, jdex, slope, intercept, power, thisRange, numMassGraphsDisplayed, tempPeakLoc, OneRunNumPnts
	variable returnVal = 1, numMasses, var0, var1, var2, graphIndex
	string tempStr
	
	make/d/o/n=3 myCoeffWave 		// 1.47I change to double precision
	
	make/o/t myConstraintWave = {"K2>0.499", "K2<.501"}		// changed in 1.51C

	slope = mzSlope[currentRunIndex]		// daq values
	intercept = mzIntercept[currentRunIndex]
	power = mzPower[currentRunIndex]

	mz_OrigSlopeVar = slope		// change in 1.48D to prevent first run from showing up bad
	mz_OrigInterceptVar = intercept
	mz_OrigPowerVar = power

	if (mz_UsePreviousRunParams && currentRunIndex>0 )
		slope = numtype(mz_FitSlope[currentRunIndex-1])==0 ? mz_FitSlope[currentRunIndex-1] :slope
		intercept =  numtype(mz_FitIntercept[currentRunIndex-1])==0 ? mz_FitIntercept[currentRunIndex-1] : intercept
		power =  numtype(mz_FitPower[currentRunIndex-1])==0 ? mz_FitPower[currentRunIndex-1] :power
	endif
	
	numMassGraphsDisplayed=0
	numMasses = numpnts(mz_Mass)
	
	wavestats/q/m=1 OneRunRawSpectra
	OneRunNumPnts = V_npnts
		
	// if this mass is turned off (is 0), just skip to next item in mz_Mass wave
	AllRunsMassSigma[currentRunIndex][jdex] = nan

	if ( OneRunNumPnts >0)

		for(jdex=0;jdex<numpnts(mz_SpecType);jdex+=1)
			
			if (   mz_SpecType[jdex]>0 )

				OneRunLoggedTime[jdex] = intercept + slope*(mz_Mass[jdex])^(power)
				///.1.14I  we dont care if intercept is positive
									
				// define a range to search for peak over based on m/z 
				thisRange = 10/sqrt(28)*sqrt(mz_Mass[jdex])*mz_RegionScalar 

//			if (   mz_checkMz_MS && (DoDiff || DoClosed || DoOpen)   )
				OneRunFitTime[jdex] =  mz_GetOneFitEstimate(slope, intercept, thisRange, currentRunIndex, jdex, mz_Mass[jdex], mz_DeltaNum[jdex], OneRunLoggedTime[jdex], OneRunRawSpectra)
				if (numMassGraphsDisplayed< 6 && mz_LiveUpdate==1 && mz_Graph[jdex]>0)
					tempPeakLoc = numtype(OneRunFitTime[jdex])==0? OneRunFitTime[jdex] : OneRunLoggedTime[jdex]
					wave/z gaussYFitwave = $"root:mzFitting:fit_gauss_Y_"+num2str(numMassGraphsDisplayed)
					wave/z gaussXFitwave = $"root:mzFitting:fit_gauss_X_"+num2str(numMassGraphsDisplayed)  
					gaussXFitwave = OneRunFitTime[jdex] - mz_DeltaNum[jdex]+p*0.1*( (2*mz_DeltaNum[jdex]+1)/5)		//^ get a finer resolution of x wave for display purposes (than raw)
					gaussYFitwave = W_coef[0]+W_coef[1]*exp(-((gaussXFitwave-W_coef[2])/W_coef[3])^2)
					if (modifyGraphLive)		//1.57E
						mz_adjustFitAxis(OneRunRawSpectra, jdex, tempPeakLoc, thisRange, numMassGraphsDisplayed, 1)		//^ simply changes axes of graphs in panels.
					endif
					numMassGraphsDisplayed+=1
				endif
			else
				OneRunFitTime[jdex]=nan
			endif
		
		endfor // m/z loop

		if ( mz_LiveUpdate==1)
			for(jdex=numMassGraphsDisplayed;jdex<6;jdex+=1)
				mz_adjustFitAxis(OneRunRawSpectra, jdex, nan, nan, jdex, 0)		//^ simply changes axes of graphs in panels.
			endfor
		endif

	else
		fastop OneRunFitTime=(nan)
		NoRawSpectra+=1
	endif		// we have a blank closed spectra

	// power fit of timeRefit vs mz_Mass

	wavestats /q/m=1 OneRunFitTime
	if (v_npnts<3)
		mz_FitSlopeVar = nan
		mz_FitInterceptVar = nan
		mz_FitPowerVar =nan
		OneRunPowerFit=nan
		OneRunAccuracyMass=nan
		OneRun_deltaTSquared=nan
		AllRunsAccuracyTime[currentRunIndex][]=nan
		AllRunsAccuracyMass[currentRunIndex][] =nan
		mz_FitChiSq[currentRunIndex] = nan
		ppmStd[currentRunIndex] = nan
		deltaTSquared_Chisq[currentRunIndex]=nan
	else
		V_FitError=0
 		variable/g V_FitTol = 0.0000001			// changed in .147I

		// 1.44B  added initial guesses to try to make it go faster
		myCoeffWave = {mz_OrigInterceptVar , mz_OrigSlopeVar, mz_OrigPowerVar}
 		if (KeepPowerParamConstant)
			myCoeffWave[2] = PowerConstant		//1.49A
			curveFit/NTHR=0/g/n/q/H="001" power  kwCWave=myCoeffWave OneRunFitTime /X=mz_Mass /D=OneRunPowerFit  /R=OneRunAccuracyTime		//1.47I, use /g flag!
		else
			OneRunAccuracyTime=nan			
			curveFit/g/n/q/NTHR=0 power  kwCWave=myCoeffWave OneRunFitTime /X=mz_Mass /D=OneRunPowerFit  /R=OneRunAccuracyTime /C=myConstraintWave  	//1.47I, use /g flag!
 		endif

		if (V_FitError==0)		//^ good fit
			var0 = myCoeffWave[0]
			var1 = myCoeffWave[1] 
			var2 = myCoeffWave[2]
			returnVal=0
			if (SingleRunFlag==0)	//^ for now, just put results in display variables, NOT waves
				mz_FitChiSq[currentRunIndex] = V_chisq
			endif
			OneRunPowerFit=(var0)+(var1)*mz_Mass^(var2)		//^ calc for all masses even if not selected in mz_SpecType
			OneRunPowerFitDisplayY=var0+var1*OneRunPowerFitDisplayX^var2
			mz_FitInterceptVar  =var0 // W_coef[0]	
			mz_FitSlopeVar = var1 //=W_coef[1]	
			mz_FitPowerVar = var2 //=W_coef[2]	
			
//			OneRunAccuracyMass = ((OneRunPowerFit+OneRunAccuracyTime - K0)/K1)^(1/K2)- mz_Mass
			OneRunAccuracyMass = ((OneRunFitTime - var0)/var1)^(1/var2) - mz_Mass
			OneRunAccuracyMass/=mz_Mass	//   dm/m
			OneRunAccuracyMass*= (OneRunAccuracyTime/OneRunAccuracyTime)	// nan out masses not used in fitting 
			OneRunAccuracyMass*=1e6			
			
			OneRun_deltaTSquared =  (  (AllRunsMassSigma[currentRunIndex][p]/sqrt(2)) * (2*sqrt(2*ln(2))) )^2	//  FWHM = sigma *  (2*sqrt(2*ln(2))) 
			// igor's gaussian fit is such that "Note that the width parameter is sqrt(2) times the standard deviation of the peak" do igor search for this phrase if you have ?s
			OneRun_deltaTSquared /= mz_SpecType[p]>0 

			curveFit/NTHR=0/n/q line OneRun_deltaTSquared /X=mz_Mass
			wave w_coef = root:W_coef
			OneRun_deltaTSquared_Fit = W_coef[0] + W_coef[1]*mz_Mass
				
			ppmGuidelinesTop = W_coef[0] + W_coef[1]*ppmGuidelinesMz
			ppmGuidelinesTop /=10^6		// peak width numbers originally in ppm
			ppmGuidelinesTop = .1*10^6*(1/ppmGuidelinesMz)*sqrt(ppmGuidelinesTop)		//10% of 
			ppmGuidelinesBottom = - ppmGuidelinesTop

			if (SingleRunFlag==0)	//^ for now, just put results for one run in display variables, NOT waves
//				WaveStats/q OneRunAccuracyMass
//				ppmStd[currentRunIndex] = V_sdev
				deltaTSquared_Chisq[currentRunIndex] = V_chisq/100		// V_chisq from line fit
				deltaTSquared_coefs[currentRunIndex][] = W_coef[q]		// W_coef from line fit		//1.58G			
				t_ion[currentRunIndex] = sqrt(W_coef[0])					// W_coef from line fit
				Resolution[currentRunIndex]= 1/ (2*(1/mz_FitSlopeVar)* sqrt(W_coef[1]) ) //W_coef from line fit // 1/(2*s*sqrt(slope of fit) )  // and sqrt(m) = s*t
				AllRunsAccuracyTime[currentRunIndex][] = OneRunAccuracyTime[q]	// in time space
				AllRunsAccuracyMass[currentRunIndex][] = OneRunAccuracyMass[q]	// in mass space
				for(jdex=0;jdex<numMasses;jdex+=1)
					wave accuracyWave = $"root:mzFitting:Accuracy_"+StringFromList(jdex, mz_FitMassList)
					accuracyWave[currentRunIndex]=OneRunAccuracyMass[jdex]
				endfor
			endif  	//SingleRun

		else
			mz_FitChiSq[currentRunIndex] = nan
			OneRunPowerFit = nan
			mz_FitInterceptVar = nan
			mz_FitSlopeVar = nan
			mz_FitPowerVar = nan
			OneRunAccuracyTime = nan
			OneRunAccuracyMass = nan
			ppmGuidelinesTop=nan
			ppmGuidelinesBottom=nan
			if (SingleRunFlag==0)	//^ for now, just put results in display variables, NOT waves
				AllRunsAccuracyTime[currentRunIndex][] =nan	// in time space
				AllRunsAccuracyMass[currentRunIndex][] =nan	// in time space
			endif  	//SingleRun
		endif
	endif

	mz_RatioInterceptVar = mz_FitInterceptVar/intercept
	mz_RatioSlopeVar = mz_FitSlopeVar/slope
	mz_RatioPowerVar = mz_FitPowerVar/0.5

	mz_OrigSlopeVar = slope
	mz_OrigInterceptVar = intercept
	mz_OrigPowerVar = power
	
	if (SingleRunFlag==0)	//^ for now,  put results in waves only if doing lots of runs
		if (ParamIsDefault(PToFBinNum))
			mz_FitSlope[currentRunIndex] = mz_FitSlopeVar
			mz_FitIntercept[currentRunIndex] = mz_FitInterceptVar
			mz_FitPower[currentRunIndex] = mz_FitPowerVar
			mz_RatioSlope[currentRunIndex] = mz_RatioSlopeVar
			mz_RatioIntercept[currentRunIndex] = mz_RatioInterceptVar
			mz_RatioPower[currentRunIndex] = mz_RatioPowerVar
		else
			mz_FitSlopePToFSingle[currentRunIndex][PToFBinNum] = mz_FitSlopeVar
			mz_FitInterceptPToFSingle[currentRunIndex][PToFBinNum] = mz_FitInterceptVar
			mz_FitPowerPToFSingle[currentRunIndex][PToFBinNum] = mz_FitPowerVar
		endif
	else
		KillWaves/z W_coef, W_ParamConfidenceInterval, W_sigma, myCoeffWave, myConstraintWave//^
		KillVariables/z V_FitOptions, V_FitError		//^
	endif

	return returnVal
	
End


Function mz_calcFitOneMassSpec()

	nvar mz_currentRunNum =  root:mzFitting:mz_currentRunNum	
	nvar mz_checkMz_MS =  root:mzFitting:mz_checkMz_MS
	wave run_series = root:index:rn_series
	wave mz_Mass = root:mzFitting:mz_Mass
	wave/t mz_Name = root:mzFitting:mz_Name
	wave mz_SpecType = root:mzFitting:mz_SpecType 	
 	
 	variable maxMz, idex
 	
 	variable currentRunIndex =sq_FindRun(run_series, mz_currentRunNum)
	nvar mz_spectraType = root:mzFitting:mz_spectraType
 	
	if (currentRunIndex<0)
 		Abort "This run number doesn't show up in the index. - Aborting from mz_calcFitOneMassSpec"
 	endif
 
	sq_initializeGlobalNVar("root:mzFitting:mz_UsePreProcessed", 0)  		//1.17c
	nvar mz_UsePreProcessed = root:mzFitting:mz_UsePreProcessed
	string preprocSuffix = selectstring (mz_UsePreProcessed, "", "", "_p")

 	make/o/i/n=1/free todo = mz_currentRunNum
 	maxMz = sq_findMaxMinMz(todo, 1, 0)		//1.52E1  find the smallest of the max mzs.  Make sure we don't request to fit a mass > smallest mz
	if (numtype(maxMz) !=0 || maxMz<0 || maxMz>1e8)		// 1e8 is arbitrary
		abort "The maximum Mz of "+num2str(maxMz)+" seems incorrect.  Aborting from mz_butt_beginMzFitting" 
	endif		//1.60L
	for (idex=0;idex<dimsize(mz_Mass,0); idex+=1)		// does not require that masses are monotonically increasing
		if (mz_SpecType[idex]>0 && mz_Mass[idex]>maxMz)
			DoAlert 1,  "Cannot include mass "+mz_Name[idex] +" in mz calibration because the the max mz value at this spectra was "+num2str(maxMz)+ ".  Select Yes to continue and not fit this mass.  Select No to abort"
			if (V_flag==2)		// user selected NO
				abort "The user chose to abort"
			else
				mz_SpecType[idex]=0
			endif 
		endif
	endfor
	
	switch (mz_spectraType)
		case 1:  // Diff
			sq_GetThisRawMS(mz_currentRunNum, "mzFitting", "OneRunRawSpectraOpen", "MSOpen"+preprocSuffix)	//1.17c
			sq_GetThisRawMS(mz_currentRunNum, "mzFitting", "OneRunRawSpectraClosed", "MSClosed"+preprocSuffix+";")	//1.17c
			wave OneRunRawSpectraOpen = root:mzFitting:OneRunRawSpectraOpen
			wave OneRunRawSpectraClosed = root:mzFitting:OneRunRawSpectraClosed
			duplicate/o OneRunRawSpectraOpen root:mzFitting:OneRunRawSpectra
			wave OneRunRawSpectra = root:mzFitting:OneRunRawSpectra
			OneRunRawSpectra = OneRunRawSpectraOpen - OneRunRawSpectraClosed
			break
		case 2:
			sq_GetThisRawMS(mz_currentRunNum, "mzFitting", "OneRunRawSpectra", "MSClosed"+preprocSuffix)	//1.17c
			break
		case 3:
			sq_GetThisRawMS(mz_currentRunNum, "mzFitting", "OneRunRawSpectra", "MSOpen"+preprocSuffix)	//1.17c
			break
 		case 4:
			sq_GetThisRawMS(mz_currentRunNum, "mzFitting", "OneRunRawSpectraPToF", "PToF")		// 1.49A		// extracted from MS_PToF, the sum of all ptof bins
			sq_PToFCollapseSizeOneRun(mz_currentRunNum, "root:mzFitting:", "OneRunRawSpectra", 1,0)
	endswitch
 		
 	mz_FitOneRun(currentRunIndex, 1)
 	
 End


Function mz_findPValMax(RangeLeft,RangeRight, w)
	variable RangeLeft,RangeRight
	wave w

	variable idex, myMaxVal = -inf, returnVal=-inf, myL = floor(RangeLeft), myR=ceil(RangeRight)
	
	for(idex=myL; idex<=myR; idex+=1)
		if ( w[idex]>myMaxVal)
			myMaxVal = w[idex]
			returnVal = idex
		endif
	endfor
	
	return returnVal

End




//*********************************************************************************************************** 
//**************************************  mz panel functions  ******************************** 

//  Controls the MS or PToF radio buttons.
Function mz_ck_checkMSPToF(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar mz_checkMz_MS = root:mzFitting:mz_checkMz_MS
	nvar mz_checkMz_PToF =  root:mzFitting:mz_checkMz_PToF
	
	strswitch(ctrlName)	// string switch
		case "checkMz_MS":		
			mz_checkMz_PToF = !checked
			break
		case "checkMz_PToF":		
			mz_checkMz_MS = !checked
			break
	endswitch	
	
End


// Fit one run button
Function mz_butt_fitThisRun(ctrlName) : ButtonControl
	String ctrlName

	mz_ReSizeMzCalWaves()
	mz_IndividualMassFitGraphs()
	nvar mz_LiveUpdate = root:mzFitting:mz_LiveUpdate
 	mz_LiveUpdate =1	// The user will always want to see the results in the panel when viewing one run.  1.43I

	// 1.60Y
	nvar mz_currentRunNum =  root:mzFitting:mz_currentRunNum	
	nvar mz_spectraType = root:mzFitting:mz_spectraType		// 1 = diff,2 = closed, 3 = open, 4 = ptof
	wave/z FastKey = root:diagnostics:FastKey
	if (WaveExists(FastKey) && Wavemax(FastKey)>0)
		variable pos =sq_FindRun(root:index:rn_series, mz_currentRunNum)
		if (pos>=0 && FastKey[pos]==2 && mz_spectraType!=2)
			Abort "This run is fast mode closed, but the spectra type chosen is not closed. Reselect spectra type or run."
		elseif (pos>=0 && FastKey[pos]==0 && mz_spectraType!=3)
			Abort "This run is fast mode open, but the spectra type chosen is not open. Reselect spectra type or run."
		endif
	endif
	mz_calcFitOneMassSpec()

End


Function mz_setVar_runNum(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName
	
	svar mz_RunModeStr = root:mzFitting:mz_RunModeStr
 	mz_RunModeStr = sq_getDetectorStr(varNum)  // sq_getToFIonizationStr(varNum) 			//1.49A
 
End


Function mz_populate_FittingChoicesTable()

	SetDataFolder root:mzFitting:
	wave mz_Name, mz_Mass, mz_SpecType, mz_DeltaNum, mz_Graph
	
	AppendToTable mz_Name, mz_Mass, mz_SpecType, mz_DeltaNum, mz_Graph 
	ModifyTable width(Point)=20,title(Point)="Pt"
	ModifyTable title(mz_Name)="Name", title(mz_Mass)="Mass",title(mz_SpecType)="Spec Type"
	ModifyTable title(mz_DeltaNum)="Delta", title(mz_Graph)="Graph"
	ModifyTable width(mz_Mass)=60, width(mz_SpecType)=50, width(mz_DeltaNum)=30, width(mz_Graph)=30
	SetDataFolder root:

End


Function mz_populate_FitOneMassGraph()
 
	string TraceList =TraceNameList("",";",1)
	
	SetDataFolder root:mzFitting:
	wave  OneRunDisplayPC_Log, OneRunLoggedTime, OneRunDisplayPC_GaussFit,OneRunDisplayPC_Fit,OneRunFitTime,OneRunPowerFit
	
	AppendToGraph OneRunDisplayPC_Log vs OneRunLoggedTime
	AppendToGraph OneRunDisplayPC_GaussFit vs OneRunFitTime
	AppendToGraph OneRunDisplayPC_Fit vs OneRunPowerFit
	ModifyGraph mode(OneRunDisplayPC_GaussFit)=1
	ModifyGraph mode(OneRunDisplayPC_Fit)=1
	ModifyGraph mode(OneRunDisplayPC_Log)=1
	ModifyGraph rgb(OneRunDisplayPC_Fit)=(39168,39168,0)
	ModifyGraph rgb(OneRunDisplayPC_GaussFit)=(65280,0,0)
	ModifyGraph rgb(OneRunDisplayPC_Log)=(0,0,0)
	ModifyGraph lsize(OneRunDisplayPC_Fit)=3
	ModifyGraph lsize(OneRunDisplayPC_Log)=2
	ModifyGraph lsize(OneRunDisplayPC_GaussFit)=2
	ModifyGraph margin(left)=36,margin(bottom)=36,margin(top)=7,margin(right)=7

	variable idex, num

	for(idex=0;idex<6;idex+=1)
		wave wx = $"root:mzFitting:fit_gauss_X_"+num2str(idex)
		wave wy = $"root:mzFitting:fit_gauss_Y_"+num2str(idex)
		AppendToGraph wy vs wx
		ModifyGraph rgb($NameofWave(wy))=(65280,0,0)
		ModifyGraph lsize($NameofWave(wy))=2
	endfor
	
	// check to see if thi was a single graph or no
	if (ItemsInList(TraceList)==0)
		wave OneRunRawSpectra
		AppendToGraph OneRunRawSpectra
		ModifyGraph rgb(OneRunRawSpectra)=(0,0,0)
		ModifyGraph mode(OneRunRawSpectra)=4,marker(OneRunRawSpectra)=19
		ModifyGraph msize(OneRunRawSpectra)=2
		SetAxis left -0.1,1
		Legend/C/N=text0/J "\\s(OneRunDisplayPC_Fit) OneRunDisplayPC_Fit\r\\s(OneRunDisplayPC_Log) OneRunDisplayPC_Log\r\\s(OneRunDisplayPC_GaussFit) OneRunDisplayPC_GaussFit"
	endif
		
	SetDataFolder root:

End


Function mz_populate_ParamRatioGraph()
 
	SetDataFolder root:mzFitting:
	wave mz_RatioPower,mz_RatioIntercept,mz_RatioSlope
	AppendToGraph mz_RatioPower vs ::index:rn_series
	AppendToGraph mz_RatioIntercept vs ::index:rn_series
	AppendToGraph mz_RatioSlope vs ::index:rn_series
	ModifyGraph margin(left)=50,margin(bottom)=36,margin(top)=7,margin(right)=50
	ModifyGraph mode=4
	ModifyGraph marker=8
	ModifyGraph rgb(mz_RatioPower)=(0,39168,0),rgb(mz_RatioIntercept)=(44032,29440,58880)
	ModifyGraph rgb(mz_RatioSlope)=(0,0,65280)
	ModifyGraph msize(mz_RatioIntercept)=4
	ModifyGraph grid=2
	ModifyGraph mirror=2
	ModifyGraph nticks(bottom)=9
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph margin(left)=50,margin(bottom)=36
	Label left "Fit/Logged"
	Label bottom "Run number"
	SetAxis left 0.99,1.01
	Legend/N=text0/J/F=0/A=RT "\\K(29440,0,58880)Intercept\r\\K(0,0,65280)Slope\r\\K(0,39168,0)Power"
	Legend/C/N=text0/J/X=-15.00/Y=8.00
	SetDataFolder root:

End


Function mz_populate_DeltaTSquaredGraph()

	SetDataFolder root:mzFitting:
	wave OneRun_deltaTSquared,OneRun_deltaTSquared_fit, mz_Mass
	AppendToGraph  OneRun_deltaTSquared,OneRun_deltaTSquared_fit vs mz_Mass
	ModifyGraph margin(left)=41,margin(bottom)=36,margin(top)=7,margin(right)=7,wbRGB=(48896,59904,65280)
	ModifyGraph mode(OneRun_deltaTSquared)=3
	ModifyGraph marker(OneRun_deltaTSquared)=8
	ModifyGraph rgb(OneRun_deltaTSquared)=(0,0,0)
//	Label left "dt^2"
	Label left "FWHM^2"		//1.54E
	Label bottom "Exact m/z"
	SetAxis left 0,50
	SetAxis bottom 0,300
	SetDataFolder root:

End


Function mz_populate_ResolutionGraph()
 
	SetDataFolder root:mzFitting:
	wave Resolution,t_ion
	AppendToGraph/R Resolution vs ::index:rn_series
	AppendToGraph t_ion vs ::index:rn_series
	ModifyGraph margin(left)=50,margin(bottom)=36,margin(top)=7,margin(right)=50
	ModifyGraph mode=4
	ModifyGraph marker(Resolution)=17,marker(t_ion)=23
	ModifyGraph rgb(t_ion)=(39168,26112,0)
	ModifyGraph grid(bottom)=2,grid(left)=2
	ModifyGraph nticks(bottom)=9
	ModifyGraph axOffset(left)=-3.16667
	ModifyGraph gridRGB(bottom)=(34816,34816,34816),gridRGB(left)=(34816,34816,34816)
	ModifyGraph axRGB(right)=(65280,0,0),axRGB(left)=(39168,26112,0)
	ModifyGraph tlblRGB(right)=(65280,0,0),tlblRGB(left)=(39168,26112,0)
	ModifyGraph alblRGB(right)=(65280,0,0),alblRGB(left)=(39168,26112,0)
	ModifyGraph margin(left)=50,margin(bottom)=36
	ModifyGraph wbRGB=(48896,59904,65280)
	Label right "Resolution"
	Label bottom "Run number"
//	Label left "t_ion"
	Label left "FWHM at m/z = 0"			// 1.54 E
	SetAxis right 0,8000
	SetAxis left 0,4
	SetDataFolder root:
	
End


Function mz_populate_PpmGraph()
 
	SetDataFolder root:mzFitting:
	wave mz_FitChiSq,ppmStd
	AppendToGraph mz_FitChiSq vs ::index:rn_series
	AppendtoGraph/R ppmStd vs root:index:rn_series
	ModifyGraph margin(top)=7,margin(right)=50,wbRGB=(65280,65280,48896)
	ModifyGraph mode=4
	ModifyGraph marker(mz_FitChiSq)=19
	ModifyGraph rgb(mz_FitChiSq)=(0,0,0)
	ModifyGraph grid(left)=2,grid(bottom)=2
	ModifyGraph gridRGB(left)=(34816,34816,34816),gridRGB(bottom)=(34816,34816,34816)
	ModifyGraph axRGB(right)=(16384,28160,65280)
	ModifyGraph tlblRGB(right)=(16384,28160,65280)
	Label right "\\K(16384,28160,65280)Accuracy ppm"
	Label bottom "Run number"
	Label left "Chi Squared from fit"
	SetAxis right -50,50
	SetAxis left 0,5
	ModifyGraph zero(right)=1
	ModifyGraph margin(left)=50,margin(bottom)=36

	SetDataFolder root:
	
	wave mz_Mass = root:mzFitting:mz_Mass
	variable idex, num = numpnts(mz_Mass)
	string tempStr
	
	sq_MakeRainbowColorTable()		//1.51M
	WAVE RainbowColorTable = $"root:panel:RainbowColorTable"

	for(idex=0;idex<num;idex+=1)
		sprintf tempStr "%1.2f", mz_Mass[idex]
		wave/z accuracyWave = $"root:mzFitting:Accuracy_"+ReplaceString(".", tempStr, "_")
		if (waveExists(accuracyWave))
			AppendtoGraph/R accuracyWave vs root:index:rn_series
			ModifyGraph rgb($NameofWave(accuracyWave))=(16384,16384,65280),marker($NameofWave(accuracyWave))=5
			ModifyGraph msize($NameofWave(accuracyWave))=1, mode=4
			ModifyGraph rgb($NameofWave(accuracyWave))=(RainbowColorTable[mod(idex,26)][0],RainbowColorTable[mod(idex,26)][1],RainbowColorTable[mod(idex,26)][2]);DelayUpdate
		endif
	endfor
	
	wave ppmStd = root:mzFitting:ppmStd
	fastop  ppmStd = (nan)

End

// *************************************************
// Makes a color table of 21 different colors

Function sq_MakeRainbowColorTable()

	Make/O/n=(21,3) root:panel:RainbowColorTable/wave=RainbowColorTable

	RainbowColorTable[0]={ {65535}, {0}, {0} }		//red
	RainbowColorTable[1]={ {0}, {65535}, {0} }		//green
	RainbowColorTable[2]={ {0}, {0}, {65535} }		//blue

	RainbowColorTable[3]={ {65535}, {65535}, {0} }	//yellow
	RainbowColorTable[4]={ {0}, {65535}, {65535} }	//cyan
	RainbowColorTable[5]={ {65535}, {0}, {65535} }	//magenta

	RainbowColorTable[6]={ {32767}, {0}, {0} }	//brick
	RainbowColorTable[7]={ {0}, {32767}, {0} }	//darkgreen
	RainbowColorTable[8]={ {0}, {0}, {32767} }	//darkblue

	RainbowColorTable[9]={ {32767}, {32767}, {0} }	//mud
	RainbowColorTable[10]={ {0}, {32767}, {32767} }	//teal
	RainbowColorTable[11]={ {32767}, {0}, {32767} }	//redpurple

	RainbowColorTable[12]={ {32767}, {65535}, {0} }	//lightgreen
	RainbowColorTable[13]={ {0}, {32767}, {65535} }	//medblue
	RainbowColorTable[14]={ {65535}, {0}, {32767} }	//pinkyred

	RainbowColorTable[15]={ {65535}, {32767}, {0} }	//orange
	RainbowColorTable[16]={ {0}, {65535}, {32767} }	//othergreen
	RainbowColorTable[17]={ {32767}, {0}, {65535} }	//darkpurple

	RainbowColorTable[18]={ {32767}, {65535}, {32767} }	//palegreen
	RainbowColorTable[19]={ {32767}, {32767}, {65535} }	//slate
	RainbowColorTable[20]={ {65535}, {32767}, {32767} }	//coral

	RainbowColorTable[21]={ {65535}, {32767}, {65535} }	//pink
	RainbowColorTable[22]={ {65535}, {65535}, {32767} }	//lightyellow
	RainbowColorTable[23]={ {32767}, {65535}, {65535} }	//paleblue

	RainbowColorTable[24]={ {0}, {0}, {0} }					//black
	RainbowColorTable[25]={ {32767}, {32767}, {32767} }		//gray
	RainbowColorTable[26]={ {65535}, {65535}, {65535} }		//white

End


Function mz_populate_CalAccuracyGraph()

	SetDataFolder root:mzFitting:
	wave OneRunFitTime,OneRunPowerFitDisplayY,OneRunAccuracyMass, ppmGuidelinesBottom,mz_Mass,ppmGuidelinesTop, ppmGuidelinesMz,OneRunPowerFitDisplayX
	AppendToGraph OneRunFitTime vs mz_Mass
	AppendToGraph OneRunPowerFitDisplayY vs OneRunPowerFitDisplayX
	AppendToGraph/R OneRunAccuracyMass vs mz_Mass
	AppendToGraph/R ppmGuidelinesBottom,ppmGuidelinesTop vs ppmGuidelinesMz
	SetDataFolder root:
	ModifyGraph rgb(ppmGuidelinesBottom)=(34816,34816,34816)
	ModifyGraph rgb(ppmGuidelinesTop)=(34816,34816,34816)
	ModifyGraph margin(left)=39,margin(bottom)=36,margin(top)=7,margin(right)=41,wbRGB=(65280,65280,48896)
	ModifyGraph mode(OneRunFitTime)=3
	ModifyGraph mode(OneRunAccuracyMass)=1
	ModifyGraph lsize(OneRunAccuracyMass)=3	
	ModifyGraph marker(OneRunFitTime)=8,marker(OneRunPowerFitDisplayY)=8
	ModifyGraph rgb(OneRunFitTime)=(0,0,0),rgb(OneRunPowerFitDisplayY)=(65280,0,0),rgb(OneRunAccuracyMass)=(16384,16384,65280)
	ModifyGraph zero(right)=1
	ModifyGraph axRGB(right)=(0,0,65280)
	ModifyGraph tlblRGB(right)=(0,0,65280)
	ModifyGraph lblLatPos(left)=17,lblLatPos(right)=8
//	Label left "Ion Time of Flight"
	Label left "Sample number"		//1.54E
	Label bottom "Exact m/z"
	Label right "\\K(0,0,65280) Accuracy, ppm"
	SetAxis left 0,5e4
	SetAxis bottom 0,300
	SetAxis right -50,50

End


// new in 1.50D
Function mz_showGraph_CheckProc(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	string childList, grName
	variable GraphExists
	
	grName = StringFromList(1, ctrlName, "_")
	childList =  ChildWindowList("SQ_mzCalibration_Panel" )
	GraphExists = WhichListItem(grName, childList)>=0
	nvar check_XGraph = $"root:mzFitting:Show"+grName

//	print mywavelist
	if (check_XGraph) // show
		// make sure it is not already displayed
		if (!GraphExists)		// isn't displayed
			strswitch(grName)
			case "PPMGraph":
				Display/W=(486,72,885,198)/FG=(UGV4,,,)/HOST=SQ_mzCalibration_Panel
			break
			case "ResolutionGraph":
				Display/W=(487,202,885,328)/FG=(UGV4,,,)/HOST=SQ_mzCalibration_Panel
			break
			case "ParamGraph":
				Display/W=(486,357,885,568)/FG=(UGV4,$"",$"",$"")/HOST=SQ_mzCalibration_Panel
			break
			endswitch
			Execute "mz_populate_"+grName+"()"
			RenameWindow #, $grName
			SetActiveSubwindow ##
		endif
	else		// do not show
		if (GraphExists)		// isn't displayed
			KillWindow $"SQ_mzCalibration_Panel#"+grName
		endif
	endif

End

// 1.61E
Function mz_butt_copyMzTable(ctrlName) : ButtonControl
	String ctrlName

	wave/t mz_Name = root:mzFitting:mz_Name
	wave mz_Mass = root:mzFitting:mz_Mass
	wave mz_SpecType = root:mzFitting:mz_SpecType
	wave mz_DeltaNum = root:mzFitting:mz_DeltaNum
	wave mz_Graph = root:mzFitting:mz_Graph

	string suffixStr, helpStr
	helpStr = ""
	helpStr+="You can save a copy of the waves in the m/z calibration table for later referral and use. The"
	helpStr+=" suffix you enter will be appended to the wave copies. If you enter HiOrg, i.e."
	helpStr+=" a copy of the waves named mz_mass_HiOrg, etc. will be put in root:mzFitting"
	
	suffixStr = ""
	Prompt suffixStr, "Enter the wave name suffix" 
	DoPrompt/HELP=helpStr " *** Press the Help button for more info ***", suffixStr

	if (V_flag == 0 && strlen(suffixStr)>0)		// we are to continue
		suffixStr = CleanupName(suffixStr, 0)
		duplicate/o mz_Name $"root:mzFitting:mz_Name_"+suffixStr
		duplicate/o mz_Mass $"root:mzFitting:mz_Mass_"+suffixStr
		duplicate/o mz_SpecType $"root:mzFitting:mz_SpecType_"+suffixStr
		duplicate/o mz_DeltaNum $"root:mzFitting:mz_DeltaNum_"+suffixStr
		duplicate/o mz_Graph $"root:mzFitting:mz_Graph_"+suffixStr
		DoAlert 0,  "The waves named root:mzFitting:mz_Mass_"+suffixStr + " etc. were created."
	endif

End


//1.44B
Function mz_butt_loadMzTable(ctrlName) : ButtonControl
	String ctrlName

	string suffixStr, helpStr
	
	helpStr = ""
	helpStr+="You can overwrite all the values in the m/z calibration table with a set of previously saved waves."
	helpStr+=" If you enter HiOrg, i.e."
	helpStr+=" squirrel will search root:mzFitting for waves mz_mass_HiOrg, etc and will overwrite"
	helpStr+=" the existing values with these new values."	

	suffixStr = ""
	Prompt suffixStr, "Enter the wave name suffix" 
	DoPrompt/HELP=helpStr "*** Press the Help button for more info ***", suffixStr

	if (V_flag == 0 && strlen(suffixStr)>0)		// we are to continue
		suffixStr = CleanupName(suffixStr, 0)
		wave/t/z mz_NameX = $"root:mzFitting:mz_Name_"+suffixStr
		wave/z mz_MassX = $"root:mzFitting:mz_Mass_"+suffixStr
		wave/z mz_SpecTypeX = $"root:mzFitting:mz_SpecType_"+suffixStr
		wave/z mz_DeltaNumX = $"root:mzFitting:mz_DeltaNum_"+suffixStr
		wave/z mz_GraphX = $"root:mzFitting:mz_Graph_"+suffixStr
		if (WaveExists(mz_NameX) && WaveExists(mz_MassX) && WaveExists(mz_SpecTypeX) && WaveExists(mz_DeltaNumX) && WaveExists(mz_GraphX) )
			duplicate/o mz_NameX root:mzFitting:mz_Name
			duplicate/o mz_MassX root:mzFitting:mz_Mass
			duplicate/o mz_SpecTypeX root:mzFitting:mz_SpecType
			duplicate/o mz_DeltaNumX root:mzFitting:mz_DeltaNum
			duplicate/o mz_GraphX root:mzFitting:mz_Graph
			DoAlert 0,  "The waves named root:mzFitting:mz_Mass_"+suffixStr + " etc. were loaded into the m/z calibration table waves."
		else
			DoAlert 0,  "The waves named root:mzFitting:mz_Mass_" + " etc. were NOT FOUND and thus not loaded."
		endif
	endif

End


Function mz_butt_declareParamsAsOC(ctrlName) : ButtonControl
	String ctrlName

	wave mz_FitIntercept = root:mzFitting:mz_FitIntercept
	wave mz_FitSlope = root:mzFitting:mz_FitSlope
	wave mz_FitPower = root:mzFitting:mz_FitPower

	string OpenClosedStr
	
	if (strsearch(lowerstr(ctrlName), "closed", 0)>0	)
		OpenClosedStr = "Closed"	
	elseif(strsearch(lowerstr(ctrlName), "open", 0)>0 )
		OpenClosedStr = "Open"
	else			//1.49A
		OpenClosedStr = "PToF"
	endif
	
	wave/z mz_FitInterceptOC =$"root:mzFitting:mz_FitIntercept"+OpenClosedStr
	wave/z mz_FitSlopeOC =$"root:mzFitting:mz_FitSlope"+OpenClosedStr
	wave/z mz_FitPowerOC =$"root:mzFitting:mz_FitPower"+OpenClosedStr
	if (!WaveExists(mz_FitInterceptOC) || !WaveExists(mz_FitSlopeOC)  || !WaveExists(mz_FitPowerOC) )		
		duplicate/o  mz_FitIntercept $"root:mzFitting:mz_FitIntercept"+OpenClosedStr/wave=mz_FitInterceptOC
		duplicate/o  mz_FitSlope $"root:mzFitting:mz_FitSlope"+OpenClosedStr/wave=mz_FitSlopeOC
		duplicate/o  mz_FitPower $"root:mzFitting:mz_FitPower"+OpenClosedStr/wave=mz_FitPowerOC
		mz_FitInterceptOC=nan
		mz_FitSlopeOC=nan
		mz_FitPowerOC=nan
	endif

	ControlInfo/W=SQ_MzCalibration_Panel popup_ToDoWave
	wave/z todo=$"root:"+S_value
	make/free/o/n=(numpnts(mz_FitIntercept)) mask=1
	if (WaveExists(todo))
		sq_makeMaskFromTodofindRun(mask,todo)
	endif
	
	mz_FitInterceptOC = mask[p]==1 ? mz_FitIntercept[p] : mz_FitInterceptOC[p]
	mz_FitSlopeOC = mask[p]==1 ? mz_FitSlope[p] : mz_FitSlopeOC[p]
	mz_FitPowerOC = mask[p]==1 ? mz_FitPower[p] : mz_FitPowerOC[p]

	print "// The current m/z fitting parameters have been declared for runs in todo wave "+S_Value+" as "+OpenClosedStr+" at "+ date() + time()

End


Function mz_checkHideDaQ(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	if (checked)
		ModifyGraph hideTrace(mzSlope)=1
		ModifyGraph hideTrace(mzInt)=1
		ModifyGraph hideTrace(mzPower)=1
	else
		ModifyGraph hideTrace(mzSlope)=0
		ModifyGraph hideTrace(mzInt)=0
		ModifyGraph hideTrace(mzPower)=0
	endif
	
End


Function mz_butt_revertMzCal_Spec(ctrlName) : ButtonControl
	String ctrlName

	wave mz_SpecType = root:mzFitting:mz_specType
	
	ControlInfo/w=Sq_mzcalibration_panel popup_MzSelectMasses
	
	switch(V_Value)
	case 1:
		 DoAlert 1, "Are you sure you want to reset the m/z Name, Mass, Spec Type, Delta and Plot waves and the 2 checkboxes and peak search factor to default values?"
		 if (V_flag==1)
	 		mz_makeMzCal_Waves()
		endif
		break
	case 2:
		mz_SpecType = (mz_SpecType[p]>0 )? 2:0 
		break
	case 3:
		mz_SpecType = (mz_SpecType[p]>0 )? 3:0 
		break	
	case 4:
		mz_SpecType = (mz_SpecType[p]>0 )? 4:0 		//1.49A
		break	
	endswitch

	nvar KeepPowerParamConstant = root:mzFitting:KeepPowerParamConstant	
	KeepPowerParamConstant=0
	nvar mz_UsePreviousRunParams = root:mzFitting:mz_UsePreviousRunParams	
	mz_UsePreviousRunParams=0
	nvar mz_RegionScalar = root:mzFitting:mz_RegionScalar	
	mz_RegionScalar=1
				
End


Function mz_butt_smoothAvgParams(ctrlName) : ButtonControl
	String ctrlName
	
	wave/z mz_FitSlope = root:mzFitting:mz_FitSlope
	wave/z mz_FitIntercept = root:mzFitting:mz_FitIntercept
	wave/z mz_FitPower = root:mzFitting:mz_FitPower
	if (!WaveExists(mz_FitSlope))
		DoAlert, 1, "You have not preformed m/z fitting in Step 3 of the m/z calibration panel."
	endif
		
	wave mz_TofTypeDisplayKey = root:mzFitting:mz_TofTypeDisplayKey 
	nvar mz_smoothFinalParamsVar =  root:mzFitting:mz_smoothFinalParamsVar	
	svar sq_toDoList = root:panel:sq_toDoList
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	nvar FilterNumNans =  root:mzFitting:FilterNumNans	
	nvar isW =  root:diagnostics:isW	
	nvar isV =  root:diagnostics:isV	

	ControlInfo mz_popupParmGraphTodo
	if (!stringMatch(S_value,sq_toDoWvNm))
		Abort "Please reselect the todo wave."
	endif
	wave todo =$"root:"+sq_toDoWvNm
	
	if (stringmatch("butt_smooth",ctrlName) && mz_smoothFinalParamsVar<=0)
		Abort "Cannot smooth 0 or fewer parameters  - Aborting from mz_butt_smoothAvgParams"
	endif
	
	ControlInfo checkBetweenCsrs
	if (stringmatch("butt_average",ctrlName) && V_value)
		variable ptA =pCsr(a) 
		variable ptB =pCsr(B) 
		if( !( ptA>=0 && ptB>=0) )
			Abort "Please place the cursors on data points - Aborting from mz_butt_smoothAvgParams"
		elseif (ptB < ptA)
			variable temp = ptA
			ptA = ptB
			ptB = temp
		endif
	endif

	make/o/n=0/free maskW
	sq_makeMaskFromTodofindRun(maskW,todo)	
	sq_TodoWaveHasOnlyModeX(todo, maskW=maskW)	
	mz_TofTypeDisplayKey = maskW
	
	variable Copen, Cclosed, Clast, csrFlag
	ControlInfo/W=MzFittingParamGraph checkLast; Clast=V_Value 
	ControlInfo/W=MzFittingParamGraph checkOpen; Copen=V_Value
	ControlInfo/W=MzFittingParamGraph checkClosed; Cclosed=V_Value
	ControlInfo/W=MzFittingParamGraph checkBetweenCsrs; csrFlag=V_Value

	if (stringmatch("butt_interpolate",ctrlName))
		// maybe the user changed a parameter through the table
//		if (FilterNumNans==0)
			duplicate/free  maskW, NanMask	
			NanMask*=numtype(mz_FitSlope[p])!=2
			NanMask*=numtype(mz_FitIntercept[p])!=2
			NanMask*=numtype(mz_FitPower[p])!=2
			FilterNumNans = sum(maskW) - sum(NanMask)
//		endif		
		if (FilterNumNans==0)
			Abort "There are no nan values to interpolate over - perhaps select a different todo wave? Aborting from mz_butt_smoothAvgParams"
		endif
	endif

	if (Cclosed)
		wave/z mz_FitSlopeC = $"root:mzFitting:mz_FitSlopeClosed"
		wave/z mz_FitInterceptC = $"root:mzFitting:mz_FitInterceptClosed"
		wave/z mz_FitPowerC = $"root:mzFitting:mz_FitPowerClosed"
		if (!WaveExists(mz_FitSlopeC))  // presu me if one is missing all are
			DoAlert 1,  "There does not seem to be any closed parameters declared in step 6 of the m/z calibration panel.  To uncheck the Closed checkbox and continue, press yes."
			if (V_flag!=1)
				return 0
			endif
			Checkbox checkClosed Value=0, win=MzFittingParamGraph
			Cclosed=0
		endif	
	endif
	if (Copen)
		wave/z mz_FitSlopeO = $"root:mzFitting:mz_FitSlopeOpen"
		wave/z mz_FitInterceptO = $"root:mzFitting:mz_FitInterceptOpen"
		wave/z mz_FitPowerO = $"root:mzFitting:mz_FitPowerOpen"
		DoAlert 1,  "There does not seem to be any open parameters declared in step 6 of the m/z calibration panel.  To uncheck the Open checkbox and continue, press yes."
		if (V_flag!=1)
			return 0
		endif
		Checkbox checkOpen Value=0, win=MzFittingParamGraph
		Copen=0
	endif

	strswitch (ctrlName)
	case "butt_smooth":
		if (Clast)
			mz_smooth(mz_smoothFinalParamsVar, mz_FitSlope, mz_FitIntercept, mz_FitPower, mz_TofTypeDisplayKey)
		endif
		if (Copen)
			mz_smooth(mz_smoothFinalParamsVar, mz_FitSlopeO, mz_FitInterceptO, mz_FitPowerO, mz_TofTypeDisplayKey)
		endif
		if (Cclosed)
			mz_smooth(mz_smoothFinalParamsVar, mz_FitSlopeC, mz_FitInterceptC, mz_FitPowerC, mz_TofTypeDisplayKey)
		endif
	break
	case "butt_average":
		if (Clast)
			Mz_Average(csrFlag, ptA, ptB, mz_FitSlope, mz_FitIntercept, mz_FitPower, mz_TofTypeDisplayKey)
		endif
		if (Copen)
			Mz_Average(csrFlag, ptA, ptB, mz_FitSlopeO, mz_FitInterceptO, mz_FitPowerO, mz_TofTypeDisplayKey)
		endif
		if (Cclosed)
			Mz_Average(csrFlag, ptA, ptB, mz_FitSlopeC, mz_FitInterceptC, mz_FitPowerC, mz_TofTypeDisplayKey)
		endif
	break
//	case "butt_revert":
//		if (Clast)
//			Mz_Revert("", mz_TofTypeDisplayKey)
//		endif
//		if (Copen)
//			Mz_Revert("Open", mz_TofTypeDisplayKey)
//		endif
//		if (Cclosed)
//			Mz_Revert("Closed", mz_TofTypeDisplayKey)
//		endif
//	break
	case "butt_interpolate":
		if (Clast)
			mz_interpolate( mz_FitSlope, mz_FitIntercept, mz_FitPower, mz_TofTypeDisplayKey)
		endif
		if (Copen)
			mz_interpolate(mz_FitSlopeO, mz_FitInterceptO, mz_FitPowerO, mz_TofTypeDisplayKey)
		endif
		if (Cclosed)
			mz_interpolate( mz_FitSlopeC, mz_FitInterceptC, mz_FitPowerC, mz_TofTypeDisplayKey)
		endif
	break
	endswitch
	
End


Function mz_ShowOnlyCheckProc(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	string which = ReplaceString("check", ctrlName,"")
	string df = GetDataFolder(1)
	SetDataFolder root:mzfitting
	string wlist = WaveList("*", ";", "WIN:MzFittingParamGraph")
	SetDataFolder $df
	wlist=RemoveFromList("mzPower;mzSlope;mzInt;", wlist)	

	strswitch(which)
	case "Last":
		ModifyGraph hideTrace(mz_FitIntercept) = !checked
		ModifyGraph hideTrace(mz_FitSlope) = !checked
		ModifyGraph hideTrace(mz_FitPower) = !checked
	break
	case "Open":
		if (WhichListItem("mz_FitPowerOpen", wlist) >0 )
			ModifyGraph hideTrace(mz_FitInterceptOpen) = !checked
			ModifyGraph hideTrace(mz_FitSlopeOpen) = !checked
			ModifyGraph hideTrace(mz_FitPowerOpen) = !checked
		elseif (Exists("root:mzFitting:mz_FitPowerOpen"))
			wave mz_FitPowerW = $"root:mzFitting:mz_FitPowerOpen"
			wave mz_FitSlopeW = $"root:mzFitting:mz_FitSlopeOpen"
			wave mz_FitInterceptW = $"root:mzFitting:mz_FitInterceptOpen"
			wave rn_series = root:index:rn_series
			AppendThese(mz_FitPowerW, mz_FitSlopeW, mz_FitInterceptW, rn_series, 1)
		else
			Checkbox $ctrlName value=0
			abort "There does not seem to be any open parameters declared in step 6 of the m/z calibration panel."
		endif
	break
	case "Closed":
		if (WhichListItem("mz_FitPowerClosed", wlist) >0 )
			ModifyGraph hideTrace(mz_FitInterceptClosed)  = !checked
			ModifyGraph hideTrace(mz_FitSlopeClosed) = !checked
			ModifyGraph hideTrace(mz_FitPowerClosed) = !checked
		elseif (Exists("root:mzFitting:mz_FitPowerClosed"))
			wave mz_FitPowerW = $"root:mzFitting:mz_FitPowerClosed"
			wave mz_FitSlopeW = $"root:mzFitting:mz_FitSlopeClosed"
			wave mz_FitInterceptW = $"root:mzFitting:mz_FitInterceptClosed"
			wave rn_series = root:index:rn_series
			AppendThese(mz_FitPowerW, mz_FitSlopeW, mz_FitInterceptW, rn_series, 0)
		else
		else
			Checkbox $ctrlName value=0
			abort "There does not seem to be any closed parameters declared in step 6 of the m/z calibration panel."
		endif
	break
	endswitch
	
End


Function mz_interpolate(slope, inter, power, todoMask)
wave slope, inter, power, todoMask

	duplicate/free slope slopeFree
	duplicate/free inter interFree
	duplicate/free power powerFree

	slopeFree /= todoMask
	interFree /= todoMask
	powerFree /= todoMask
	
	sq_interpolateWave(slopeFree, slopeFree, 1)
	sq_interpolateWave(interFree, interFree, 1)
	sq_interpolateWave(powerFree, powerFree, 1)

	slope = todoMask[p] == 1 ? slopeFree[p] : slope[p]
	inter = todoMask[p] == 1 ? interFree[p] : inter[p]
	power = todoMask[p] == 1 ? powerFree[p] : power[p]

End


Function mz_average(csrFlag, ptA, ptB, slope, inter, power, todoMask)
variable csrFlag, ptA, ptB
wave slope, inter, power, todoMask
		
	duplicate/free slope slopeFree
	duplicate/free inter interFree
	duplicate/free power powerFree

	slopeFree /= todoMask
	interFree /= todoMask
	powerFree /= todoMask

	if (!csrFlag)
		Wavestats/q/M=1 slopeFree
		slope = todoMask[p] == 1 ? V_avg : slope[p]
		Wavestats/q/M=1 interFree
		inter = todoMask[p] == 1 ? V_avg : inter[p]
		Wavestats/q/M=1 powerFree
		power = todoMask[p] == 1 ? V_avg : power[p]
	else
		Wavestats/q/M=1/r=[ptA,ptB] slopeFree
		slope = (todoMask[p] == 1 && p >= ptA && p <=ptB ) ? V_avg : slope[p]
		Wavestats/q/M=1/r=[ptA,ptB] interFree
		inter = (todoMask[p] == 1 && p >= ptA && p <=ptB ) ? V_avg : inter[p]
		Wavestats/q/M=1/r=[ptA,ptB] powerFree
		power = (todoMask[p] == 1 && p >= ptA && p <=ptB ) ? V_avg : power[p]
	endif
End


Function mz_smooth(smoothVar, slope, inter, power, todoMask)
variable smoothVar
wave slope, inter, power, todoMask

	duplicate/free slope slopeFree
	duplicate/free inter interFree
	duplicate/free power powerFree

	slopeFree /= todoMask
	interFree /= todoMask
	powerFree /= todoMask

	sq_smooth_nans(slopeFree, smoothVar)
	sq_smooth_nans(interFree, smoothVar)
	sq_smooth_nans(powerFree, smoothVar)

	slope = todoMask[p] == 1 ? slopeFree[p] : slope[p]
	inter = todoMask[p] == 1 ? interFree[p] : inter[p]
	power = todoMask[p] == 1 ? powerFree[p] : power[p]
end


Function mz_populate_ParamGraph()

	String fldrSav0= GetDataFolder(1)
	SetDataFolder root:mzFitting:
	wave mz_FitSlope, mz_FitPower,mz_FitIntercept
	string legstr=""
	wave rn_series = root:index:rn_series
	wave mz_ToFTypeDisplayKey = root:mzFitting:mz_ToFTypeDisplayKey

	variable OpenExists, ClosedExists, PToFExists
	
	OpenExists = WaveExists(root:mzFitting:mz_FitInterceptOpen)		// could use intercept, slope or power
	ClosedExists = WaveExists(root:mzFitting:mz_FitInterceptClosed)		// could use intercept, slope or power
	PToFExists = WaveExists(root:mzFitting:mz_FitInterceptPToF)		// could use intercept, slope or power

	AppendToGraph/L=left_int mz_FitIntercept vs rn_series
	AppendToGraph/L=left_slp mz_FitSlope vs rn_series
	AppendToGraph/L=left_pow mz_FitPower vs rn_series
	AppendToGraph/L=left_pow ::diagnostics:mzPower vs rn_series
	AppendToGraph/L=left_slp ::diagnostics:mzSlope vs rn_series
	AppendToGraph/L=left_int ::diagnostics:mzInt vs rn_series

	legstr+= "DAQ" 

	if (OpenExists)
		wave mz_FitPowerOpen, mz_FitSlopeOpen, mz_FitInterceptOpen
		wave rn_series = root:index:rn_series
		AppendThese(mz_FitPowerOpen, mz_FitSlopeOpen, mz_FitInterceptOpen, rn_series, 1)
	endif	
	if (ClosedExists)
		wave/z mz_FitPowerClosed, mz_FitSlopeClosed, mz_FitInterceptClosed
		wave rn_series = root:index:rn_series
		AppendThese(mz_FitPowerClosed, mz_FitSlopeClosed, mz_FitInterceptClosed, rn_series, 0)
	endif
//	if (PToFExists)
//		wave/z mz_FitPowerPToF, mz_FitSlopePToF, mz_FitInterceptPToF
//		AppendToGraph/L=left_pow mz_FitPowerPToF vs rn_series
//		AppendToGraph/L=left_slp mz_FitSlopePToF vs rn_series
//		AppendToGraph/L=left_int mz_FitInterceptPToF vs rn_series
//	endif

	ModifyGraph mode(mz_FitIntercept)=4,mode(mz_FitSlope)=4,mode(mz_FitPower)=4
	ModifyGraph marker(mz_FitIntercept)=5,marker(mz_FitSlope)=5,marker(mz_FitPower)=5
	ModifyGraph rgb(mz_FitIntercept)=(44032,29440,58880),rgb(mz_FitSlope)=(0,0,65280)
	ModifyGraph rgb(mz_FitPower)=(19456,39168,0),rgb(mzPower)=(0,0,0),rgb(mzSlope)=(0,0,0)
	ModifyGraph rgb(mzInt)=(0,0,0)
	ModifyGraph msize(mz_FitIntercept)=2,msize(mz_FitSlope)=2,msize(mz_FitPower)=2
	ModifyGraph grid=2
	ModifyGraph gridRGB(left_int)=(34816,34816,34816),gridRGB(bottom)=(52224,52224,52224)
	ModifyGraph gridRGB(left_slp)=(34816,34816,34816),gridRGB(left_pow)=(34816,34816,34816)
	ModifyGraph lblPos(left_int)=65,lblPos(left_slp)=65,lblPos(left_pow)=65
	ModifyGraph lblLatPos(left_int)=-5,lblLatPos(left_slp)=-5,lblLatPos(left_pow)=-5
	ModifyGraph freePos(left_int)=-40
	ModifyGraph freePos(left_slp)=-40
	ModifyGraph freePos(left_pow)=-40
	ModifyGraph axisEnab(left_int)={0.05,0.35}
	ModifyGraph axisEnab(bottom)={0.15,1}
	ModifyGraph axisEnab(left_slp)={0.38,0.68}
	ModifyGraph axisEnab(left_pow)={0.7,1}
	Label left_int "\\K(44032,29440,58880)Fit Intercept"
	Label bottom "Run number"
	Label left_slp "\\K(0,0,65280)Fit Slope"
	Label left_pow "\\K(19456,39168,0)Fit Power"
	Legend/C/N=leg legstr
	SetDataFolder fldrSav0
End


Function AppendThese(mz_FitPowerW, mz_FitSlopeW, mz_FitInterceptW, rn_series, Oflag)
wave mz_FitPowerW, mz_FitSlopeW, mz_FitInterceptW, rn_series
variable Oflag

	AppendToGraph/L=left_pow mz_FitPowerW vs rn_series
	AppendToGraph/L=left_slp mz_FitSlopeW vs rn_series
	AppendToGraph/L=left_int mz_FitInterceptW vs rn_series
	ModifyGraph mode($NameofWave(mz_FitSlopeW))=4,mode($NameofWave(mz_FitInterceptW))=4,mode($NameofWave(mz_FitPowerW))=4
	ModifyGraph msize($NameofWave(mz_FitSlopeW))=2,msize($NameofWave(mz_FitInterceptW))=2,msize($NameofWave(mz_FitPowerW))=2
	variable marker = Oflag ?  8 : 1
	variable r = Oflag ?  65535 : 39321
	variable g = Oflag ?  34958 : 26208
	variable b = Oflag ?  1 : 1	
	ModifyGraph marker($NameofWave(mz_FitPowerW))=marker,marker($NameofWave(mz_FitSlopeW))=marker,marker($NameofWave(mz_FitInterceptW))=marker
	ModifyGraph rgb($NameofWave(mz_FitPowerW))=(r,g,b),rgb($NameofWave(mz_FitSlopeW))=(r,g,b),rgb($NameofWave(mz_FitInterceptW))=(r,g,b)
End


Function mz_AppendParamControls()
	ControlBar 90
	GroupBox group0,pos={1.00,25.00},size={178.00,38.00}
	PopupMenu mz_popupParmGraphTodo,pos={5.00,3.00},size={125.00,19.00},proc=mz_pop_toDoList,title="Display this todo"
	PopupMenu mz_popupParmGraphTodo,mode=1,popvalue="all",value= #"root:panel:sq_toDoList"
	SetVariable setvar_num2smooth,pos={384.00,40.00},size={116.00,15.00},bodyWidth=35,title="# runs to smooth"
	SetVariable setvar_num2smooth,fSize=10,value=:mzFitting:mz_smoothFinalParamsVar
	GroupBox group_smooth,pos={230.00,2.00},size={290.00,84.00},title="Parameter replacement for todo"
	GroupBox group_smooth,fColor=(1,1,1)
//	Button butt_revert,pos={509.00,43.00},size={60.00,35.00},proc=mz_butt_RevertParams,title="Revert \rvalues"
	Button butt_smooth,pos={235.00,39.00},size={140.00,20.00},proc=mz_butt_smoothAvgParams,title="Smooth parameters"
	Button butt_average,pos={235.00,61.00},size={140.00,20.00},proc=mz_butt_smoothAvgParams,title="Average parameters"
	Button butt_interpolate,pos={235.00,17.00},size={140.00,20.00},proc=mz_butt_smoothAvgParams,title="Interpolate across nans"
	CheckBox checkBetweenCsrs,pos={384.00,65.00},size={92.00,14.00},title="Avg between csrs"
	CheckBox checkBetweenCsrs,fSize=10,value= 0
	CheckBox checkLast,pos={5.00,44.00},size={74.00,15.00},proc=mz_ShowOnlyCheckProc,title="Last calced"
	CheckBox checkLast,value= 1
	CheckBox checkOpen,pos={93.00,27.00},size={45.00,15.00},proc=mz_ShowOnlyCheckProc,title="Open"
	CheckBox checkOpen,value= 1, fColor=(52428,34958,1)
	CheckBox checkClosed,pos={93.00,44.00},size={52.00,15.00},proc=mz_ShowOnlyCheckProc,title="Closed"
	CheckBox checkClosed,value= 1, fColor=(39321,26208,1)
	TitleBox title0,pos={6.00,26.00},size={67.00,15.00},title="Display only:"
	TitleBox title0,frame=0
	Button butt_back,pos={2.00,64.00},size={140.00,20.00},proc=sq_butt_checkMz,title="Back to m/z cal panel"
	SetVariable setvar_nanNum,pos={385.00,18.00},size={132.00,15.00},bodyWidth=30,title="# runs where fit = nan"
	SetVariable setvar_nanNum,help={"Indicates the number of bad fits to be removed by filtering."}
	SetVariable setvar_nanNum,fSize=10
	SetVariable setvar_nanNum,limits={0,inf,0},value= root:mzFitting:FilterNumNans,noedit= 1
	Button button_paramTable,pos={185.00,27.00},size={40.00,30.00},proc=mz_butt_FitParamTable,title="Param\rTable"
	Button button_paramTable,fSize=10
	ShowInfo
End


Function mz_butt_paramGraph(ctrlName) : ButtonControl
	String ctrlName

	 DoWindow/F mzFittingParamGraph
	 if (V_flag)
	 	return 0
	 endif
	 
	svar sq_toDoList = root:panel:sq_toDoList
	svar sq_toDoWvNm = root:panel:sq_toDoWvNm

	Display/N=mzFittingParamGraph as "mzFittingParamGraph"
	mz_populate_ParamGraph()
	mz_AppendParamControls()
 
	variable var = WhichListItem(sq_toDoWvNm, sq_toDoList)
	
	PopupMenu mz_popupParmGraphTodo,mode=max(1,var+1)
End


Function mz_pop_toDoList(controlName,popNum,popStr) : PopUpMenuControl
	string controlName
	variable popNum
	string popStr
	
	svar sq_toDoList=root:panel:sq_toDoList
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	
	if ( stringmatch( popStr, "Get List") )
		sq_todolist=SQ_getTODOwaves()
		if (strlen(sq_todolist)>0)
			PopupMenu ams_toDoList_pop,win=ams_panel,mode=1,popvalue=stringfromlist(0,sq_todolist)
			PopupMenu/Z HRGen_todolist_pop,win=HR_Analysis_panel,mode=1,popvalue=stringfromlist(0,sq_todolist)	// 1.46D
			sq_toDoWvNm=stringfromlist(0,sq_todolist)
		endif
	else
		wave/z todo =$"root:"+PopStr		//1.59C
		if (WaveExists(todo))
			sq_setTof0_PToFePToFtitle(todo)
			sprintf sq_toDoWvNm, "%s", popStr
			PopupMenu ams_toDoList_pop,win=ams_panel,mode=popNum
			PopupMenu/Z HRGen_todolist_pop,win=HR_Analysis_panel,mode=popNum
			PopupMenu/Z mz_popupParmGraphTodo,win=mzFittingParamGraph,mode=popNum
			PopupMenu popup_ToDoWave,win=SQ_MzCalibration_Panel,mode=popNum
		endif
		if (stringmatch("mz_popupParmGraphTodo", controlName))
			wave mz_TofTypeDisplayKey = root:mzFitting:mz_TofTypeDisplayKey 
			sq_makeMaskFromTodofindRun(mz_TofTypeDisplayKey,todo)	
			ModifyGraph mask={root:mzFitting:mz_TofTypeDisplayKey,1,1 }
		endif
	endif

End


//Function mz_Revert(OCstr,todoMask)
//string OCstr
//wave todoMask
//
//	wave/z mz_FitSlopeOC = $"root:mzFitting:mz_FitSlope"+OCstr
//	wave/z mz_FitInterceptOC = $"root:mzFitting:mz_FitIntercept"+OCstr
//	wave/z mz_FitPowerOC = $"root:mzFitting:mz_FitPower"+OCstr
//	if (!WaveExists(mz_FitSlopeOC))
//		DoAlert, 1, "You have not defined "+OCstr+" parameters from Step 6 of the m/z calibration panel."
//	endif
//	
////	wave/z mz_FitSlopeOC_orig = $"root:mzFitting:mz_FitSlope"+OCstr+"_orig"
////	wave/z mz_FitInterceptOC_orig = $"root:mzFitting:mz_FitIntercept"+OCstr+"_orig"
////	wave/z mz_FitPowerOC_orig = $"root:mzFitting:mz_FitPower"+OCstr+"_orig"
////	if (WaveExists(mz_FitSlopeOC_orig)==0 )  // assume if one isn't there none are
////		DoAlert, 1, "There is a problem with the original "+OCstr+" parameters from Step 6 of the m/z calibration panel."
////	endif
//	
//	mz_FitSlopeOC = todoMask[p] == 1 ? mz_FitSlopeOC_orig[p] : mz_FitSlopeOC[p]
//	mz_FitInterceptOC = todoMask[p] == 1 ? mz_FitInterceptOC_orig[p] : mz_FitInterceptOC[p]
//	mz_FitPowerOC = todoMask[p] == 1 ? mz_FitPowerOC_orig[p] : mz_FitPowerOC[p]
//
//End


Function sq_TodoWaveHasOnlyModeX(todo, [maskW])
wave todo, maskW

	if (ParamIsDefault(maskW))
		make/free/o/n=1 tempW
		sq_makeMaskFromTodofindRun(tempW,todo)
		wave maskW = tempW
	endif

	wave TofTypeVKey = root:diagnostics:TofTypeVKey
	wave TofTypeWKey = root:diagnostics:TofTypeWKey

	duplicate/free TofTypeVKey VFree
	duplicate/free TofTypeVKey WFree

	VFree *=maskW
	WFree *=maskW
	
	variable num = numpnts(todo)

	WaveStats/q/m=1 	VFree
	if (V_Sum> 0 && V_Sum!=num)
		abort "There are runs of type V and W in the selected todo wave of "+NameofWave(todo)+ " - aborting from sq_TodoWaveHasOnlyModeX"
	endif

	WaveStats/q/m=1 	WFree
	if (V_Sum> 0 && V_Sum!=num)
		abort "There are runs of type V and W in the selected todo wave of "+NameofWave(todo)+ " - aborting from sq_TodoWaveHasOnlyModeX"
	endif
	
End


//*********************************************************************************************************** 
//**************************************  background panel & functions  ******************************** 

Function bk_createGlobalsBaseline()
 
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	wave todowave = $"root:"+sq_toDoWvNm
	wave mFinish = root:diagnostics:mFinish
	
	variable numRaw, MaxMz
				
	wavestats/q/m=1 mFinish
	MaxMz = v_max
			
	NewDataFolder/o root:baselineFitting
	
	// create global strings and numeric variables
	sq_initializeGlobalSVar("root:baselineFitting:baseline_runModeStr", "")
	sq_initializeGlobalSVar("root:baselineFitting:bk_AdvancedInfoStr", "By checking either box below, a new panel with instructions will appear.")
	KillStrings/z root:baselineFitting:bk_ResolutionStrInfo
	sq_initializeGlobalSVar("root:baselineFitting:bk_ResolutionStrInfo", "UMR integration width formula:\rR0*(1-(1/(1+exp((m-m0)/dm)))")
	KillStrings/z root:baselineFitting:bk_ResolutionStrInfo2
	sq_initializeGlobalSVar("root:baselineFitting:bk_ResolutionStrInfo2", "M/z where stick region >.8 m/z")
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_CurrentRunNum", todowave[0])
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_viewManySleepSec",  2)		
	sq_initializeGlobalNVar("root:baselineFitting:bk_ck_AdditionalStickComp", 0)
	sq_initializeGlobalNVar("root:baselineFitting:bk_UseMassDefect", 0)
	sq_initializeGlobalNVar("root:baselineFitting:bk_DiffDelta", 0.001)
	
//	sq_initializeGlobalNVar("root:baselineFitting:bk_UseRunningAvg",0)		//1.20Y
//	sq_initializeGlobalNVar("root:baselineFitting:bk_RunningAvgDeltaRunNum",0) 	//1.20Y

	KillStrings/z root:baselineFitting:bk_FitOptionsStr
	sq_initializeGlobalSVar("root:baselineFitting:bk_FitOptionsStr", "If Beyond m/z value = -1 then fit to max m/z. Else\rreplace baseline fit with constant after chosen m/z.")
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_MassAxisStart", 10)
	sq_initializeGlobalNVar("root:baselineFitting:bk_MassAxisStop", 110)
//	sq_initializeGlobalNVar("root:baselineFitting:bk_MassAxisDelta", 100)		1.60Y
	sq_initializeGlobalNVar("root:baselineFitting:bk_MassLogAxis_ck", 0)		// checkbox variable
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_UseMzFit_ck", 1)
	sq_initializeGlobalNVar("root:baselineFitting:bk_StickRegionMaxAmu" , 0.8)
	sq_initializeGlobalNVar("root:baselineFitting:bk_OneRunIsInWMode", nan)	
	sq_initializeGlobalNVar("root:baselineFitting:bk_smoothBackground",10)
	sq_initializeGlobalSVar("root:baselineFitting:bk_MassWhenDeltaGT4", "")	
	sq_initializeGlobalSVar("root:baselineFitting:bk_RunModeStr", "")
	sq_initializeGlobalSVar("root:baselineFitting:bk_graphStr", "")
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_YAxisMinY", 1e-6)
	sq_initializeGlobalNVar("root:baselineFitting:bk_YAxisMaxY", 0.01)
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_StdDevNoise_VOpen", 1e-4)			// arbitrary default values
	sq_initializeGlobalNVar("root:baselineFitting:bk_StdDevNoise_VClosed", 1e-4)		// arbitrary default values
	sq_initializeGlobalNVar("root:baselineFitting:bk_StdDevNoise_WOpen", 1e-4)		// arbitrary default values
	sq_initializeGlobalNVar("root:baselineFitting:bk_StdDevNoise_WClosed", 1e-4)		// arbitrary default values

	sq_initializeGlobalNVar("root:baselineFitting:bk_UseLinear", 1)
	sq_initializeGlobalNVar("root:baselineFitting:bk_UseCubicSpline", 0)		

	sq_initializeGlobalNVar("root:baselineFitting:bk_ck_ShowStickIntegRegion", 1)		
	sq_initializeGlobalNVar("root:baselineFitting:bk_ck_DiffNeg", 0)		// added 1.43A, modified in 1.45A	
	sq_initializeGlobalNVar("root:baselineFitting:bk_DisplayOneRunDiffBk", 0)	

	sq_initializeGlobalNVar("root:baselineFitting:bk_BKIsZeroBeyondThisMass", -1)			//1.40D 
	sq_initializeGlobalNVar("root:baselineFitting:bk_BKIsX_Open", 0)
	sq_initializeGlobalNVar("root:baselineFitting:bk_BKIsX_Closed", 0)

	sq_initializeGlobalNVar("root:baselineFitting:bk_SliderSetVar", 1)		//1.45 changed
	sq_initializeGlobalNVar("root:baselineFitting:bk_ck_LockRange",0)		//1.60X

	// create waves for panel some are created so that the panel can be created
	make/o/n=(0) root:baselineFitting:OneRunRawSpectraOpen
	make/o/n=(0) root:baselineFitting:OneRunRawSpectraClosed
	make/o/n=(0) root:baselineFitting:OneRunRawSpectraDiff	
	make/o/n=(0) root:baselineFitting:OneRunRawSpectraPToF
				
	wave/z PToF_A = root:PToF:PToF_A		//1.52
	if (!WaveExists(PToF_A))
		NewDataFolder/o root:PToF
		make/o/n=0 root:PToF:PToF_A
	endif
	
	wave/z OneRunRawSpectraClosed = root:baselineFitting:OneRunRawSpectraClosed		// could use open

	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraDiff=nan

	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraMz=nan
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraRes=nan
	
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraClosedBk=nan
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraOpenBk=nan

	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraClosedBkFit=nan
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraOpenBkFit=nan

	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraDiffBk=nan
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraDiffBkFit=nan
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraDiffLessBks=nan
	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraDiffBkLessFit=nan

	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraNegDiff=nan		// 1.43A		// a wave to inidcate when difference spectra <0
//	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraInteg=nan		// 1.43A		// a wave to show the region of integration

	make /o/n=(numRaw) root:baselineFitting:OneRunRawSpectraCompMask		//1.41RC
	
	make /o/n=(MaxMz) root:baselineFitting:OneRunStickClosed=nan		// to be used later
	make /o/n=(MaxMz) root:baselineFitting:OneRunStickOpen=nan		// to be used later
	make /o/n=(MaxMz) root:baselineFitting:OneRunStickDiff=nan		// to be used later
	
	 // 1.44B
	killwaves/z root:baselineFitting:pt_peak		//1.47J
//	 make/o/n=(MaxMz) root:baselineFitting:pt_peak=nan		1.47J
	 make/o/n=(MaxMz) root:baselineFitting:pt_start=nan
	 make/o/n=(MaxMz) root:baselineFitting:pt_end=nan

	killwaves/z  root:baselineFitting:mz_peak, root:baselineFitting:mz_start, root:baselineFitting:mz_end
	
	// These strings are too long to fit nicely
	string/g root:baselineFitting:bk_disclaimerStr, root:baselineFitting:bk_legendStr

	svar bk_disclaimerStr = root:baselineFitting:bk_disclaimerStr
	bk_disclaimerStr =   "NOTE: The parameters\r"
	bk_disclaimerStr +=  "identified in this panel will\r"
	bk_disclaimerStr +=   "only have an effect PToF\r"
	bk_disclaimerStr +=  "in the recalculation of the MS\r"
	bk_disclaimerStr +=  "sticks if the checkboxt \"Use\r"
	bk_disclaimerStr +=  "baseline fit params\" is\r"
	bk_disclaimerStr +=  "checked in the main AMS\r"
	bk_disclaimerStr +=  "panel, HDF index tab\r"
 	bk_disclaimerStr += "pre-Process Data section."
	
	sq_initializeGlobalSVar(" root:baselineFitting:bk_HelpStr", "")	
	
	svar bk_HelpStr = root:baselineFitting:bk_HelpStr
	bk_HelpStr = "Fitted baselines will be\r"
	bk_HelpStr += "displayed for each run in\r" 
	bk_HelpStr += "the todo wave, with a sleep\r"
	bk_HelpStr += "period in between."

	sq_initializeGlobalSVar(" root:baselineFitting:bk_Step3Str", "")	
	svar bk_Step3Str = root:baselineFitting:bk_Step3Str
	bk_Step3Str = "3. View fits for runs in todo."		//1.14M
	
	svar bk_legendStr = root:baselineFitting:bk_legendStr
	bk_legendStr = "Legend:\r"
	bk_legendStr += "Blue=raw spectra\r"
	bk_legendStr +="Black=non integration region\r"
	bk_legendStr +="  = stick complement\r"
	bk_legendStr +="Red = baseline = BL\r"
	bk_legendStr +="Orange = diff = open-closed\r"	
	bk_legendStr +="Green =(open-BL)-(closed-BL)\r"
	bk_legendStr +="Gray = stick compliment \r"
//	bk_legendStr +="Purple = diff - diff BL \r"
	bk_legendStr +="Pink = stick integration area"   // 1.43A change
//	bk_legendStr +="Olive = Diff < 0 points"

	sq_initializeGlobalNVar(" root:baselineFitting:bk_ck_PToF", 0)	

	bk_createGlobalsBaseStickComp()

	sq_initializeGlobalNVar("root:baselineFitting:bk_numRandomSubset", 5)		//1.51N 

	sq_initializeResolutionParams()
	
	wave/z StickRegion_key = root:baselineFitting:StickRegion_key		// 1.44B
	wave/z BaselineRegion_Key = root:baselineFitting:BaselineRegion_Key	// 1.44B
	if (!waveExists(StickRegion_key) || !waveExists(BaselineRegion_Key ) )
		// these waves will be resized in sq_stickCalcGetRegions.  Each point will be 0.01mz
		make/o/n=(0) root:baselineFitting:StickRegion_Key
		make/o/n=(0) root:baselineFitting:BaselineRegion_Key
		SetScale/P x 0,0.01,"" root:baselineFitting:BaselineRegion_Key, root:baselineFitting:StickRegion_Key
	endif
	
	bk_TofwerkBLGlobals()
End


// added in 1.44B to overwrite som existing globals
Function  bk_createGlobalsBaseStickComp()

	string/g root:baselineFitting:bk_ExtraStickComplimentStr2
	string/g root:baselineFitting:bk_ExtraStickComplimentStr3

	KillStrings/z bk_ExtraStickComplimentStr1

	svar bk_ExtraStickComplimentStr2 = root:baselineFitting:bk_ExtraStickComplimentStr2
	svar bk_ExtraStickComplimentStr3 = root:baselineFitting:bk_ExtraStickComplimentStr3		//^   1.34

	bk_ExtraStickComplimentStr2 =  "The entries do not have to be in ascending m/z order, but all \r"
	bk_ExtraStickComplimentStr2 += "waves need to have the same number of points. These\r"
	bk_ExtraStickComplimentStr2 += "waves can have zero number of points. If you are unclear,\r"
	bk_ExtraStickComplimentStr2 += "make all waves zero length."

	bk_ExtraStickComplimentStr3 = "There are 4 ways to change baseline and stick integration regions.\r"
	bk_ExtraStickComplimentStr3 +="These methods are indicated by values 0 - 3 in the method column.\r\r"
	bk_ExtraStickComplimentStr3 +="0: Removes values from the stick complement region.  The region\r"
	bk_ExtraStickComplimentStr3 +="can overlap existing stick complement regions.\r"
	bk_ExtraStickComplimentStr3 +="1: Removes values from stick *and* stick complement regions; this\r"
	bk_ExtraStickComplimentStr3 +="option is for truly pathological sections of raw data.\r"
	bk_ExtraStickComplimentStr3 += "2: Adds regions to the stick complement region.\r" 
	bk_ExtraStickComplimentStr3 += "3: Adds regions to the stick integration region.\r" 
	bk_ExtraStickComplimentStr3 += "Methods 1, 2, 3 can change the stick integration regions for stick\r"			//1.44B
	bk_ExtraStickComplimentStr3 += "recalculation. Methods 0 - 3 change the stick complement region."

End

//^ sets all pertinent waves to nan
Function bk_initializeBkWaves()

	wave OneRunRawSpectraClosedBk = root:baselineFitting:OneRunRawSpectraClosedBk
	wave OneRunRawSpectraClosedBkFit = root:baselineFitting:OneRunRawSpectraClosedBkFit
	wave OneRunRawSpectraOpenBk = root:baselineFitting:OneRunRawSpectraOpenBk
	wave OneRunRawSpectraOpenBkFit = root:baselineFitting:OneRunRawSpectraOpenBkFit
	wave OneRunRawSpectraDiff = root:baselineFitting:OneRunRawSpectraDiff
	wave OneRunRawSpectraDiffLessBks = root:baselineFitting:OneRunRawSpectraDiffLessBks

//	wave/z OneRunRawSpectraInteg = root:baselineFitting:OneRunRawSpectraInteg			// 1.43A
	wave/z OneRunRawSpectraNegDiff = root:baselineFitting:OneRunRawSpectraNegDiff	 // 1.43A
	
	fastop OneRunRawSpectraClosedBk=(nan)
	fastop OneRunRawSpectraClosedBkFit=(nan)
	fastop OneRunRawSpectraOpenBk=(nan)
	fastop OneRunRawSpectraOpenBkFit=(nan)
	fastop OneRunRawSpectraDiff=(nan)
	fastop OneRunRawSpectraDiffLessBks=(nan)
	
	if (WaveExists(OneRunRawSpectraNegDiff))
//		OneRunRawSpectraInteg=nan		 // 1.43A
		fastop OneRunRawSpectraNegDiff=(nan)	 // 1.43A
	endif
	
End


Function bk_BaselinePanel()  // significantly changed in 1.60Y

	bk_initializeBkWaves()
	PauseUpdate; Silent 1		// building window...
	NewPanel/K=1/N=SQ_Baseline_Panel /W=(220,84,1133,680) as "SQ_Baseline_Panel"
	ModifyPanel fixedSize=1

	ShowTools/A arrow
	SetDrawLayer UserBack
	SetDrawEnv linefgc= (0,43520,65280),fillpat= 0,fillfgc= (60928,60928,60928)
	DrawRect 5,5,414,200
	SetDrawEnv fstyle= 1
	DrawText 10,22,"0. Choose data type, run(s)"
	SetDrawEnv fstyle= 1
	DrawText 425,20,"1. Choose UMR integration regions"
	SetDrawEnv linefgc= (0,52224,0),fillpat= 0,fillfgc= (60928,60928,60928)
	DrawRect 419,5,636,200
	SetDrawEnv fstyle= 1
	DrawText 646,20,"2. Choose baseline type and parameters"
	SetDrawEnv linefgc= (36864,14592,58880),fillpat= 0,fillfgc= (60928,60928,60928)
	DrawRect 900,5,640,200
	GroupBox group0,pos={422.00,47.00},size={213.00,97.00}
	GroupBox group1,pos={9.00,75.00},size={248.00,124.00}
	GroupBox group2,pos={261.00,108.00},size={152.00,90.00}
	GroupBox group3,pos={9.00,26.00},size={147.00,23.00}
	
	CheckBox check_MS,pos={26.00,55.00},size={30.00,14.00},proc=bk_ck_PToFMS,title="MS"
	CheckBox check_MS,fSize=10,value= 1,mode=1
	CheckBox check_PToF,pos={85.00,55.00},size={37.00,14.00},proc=bk_ck_PToFMS,title="PToF"
	CheckBox check_PToF,fSize=10,value= 0,mode=1
	CheckBox check_ePToFSum,pos={144.00,56.00},size={65.00,14.00},proc=bk_ck_PToFMS,title="ePToF Sum"
	CheckBox check_ePToFSum,fSize=10,value= 0,mode=1
//	CheckBox check_somePToF,pos={418.00,165.00},size={40.00,15.00},disable=1
//	CheckBox check_somePToF,value= 0

	// which run
	SetVariable setvar_CurrentRunNum,pos={172.00,6.00},size={90.00,18.00},bodyWidth=65,proc=bk_setVar_RunNumberVW,title="Run"
	SetVariable setvar_CurrentRunNum,help={"Enter the run number to view specific run info."}
	SetVariable setvar_CurrentRunNum,fSize=12,format="%u"
	SetVariable setvar_CurrentRunNum,value= root:baselineFitting:bk_CurrentRunNum
	TitleBox title_runModeStr,pos={270.00,10.00},size={18.00,12.00},fSize=10,frame=0
	TitleBox title_runModeStr,variable= root:baselineFitting:bk_RunModeStr
	CheckBox check_UseNewmz,pos={16.00,30.00},size={122.00,14.00},title="Use new m/z fit params."
	CheckBox check_UseNewmz,fSize=10,variable= root:baselineFitting:bk_UseMzFit_ck
	Button button_ShowThisRun,pos={311.00,8.00},size={100.00,20.00},proc=bk_butt_RawSpectraThisRun,title="View this run"
	Button button_ShowThisRun,fSize=12,fColor=(65280,49152,16384)

	// iterate random subset
	SetVariable it_setvarRandomSubset,pos={270.00,125.00},size={119.00,15.00},bodyWidth=35,title="# runs in subset ="
	SetVariable it_setvarRandomSubset,fSize=10
	SetVariable it_setvarRandomSubset,limits={1,inf,1},value= root:baselineFitting:bk_numRandomSubset
	SetVariable it_setvar_sleepBetweenRuns,pos={270.00,143.00},size={133.00,15.00},bodyWidth=35,title="Sleep between runs, s"
	SetVariable it_setvar_sleepBetweenRuns,fSize=10,format="%1.1f"
	SetVariable it_setvar_sleepBetweenRuns,limits={0,60,0.5},value= root:baselineFitting:bk_viewManySleepSec
	PopupMenu it_popup_ToDoWave,pos={273.00,38.00},size={125.00,19.00},bodyWidth=100,proc=sq_pop_toDoList,title="Todo"
	PopupMenu it_popup_ToDoWave,fSize=10
	PopupMenu it_popup_ToDoWave,mode=8,popvalue="Get List",value= #"root:panel:sq_toDoList+\"Get List;\"\t"
	Button it_nextTodoRun,pos={341.00,60.00},size={60.00,20.00},proc=sq_butt_FindRunInTodo,title="next run"
	Button it_nextTodoRun,fSize=10
	Button it_previousTodoRun,pos={274.00,59.00},size={60.00,20.00},proc=sq_butt_FindRunInTodo,title=" prev. run"
	Button it_previousTodoRun,fSize=10
	Button it_button_calcBaseline4ToDo,pos={262.00,162.00},size={145.00,30.00},proc=bk_butt_viewManyBaselines,title="View each run or\rsubset of runs from todo"
	Button it_button_calcBaseline4ToDo,fSize=12,fColor=(65280,49152,16384)
	Button it_button_calcBaselineInToDo,pos={266.00,82.00},size={140.00,20.00},proc=bk_butt_rawSpectraThisRun,title="View average todo"
	Button it_button_calcBaselineInToDo,fSize=12,fColor=(65280,49152,16384)
	CheckBox it_check_UseRandomSubset,pos={270,111},size={118.00,14.00},proc=bk_ck_subset,title="random subset of todo"
	CheckBox it_check_UseRandomSubset,fSize=10,value= 1
		
	// for PToF data
	SetVariable PT_setvar_SpectraAStart,pos={19.00,120.00},size={77.00,15.00},bodyWidth=55,title="start"
	SetVariable PT_setvar_SpectraAStart,fSize=10,value= _NUM:NaN
	SetVariable PT_setvar_SpectraAStop,pos={19.00,141.00},size={78.00,15.00},bodyWidth=55,title="stop"
	SetVariable PT_setvar_SpectraAStop,fSize=10,value= _NUM:NaN
	SetVariable PT_setvar_SpectraBStart,pos={137.00,120.00},size={77.00,15.00},bodyWidth=55,title="start"
	SetVariable PT_setvar_SpectraBStart,fSize=10,value= root:panel:cor3_dcMarker3
	SetVariable PT_setvar_SpectraBStop,pos={136.00,140.00},size={78.00,15.00},bodyWidth=55,title="stop"
	SetVariable PT_setvar_SpectraBStop,fSize=10,value= root:panel:cor3_dcMarker4
	CheckBox PT_check_binNum,pos={16.00,82.00},size={63.00,14.00},title="bin # units"
	CheckBox PT_check_binNum,fSize=10,variable= root:panel:ptof_dcUseBinNumUnits
	Button PT_buttonDva,pos={201.00,78.00},size={50.00,20.00},proc=sq_butt_DVaGraph,title="dVa gr"
	Button PT_buttonDva,fSize=10
//	TitleBox title_ePToF,pos={93.00,72.00},size={128.00,24.00},title="Not available for ePToF runs;\rdata should be deconvolved."
//	TitleBox title_ePToF,fSize=10,frame=0
	Button PT_buttonSetToDCregion2,pos={101.00,160.00},size={150.00,18.00},proc=bk_butt_SetToDCRegion2,title="Set Spectra B to DC region 2"
	Button PT_buttonSetToDCregion2,fSize=10
	TitleBox PT_TitleMSA,pos={19.00,103.00},size={93.00,12.00},title="Spectra A ~MS Open"
	TitleBox PT_TitleMSA,fSize=10,frame=0
	TitleBox PT_TitleMSB,pos={134.00,103.00},size={107.00,12.00},title="Spectrum B ~MS Closed"
	TitleBox PT_TitleMSB,fSize=10,frame=0
	TitleBox PToF_TitleSpecC,pos={20.00,181.00},size={218.00,12.00},title="Spectrum C = Spectrum A - Spectrum B ~MS Diff"
	TitleBox PToF_TitleSpecC,fSize=10,frame=0
	Button PT_buttonDCMarker,pos={117.00,79.00},size={80.00,20.00},proc=sq_butt_PToFDCGr_show,title="DC Marker gr"
	Button PT_buttonDCMarker,fSize=10

// stick integration region
	TitleBox bk1Res_titleMax,pos={432.00,124.00},size={138.00,12.00},fSize=10
	TitleBox bk1Res_titleMax,frame=0
	TitleBox bk1Res_titleMax,variable= root:baselineFitting:bk_ResolutionStrInfo2
	SetVariable bk1Res_MaxStickRegionAmu,pos={432.00,106.00},size={153.00,15.00},title="Max stick region, m/z"
	SetVariable bk1Res_MaxStickRegionAmu,help={"Enter the maximum region of peak integration."}
	SetVariable bk1Res_MaxStickRegionAmu,fSize=10,format="%1.2f"
	SetVariable bk1Res_MaxStickRegionAmu,limits={0.1,0.99,0.01},value= root:baselineFitting:bk_StickRegionMaxAmu
	Button bk1Res_butt_SetDefaultResol1,pos={422.00,26.00},size={100.00,20.00},proc=bk_butt_SetResolutionToDefault,title="Set to default values"
	Button bk1Res_butt_SetDefaultResol1,fSize=10
	SetVariable bk1Res_setvar_Resolution_dm,pos={572.00,87.00},size={60.00,15.00},proc=bk_setVar_ResolutionParam,title="dm"
	SetVariable bk1Res_setvar_Resolution_dm,fSize=10,format="%1.1f"
	SetVariable bk1Res_setvar_Resolution_dm,limits={0,200,1},value= root:diagnostics:resolution_dm
	SetVariable bk1Res_setvar_Resolution_m0,pos={569.00,69.00},size={63.00,15.00},bodyWidth=45,proc=bk_setVar_ResolutionParam,title="m0"
	SetVariable bk1Res_setvar_Resolution_m0,fSize=10,format="%1.1f"
	SetVariable bk1Res_setvar_Resolution_m0,limits={0,20000,1},value= root:diagnostics:resolution_m0
	TitleBox bk1Res_title,pos={426.00,51.00},size={136.00,24.00},fSize=10,frame=0
	TitleBox bk1Res_title,variable= root:baselineFitting:bk_ResolutionStrInfo
	SetVariable bk1Res_setvar_Resolution_R0,pos={572.00,51.00},size={60.00,15.00},bodyWidth=45,proc=bk_setVar_ResolutionParam,title="R0"
	SetVariable bk1Res_setvar_Resolution_R0,fSize=10,format="%1.1f"
	SetVariable bk1Res_setvar_Resolution_R0,limits={0,20000,1},value= root:diagnostics:resolution_R0
	TitleBox bk1Res_title_MassWhereDeltaGT4,pos={579.00,125.00},size={22.00,12.00}
	TitleBox bk1Res_title_MassWhereDeltaGT4,fSize=10,frame=0
	TitleBox bk1Res_title_MassWhereDeltaGT4,variable= root:baselineFitting:bk_MassWhenDeltaGT4
	GroupBox bk1Adv_groupPanelOpts,pos={425.00,144.00},size={203.00,54.00},title="Options"
	GroupBox bk1Adv_groupPanelOpts,fSize=10,fColor=(1,1,1)
	CheckBox bk1Adv_ck_UseMassDefect,pos={427.00,160.00},size={186.00,14.00},proc=bk_ck_UseMassDefect,title="Use a mass defect wave as peak center"
	CheckBox bk1Adv_ck_UseMassDefect,fSize=10
	CheckBox bk1Adv_ck_UseMassDefect,variable= root:baselineFitting:bk_UseMassDefect
	CheckBox bk1Adv_ck_RemoveExtraMzRegions,pos={427.00,180.00},size={190.00,14.00},proc=bk_ck_RemoveMoreStickCompMz,title="Alter stick and stick compliment regions"
	CheckBox bk1Adv_ck_RemoveExtraMzRegions,fSize=10
	CheckBox bk1Adv_ck_RemoveExtraMzRegions,variable= root:baselineFitting:bk_ck_AdditionalStickComp

	// baseline fitting options
	CheckBox check_Tofwerk,pos={679.00,21.00},size={49.00,14.00},proc=bk_ck_UseLinearOrSpline,title="Tofwerk"
	CheckBox check_Tofwerk,fSize=10
	CheckBox check_Tofwerk,variable= root:baselineFitting:bk_UseTofwerk,mode=1
	CheckBox check_Linear,pos={742.00,22.00},size={42.00,14.00},proc=bk_ck_UseLinearOrSpline,title="Linear"
	CheckBox check_Linear,fSize=10
	CheckBox check_Linear,variable= root:baselineFitting:bk_UseLinear,mode=1
	CheckBox check_CubicSpline,pos={801.00,21.00},size={91.00,14.00},proc=bk_ck_UseLinearOrSpline,title="Smoothed Spline"
	CheckBox check_CubicSpline,fSize=10
	CheckBox check_CubicSpline,variable= root:baselineFitting:bk_UseCubicSpline,mode=1

	Button button_FitBkThisRun,pos={646.00,179.00},size={250.00,20.00},proc=bk_butt_CalcBkFit,title="Recalculate the baseline for this spectra"
	Button button_FitBkThisRun,fColor=(65280,49152,16384)

	// linear
	SetVariable bkFItln_setvar_smoothBackground,pos={647.00,44.00},size={235.00,15.00},bodyWidth=40,title="Number of pts to smooth stick compliment"
	SetVariable bkFItln_setvar_smoothBackground,fSize=10
	SetVariable bkFItln_setvar_smoothBackground,value= root:baselineFitting:bk_smoothBackground
	TitleBox bkFitln_sp_Title,pos={774.00,99.00},size={115.00,12.00},title="Override BL with constant:"
	TitleBox bkFitln_sp_Title,fSize=10,frame=0
	SetVariable bkFitln_sp_BkIsZeroBeyondMass,pos={804.00,114.00},size={89.00,15.00},bodyWidth=45,title="At m/z >"
	SetVariable bkFitln_sp_BkIsZeroBeyondMass,fSize=10
	SetVariable bkFitln_sp_BkIsZeroBeyondMass,value= root:baselineFitting:bk_BKIsZeroBeyondThisMass
	SetVariable bkFitln_sp_BkIsX_open,pos={787.00,131.00},size={106.00,15.00},bodyWidth=50,title="Open BL = "
	SetVariable bkFitln_sp_BkIsX_open,fSize=10,format="%1.4f"
	SetVariable bkFitln_sp_BkIsX_open,value= root:baselineFitting:bk_BKIsX_Open
	SetVariable bkFitln_sp_BkIsX_closed,pos={773.00,148.00},size={120.00,15.00},bodyWidth=60,title="Closed BL = "
	SetVariable bkFitln_sp_BkIsX_closed,fSize=10,format="%1.4f"
	SetVariable bkFitln_sp_BkIsX_closed,value= root:baselineFitting:bk_BKIsX_Closed
//	TitleBox bkFitln_sp_FitOption,pos={652.00,147.00},size={222.00,24.00},fSize=10
//	TitleBox bkFitln_sp_FitOption,frame=0
//	TitleBox bkFitln_sp_FitOption,variable= root:baselineFitting:bk_FitOptionsStr
	GroupBox bkFitln_rare,pos={770.00,81.00},size={129.00,94.00},title="Very rare option"
	GroupBox bkFitln_rare,fSize=10

// tofwerk
	Button bkFIttw_butt_SetDefault,pos={652.00,49.00},size={110.00,20.00},proc=bk_butt_setTWToDefault,title="Set to default values"
	Button bkFIttw_butt_SetDefault,fSize=10
	SetVariable bkFIttw_width,pos={653.00,74.00},size={65.00,15.00},bodyWidth=35,title="Width"
	SetVariable bkFIttw_width,fSize=10,value= root:baselineFitting:bk_twWidth
	SetVariable bkFIttw_NoiseScaling,pos={653.00,96.00},size={96.00,15.00},bodyWidth=35,title="Noise scaling"
	SetVariable bkFIttw_NoiseScaling,fSize=10,format="%0.1f"
	SetVariable bkFIttw_NoiseScaling,limits={0,inf,0.1},value= root:baselineFitting:bk_twNoiseScaling
	CheckBox bkFIttw_LowPass,pos={653.00,119.00},size={77.00,14.00},title="Low pass filter"
	CheckBox bkFIttw_LowPass,fSize=10,variable= root:baselineFitting:bk_twckLoPass
	SetVariable bkFIttw_f2,pos={653.00,142.00},size={52.00,15.00},bodyWidth=40,title="f2"
	SetVariable bkFIttw_f2,fSize=10,format="%0.2f"
	SetVariable bkFIttw_f2,limits={0,inf,0.01},value= root:baselineFitting:bk_twf2
	SetVariable bkFIttw_N,pos={715.00,141.00},size={46.00,15.00},bodyWidth=35,title="N"
	SetVariable bkFIttw_N,fSize=10,value= root:baselineFitting:bk_twN

// smoothed spline
	Button bkFitsp_FindStdDevNoiseThisRun,pos={652.00,82.00},size={120.00,15.00},proc=bk_butt_FindStdDev,title="Estimate std dev noise"
	Button bkFitsp_FindStdDevNoiseThisRun,fSize=10
	SetVariable bkFitsp_StdDev_VOpen,pos={654.00,100.00},size={119.00,15.00},bodyWidth=70,title="C/V Open"
	SetVariable bkFitsp_StdDev_VOpen,fSize=10,format="%1.2e",fStyle=1
	SetVariable bkFitsp_StdDev_VOpen,limits={-inf,inf,1e-005},value= root:baselineFitting:bk_StdDevNoise_VOpen	//,noedit= 1
	SetVariable bkFitsp_StdDev_VClosed,pos={649.00,120.00},size={124.00,15.00},bodyWidth=70,title="C/V Closed"
	SetVariable bkFitsp_StdDev_VClosed,fSize=10,format="%1.2e",fStyle=1
	SetVariable bkFitsp_StdDev_VClosed,limits={-inf,inf,1e-005},value= root:baselineFitting:bk_StdDevNoise_VClosed	//,noedit= 1
	SetVariable bkFitsp_StdDev_WOpen,pos={662.00,140.00},size={111.00,15.00},bodyWidth=70,title="W Open"
	SetVariable bkFitsp_StdDev_WOpen,fSize=10,format="%1.2e",fStyle=0
	SetVariable bkFitsp_StdDev_WOpen,limits={-inf,inf,1e-005},value= root:baselineFitting:bk_StdDevNoise_WOpen	//,noedit= 1
	SetVariable bkFitsp_StdDev_WClosed,pos={658.00,160.00},size={115.00,15.00},bodyWidth=70,title="W Closed"
	SetVariable bkFitsp_StdDev_WClosed,fSize=10,format="%1.2e",fStyle=0
	SetVariable bkFitsp_StdDev_WClosed,limits={-inf,inf,1e-005},value= root:baselineFitting:bk_StdDevNoise_WClosed,noedit= 1
	TitleBox bkFitsp_Note,pos={652.00,47.00},size={213.00,30.00},title="This method is no longer recommended\rUse with caution!"
	TitleBox bkFitsp_Note,frame=0

//	right side controls 
	GroupBox gr_groupAxes,pos={753.00,228.00},size={147.00,113.00},title="Open and Closed Plots"
	GroupBox gr_groupAxes,fSize=10,fColor=(1,1,1)
	CheckBox gr_check_leftLog,pos={765.00,242.00},size={33.00,14.00},proc=bk_ck_LeftAxisLog,title="Log"
	CheckBox gr_check_leftLog,fSize=10
	CheckBox gr_check_leftLog,variable= root:baselineFitting:bk_MassLogAxis_ck
	CheckBox gr_lockRange,pos={753.00,206.00},size={92.00,14.00},title="Lock y axis range"
	CheckBox gr_lockRange,fSize=10,variable= root:baselineFitting:bk_ck_LockRange
	Button gr_button_Expand25,pos={758.00,293.00},size={100.00,20.00},proc=bk_butt_YaxisExpand,title="Y axis expand 25%"
	Button gr_button_Expand25,fSize=10
	Button gr_button_Shrink25,pos={758.00,315.00},size={100.00,20.00},proc=bk_butt_YaxisShrink,title="Y axis shrink 25%"
	Button gr_button_Shrink25,fSize=10
	SetVariable gr_setvar_bk_YAxisMinY,pos={765.00,273.00},size={118.00,15.00},bodyWidth=70,proc=bk_setVar_MinMaxYVal,title="Min y axis"
	SetVariable gr_setvar_bk_YAxisMinY,fSize=10,format="%1.2e"
	SetVariable gr_setvar_bk_YAxisMinY,limits={-1,1000,0.001},value= root:baselineFitting:bk_YAxisMinY
	SetVariable gr_setvar_bk_YAxisMaxY,pos={765.00,255.00},size={120.00,15.00},bodyWidth=70,proc=bk_setVar_MinMaxYVal,title="Max y axis"
	SetVariable gr_setvar_bk_YAxisMaxY,fSize=10,format="%1.2e"
	SetVariable gr_setvar_bk_YAxisMaxY,limits={-1,1000,0.001},value= root:baselineFitting:bk_YAxisMaxY
	SetVariable gr_setvar_bk_DiffDelta,pos={760.00,358.00},size={135.00,15.00},proc=bk_setVar_DiffYAxis,title="Diff y axis max "
	SetVariable gr_setvar_bk_DiffDelta,fSize=10,format="%1.3e"
	SetVariable gr_setvar_bk_DiffDelta,limits={1e-010,inf,1e-005},value= root:baselineFitting:bk_DiffDelta
	GroupBox gr_groupAxesDiff,pos={752.00,343.00},size={148.00,39.00},title="Diff Plot"
	GroupBox gr_groupAxesDiff,fSize=10,fColor=(1,1,1)
//	CheckBox gr_ShowRawDiffStickComp,pos={758.00,372.00},size={126.00,14.00},proc=bk_ck_showDiffComp,title="Show diff compliment, fit"
//	CheckBox gr_ShowRawDiffStickComp,fSize=10
//	CheckBox gr_ShowRawDiffStickComp,variable= root:baselineFitting:bk_DisplayOneRunDiffBk
	CheckBox gr_ShowDiffIntegrRegion,pos={753.00,387.00},size={150.00,14.00},proc=bk_ck_showDiffIntegRegion,title="Show UMR integration regions"
	CheckBox gr_ShowDiffIntegrRegion,fSize=10
	CheckBox gr_ShowDiffIntegrRegion,variable= root:baselineFitting:bk_ck_ShowStickIntegRegion
//	CheckBox gr_ShowDiffNegRegion,pos={758.00,391.00},size={105.00,14.00},proc=bk_ck_showDiffNeg,title="Show diff < 0 points"
//	CheckBox gr_ShowDiffNegRegion,fSize=10
//	CheckBox gr_ShowDiffNegRegion,variable= root:baselineFitting:bk_ck_DiffNeg
	TitleBox gr_title_legend,pos={754.00,406.00},size={128.00,132.00},fSize=10
	TitleBox gr_title_legend,frame=0,variable= root:baselineFitting:bk_legendStr
	Button gr_autoaxis,pos={861.00,294.00},size={35.00,35.00},proc=bk_autoAxis,title="Auto\ry axis"
	Button gr_autoaxis,fSize=8

// bottom controls
	SetVariable setvar_MzStart,pos={268.00,575.00},size={112.00,18.00},bodyWidth=60,proc=bk_setVar_mzStartStop,title="Start m/z"
	SetVariable setvar_MzStart,help={"Enter the starting m/z value."},fSize=12
	SetVariable setvar_MzStart,format="%0.1f"
	SetVariable setvar_MzStart,limits={0.5,5000,1},value= root:baselineFitting:bk_MassAxisStart
	SetVariable setvar_MzStop,pos={395.00,575.00},size={112.00,18.00},bodyWidth=60,proc=bk_setVar_mzStartStop,title="Stop m/z"
	SetVariable setvar_MzStop,help={"Enter the stopping m/z value."},fSize=12
	SetVariable setvar_MzStop,format="%0.1f"
	SetVariable setvar_MzStop,limits={0.5,5000,1},value= root:baselineFitting:bk_MassAxisStop
	Button buttonGoLeft,pos={229.00,573.00},size={25.00,20.00},proc=bk_butt_Xaxis,title="<"
	Button buttonGoRight,pos={525.00,574.00},size={25.00,20.00},proc=bk_butt_Xaxis,title=">"

	Button button_bk_RawSpectraGraph,pos={697.00,575.00},size={50.00,18.00},proc=sq_butt_popThis,title="pop"
	Button button_bk_RawSpectraGraph,fSize=10
	Button gr_autoXaxis,pos={20.00,575.00},size={100.00,18.00},proc=bk_autoAxis,title="Autoscale x axis"
	Button gr_autoXaxis,fSize=10
	Button button_bkEnd,pos={848.00,575.00},size={50.00,20.00},proc=sq_butt_End,title="End"
	Button button_bkEnd,fSize=10,fStyle=1

	Display/W=(5,205,745,570)/HOST=#
	RenameWindow #,RawSpectraGraph		// bug fix 103B
	bk_populate_RawSpectraGraph()
	SetActiveSubwindow ##

	nvar bk_UseLinear = root:baselineFitting:bk_UseLinear
	nvar bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline
	nvar bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk
	variable type = bk_UseLinear
	if(!bk_UseLinear)
		if(!bk_UseCubicSpline)
			type=3
		else
			type=2
		endif
	endif
	bk_ck_useLinearOrSpline(StringFromList(type-1,"check_Linear;check_CubicSpline;check_Tofwerk"),1)
	
	bk_ck_PToFMS("check_MS",1)		// 1.60Y

	bk_ck_leftAxisLog("",0)	// 1.45
	//bk_tab_grIterate("sq_baseline_panel", 0)		//1.14M

	HideTools/A
End


// The tab control for the fit section of the background panel.
Function bk_tabFit(ctrlName,tabNum) : TabControl
	String ctrlName
	Variable tabNum
	
	nvar/z bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk
	nvar bk_UseLinear = root:baselineFitting:bk_UseLinear
	nvar bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline
	if (!NVar_exists(bk_UseTofwerk))
		bk_TofwerkBLGlobals()
		abort "Please recreate the baseline panel."
	endif

	variable cont_disp,idex,num
	string cont_list, cont_item

	cont_list=controlnamelist("", ";", "bk2*")
	num=itemsinlist(cont_list)
	for (idex=0;idex<num;idex+=1)
		cont_item=stringfromlist(idex,cont_list)
		strswitch(cont_item[3,5])
			case "Spl":
				cont_disp=(!(tabNum==0)) || !bk_UseCubicSpline
				break
			case "Twk":
				cont_disp=(!(tabNum==0)) || !bk_UseTofwerk
				break
			case "Opt":
				cont_disp=!(tabNum==1)
				break
		endswitch
		controlinfo $cont_item
		switch (abs(v_flag))
			case 1:
				button $cont_item disable=cont_disp
				break
			case 2:
				checkbox  $cont_item disable=cont_disp
				break
			case 3:
				popupmenu $cont_item disable=cont_disp
				break
			case 4:
				valdisplay $cont_item disable=cont_disp
				break
			case 5:
				setvariable $cont_item disable=cont_disp
				break
			case 6:
				chart $cont_item disable=cont_disp
				break
			case 7:
				slider $cont_item disable=cont_disp
				break
			case 8:
				tabcontrol $cont_item disable=cont_disp
				break
			case 9:
				groupbox $cont_item disable=cont_disp
				break
			case 10:
				titlebox $cont_item disable=cont_disp
				break
			case 11:
				listbox $cont_item disable=cont_disp
				break
		endswitch	
	
	endfor

End


Function  bk_butt_setResolutionToDefault(ctrlName) : ButtonControl	
	string ctrlName

	nvar resolution_R0 = root:diagnostics:resolution_R0		// modified in 1.49E
	nvar resolution_dm = root:diagnostics:resolution_dm
	nvar resolution_m0 = root:diagnostics:resolution_m0
	
	nvar AMSType = root:AMSType
	
	resolution_R0 = 350			
	resolution_dm = 50 		
	resolution_m0 = 75		

End


//1.60Z
Function bk_getTWBLWidth()
	//	bk_UseTofwerk=0
	nvar isC = root:diagnostics:isC
	nvar isV = root:diagnostics:isV
	nvar isW = root:diagnostics:isW
	nvar/z isL = root:diagnostics:isL
	
//	ETOF: 40
//	CTOF: 25
//	HTOF: 15
//	LTOF: 8
	if (isC)
		return 25
	elseif(isV || isW)	
		return 15
	elseif(isL)	
		return 8
	endif	

end

//1.60Y
Function  bk_butt_setTWToDefault(ctrlName) : ButtonControl	
	string ctrlName
	
	nvar bk_twWidth = root:baselineFitting:bk_twWidth
	nvar bk_twNoiseScaling = root:baselineFitting:bk_twNoiseScaling
	nvar bk_twckLoPass = root:baselineFitting:bk_twckLoPass
	nvar bk_twf2 = root:baselineFitting:bk_twf2
	nvar bk_twN = root:baselineFitting:bk_twN	

	bk_twWidth=bk_getTWBLWidth()

	bk_twNoiseScaling=1
	bk_twckLoPass=1
	bk_twf2=0.05
	bk_twN=20

End


Function bk_setVar_resolutionParam(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	svar bk_MassWhenDeltaGT4 = root:baselineFitting:bk_MassWhenDeltaGT4

	nvar resolution_R0 = root:diagnostics:resolution_R0
	nvar resolution_dm = root:diagnostics:resolution_dm
	nvar resolution_m0 = root:diagnostics:resolution_m0

	variable pt
	wave OneRunRawSpectraMz = root:baselineFitting:OneRunRawSpectraMz
	if (WaveExists(OneRunRawSpectraMz) && numpnts(OneRunRawSpectraMz)>0 )		//1.59A
		duplicate/o OneRunRawSpectraMz res_temp
		wave res_temp
		res_temp=resolution_R0-(resolution_R0/(1+exp((OneRunRawSpectraMz[p]-resolution_m0)/resolution_dm)))
		res_temp = OneRunRawSpectraMz/(2*res_temp)
		pt = BinarySearchInterp(res_temp, .4 )
		if (pt>0)
			sprintf bk_MassWhenDeltaGT4, "%1.1f",OneRunRawSpectraMz[pt]
		else
			bk_MassWhenDeltaGT4 = ">MaxMz"
		endif
		killwaves/z res_temp
	endif	
	
End



Function bk_butt_viewManyBaselines(ctrlName) : ButtonControl
	String ctrlName
	
	svar todoStr=root:panel:sq_toDoWvNm
	wave/z todo=$"root:"+todoStr		//1.44B
	
	ControlInfo/w=SQ_baseline_panel it_popup_ToDoWave		// 1.42E fix
	if (!stringmatch(S_Value, todoStr))
		abort "Please re-select the todo wave.  Aborting from bk_butt_viewManyBaselines"
	endif
	
	ControlInfo/w=SQ_baseline_panel it_check_UseRandomSubset
	if ( !(V_flag!=0 && V_Value==1)	)	// control exists
		if (numpnts(todo)>100)
			DoAlert 1, "You are about to step through every run in this todo wave (which may take some time).  Continue?"
			if (V_flag==2)
				return 0
			endif
		endif
	else
		ControlInfo/w=SQ_baseline_panel it_check_UseRandomSubset
		nvar bk_numRandomSubset = root:baselineFitting:bk_numRandomSubset
		sq_CreateRandom(bk_numRandomSubset, todo, "randomTodoTemp")
		wave/z todo=root:randomTodoTemp		//1.44B
	endif
	
	nvar bk_currentRunNum = root:baselineFitting:bk_currentRunNum
	nvar bk_viewManySleepSec = root:baselineFitting:bk_viewManySleepSec
		
	variable idex, num, currentRunIndex
	num = numpnts(todo)
	
	for(idex=0;idex<num;idex+=1)
		bk_currentRunNum = todo[idex]
		bk_setVar_runNumberVW("",nan,"","")
		bk_butt_rawSpectraThisRun("")
		bk_butt_calcBkFit("")		
//		print "// Viewed baseline for run "num2str(bk_currentRunNum)
		DoUpdate
		if (idex<num-1)		// don't sleep for last one
			sleep/s bk_viewManySleepSec
		endif
	endfor

	killwaves/z root:randomTodoTemp
End


Function bk_slider_mzAxis(ctrlName,sliderValue,event) : SliderControl
String ctrlName
Variable sliderValue
Variable event	// bit field: bit 0: value set, 1: mouse down, 2: mouse up, 3: mouse moved
	Abort "Please kill and recreate the baseline panel."
End
//	nvar bk_MassAxisStart= root:baselineFitting:bk_MassAxisStart
//	nvar bk_MassAxisDelta= root:baselineFitting:bk_MassAxisDelta
//	
//	SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStart+bk_MassAxisDelta
//	
//End


// new in 1.44B
Function bk_ck_SliderOrSetVar(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked
	Abort "Please kill and recreate the baseline panel."
End
//
//	nvar bk_MassAxisStart= root:baselineFitting:bk_MassAxisStart
//	nvar bk_MassAxisDelta= root:baselineFitting:bk_MassAxisDelta
//	nvar bk_MassAxisStop= root:baselineFitting:bk_MassAxisStop
//
//	nvar bk_SliderSetVar = root:baselineFitting:bk_SliderSetVar
//	if (strsearch(ctrlName, "slider", 0, 2)>=0 )
//		bk_SliderSetVar = 1
//		SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStart+bk_MassAxisDelta
//	else
//		bk_SliderSetVar = 0
//		SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStop
//	endif
//
///	Checkbox bk_RadioXaxisSlider value =bk_SliderSetVar, win=SQ_Baseline_Panel
//	Slider slider_MzAxis disable = !bk_SliderSetVar*2, win=SQ_Baseline_Panel
	
//	Checkbox bk_RadioXaxisSetVariable value =!bk_SliderSetVar, win=SQ_Baseline_Panel
//	SetVariable setvar_MzStop disable = bk_SliderSetVar*2, win=SQ_Baseline_Panel

Function bk_setVar_LeftRight(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	nvar bk_MassAxisStart= root:baselineFitting:bk_MassAxisStart
	nvar bk_MassAxisStop= root:baselineFitting:bk_MassAxisStop

	variable left = stringmatch(ctrlName, "buttonGoLeft")
	variable delta = min (1, abs(bk_MassAxisStop - bk_MassAxisStart))
	if (left)
		SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart-delta, bk_MassAxisStop-delta
	else
		SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart+delta, bk_MassAxisStop+delta
	endif
End


Function bk_ck_maxBk(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	wave OneRunRawSpectraOpenBk =  root:baselineFitting:OneRunRawSpectraOpenBk
	wave OneRunRawSpectraClosedBk =  root:baselineFitting:OneRunRawSpectraClosedBk
	wave OneRunRawSpectraDiff=  root:baselineFitting:OneRunRawSpectraDiff

	SetActiveSubwindow SQ_Baseline_Panel#RawSpectraGraph

	nvar ExamineMinYVal  =  root:baselineFitting:ExamineMinYVal

	wavestats/q/m=1 OneRunRawSpectraOpenBk
	SetAxis LOpen, ExamineMinYVal, V_max
	wavestats/q/m=1 OneRunRawSpectraClosedBk
	SetAxis LClosed,  ExamineMinYVal,  V_max
	wavestats/q/m=1 OneRunRawSpectraDiff
	SetAxis LDiff,  ExamineMinYVal,  V_max

End


Function bk_ck_leftAxisLog(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked
	
	SetActiveSubwindow SQ_Baseline_Panel#RawSpectraGraph
	ModifyGraph log(LOpen)=checked
	ModifyGraph log(LClosed)=checked
	//1.60V modifications
	GetAxis/Q/W=SQ_Baseline_Panel#RawSpectraGraph LOpen
	variable Amin = V_min, Amax = V_max
	GetAxis/Q/W=SQ_Baseline_Panel#RawSpectraGraph LClosed
	Amin = min(V_min, AMin)	
	Amax = min(V_max, AMax)
	nvar bk_YAxisMinY= root:baselineFitting:bk_YAxisMinY
	nvar bk_YAxisMaxY= root:baselineFitting:bk_YAxisMaxY
	if (checked && Amin<=0)
		SetAxis /W=SQ_Baseline_Panel#RawSpectraGraph LClosed, Amax*(10e-8), Amax
		SetAxis /W=SQ_Baseline_Panel#RawSpectraGraph LOpen, Amax*(10e-8), Amax
		bk_YAxisMinY = Amax*(10e-8)
		bk_YAxisMaxY = Amax
	endif	
End


Function bk_butt_yAxisShrink(ctrlName) : ButtonControl
	String ctrlName

	nvar bk_YAxisMinY= root:baselineFitting:bk_YAxisMinY
	nvar bk_YAxisMaxY= root:baselineFitting:bk_YAxisMaxY

	if(bk_YAxisMinY>0)
		bk_YAxisMinY*=0.8
	else
		bk_YAxisMinY*=1.2
	endif
	
	if(bk_YAxisMaxY>0)
		bk_YAxisMaxY*=1.2
	else
		bk_YAxisMaxY*=0.8
	endif
	
	bk_setVar_MinMaxYVal("",nan,"","")

End


Function bk_butt_yAxisExpand(ctrlName) : ButtonControl
	String ctrlName

	nvar bk_YAxisMinY= root:baselineFitting:bk_YAxisMinY
	nvar bk_YAxisMaxY= root:baselineFitting:bk_YAxisMaxY

	if(bk_YAxisMinY>0)
		bk_YAxisMinY*=1.2
	else
		bk_YAxisMinY*=0.8
	endif
	
	if(bk_YAxisMaxY>0)
		bk_YAxisMaxY*=0.8
	else
		bk_YAxisMaxY*=1.2
	endif
	
	bk_setVar_MinMaxYVal("",nan,"","")

End




// new in 1.46D
Function bk_butt_Xaxis(ctrlName) : ButtonControl
	String ctrlName
	
	nvar bk_massAxisStart = root:baselineFitting:bk_massAxisStart
	nvar bk_massAxisStop = root:baselineFitting:bk_massAxisStop

	variable delta = bk_massAxisStop - bk_massAxisStart

	if (stringmatch(ctrlName, "buttonGoRight") )
		bk_massAxisStart+=delta
		bk_massAxisStop+=delta
	else
		bk_massAxisStart-=delta
		bk_massAxisStop-=delta
	endif
	
	SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStop

End


//^ prepare a raw spectra for baseline fitting	
Function bk_setUpRawSpectraThisRun([avgFlag])
variable avgFlag

	wave OneRunRawSpectraOpen = root:baselineFitting:OneRunRawSpectraOpen	
	wave OneRunRawSpectraClosed = root:baselineFitting:OneRunRawSpectraClosed
	wave OneRunRawSpectraOpenBk = root:baselineFitting:OneRunRawSpectraOpenBk
	wave OneRunRawSpectraClosedBk = root:baselineFitting:OneRunRawSpectraClosedBk
	wave OneRunRawSpectraOpenBkFit = root:baselineFitting:OneRunRawSpectraOpenBkFit
	wave OneRunRawSpectraClosedBkFit = root:baselineFitting:OneRunRawSpectraClosedBkFit
	wave OneRunRawSpectraMz = root:baselineFitting:OneRunRawSpectraMz
	wave OneRunRawSpectraRes = root:baselineFitting:OneRunRawSpectraRes
	wave OneRunRawSpectraDiffLessBks =  root:baselineFitting:OneRunRawSpectraDiffLessBks
	wave OneRunRawSpectraDiff =  root:baselineFitting:OneRunRawSpectraDiff
	wave OneRunRawSpectraDiffBk =  root:baselineFitting:OneRunRawSpectraDiffBk
	wave OneRunRawSpectraDiffBkFit =  root:baselineFitting:OneRunRawSpectraDiffBkFit
	wave OneRunRawSpectraDiffBkLessFit =  root:baselineFitting:OneRunRawSpectraDiffBkLessFit

	// 1.40D accomodate TimO's request for adding values in the stick complement
	wave/z OneRunRawSpectraCompMask = root:baselineFitting:OneRunRawSpectraCompMask
	if (!WaveExists(OneRunRawSpectraCompMask) || numpnts(OneRunRawSpectraCompMask)!=numpnts(OneRunRawSpectraOpen)  )
		make/o/n=(numpnts(OneRunRawSpectraOpen)) root:baselineFitting:OneRunRawSpectraCompMask=1
	else
		fastop OneRunRawSpectraCompMask=1
	endif
	
	wave run_series = root:index:rn_series
	wave mStart = root:diagnostics:mStart
	wave mFinish = root:diagnostics:mFinish
	wave/z allMS
	
	nvar bk_currentRunNum =  root:baselineFitting:bk_currentRunNum
	nvar bk_UseMzFit_ck = root:baselineFitting:bk_UseMzFit_ck	
	nvar bk_DisplayOneRunDiffBk = root:baselineFitting:bk_DisplayOneRunDiffBk

//	nvar bk_smoothBackground = root:baselineFitting:bk_smoothBackground
//	variable smoothBackground = bk_smoothBackground<=0? 1: bk_smoothBackground
 	
// 	nvar bk_UseRunningAvg = root:baselineFitting:bk_UseRunningAvg			//   1.60Y
//	nvar bk_RunningAvgDeltaRunNum =  root:baselineFitting:bk_RunningAvgDeltaRunNum 	
 	variable numptsRaw,  intercept, slope, power, currentRunIndex
 	
	nvar bk_ck_ShowStickIntegRegion = root:baselineFitting:bk_ck_ShowStickIntegRegion
	nvar VWSwitching = root:diagnostics:VWSwitching
	
 	nvar/z bk_ck_PToF = root:baselineFitting:bk_ck_PToF
 	
 	string str1, str2
 	
	// current run number valid?
	currentRunIndex =sq_FindRun(run_series, bk_currentRunNum)	
	if (currentRunIndex<0)
		Abort "Could not extract raw spectra because the run number wasn't in the index.  - Aborting from bk_setUpRawSpectraThisRun"
	endif

	// get spectra.  Choices are either MS/PToF SingleRun/Average Runs
//	if (!NVar_Exists(bk_ck_PToF) || !bk_ck_PToF)		//1.51P addition  if global variable doesn't exist or if it does exist but we want MS
	switch (bk_ck_PToF)	
		case 1:  // MS
		// first check if current run has MS data
	//		wave/z allMS = root:allMS
			if ( waveexists(allMS)  && sq_FindRun(allMS, bk_currentRunNum)<0  )  
	//		if (  ! (!waveexists(allMS) || sq_FindRun(allMS, bk_currentRunNum)<0)  )  		// 1.52A
				sprintf str1, "%d" , bk_currentRunNum		// small bug, things can go wrong with run numbers > 1e6
				abort "The run "+str1 + " does not have MS data.  Aborting from bk_setUpRawSpectraThisRun"
			endif
//		  	if (bk_UseRunningAvg==1)		// MS AVERAGE
//	  1.60Y
//				sprintf str1, "%d" , bk_currentRunNum- bk_RunningAvgDeltaRunNum		// small bug, things can go wrong with run numbers > 1e6
//				sprintf str2, "%d" , bk_currentRunNum+bk_RunningAvgDeltaRunNum		// small bug, things can go wrong with run numbers > 1e6
//				if (VWSwitching)		// we have v/w data
//					wave toftypeVKey = root:diagnostics:toftypeVKey
//					sq_create_todo(str1+"-"+str2+" and all"+selectstring(toftypeVKey[currentRunIndex]==1, "W", "V"),"myTempTodo")
//		  		else
//					sq_create_todo(str1+"-"+str2+" and all","myTempTodo")
//		  		endif
//		  		wave myTempTodo = root:myTempTodo		// assumes current run (and perhaps more) has data of type requested
//		  		sq_RoughAvgRawSpecNonp(myTempTodo, "baselineFitting", 0)
//				wave AvgOpen = root:baselineFitting:AvgOpen
//				wave AvgClosed = root:baselineFitting:AvgClosed
//				wave AvgDiff = root:baselineFitting:AvgDiff
//		  		OneRunRawSpectraClosed= AvgClosed
//		  		OneRunRawSpectraOpen =  AvgOpen
//		 		OneRunRawSpectraDiff =  AvgDiff
//		    		Killwaves/z AvgOpen, AvgClosed, AvgDiff, myTempTodo
//		    	else // MS AVERAGE OF TODO
				if (ParamIsDefault(avgFlag) || avgFlag==0)
					sq_GetThisRawMS(bk_currentRunNum, "baselineFitting", "OneRunRawSpectraClosed", "MSClosed")
					sq_GetThisRawMS(bk_currentRunNum, "baselineFitting", "OneRunRawSpectraOpen", "MSOpen")
				else
					svar sq_toDoWvNm=root:panel:sq_toDoWvNm
			  		wave/z todo = $"root:"+ sq_toDoWvNm
			  		if (numpnts(todo)>100)
			  			doAlert 1, "The averaging of this many raw spectra may be time consuming.  Continue?"
			  			if (V_flag==2)
			  				return 0
			  			endif
			  		endif
			  		sq_RoughAvgRawSpecNonp(todo, "baselineFitting", 0)
					wave AvgOpen = root:baselineFitting:AvgOpen
					wave AvgClosed = root:baselineFitting:AvgClosed
					wave AvgDiff = root:baselineFitting:AvgDiff
			  		redimension/n=(numpnts(AvgOpen)) OneRunRawSpectraClosed, OneRunRawSpectraOpen, OneRunRawSpectraDiff
			  		OneRunRawSpectraClosed= AvgClosed
			  		OneRunRawSpectraOpen =  AvgOpen
			 		OneRunRawSpectraDiff =  AvgDiff
		    		Killwaves/z AvgOpen, AvgClosed, AvgDiff, myTempTodo
				endif
//			endif
		break
		case 2:  // PToF
			// first check if current run has PToF data
			bk_getPToFForBaselinePanel( avgFlag)
	//	  	if (bk_UseRunningAvg==1)		// PToF  AVERAGE
	//			wave OneRunRawSpectraClosed = root:baselineFitting:OneRunRawSpectraClosed
	//			wave OneRunRawSpectraOpen = root:baselineFitting:OneRunRawSpectraOpen
	//			wave OneRunRawSpectraMz = root:baselineFitting:OneRunRawSpectraMz
	//			sprintf str1, "%d" , bk_currentRunNum- bk_RunningAvgDeltaRunNum		// small bug, things can go wrong with run numbers > 1e6
	//			sprintf str2, "%d" , bk_currentRunNum+bk_RunningAvgDeltaRunNum		// small bug, things can go wrong with run numbers > 1e6
	//			if (VWSwitching)		// we have v/w data
	//				wave toftypeVKey = root:diagnostics:toftypeVKey
	//				sq_create_todo(str1+"-"+str2+" and all"+selectstring(toftypeVKey[currentRunIndex]==1, "W", "V"),"myTempTodo")
	//	  		else
	//				sq_create_todo(str1+"-"+str2+" and all","myTempTodo")
	//	  		endif
	//	  		wave myTempTodo = root:myTempTodo
	//	  		sq_RoughAvgRawSpecNonp(myTempTodo, "baselineFitting", 0)
	//			wave AvgOpen = root:baselineFitting:AvgOpen
	//			wave AvgClosed = root:baselineFitting:AvgClosed
	//			wave AvgDiff = root:baselineFitting:AvgDiff
	//	  		OneRunRawSpectraClosed= AvgClosed
	//	  		OneRunRawSpectraOpen =  AvgOpen
	//	 		OneRunRawSpectraDiff =  AvgDiff
	//	    		Killwaves/z AvgOpen, AvgClosed, AvgDiff, myTempTodo
	//	    	else // PToF AVERAGE OF TODO
	//			sq_GetThisRawMS(bk_currentRunNum, "baselineFitting", "OneRunRawSpectraClosed", "MSClosed")
	//			sq_GetThisRawMS(bk_currentRunNum, "baselineFitting", "OneRunRawSpectraOpen", "MSOpen")
	//		endif
		break
		case 3:		// ePToFSum
			bk_getSumPToFForBaselinePanel()
	endswitch
 	
 	numptsRaw= numpnts(OneRunRawSpectraClosed)			// could use OneRunRawSpectraOpen

//	redimension other waves from the recently acquired OneRunRawSpectraClosed
	wave/z OneRunRawSpectraNegDiff = root:baselineFitting:OneRunRawSpectraNegDiff
	wave/z OneRunRawSpectraInteg = root:baselineFitting:OneRunRawSpectraInteg
	if (!WaveExists(OneRunRawSpectraInteg) || !WaveExists(OneRunRawSpectraNegDiff) || numpnts(OneRunRawSpectraNegDiff) != numptsRaw  )
		make /o/n=(numptsRaw) root:baselineFitting:OneRunRawSpectraNegDiff=nan		// 1.43A		// a wave to inidcate when difference spectra <0
	endif
	 	
	if (numptsRaw!=numpnts(OneRunRawSpectraClosedBk) )		// assume that if one is wrong size, all are
 		redimension/n =(numptsRaw) OneRunRawSpectraOpenBk, OneRunRawSpectraClosedBk
 		redimension/n =(numptsRaw) OneRunRawSpectraOpenBkFit, OneRunRawSpectraClosedBkFit
  		redimension/n =(numptsRaw) OneRunRawSpectraDiff, OneRunRawSpectraDiffLessBks
		redimension/n =(numptsRaw) OneRunRawSpectraDiffBk, OneRunRawSpectraDiffBkFit, OneRunRawSpectraDiffBkLessFit
 		redimension/n =(numptsRaw) OneRunRawSpectraMz, OneRunRawSpectraRes
 		redimension/n =(numptsRaw) OneRunRawSpectraMz, OneRunRawSpectraRes
 		redimension/n =(numptsRaw) OneRunRawSpectraCompMask		// 1.40D
	endif
 	
//	deal with stick integration regions
	sq_stickCalcGetRegions(mFinish[currentRunIndex])
 	 wave StickRegion_startMz = root:baselineFitting:StickRegion_startMz
	 wave StickRegion_stopMz = root:baselineFitting:StickRegion_stopMz
 	 wave BaselineRegion_startmz = root:baselineFitting:BaselineRegion_startmz
	 wave BaselineRegion_stopmz = root:baselineFitting:BaselineRegion_stopmz
 
 // deal with which mz params to use 
 	if (bk_UseMzFit_ck)		// for now we do not distinguish between open and closed m/z parameters.
  		wave/z mzSlope=root:mzFitting:mz_FitSlope
		wave/z mzIntercept=root:mzFitting:mz_FitIntercept
		wave/z mzPower=root:mzFitting:mz_FitPower
		if (WaveExists(mzSlope) ==0)
			Abort "Could not find the new mz Fitting parameters.  Uncheck the 'Use new m/z fitting parameters' or find them.  - Aborting from bk_setUpRawSpectraThisRun"
 		endif
 	else
 		wave mzSlope=root:diagnostics:mzSlope
		wave mzIntercept=root:diagnostics:mzInt
		wave/z mzPower=root:diagnostics:mzPower
		if (WaveExists(mzPower)==0)
			duplicate/o mzSlope root:diagnostics:mzPower/wave=mzPower
			mzPower=.5
		endif	
 	endif
 	
	intercept = mzIntercept[currentRunIndex]
	slope = mzSlope[currentRunIndex]
	power = mzPower[currentRunIndex]
		
 	if (numtype(Slope)!=0 || numtype(Intercept)!=0 || numtype(Power)!=0)
		Abort " One of the m/z parameters are nan/inf.  Cannot do calculations!  - Aborting from bk_butt_RawSpectraThisRun"
 	endif

// 	make some wave used in the graph
	make/o/n=(mFinish[currentRunIndex]) root:baselineFitting:pt_start
	make/o/n=(mFinish[currentRunIndex]) root:baselineFitting:pt_end
  	wave pt_start = root:baselineFitting:pt_start
 	wave pt_end = root:baselineFitting:pt_end
 	
//  	Slider/z slider_MzAxis limits = {0.5, mFinish[currentRunIndex], 1},  win=SQ_Baseline_Panel	//1.44B	//1.49E
 	SetVariable/z setvar_MzStart, Win=SQ_Baseline_Panel, limits={0.5,mFinish[currentRunIndex],0.1},  win=SQ_Baseline_Panel	 	
  	 	
 	fastop OneRunRawSpectraCompMask=1		//1.40D
 	
// 	x axis wave in graph
 	OneRunRawSpectraMz = ((p - intercept)/slope)^(1/(power))
	if (intercept>0)		//1.14I
 		OneRunRawSpectraMz[0,ceil(intercept)]=0			//1.55I  Tim O issue
	endif

//	get stick integration region	
	sq_StickCalcPrepRegion(OneRunRawSpectraOpen, OneRunRawSpectraMz, mStart[currentRunIndex], mFinish[currentRunIndex], StickRegion_startmz, StickRegion_stopmz, pt_start, pt_end)
 		
	bk_createStickComplimentMask(OneRunRawSpectraCompMask, BaselineRegion_startmz, BaselineRegion_stopmz, OneRunRawSpectraMz )

// 	deal with baseline waves (black points in graphs	
	fastop OneRunRawSpectraOpenBk = OneRunRawSpectraOpen*OneRunRawSpectraCompMask

// 	sq_smooth_nans(OneRunRawSpectraOpenBk, smoothBackground)	//1.53N  This bug was really really annoying  it actually doesn't hurt, but it is not the same when calcing sticks

 	fastop OneRunRawSpectraClosedBk = OneRunRawSpectraClosed*OneRunRawSpectraCompMask
 
 //	sq_smooth_nans(OneRunRawSpectraClosedBk, smoothBackground) //1.53N  This bug was really really annoying
 
 	fastop OneRunRawSpectraDiff = OneRunRawSpectraOpen - OneRunRawSpectraClosed
  	fastop OneRunRawSpectraDiffBk = OneRunRawSpectraDiff*OneRunRawSpectraCompMask
 //	sq_smooth_nans(OneRunRawSpectraDiffBk, smoothBackground)		//1.53N  This bug was really really annoying
	
//	deal with negative points in spectra wave
	OneRunRawSpectraNegDiff = OneRunRawSpectraDiff[p] <0 ? -1e8 :  nan			// 1.43A		-1e8 is arbitrary
  	
//	clear out baseline fits  	
	fastop OneRunRawSpectraOpenBkFit = (nan)
	fastop OneRunRawSpectraClosedBkFit = (nan)
  	fastop OneRunRawSpectraDiffBkFit=(nan)
  	fastop OneRunRawSpectraDiffBkLessFit=(nan)
	fastop OneRunRawSpectraDiffLessBks= (nan)

	killwaves/z mz_peak, pt_start, pt_end
	
	switch (bk_ck_PToF)	
//	if (!NVar_Exists(bk_ck_PToF) || !bk_ck_PToF)	
		case 1:
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LOpen "Open"
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LClosed "Closed"
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LDiff "Diff"
		break
		case 2:
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LOpen "Spectra A\r ~MS Open"
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LClosed "Spectra B\r ~MS Closed"
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LDiff "Spectra A - B\r ~MS Diff"
		break
		case 3:
			Label/W=SQ_Baseline_Panel#RawSpectraGraph LOpen "sum PTOF"
	endswitch
End


//^ changes values in BkMask to a 'key" wave with nans and ones
Function bk_createStickComplimentMask(BkMask, BaselineRegion_startmz, BaselineRegion_stopmz, MzAxis )
	wave BkMask, BaselineRegion_startmz, BaselineRegion_stopmz, MzAxis

	variable idex, num, startPt, stopPt		//1.59B
		  
 	fastop  BkMask=(nan)
 	num = numpnts(BaselineRegion_startmz)		// goes through the highest integer m/z
	for(idex=0;idex<num;idex+=1)		//1.58G
		if (numtype(BaselineRegion_startmz[idex])==0)
			startPt =binarysearchinterp(MzAxis, BaselineRegion_startmz[idex])
			stopPt=binarysearchinterp(MzAxis,BaselineRegion_stopmz[idex])
			if (startPt>=0 && stopPt>=0)
				BkMask[startPt,stopPt]=1
			endif
		endif
	endfor
End 


Function bk_fitStickCompliment(ResultWave, isWFlag, isClosedFlag, kill, smoothpnts, method)		// JDA change 1.47G  added smoothpnts, method parameters
	wave ResultWave
	variable isWFlag, isClosedFlag, kill, smoothpnts, method

//	nvar/z bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline // DIE, GLOBALS, DIE!!!
	variable spline_op=method&1

	variable UseThisStdDev=0
	variable pTOF_flag=dimsize(resultwave,1)>0,i,ncol=max(dimsize(resultwave,1),1)
	
//	WaveStats/M=1/q ResultWave
//	if (V_npnts<5)		// some arbitrary value
	if (numpnts(ResultWave)<5)		// some arbitrary value  //1.20Y
		fastop ResultWave = (nan)
		return 0
	endif
	
	if (spline_op)	
		nvar bk_StdDevNoise_WOpen = root:baselineFitting:bk_StdDevNoise_WOpen
		nvar bk_StdDevNoise_WClosed = root:baselineFitting:bk_StdDevNoise_WClosed
		nvar bk_StdDevNoise_VOpen = root:baselineFitting:bk_StdDevNoise_VOpen
		nvar bk_StdDevNoise_VClosed = root:baselineFitting:bk_StdDevNoise_VClosed
		nvar /z bk_StdDevNoise_pTOF = root:baselineFitting:bk_StdDevNoise_pTOF //& Deal with W pTOF later...
	
		if (ptof_flag)		//JDA change 1.47G
			UseThisStdDev = bk_StdDevNoise_pTOF
		elseif (isWFlag && isClosedFlag)
			UseThisStdDev = bk_StdDevNoise_WClosed
		elseif(isWFlag && !isClosedFlag)
			UseThisStdDev = bk_StdDevNoise_WOpen
		elseif (!isWFlag && isClosedFlag)
			UseThisStdDev = bk_StdDevNoise_VClosed
		elseif (!isWFlag && !isClosedFlag)
			UseThisStdDev = bk_StdDevNoise_VOpen
		endif
		
		if (UseThisStdDev==0 || numtype(UseThisStdDev)!=0)
			abort "The user should set or calculate appropriate standard deviation values to use the cubic spline.  - Aborting from bk_calcOneRunOneWaveBackground"
		endif	
		
//& Slightly restructured to make it multidimensional friendly. Got rid of the nonans thing
// NameofWave		
		if (!ptof_flag)
			wavestats /q/m=1 resultwave		//1.160Z
			if (v_npnts>0)
				duplicate /o resultwave,stickcomp_tmp1,stickcomp_tmp1_ss
				Interpolate2/T=3/I=3/F=1/S=(UseThisStdDev)/Y=stickcomp_tmp1_ss stickcomp_tmp1
	//			fastop resultwave=stickcomp_tmp1_ss			//1.57K
				duplicate/o stickcomp_tmp1_ss $GetWavesDataFolder(resultwave,2)
			endif
		else
			for (i=0;i<ncol;i+=1)
				matrixop /o stickcomp_tmp1=col(resultwave,i)
				Interpolate2/T=3/I=3/F=1/S=(UseThisStdDev)/Y=stickcomp_tmp1_ss stickcomp_tmp1
				imagetransform /d=stickcomp_tmp1_ss/g=(i) putcol resultwave
			endfor			
		endif
		
//		duplicate/o ResultWave tempBk_noNan_Y, tempBk_noNan_X, tempBk_X, temp_result
//		tempBk_X = p
//		tempBk_noNan_X = p
//		sort tempBk_noNan_Y tempBk_noNan_Y, tempBk_noNan_X
//		wavestats/q/m=1 tempBk_noNan_Y
//		deletepoints V_npnts, V_numnans, tempBk_noNan_Y, tempBk_noNan_X, temp_result
	
//		if (isWFlag == 1)
//			Interpolate2/T=3/I=3/F=1/S=(UseThisStdDev)/Y=temp_result/X=tempBk_X tempBk_noNan_X, tempBk_noNan_Y
//		else
//			Interpolate2/T=3/I=3/F=1/S=(UseThisStdDev)/Y=temp_result/X=tempBk_X tempBk_noNan_X, tempBk_noNan_Y
//		endif
//		ResultWave = temp_result
		
		if (kill)
			 killwaves/z stickcomp_tmp1,stickcomp_tmp1_ss
		endif
			
	else
	// use linear ... this is ugly
			if (smoothpnts>0)
				bk_smoothcompliment(resultwave,smoothpnts,kill) //& Put here so it doesn't double up on the spline version
			endif
			sq_InterpolateWave(ResultWave, ResultWave, kill)
	endif
	
End

//& A version that simulates the old smooth_nans function, but is much more efficient
//& Now with multidimensional awareness!
Function bk_smoothcompliment(wav,smoothpnts,kill)
	wave wav
	variable smoothpnts,kill
	
	variable p1,p2,p3,np
	if (numtype(Wavemax(wav)) !=0)  // i.e. wave is fast mode or 'closed' for ePToFSum
		return 0
	endif
	
	np=dimsize(wav,0)
	make /o/n=(np) smoothcomp_tmp=numtype(wav[p][0])>0 	// mask wave, 1 indicates nan, 0 indicates number
	if (smoothcomp_tmp[0]) // Leading nans
		findvalue /v=0/z smoothcomp_tmp
		p2=v_value
		wav[0,p2-1][]=wav[p2][q]
	else
		p2=0
	endif
	do
		findvalue /s=(p2)/v=1/z smoothcomp_tmp // Find the next non-real number
		if (v_value==-1) // None found - dump out
			break
		endif
		p1=v_value-1
		findvalue /s=(p1+1)/v=0/z smoothcomp_tmp // Find a real number
		p2=v_value
		if (p2==-1) // none found - fill remaining points and dump out
			wav[p1+1,np-1][]=wav[p1][q]
			break
		endif
		p3=round((p1+p2)*0.5) // Fill the gap with the values either side of the compliment
		wav[p1+1,p3][]=wav[p1][q] // This creates the same effect as what smooth_nans did
		wav[p3+1,p2-1][]=wav[p2][q]
	while (1)
	
	smooth /dim=0/e=3 smoothpnts,wav
	smoothcomp_tmp=smoothcomp_tmp?(nan):(1)
	if (dimsize(wav,1)>0 )	// multidimensional		//1.52L
		MatrixOp/o wavT = wav^t		// x rows np columns
		wavT =wavT[p][q]  * smoothcomp_tmp[q] /// number of columns in wavT must = number rows in smoothcomp_tmp
		MatrixOp/o wav = wavT^t	// 2 rows 10 columns
	else
		multithread wav =smoothcomp_tmp*wav 			// from FastOp  //1.57K  // Put the nans back in  
	endif
	if (kill)
		killwaves /z smoothcomp_tmp, wavT, NewwavT
	endif
end


//^ Changes the background (baseline wave to be zero beyond a given m/z value.
Function bk_makeBkZeroBeyondMassX(OneRunRawSpectraMz, BkWave,SpecTypeFlag)
	wave OneRunRawSpectraMz, BkWave
	variable SpecTypeFlag

	nvar/z bk_BKIsZeroBeyondThisMass = root:baselineFitting:bk_BKIsZeroBeyondThisMass
	nvar/z bk_BKIsX_Open = root:baselineFitting:bk_BKIsX_Open
	nvar/z bk_BKIsX_Closed = root:baselineFitting:bk_BKIsX_Closed
	nvar/z bk_BKIsX_pTOF = root:baselineFitting:bk_BKIsX_pTOF //& Errr... OK...
	
	variable pt
	
	if (NVar_Exists(bk_BKIsZeroBeyondThisMass) && bk_BKIsZeroBeyondThisMass>=0)
		pt = binarysearch(OneRunRawSpectraMz, bk_BKIsZeroBeyondThisMass)
		if (spectypeflag==4)			//JDA change 1.47G for PToF data
			if (NVar_Exists(bk_BKIsX_pTOF))
				BkWave[pt,][]=bk_BKIsX_pTOF
			else
				BkWave[pt,][]=0
			endif
		elseif (NVar_Exists(bk_BKIsX_Closed) && NVar_Exists(bk_BKIsX_Open))
			switch (SpecTypeFlag)
				case 1:
					BkWave[pt,]=bk_BKIsX_Open - bk_BKIsX_Closed
				break
				case 2:
					BkWave[pt,]=bk_BKIsX_Closed
				break
				case 3:
					BkWave[pt,]=bk_BKIsX_Open
			endswitch
		else
			BkWave[pt,]=0
		endif
	endif
	
End


Function bk_butt_calcBkFit(ctrlName) : ButtonControl
	String ctrlName

	wave OneRunRawSpectraOpen = root:baselineFitting:OneRunRawSpectraOpen
	wave OneRunRawSpectraClosed = root:baselineFitting:OneRunRawSpectraClosed
	wave OneRunRawSpectraOpenBk = root:baselineFitting:OneRunRawSpectraOpenBk
	wave OneRunRawSpectraClosedBk = root:baselineFitting:OneRunRawSpectraClosedBk
	wave OneRunRawSpectraOpenBkFit = root:baselineFitting:OneRunRawSpectraOpenBkFit
	wave OneRunRawSpectraClosedBkFit = root:baselineFitting:OneRunRawSpectraClosedBkFit
	wave OneRunRawSpectraDiff = root:baselineFitting:OneRunRawSpectraDiff
	wave OneRunRawSpectraDiffBkFit = root:baselineFitting:OneRunRawSpectraDiffBkFit
	wave OneRunRawSpectraDiffBkLessFit = root:baselineFitting:OneRunRawSpectraDiffBkLessFit
	wave OneRunRawSpectraDiffBk = root:baselineFitting:OneRunRawSpectraDiffBk
	wave OneRunRawSpectraDiffLessBks = root:baselineFitting:OneRunRawSpectraDiffLessBks
	wave OneRunRawSpectraMz = root:baselineFitting:OneRunRawSpectraMz

	wave OneRunRawSpectraDiffLessBks = root:baselineFitting:OneRunRawSpectraDiffLessBks
	wave OneRunRawSpectraMz = root:baselineFitting:OneRunRawSpectraMz
	wave tofTypeWKey =  root:diagnostics:tofTypeWKey
	wave run_series = root:index:rn_series
	
	nvar bk_DisplayOneRunDiffBk =  root:baselineFitting:bk_DisplayOneRunDiffBk
	nvar bk_currentRunNum =  root:baselineFitting:bk_currentRunNum
	
	variable currentIndex =sq_findRun(run_series,bk_currentRunNum)
	variable isWFlag = tofTypeWKey[currentIndex]
	
	nvar/z bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk		//1.60Y
	nvar bk_UseLinear = root:baselineFitting:bk_UseLinear
	nvar bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline
	nvar bk_smoothBackground = root:baselineFitting:bk_smoothBackground		// typo in James code - he had this variable in the mzFitting data folder	
	if (!NVar_exists(bk_UseTofwerk))
		bk_TofwerkBLGlobals()
		abort "Please recreate the baseline panel."
	endif

	if (numpnts(OneRunRawSpectraOpen)==0 && numpnts(OneRunRawSpectraClosed)==0 )
		abort "Pleare go back to step 0, choose a run and data set."
	endif
//	fastop OneRunRawSpectraClosedBkFit = OneRunRawSpectraClosedBk
//	fastop OneRunRawSpectraOpenBkFit = OneRunRawSpectraOpenBk
	duplicate/o OneRunRawSpectraClosedBk,  root:baselineFitting:OneRunRawSpectraClosedBkFit		// duplicate is faster than fastop here
	duplicate/o OneRunRawSpectraOpenBk,  root:baselineFitting:OneRunRawSpectraOpenBkFit		// duplicate is faster than fastop here
	
	if (bk_UseLinear || bk_UseCubicSpline)
		bk_makeBkZeroBeyondMassX(OneRunRawSpectraMz, OneRunRawSpectraClosedBkFit, 2)
		bk_makeBkZeroBeyondMassX(OneRunRawSpectraMz, OneRunRawSpectraOpenBkFit, 3)
	
		bk_fitStickCompliment(OneRunRawSpectraOpenBkFit, isWFlag, 0, 1,bk_smoothBackground,bk_UseCubicSpline)		// JDA change 1.47G, more parameters to this function
		bk_fitStickCompliment(OneRunRawSpectraClosedBkFit, isWFlag, 1, 1,bk_smoothBackground,bk_UseCubicSpline)	// JDA change 1.47G
	else
		struct Tofware#tw_bsl_smooth_var f	
		nvar bk_twWidth = $"root:baselineFitting:bk_twWidth"
		nvar bk_twNoiseScaling = $"root:baselineFitting:bk_twNoiseScaling"
		nvar bk_twckLoPass = $"root:baselineFitting:bk_twckLoPass"
		nvar bk_twf2 = $"root:baselineFitting:bk_twf2"
		nvar bk_twN = $"root:baselineFitting:bk_twN"
		Tofware#tw_bsl_smooth_varDef(f)
		f.width=bk_twWidth
		f.loPass_active=bk_twckLoPass
		f.loPass_f2=bk_twf2
		f.loPass_n=bk_twN
		f.noiseScaleFactor=bk_twNoiseScaling
		Tofware#tw_bsl_smooth_getBsl(OneRunRawSpectraOpen,OneRunRawSpectraOpenBkFit,f)
		Tofware#tw_bsl_smooth_getBsl(OneRunRawSpectraClosed,OneRunRawSpectraClosedBkFit,f)
	endif
	
	OneRunRawSpectraDiffBkFit =  OneRunRawSpectraOpenBk - OneRunRawSpectraClosedBk
//	bk_fitStickCompliment(OneRunRawSpectraDiffBkFit, isWFlag, 0, 1,bk_smoothBackground,bk_UseCubicSpline) 	// JDA change 1.47G  //1.60Y

	multithread OneRunRawSpectraDiffBkLessFit = OneRunRawSpectraDiff - OneRunRawSpectraDiffBkFit // from FastOp  //1.57K 
	multithread OneRunRawSpectraDiffLessBks = (OneRunRawSpectraOpen - OneRunRawSpectraOpenBkFit) - (OneRunRawSpectraClosed - OneRunRawSpectraClosedBkFit)     //1.57K 
	
End


// This function returns the bk_tmp raw spectra matrix with its baselines removed
Function bk_createBackgroundValues(index_pos, bk_tmp, mz_slope, mz_intercept, mz_power, deststr )
wave index_pos, bk_tmp
wave  mz_slope, mz_intercept, mz_power
string deststr	
variable killFlag
	
	if (!DataFolderExists("root:baselineFitting:") )
		bk_createGlobalsBaseline()
	endif
	
	nvar bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline
	nvar/z bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk
	if (!NVar_exists(bk_UseTofwerk))
		bk_TofwerkBLGlobals()
		abort "Please recreate the baseline panel."
	endif

	variable peakIntegrationDelta, idex, num, pos, isWFlag, specType, numInRawSpectra, maxMz, firstMaxMz, kdex
	
	num=numpnts(index_pos)
	
	make/o/n=4/free dims = dimsize(bk_tmp,p)

	numInRawSpectra = dims[2] == 0 ? dims[1] : dims[2] // 1.57K
	make/o/n=(numInRawSpectra) oneRun_temp		// , oneRun_res

	if (!bk_UseTofwerk)
		wave series_index = root:index:series_index		// 1.44B
		wave mFinish = root:diagnostics:mFinish
		wave mStart = root:diagnostics:mStart
		nvar bk_smoothBackground = root:baselineFitting:bk_smoothBackground
		wave/z ToFTypeWKey = root:diagnostics:ToFTypeWKey
		firstMaxMz = mFinish[series_index[index_pos[0]]]
		make/o/n=(numInRawSpectra) oneRun_mz		// , oneRun_res
		make/o/n=(firstMaxMz) root:baselineFitting:pt_start
		make/o/n=(firstMaxMz) root:baselineFitting:pt_end
		wave pt_start = root:baselineFitting:pt_start
		wave pt_end = root:baselineFitting:pt_end	
		maxMz = Wavemax(mFinish)  // 1.57K   not necessarily the best way for SP ams data
		sq_stickCalcGetRegions(maxMz)
		wave BaselineRegion_startmz = root:baselineFitting:BaselineRegion_startmz
		wave BaselineRegion_stopmz = root:baselineFitting:BaselineRegion_stopmz
		wave StickRegion_startmz = root:baselineFitting:StickRegion_startmz		// 1.46 fix
		wave StickRegion_stopmz = root:baselineFitting:StickRegion_stopmz
	else
		struct Tofware#tw_bsl_smooth_var f	
	endif
	
	strswitch(deststr[2])
	case "O":
		specType=2
		break
	case "C":
		specType=3
		break
	case "P":			//1.51Q
		specType=4
		break
	default:
		specType=1
	endswitch
			
	for(idex=0;idex<num;idex+=1)  // each run
		if (index_pos[idex]<0)		//1.58G
			continue
		endif

//	  	MatrixOp/o oneRun_temp =  row(bk_tmp,idex)  // 1.57K  trying to make faster
	  	// oneRun_temp=bk_tmp[idex][p]		//1.57K
	  	if (dims[2]==0)  // regular MS
	  		ImageTransform/G=(idex) getRow bk_tmp
	  		wave W_ExtractedRow 
	  		multithread oneRun_temp = W_ExtractedRow
			if (!bk_UseTofwerk)
				pos = series_index[index_pos[idex]]
			  	isWFlag = ToFTypeWKey[pos]
			  		
			 	multithread oneRun_mz = ((p - mz_intercept[pos])/mz_slope[pos])^(1/(mz_power[pos]))  //1.57K 	
		 		if (mz_intercept[pos]>0)			//1.14I
		 			oneRun_mz[0,ceil(mz_intercept[pos])]=0 
				endif
				
				sq_StickCalcPrepRegion(oneRun_temp, oneRun_mz, mStart[pos], mFinish[pos],StickRegion_startmz, StickRegion_stopmz, pt_start, pt_end)
				bk_createStickComplimentMask(oneRun_temp, BaselineRegion_startmz, BaselineRegion_stopmz,  oneRun_mz )
		
				oneRun_temp*=bk_tmp[idex][p]		//1.46fix
		// 		sq_smooth_nans(oneRun_temp, bk_smoothBackground)
				bk_makeBkZeroBeyondMassX(oneRun_mz, oneRun_temp, specType)	
				bk_fitStickCompliment(oneRun_temp, isWFlag, 0, 1,bk_smoothBackground,bk_UseCubicSpline)		// JDA change 1.47G
			else
				bk_twbaseline(W_ExtractedRow, oneRun_temp, f)
			endif		
		  	ImageTransform/D=oneRun_temp/G=(idex) putRow bk_tmp   // 1.57K  trying to make faster
			// bk_tmp[idex][]=oneRun_temp[q]
		else  // PToF
			for(kdex=0;kdex<dims[1];kdex+=1)		// each PTOF bin
		  		ImageTransform/BEAM={1,2} getBeam bk_tmp
		  		wave W_Beam 
		  		multithread oneRun_temp = W_Beam
				bk_twbaseline(W_Beam, oneRun_temp, f)
		  		ImageTransform/D=oneRun_temp/Beam={(idex),(kdex)} setBeam bk_tmp   // 1.57K  trying to make faster
			endfor
		endif
			
	endfor

	if (killflag)
		Killwaves/z oneRun_temp, oneRun_mz, oneRun_res,W_ExtractedRow		//1.46B
	endif
	Killwaves/z oneRun_temp	
End

Function bk_setVar_runNumberVW(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName
	
	wave run_series = root:index:rn_series
	wave ToFTypeWKey = root:diagnostics:ToFTypeWKey
	wave ToFTypeVKey = root:diagnostics:ToFTypeVKey
	nvar bk_currentRunNum =  root:baselineFitting:bk_currentRunNum
	nvar bk_OneRunIsInWMode = root:baselineFitting:bk_OneRunIsInWMode
	svar bk_runModeStr = root:baselineFitting:bk_runModeStr
	
	variable currentRunIndex =sq_FindRun(run_series, bk_currentRunNum)
	
 	bk_runModeStr =  sq_getDetectorStr(bk_currentRunNum)	// sq_getToFIonizationStr(varNum)		// 1.44B change

	if(currentRunIndex>=0)
		if (ToFTypeWKey[currentRunIndex]==1 )
			bk_OneRunIsInWMode = 1
			SetVariable Sl_StdDev_VOpen fstyle=0, win=sq_baseline_panel
			SetVariable Sp_StdDev_VClosed fstyle=0, win=sq_baseline_panel
			SetVariable Spl_StdDev_WOpen fstyle=1, win=sq_baseline_panel
			SetVariable Spl_StdDev_WClosed fstyle=1, win=sq_baseline_panel
		else
			bk_OneRunIsInWMode = 0
			SetVariable Spl_StdDev_VOpen fstyle = 1, win=sq_baseline_panel
			SetVariable Spl_StdDev_VClosed fstyle = 1, win=sq_baseline_panel
			SetVariable Spl_StdDev_WOpen fstyle = 0, win=sq_baseline_panel
			SetVariable Spl_StdDev_WClosed fstyle = 0, win=sq_baseline_panel
		endif		
	endif
	
	bk_setVar_ResolutionParam("",nan,"","")		//^ initialize string telling max amu for .8 width

End


Function bk_butt_findStdDev(ctrlName) : ButtonControl
	String ctrlName
	
	wave OneRunRawSpectraOpenBk = root:baselineFitting:OneRunRawSpectraOpenBk
	wave OneRunRawSpectraClosedBk = root:baselineFitting:OneRunRawSpectraClosedBk
	wave OneRunRawSpectraMz= root:baselineFitting:OneRunRawSpectraMz

	nvar bk_StdDevNoise_VOpen = root:baselineFitting:bk_StdDevNoise_VOpen
	nvar bk_StdDevNoise_VClosed = root:baselineFitting:bk_StdDevNoise_VClosed	
	nvar bk_StdDevNoise_WOpen = root:baselineFitting:bk_StdDevNoise_WOpen
	nvar bk_StdDevNoise_WClosed = root:baselineFitting:bk_StdDevNoise_WClosed

	nvar bk_OneRunIsInWMode = root:baselineFitting:bk_OneRunIsInWMode

	nvar bk_UseLinear = root:baselineFitting:bk_UseLinear
	if (bk_UseLinear==1)
		DoAlert 0, "The standard deviation values have no effect when you are doing a linear interpolation."
	endif

	variable startpt, stoppt
	startpt = BinarySearch(OneRunRawSpectraMz, 20.2)	// this is an arbitrary value - we assume that there are no peaks between 20 and 21
	stoppt = BinarySearch(OneRunRawSpectraMz, 20.8)
	
	Wavestats/q/r =[startpt, stoppt] OneRunRawSpectraClosedBk
	if (bk_OneRunIsInWMode==1)
		bk_StdDevNoise_WClosed = V_sdev
	else
		bk_StdDevNoise_VClosed = V_sdev
	endif

	Wavestats/q/r =[startpt, stoppt] OneRunRawSpectraOpenBk
	if (bk_OneRunIsInWMode==1)
		bk_StdDevNoise_WOpen = V_sdev
	else
		bk_StdDevNoise_VOpen = V_sdev
	endif

End


Function bk_setVar_minMaxYVal(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName
 
	nvar bk_YAxisMinY= root:baselineFitting:bk_YAxisMinY
	nvar bk_YAxisMaxY= root:baselineFitting:bk_YAxisMaxY

	SetActiveSubwindow SQ_Baseline_Panel#RawSpectraGraph
	SetAxis LOpen, bk_YAxisMinY, bk_YAxisMaxY
	SetAxis LClosed, bk_YAxisMinY, bk_YAxisMaxY

End


Function bk_ck_removeMoreStickCompMz(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked
	
	bk_createGlobalsBaseStickComp()		// reinitialize some globals, 1.44B
	
	wave/z bk_RemoveFromStickCompStart = root:baselineFitting:bk_RemoveFromStickCompStart
	wave/z bk_RemoveFromStickCompStop = root:baselineFitting:bk_RemoveFromStickCompStop
	wave/z bk_RemoveFromStickCompNMLFlag = root:baselineFitting:bk_RemoveFromStickCompNMLFlag

	if (waveExists(bk_RemoveFromStickCompStart)==0  || waveExists(bk_RemoveFromStickCompStop)==0  || waveExists(bk_RemoveFromStickCompNMLFlag)==0  )
		make/o/n=0 root:baselineFitting:bk_RemoveFromStickCompStart
		make/o/n=0 root:baselineFitting:bk_RemoveFromStickCompStop
		make/o/n=0 root:baselineFitting:bk_RemoveFromStickCompNMLFlag
	endif
	
	if (checked)
		bk_removeExtraStickComplPanel()
	  endif
	  
End


Function bk_removeExtraStickComplPanel()

	DoWindow/F ExtraStickComplimentRegions
	if (V_flag ==1)
		return 0
	endif
	PauseUpdate; Silent 1		// building window...
	NewPanel/N=ExtraStickComplimentRegions /W=(781,92,1195,602) as "ExtraStickComplimentRegions"
	SetDrawLayer UserBack
	SetDrawEnv fsize= 16,textrgb= (65280,0,0)
	DrawText 20,20,"Modify Stick Integration, Stick Compliment Regions"
	TitleBox title1,pos={5,215},size={363,72},fsize=10, frame=0
	TitleBox title1,variable= root:baselineFitting:bk_ExtraStickComplimentStr2
	TitleBox title2,pos={5,35},size={403,120},fsize=10, frame=0
	TitleBox title2,variable= root:baselineFitting:bk_ExtraStickComplimentStr3
	Button butt_ExtraStickEnd,pos={145,458},size={50,30},proc=sq_butt_End,title="End"
	Button butt_ExtraStickEnd,fsize=10,fStyle=1
	Button button_bk_ExtraBkRegionTable pos={354,295}, title="p\ro\rp",size={20,50},proc=sq_butt_popThis
	
	Edit/W=(6,295,347,442)/HOST=#  
	bk_populate_ExtraBkRegionTable()
	RenameWindow #,ExtraStickCompTable
	SetActiveSubwindow ##

End


//  no longer needed since in 1.42E because we use sq_butt_end
Function bk_removeFromStickComp_butt_End(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/K ExtraStickComplimentRegions

End


//  no longer needed since in 1.42E because we are using sq_butt_end
Function bk_butt_end(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/K SQ_Baseline_Panel

End


//^ 1.34
Function bk_butt_massDefectDefault(ctrlName) : ButtonControl
	String ctrlName
	
	bk_createMassDefectDefault()
	wave/z bk_MassDefect_default = root:baselineFitting:bk_MassDefect_default
	duplicate/o bk_MassDefect_default root:StickRecalc:sr_MassDefect

End


//^ 1.34
Function bk_ck_UseMassDefect(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked
	
	string/g root:baselineFitting:bk_MassDefectStr1		// we can create this new everytime
	svar bk_MassDefectStr1 = root:baselineFitting:bk_MassDefectStr1
	
	bk_MassDefectStr1 =  "The centers of peak integration regions can be set to non-ingeter values through the use\r" 
	bk_MassDefectStr1+= "of a mass defect wave. Modify the wave in the red box to set the peak integration center\r"
	bk_MassDefectStr1 += "values. The default mass defect wave accounts for some metals and follows a 'CH' or\r"
	bk_MassDefectStr1 += "'CH2' line at higher masses.  See the comments in function bk_createMassDefectDefault.\r\r"
	bk_MassDefectStr1 += "Use the tools in the blue box to find peak centers for the current run (as selected in the\r"
	bk_MassDefectStr1 += "main baseline panel) between the two variables. One can then choose to transfer the\r"
	bk_MassDefectStr1 += "non-Nan found peak centers to the mass defect wave. Beware that peak finding routine\r"
	bk_MassDefectStr1 += "is not perfect so press the 'Copy found...' button with caution."
 
	wave/z sr_MassDefect = root:StickRecalc:sr_MassDefect

	sq_initializeGlobalNVar("root:baselineFitting:FindPeakCenter_left", nan)		//1.44B change from initializing globals every time
	sq_initializeGlobalNVar("root:baselineFitting:FindPeakCenter_right", nan)		//1.44B change from initializing globals every time
	sq_initializeGlobalNVar("root:baselineFitting:FindPeakCenterScalar", 1)		//1.44B change from initializing globals every time
	sq_initializeGlobalNVar("root:baselineFitting:bk_MassDefectCHline", 1)		//1.44B change from initializing globals every time
	sq_initializeGlobalNVar("root:baselineFitting:bk_MassDefectCH2line", 0)		//1.44B change from initializing globals every time

	make/o/n=0 root:baselineFitting:foundPeakCenterAmu, root:baselineFitting:foundPeakCentersMz, root:baselineFitting:foundPeakCentersVal
		
	if (waveExists(sr_MassDefect)==0 )
		if (DataFolderExists("root:StickRecalc")==0 )	// use full path name 1.52D
			NewDataFolder root:StickRecalc
		endif
		bk_CreateMassDefectDefault()
		wave/z bk_MassDefect_default = root:baselineFitting:bk_MassDefect_default
		duplicate/o bk_MassDefect_default root:StickRecalc:sr_MassDefect
	endif
	
	if (checked)
		bk_MassDefectPanel()
	  endif
	  
End


Function bk_massDefectPanel()

	DoWindow/F MassDefectPanel
	if (V_flag ==1)
		return 0
	endif

	NewPanel/N=MassDefectPanel /W=(835,91,1367,628) as "MassDefectPanel"		//1.43A
	SetDrawLayer UserBack
//	SetDrawEnv fsize= 16,textrgb= (65280,0,0)
//	DrawText 199,21,"For Advanced Users"
	SetDrawEnv fsize= 16,textrgb= (65280,0,0)
	DrawText 199,21,"Mass Defect Panel"
	SetDrawEnv linethick= 2,linefgc= (0,0,65280),fillpat= 0
	DrawRect 246,184,523,493
	DrawRect 506,149,506,149
	SetDrawEnv linefgc= (0,0,65280),fillpat= 0
	DrawRect 506,149,506,149
	DrawRect 240,221,240,221
	SetDrawEnv linethick= 2,linefgc= (65280,0,0),fillpat= 0
	DrawRect 9,183,240,529
	DrawRect 253,368,253,368
	DrawRect 17,170,17,170
	Button butt_MassDefectEnd,pos={474,500},size={50,30},proc=sq_butt_End,title="End"
	Button butt_MassDefectEnd,fSize=10,fStyle=1
	TitleBox title0,pos={2,27},size={517,128},fsize=10,frame=0
	TitleBox title0,variable= root:baselineFitting:bk_MassDefectStr1
	Button butt_resetToMassDefectDefault,pos={13,190},size={135,20}, fsize=10,proc=bk_butt_MassDefectDefault,title="Set to mass defect of CHx"
	SetVariable setvar_findStart,pos={252,190},size={130,16},title="Find Peak Start"
	SetVariable setvar_findStart,value= root:baselineFitting:FindPeakCenter_left
	SetVariable setvar_FindPeakRight,pos={253,210},size={130,16},title="Find Peak Stop"
	SetVariable setvar_FindPeakRight,value= root:baselineFitting:FindPeakCenter_right
	Button butt_FindPeakCenters,pos={263,230},size={150,20}, fsize=10,proc=bk_butt_FindPeakCenters,title="Find Peak Centers"
	Button butt_copyFoundPeakCenters,pos={259,467},size={250,20}, fsize=10,proc=bk_butt_copyFoundPeakCenter,title="<- Copy found peak centers to mass defect wave"
	PopupMenu popupSpecType,pos={390,191},size={127,24},title="Spec Type"
	PopupMenu popupSpecType,mode=1,popvalue="Open",value= #"\"Open;Closed;Diff\""
	Button button_bk_MassDefectTable,pos={206,190},size={30,20}, fsize=10,proc=sq_butt_popThis,title="Pop"
	Button button_bk_FindPeakCenterTable,pos={473,230},size={30,20}, fsize=10,proc=sq_butt_popThis,title="Pop"
	CheckBox check0_massDefectCH,pos={154,187},size={33,14},proc=bk_MassDefectPanel_CH_ck,title="CH"
	CheckBox check0_massDefectCH,variable= root:baselineFitting:bk_MassDefectCHline,mode=1
	CheckBox check_massDefectCH2,pos={154,204},size={39,14},proc=bk_MassDefectPanel_CH_ck,title="CH2"
	CheckBox check_massDefectCH2,variable= root:baselineFitting:bk_MassDefectCH2line,mode=1
	
	Edit/W=(14,220,229,520)/HOST=#  
	bk_populate_MassDefectTable()
	RenameWindow #,T0
	SetActiveSubwindow ##

	Edit/W=(265,260,502,450)/HOST=#  
	bk_populate_FindPeakCenterTable()
	RenameWindow #,FoundPeaks
	SetActiveSubwindow ##

End


// no longer needed since 1.42E because we use sq_butt_end
Function bk_massDefect_butt_End(ctrlName) : ButtonControl
	String ctrlName

	DoWindow/K MassDefectPanel

End


Function bk_populate_ExtraBkRegionTable()

	String fldrSav= GetDataFolder(1)
	SetDataFolder root:baselineFitting:
	wave bk_RemoveFromStickCompStart,bk_RemoveFromStickCompStop,bk_RemoveFromStickCompNMLFlag
	AppendToTable bk_RemoveFromStickCompStart,bk_RemoveFromStickCompStop
	AppendToTable bk_RemoveFromStickCompNMLFlag
	ModifyTable width(Point)=26,title(bk_RemoveFromStickCompStart)="m/z start",title(bk_RemoveFromStickCompStop)="m/z stop"
	ModifyTable title(bk_RemoveFromStickCompNMLFlag)="Method"
	SetDataFolder fldrSav

End


//^ A function which creates and sets the wave bk_MassDefect_default
//^ The forumla should be tweaked by coders to give a mor optimum default value.
//^  The idea is to account for mass defect, the atomic mass values which are slightly higher or smaller
//^ than integer values, due to presence or absence of extra hydrogens, also for metals.
//^
//^  These oddballs are for metals. They are individually, specifically set after we assume that the rest are organic -ike.
//^  Anyone wanting to add comments to indicate the metal or non-organic contribution may do so!
//^  There are the original values given to me by  Tim O on 8/26/06
//^  Tim's original mass defect wave accounted for 2 hydrogens per carbon. 
//^ Here we use a more conservative 1 hydrogen per average additional carbon mass. 
//^ This creates a default wave.  The one that is really used is root:StickRecalc:sr_MassDefect
//^ Later we will fill up the root:StickRecalc data folder with other stick recalc diagnostics.
//1.34
Function bk_createMassDefectDefault()

	wave amus = root:diagnostics:amus			//1.52K
 	make/o/n=(numpnts(amus))  root:baselineFitting:bk_MassDefect_default, root:baselineFitting:bk_MassDefectAMU
	wave bk_MassDefect_default = root:baselineFitting:bk_MassDefect_default
	wave bk_MassDefectAMU = root:baselineFitting:bk_MassDefectAMU
	
	sq_initializeGlobalNVar("root:baselineFitting:bk_MassDefectCHline", 1)
	
	nvar bk_MassDefectCHline = root:baselineFitting:bk_MassDefectCHline
	
	variable numHs = bk_MassDefectCHline ? 1:2
	
	bk_MassDefectAMU=p+1
	bk_MassDefect_default[0,11]=p+1
	
	bk_MassDefect_default[12,]=12 + (p-11)*(1+numHs*0.007825035/13)		// oked by Jesse
	
	//^ oddballs
	bk_MassDefect_default[16-1] =	15.9949		// O
	bk_MassDefect_default[20-1] =	19.9812
	bk_MassDefect_default[23-1] =	22.9898
	bk_MassDefect_default[30-1] =	29.998
	bk_MassDefect_default[36-1] =	35.9767
	bk_MassDefect_default[38-1] =	37.9737
	bk_MassDefect_default[39-1] =	38.9637
	bk_MassDefect_default[40-1] =	39.9624		// Ar
	bk_MassDefect_default[41-1] =	40.9618		//41K
	bk_MassDefect_default[43-1] =	43.0184
	bk_MassDefect_default[44-1] =	43.9898
	bk_MassDefect_default[46-1] =	45.9929
	bk_MassDefect_default[48-1] =	47.967
	bk_MassDefect_default[64-1] =	63.9619
	bk_MassDefect_default[80-1] =	79.9568
	bk_MassDefect_default[81-1] =	80.9646
	bk_MassDefect_default[91-1] =	91.0548
	bk_MassDefect_default[98-1] =	97.9674
	bk_MassDefect_default[105	-1] =105.07
	bk_MassDefect_default[182	-1] =181.948		// 182W
	bk_MassDefect_default[183	-1] =182.950		// 184W		// added in 1.43B
	bk_MassDefect_default[184	-1] =183.951		// 184W
	bk_MassDefect_default[186	-1] =185.954		// 186W

End


Function bk_populate_MassDefectTable()

	String fldrSav= GetDataFolder(1)
	SetDataFolder root:baselineFitting:
	wave bk_MassDefectAMU
	AppendToTable bk_MassDefectAMU,::StickRecalc:sr_MassDefect
	ModifyTable digits=4,format(Point)=3,width(Point)=0,format(bk_MassDefectAMU)=1,title(bk_MassDefectAMU)="m/z"
	ModifyTable format(::StickRecalc:sr_MassDefect)=3,width(::StickRecalc:sr_MassDefect)=100
	ModifyTable title(::StickRecalc:sr_MassDefect)="Mass Defect"
	SetDataFolder fldrSav

End


Function bk_populate_FindPeakCenterTable()

	String fldrSav= GetDataFolder(1)
	SetDataFolder root:baselineFitting:
	wave foundPeakCenterAmu,foundPeakCentersMz,foundPeakCentersVal
	AppendToTable foundPeakCenterAmu,foundPeakCentersMz,foundPeakCentersVal
	ModifyTable format(Point)=1,width(Point)=0,width(foundPeakCenterAmu)=40,title(foundPeakCenterAmu)="m/z"
	ModifyTable format(foundPeakCentersMz)=3,digits(foundPeakCentersMz)=4,width(foundPeakCentersMz)=70
	ModifyTable title(foundPeakCentersMz)="Peak Center",format(foundPeakCentersVal)=3
	ModifyTable digits(foundPeakCentersVal)=6,sigDigits(foundPeakCentersVal)=4,width(foundPeakCentersVal)=80
	ModifyTable title(foundPeakCentersVal)="Peak Height"
	SetDataFolder fldrSav

End




Function bk_massDefect_findPeakCenters()

	nvar FindPeakCenter_right= root:baselineFitting:FindPeakCenter_right
	nvar FindPeakCenter_left= root:baselineFitting:FindPeakCenter_left
	nvar FindPeakCenterScalar= root:baselineFitting:FindPeakCenterScalar
	 
	wave OneRunRawSpectraMz=root:baselineFitting:OneRunRawSpectraMz
	
	wave foundPeakCentersMz=root:baselineFitting:foundPeakCentersMz
	wave foundPeakCentersVal=root:baselineFitting:foundPeakCentersVal
	wave foundPeakCenterAmu=root:baselineFitting:foundPeakCenterAmu
	
	variable idex, num = FindPeakCenter_right - FindPeakCenter_left+1, leftPt, rightPt, amuDelta
	
	ControlInfo/w=Sq_baseline_panel popupSpecType
	switch(V_Value)
		case 1:
			wave OneRunRawSpectra=root:baselineFitting:OneRunRawSpectraOpen
		break
		case 2:
			wave OneRunRawSpectra=root:baselineFitting:OneRunRawSpectraClosed
		break
		case 3:
			wave OneRunRawSpectra=root:baselineFitting:OneRunRawSpectraDiff
		break
		case 0:		//1.52E fix.  The user didn't select anything.  Default is 0
			wave OneRunRawSpectra=root:baselineFitting:OneRunRawSpectraOpen
		break
	endswitch
		
	amuDelta = .4		// for a default peak width search region of .99
	
	redimension/n=(num) foundPeakCentersMz, foundPeakCentersVal, foundPeakCenterAmu
	
	foundPeakCenterAmu=(FindPeakCenter_left)+p
	fastop foundPeakCentersMz= (nan)
	fastop foundPeakCentersVal= (nan)
	
	for(idex=0;idex<num;idex+=1)
		leftPt = binarysearch(OneRunRawSpectraMz,FindPeakCenter_left+ idex-amuDelta)	
		rightPt = binarysearch(OneRunRawSpectraMz, FindPeakCenter_left+idex+amuDelta)
		wavestats/q/r=(leftPt, rightPt) OneRunRawSpectra
		FindPeak/M=(V_sdev*FindPeakCenterScalar)/b=20/p/q/r=(leftPt,rightPt) OneRunRawSpectra	
		if (V_flag ==0)		// peak found
			foundPeakCentersMz[idex]=OneRunRawSpectraMz[V_PeakLoc]
			foundPeakCentersVal[idex]=V_PeakVal
		endif
	endfor

End


Function bk_butt_findPeakCenters(ctrlName) : ButtonControl
	String ctrlName

	bk_massDefect_findPeakCenters()

End


Function bk_butt_copyFoundPeakCenter(ctrlName) : ButtonControl
	String ctrlName

	wave foundPeakCentersMz=root:baselineFitting:foundPeakCentersMz
	wave sr_MassDefect = root:StickRecalc:sr_MassDefect
	wave foundPeakCenterAMU = root:baselineFitting:foundPeakCenterAMU

	nvar FindPeakCenter_left = root:baselineFitting:FindPeakCenter_left 
	
	variable idex, num = numpnts(foundPeakCentersMz)
	
	for(idex=0;idex<num;idex+=1)
		if (numtype(foundPeakCentersMz[idex])==0)
			sr_MassDefect[foundPeakCenterAMU[idex]-1]=foundPeakCentersMz[idex]
		endif
	endfor

End


Function bk_populate_RawSpectraGraph()

	SetDataFolder root:baselineFitting:
	wave BaselineRegion_Key, StickRegion_key
	wave OneRunRawSpectraMz, OneRunRawSpectraOpen, OneRunRawSpectraClosed, OneRunRawSpectraOpenBk, OneRunRawSpectraClosedBk, OneRunRawSpectraOpenBkFit, OneRunRawSpectraClosedBkFit
	wave OneRunRawSpectraDiff	, OneRunRawSpectraDiffBk, OneRunRawSpectraDiffBkLessFit, OneRunRawSpectraDiffLessBks,OneRunRawSpectraNegDiff
	
	AppendToGraph/R BaselineRegion_Key		// added in 1.44B
	AppendToGraph/R StickRegion_key		// added in 1.44B

	AppendToGraph/L=LOpen OneRunRawSpectraOpen vs OneRunRawSpectraMz
	AppendToGraph/L=LOpen OneRunRawSpectraOpenBk vs OneRunRawSpectraMz
	AppendToGraph/L=LOpen OneRunRawSpectraOpenBkFit vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed OneRunRawSpectraClosed vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed OneRunRawSpectraClosedBk vs OneRunRawSpectraMz
	AppendToGraph/L=LClosed OneRunRawSpectraClosedBkFit vs OneRunRawSpectraMz
	AppendToGraph/L=LDiff OneRunRawSpectraDiff vs OneRunRawSpectraMz
//	AppendToGraph/L=LDiff OneRunRawSpectraDiffBk vs OneRunRawSpectraMz
//	AppendToGraph/L=LDiff OneRunRawSpectraDiffBkLessFit vs OneRunRawSpectraMz
	AppendToGraph/L=LDiff OneRunRawSpectraDiffLessBks vs OneRunRawSpectraMz
//	AppendToGraph/L=LDiff OneRunRawSpectraNegDiff vs OneRunRawSpectraMz
	
	ModifyGraph margin(left)=58,margin(bottom)=49,margin(top)=14,margin(right)=14
	ModifyGraph mode(OneRunRawSpectraOpenBk)=4,mode(OneRunRawSpectraClosedBk)=4
	ModifyGraph marker(OneRunRawSpectraOpenBk)=19,marker(OneRunRawSpectraClosedBk)=19
	ModifyGraph lSize(OneRunRawSpectraOpenBkFit)=2,lSize(OneRunRawSpectraClosedBkFit)=2
	ModifyGraph rgb(OneRunRawSpectraOpen)=(32768,40704,65280),rgb(OneRunRawSpectraClosed)=(32768,40704,65280)
	ModifyGraph rgb(OneRunRawSpectraOpenBk)=(0,0,0),rgb(OneRunRawSpectraClosedBk)=(0,0,0)
	ModifyGraph rgb(OneRunRawSpectraOpenBkFit)=(65280,0,0),rgb(OneRunRawSpectraClosedBkFit)=(65280,0,0)
	ModifyGraph rgb(OneRunRawSpectraDiff)=(65280,43520,0)
//	ModifyGraph mode(OneRunRawSpectraDiffBk)=3, rgb(OneRunRawSpectraDiffBk)=(34816,34816,34816)
//	ModifyGraph msize(OneRunRawSpectraDiffBk)=2, marker(OneRunRawSpectraDiffBk)=19
	ModifyGraph lsize(OneRunRawSpectraDiff)=2
	ModifyGraph msize(OneRunRawSpectraOpenBk)=2,msize(OneRunRawSpectraClosedBk)=2
//	ModifyGraph rgb(OneRunRawSpectraDiffBkLessFit)=(29524,1,58982)
//	ModifyGraph lsize(OneRunRawSpectraDiffBkLessFit)=2
	ModifyGraph rgb(OneRunRawSpectraDiffLessBks)=(1,39321,1)
//	ModifyGraph mode(OneRunRawSpectraInteg)=7,hbFill(OneRunRawSpectraInteg)=2		//1.44A
//	ModifyGraph usePlusRGB(OneRunRawSpectraInteg)=1,useNegRGB(OneRunRawSpectraInteg)=1
//	ModifyGraph plusRGB(OneRunRawSpectraInteg)=(39321,39321,39321)		//1.44A
//	ModifyGraph negRGB(OneRunRawSpectraInteg)=(39321,39321,39321)	//1.44A
//	ModifyGraph rgb(OneRunRawSpectraInteg)=(39321,39321,39321)	//1.44A
//	ReorderTraces OneRunRawSpectraOpen,{OneRunRawSpectraInteg}	
//	ModifyGraph mode(OneRunRawSpectraNegDiff)=1
//	ModifyGraph rgb(OneRunRawSpectraNegDiff)=(26112,26112,0)
	SetDataFolder root:
	ModifyGraph grid=2
	ModifyGraph zero(LOpen)=1,zero(LClosed)=1,zero(LDiff)=1
	ModifyGraph mirror(LOpen)=2,mirror(LClosed)=2,mirror(LDiff)=2
	ModifyGraph nticks(bottom)=10
	ModifyGraph gridRGB=(34816,34816,34816)
	ModifyGraph lblPos(LOpen)=50,lblPos(LClosed)=50,lblPos(LDiff)=50
	ModifyGraph lblLatPos(LOpen)=-8,lblLatPos(LClosed)=-8,lblLatPos(LDiff)=-3
	ModifyGraph freePos(LOpen)=0
	ModifyGraph freePos(LClosed)=0
	ModifyGraph freePos(LDiff)=0
	ModifyGraph axisEnab(LOpen)={0.7,1}
	ModifyGraph axisEnab(LClosed)={0.35,0.65}
	ModifyGraph axisEnab(LDiff)={0,0.3}
	Label bottom "m/z"

	ModifyGraph mode(StickRegion_Key)=7, mode(BaselineRegion_Key)=7
	ModifyGraph rgb(BaselineRegion_Key)=(52224,52224,52224)
	ModifyGraph rgb(StickRegion_Key)=(65280,57600,57600)
	ModifyGraph hbFill(BaselineRegion_Key)=4
	ModifyGraph hbFill(StickRegion_Key)=4
	ModifyGraph tick(right)=3,nticks(right)=0

	//  change in 1.43A
	string PanelOrGrStr = WinName(0,65)
//	bk_ck_showDiffComp(PanelOrGrStr, nan)		// call the check control function
	bk_ck_showDiffIntegRegion(PanelOrGrStr, nan)		// call the check control function
//	bk_ck_showDiffNeg(PanelOrGrStr, nan)		// call the check control function
	
	nvar bk_YAxisMinY= root:baselineFitting:bk_YAxisMinY
	nvar bk_YAxisMaxY= root:baselineFitting:bk_YAxisMaxY
	nvar bk_DiffDelta = root:baselineFitting:bk_DiffDelta
	nvar bk_MassAxisStart = root:baselineFitting:bk_MassAxisStart
	nvar bk_MassAxisStop = root:baselineFitting:bk_MassAxisStop
//	nvar bk_MassAxisDelta = root:baselineFitting:bk_MassAxisDelta
 
	SetAxis LOpen bk_YAxisMinY, bk_YAxisMaxY
	SetAxis LClosed bk_YAxisMinY, bk_YAxisMaxY
	SetAxis LDiff -bk_DiffDelta/4, bk_DiffDelta
	SetAxis bottom bk_MassAxisStart, bk_MassAxisStart +(bk_MassAxisStop-bk_MassAxisStart) // bk_MassAxisDelta
	SetAxis right 0,1
		
 	bk_LabelBk_graph()
 
End

// new in 1.52  Change the axis labels when switching between MS and PToF
Function bk_LabelBk_graph()

	nvar/z bk_ck_PToF = root:baselineFitting:bk_ck_PToF
	if(!NVar_Exists(bk_ck_PToF))			//1.52E
		variable/g root:baselineFitting:bk_ck_PToF=1
		nvar bk_ck_PToF = root:baselineFitting:bk_ck_PToF
	endif
	
	switch (bk_ck_PToF)
	case 1:
		Label LOpen "Open"
		Label LClosed "Closed"
		Label LDiff "Diff"
		break
	case 2:
		Label LOpen "Spectra A"
		Label LClosed "Spectra B"
		Label LDiff "Spectra A - Spectra B"
		break
	case 3:
		Label LOpen "Sum ePToF"
		Label LClosed ""
		Label LDiff ""
		break
	endswitch

End

Function bk_tab(ctrlName,tabNum) : TabControl
	String ctrlName
	Variable tabNum

	variable cont_disp,idex,num
	string cont_list, cont_item

	cont_list=controlnamelist("", ";", "bk1*")
	num=itemsinlist(cont_list)
	for (idex=0;idex<num;idex+=1)
		cont_item=stringfromlist(idex,cont_list)
		strswitch(cont_item[3,5])
			case "Res":
				cont_disp=!(tabNum==0)
				break
			case "Adv":
				cont_disp=!(tabNum==1)
				break
//			case "Opt":
//				cont_disp=!(tabNum==2)
//				break
		endswitch
		controlinfo $cont_item
		switch (abs(v_flag))
			case 1:
				button $cont_item disable=cont_disp
				break
			case 2:
				checkbox  $cont_item disable=cont_disp
				break
			case 3:
				popupmenu $cont_item disable=cont_disp
				break
			case 4:
				valdisplay $cont_item disable=cont_disp
				break
			case 5:
				setvariable $cont_item disable=cont_disp
				break
			case 6:
				chart $cont_item disable=cont_disp
				break
			case 7:
				slider $cont_item disable=cont_disp
				break
			case 8:
				tabcontrol $cont_item disable=cont_disp
				break
			case 9:
				groupbox $cont_item disable=cont_disp
				break
			case 10:
				titlebox $cont_item disable=cont_disp
				break
			case 11:
				listbox $cont_item disable=cont_disp
				break
		endswitch	
	
	endfor

End


Function bk_MassDefectPanel_CH_ck(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked
	
	nvar bk_MassDefectCHline = root:baselineFitting:bk_MassDefectCHline
	nvar bk_MassDefectCH2line = root:baselineFitting:bk_MassDefectCH2line
	if (strsearch(ctrlName, "CH2",0)>0)
		bk_MassDefectCHline = 0
		bk_MassDefectCH2line = 1
	else
		bk_MassDefectCHline = 1
		bk_MassDefectCH2line = 0
	endif

End


Function mz_butt_SetParamsToNan(ctrlName) : ButtonControl
	String ctrlName

	wave mz_FitSlope = root:mzFitting:mz_FitSlope
	wave mz_FitIntercept = root:mzFitting:mz_FitIntercept
	wave mz_FitPower = root:mzFitting:mz_FitPower
	
	wave mz_RatioSlope = root:mzFitting:mz_RatioSlope
	wave mz_RatioIntercept = root:mzFitting:mz_RatioIntercept
	wave mz_RatioPower = root:mzFitting:mz_RatioPower

	wave t_ion = root:mzFitting:t_ion
	wave Resolution = root:mzFitting:Resolution

	wave ppmstd = root:mzFitting:ppmstd
	wave mz_fitChiSq = root:mzFitting:mz_fitChiSq	

	wave mz_mass = root:mzFItting:mz_mass
	wave t_series = root:index:t_series

	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	wave todowave = $"root:"+sq_toDoWvNm
	
	variable idex, numMass, numRuns
	string massStr

	numRuns = numpnts(t_series)
	numMass = numpnts(mz_mass)

	make/o/n=(numRuns) maskwave		//1.49E  modified to set to nan onlyin current todo wave.
	wave maskwave =root:maskwave
	sq_makeMaskFromTodofindRun(maskwave,todowave)

	maskwave = numtype(maskwave[p])==0 ? nan : 1
		
	if (stringmatch(sq_toDoWvNm, "all")	)	// in cases where runs have been blacklisted
		maskwave=nan
	endif
	
	mz_FitSlope*=maskwave
	mz_FitIntercept*=maskwave
	mz_FitPower*=maskwave

	mz_RatioSlope*=maskwave
	mz_RatioIntercept*=maskwave
	mz_RatioPower*=maskwave
	
	t_ion*=maskwave
	Resolution*=maskwave
	
	ppmstd*=maskwave
	mz_fitChisq*=maskwave
	
	for (idex=0;idex<numMass;idex+=1)
		sprintf MassStr "%1.2f", mz_Mass[idex]
		MassStr = ReplaceString(".",MassStr,"_")			
		make/o/n=(numRuns) $"root:mzFitting:Accuracy_"+MassStr
		wave Accuracy =$"root:mzFitting:Accuracy_"+MassStr
		Accuracy *=maskwave
	endfor

	killwaves/z maskwave
		
End


// a general function for making a wave that contains nans and heightValues
// The result wave can then be plotted against the XaxisWave in a graph
// to highlight the regions identified by the leftMarks and rightMarks waves.
// The waves would be plotted as sticks or region to zero.
//  Presumes all waves are monotonically increasing
//Function gen_makeGraphicShadedRegionWave(XaxisWave, leftMarks, rightMarks, resultWave, heightValue)
wave xAxisWave, leftMarks, rightMarks, resultWave
variable heightValue

	variable idex, num, regionNum, leftPt, rightPt
	
	num = numpnts(XaxisWave)
	redimension/n=(num) resultWave
	
	fastop resultwave = (nan)
	
	regionNum = numpnts(leftMarks)		
	if (numpnts(rightMarks) != regionNum)
		print "// Something is wrong with the number of points sent to the functiongen_makeGraphicShadedRgionWave "
		return 0			// don't want to abort
	endif
	
	for(idex=0;idex<regionNum;idex+=1)
		leftPt = binarysearch(XaxisWave, leftMarks[idex])
		rightPt = binarysearch(XaxisWave, rightMarks[idex])
		if (leftPt < rightPt && leftPt >=0)
			resultWave[leftPt, rightPt]=heightValue
		endif	
	endfor

End



// Check procedure function to show the Stick complement regions for the difference spectra
// Adds 3 waves: OneRunRawSpectraDiffBk, OneRunRawSpectraDiffBkFit, OneRunRawSpectraDiffLessBks
Function bk_ck_showDiffComp(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked

	nvar bk_DisplayOneRunDiffBk = root:baselineFitting:bk_DisplayOneRunDiffBk

	if (bk_DisplayOneRunDiffBk)
//		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(OneRunRawSpectraDiffBk)=0			// fixed in 1.44A
		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(OneRunRawSpectraDiffBkLessFit)=0			// fixed in 1.44A
//		ModifyGraph hideTrace(OneRunRawSpectraDiffLessBks)=0		// fixed in 1.44A
	else
//		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(OneRunRawSpectraDiffBk)=1		//1.44A
		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(OneRunRawSpectraDiffBkLessFit)=1		//1.44A
//		ModifyGraph hideTrace(OneRunRawSpectraDiffLessBks)=1
	endif

End


// Check procedure function to display the pink background regions where we integrate sticks
Function bk_ck_showDiffIntegRegion(ctrlName,checked) : CheckBoxControl
	string ctrlName
	variable checked

	nvar bk_ck_ShowStickIntegRegion = root:baselineFitting:bk_ck_ShowStickIntegRegion
		
	if (bk_ck_ShowStickIntegRegion)
		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(BaselineRegion_Key)=0		//1.44A, B
		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(StickRegion_key)=0		//1.44A, B
	else
		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(BaselineRegion_Key)=1		//1.44A, B
		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph hideTrace(StickRegion_key)=1		//1.44A, B
	endif
End


// Check procedure function to display or not the points where raw difference spectra is  < 0
//Function bk_ck_showDiffNeg(ctrlName,checked) : CheckBoxControl
//	string ctrlName
//	variable checked
//
//	nvar bk_ck_DiffNeg = root:baselineFitting:bk_ck_DiffNeg
//
//	if (bk_ck_DiffNeg)
//		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph  hideTrace(OneRunRawSpectraNegDiff)=0		//1.44A
//	else
//		ModifyGraph/W=SQ_Baseline_panel#RawSpectraGraph  hideTrace(OneRunRawSpectraNegDiff)=1		//1.44A
//	endif
//
//	return 0
//End


//1.44B
//  makes Region_startMz and Region_stopMz
Function bk_makeStartStop(Region_Key, resultStart, resultStop)
wave Region_Key, resultStart, resultStop

	variable idex, num, BaseFlag =0, counter = 0
	string NameStr
	
	redimension/n=0 resultStart, resultStop
	
	num = numpnts(Region_Key)
	for (idex = 0;idex<num;idex+=1)
		if (Region_Key[idex]==1)
			if (BaseFlag==0)	// start a new section
				insertpoints counter, 1,  resultStart, resultStop
				resultStart[counter] = idex/100
				baseFlag = 1
			else		// baseFlag = 1 we are in the middle of a section
			endif
		else
			if (BaseFlag==1)	// end this section
				resultStop[counter] = (idex-1)/100
				baseFlag = 0
				counter+=1
			endif
		endif	
	endfor
	
	if (Region_Key[num-1]==1)
		resultStop[counter] = (num)/100
	endif

End


// new in 1.52
// button in panel for autoscaling y axis of open and diff axis
Function bk_autoAxis(ctrlName) : ButtonControl
	String ctrlName

	if (stringMatch(ctrlName, "gr_autoXaxis"))
		SetAxis/A/w=SQ_baseline_Panel#RawSpectraGraph bottom
		return 0	
	endif
	
	wave OneRunRawSpectraDiff = root:baselineFitting:OneRunRawSpectraDiff
	wave OneRunRawSpectraClosed = root:baselineFitting:OneRunRawSpectraClosed
	wave OneRunRawSpectraOpen = root:baselineFitting:OneRunRawSpectraOpen
	wave OneRunRawSpectraMz = root:baselineFitting:OneRunRawSpectraMz
	nvar bk_yAxisMaxy = root:baselineFitting:bk_yAxisMaxy
	nvar bk_yAxisMiny = root:baselineFitting:bk_yAxisMiny
	nvar bk_DiffDelta = root:baselineFitting:bk_DiffDelta
	
	variable leftp, rightp, currentMin = inf, currentmax=-inf
	
	GetAxis/q/w=SQ_baseline_Panel#RawSpectraGraph bottom
	leftp = BinarySearch(OneRunRawSpectraMz, V_min )
	rightp = BinarySearch(OneRunRawSpectraMz, V_max )
	WaveStats/q/r=[leftp,rightp] OneRunRawSpectraOpen
	currentMin = min(currentMin,  ( Numtype(V_min)==0 ? V_min : inf)      )  //1.52D
	currentMax = max(currentMax, ( Numtype(V_max)==0 ? V_max : -inf)   )
	WaveStats/q/r=[leftp,rightp] OneRunRawSpectraClosed
	currentMin = min(currentMin,  (Numtype(V_min)==0 ? V_min : inf)     ) //1.52D
	currentMax = max(currentMax, (Numtype(V_max)==0 ? V_max : -inf)   ) //1.52D
	
	SetAxis/w=SQ_baseline_Panel#RawSpectraGraph	 LClosed currentMin, currentMax
	SetAxis/w=SQ_baseline_Panel#RawSpectraGraph	 LOpen currentMin, currentMax
	bk_yAxisMaxy=currentMax
	bk_yAxisMiny=currentMin
	
	WaveStats/q/r=[leftp,rightp] OneRunRawSpectraDiff
	currentMax = max (   abs(Numtype(V_min)==0 ? V_min : 1), abs(Numtype(V_max)==0 ? V_max : 1)    ) 
	SetAxis/w=SQ_baseline_Panel#RawSpectraGraph	 LDiff -currentMax/4, currentMax

	bk_DiffDelta=currentMax

End


// new in 1.52
// Function that retrieves raw PToF spectra
Function bk_getPToFForBaselinePanel(avgFlag)		// presumes that we already know that we want PToF and not MS data.
variable avgFlag

	nvar bk_currentRunNum = root:BaselineFitting:bk_currentRunNum
// 	nvar bk_UseRunningAvg = root:baselineFitting:bk_UseRunningAvg		//1.60Y
// 	nvar bk_RunningAvgDeltaRunNum = root:baselineFitting:bk_RunningAvgDeltaRunNum
	nvar VWSwitching = root:diagnostics:VWSwitching
	wave/z toftypeVKey = root:diagnostics:toftypeVKey
	nvar chopper_duty = root:diagnostics:chopper_duty
	
	wave OneRunRawSpectraOpen = root:BaselineFitting:OneRunRawSpectraOpen
	wave OneRunRawSpectraClosed = root:BaselineFitting:OneRunRawSpectraClosed
	wave OneRunRawSpectraDiff = root:BaselineFitting:OneRunRawSpectraDiff
	nvar bk_ck_PToF = root:baselineFitting:bk_ck_PToF
	svar sq_toDoWvNm=root:panel:sq_toDoWvNm
	
	string runStr, str1, str2
	variable runPos
	
	make/o/n=0 root:PToF:ptof_CurrentRun_Timeus
	make/o/n=0 root:PToF:ptof_CurrentRun_nm

	sprintf runStr, "%d", bk_currentRunNum
	// first check if current run has PToF data
	if (	sq_doesPToFDataExist(bk_currentRunNum)!=1)
		abort "No PToF data exists for run "+runStr
	endif	
	
	// next check if spectra A and B start and stop times make sense (consider different PToF bin units
	runPos = sq_findRun(root:index:rn_series,bk_currentRunNum)
	sq_GetPToFPointNums(runPos)
	wave PToFRegionsPTnum=root:PToF:PToFRegionsPTnum
//	if (bk_ck_PToF==3)
//	endif
	// deal with a single run or an average of a todo
	if (avgFlag)			//1.60Y
//		sprintf str1, "%d" , bk_currentRunNum- bk_RunningAvgDeltaRunNum		// small bug, things can go wrong with run numbers > 1e6
//		sprintf str2, "%d" , bk_currentRunNum+bk_RunningAvgDeltaRunNum		// small bug, things can go wrong with run numbers > 1e6
		if (VWSwitching)		// we have v/w data
			sq_create_todo("allPToF and all"+selectstring(toftypeVKey[runPos]==1, "W", "V")+" and "+sq_toDoWvNm,"myTempTodo")
  		else
			sq_create_todo("allPToF and "+sq_toDoWvNm,"myTempTodo")
  		endif
  		wave myTempTodo = root:myTempTodo		// assumes current run (and perhaps more) has data of type requested
		wave/z allPToF = root:allPToF
		if (WaveExists(allPToF))
			sq_create_todo("myTempTodo and allPToF","myTempTodo")
		endif
  		wave myTempTodo = root:myTempTodo		// assumes current run (and perhaps more) has data of type requested
//		make/o root:PToF:PToFRegionsPTnum = {0}
	else
		make/o/n=1 myTempTodo=bk_currentRunNum
//		sq_GetRawPToF("A", bk_currentRunNum)
	endif	
	
	squirrel_fetch(myTempTodo,sq_MS_concentration, "timeweight_op:4;findBaseline_op:0;raw_flag:1;product_type:6;destlist:PToF_Matrix;chop_duty:"+num2str(chopper_duty),"PToF")
	killwaves/z myTempTodo
	
	wave PToF_Matrix = root:PToF_Matrix		// gets spit out as rows = mz, cols = PtoF size
	wave PToF_A = root:PToF:PToF_A

	MatrixTranspose PToF_Matrix
	Redimension/n=(dimsize(PToF_Matrix,0),dimsize(PToF_Matrix,1)) PToF_A
	PToF_A = PToF_Matrix
	killwaves/z PToF_Matrix

	bk_InputIntoBaseline("Open", "A", PToFRegionsPTnum[0],PToFRegionsPTnum[1])
	bk_InputIntoBaseline("Closed", "A", PToFRegionsPTnum[2],PToFRegionsPTnum[3])	

	redimension/n=(numpnts(OneRunRawSpectraOpen))  OneRunRawSpectraDiff
	fastop OneRunRawSpectraDiff = OneRunRawSpectraOpen - OneRunRawSpectraClosed		

End


// new in 1.52
// Checkbox control for switching between PToF bin and time units
Function bk_ck_PToFUnits(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar ptof_dcUseBinNumUnits = root:panel:ptof_dcUseBinNumUnits		// exists on main panel, DC marker graph, baseline panel

	CheckBox PT_check_binNum proc=bk_ck_PToFUnits

	if (strsearch(ctrlName, "PToFTime", 0)>=0 )
//		CheckBox PT_check_PToFTime value =1		//1.60U
//		CheckBox PT_check_binNum value =0
//		ptof_dcUseBinNumUnits = 0
//		CheckBox PT_check_nm value =0
//		CheckBox PT_check_nm value =0
	elseif(strsearch(ctrlName, "binNum", 0)>=0 )
//		CheckBox PT_check_PToFTime value =0	//1.60U
//		CheckBox PT_check_binNum value =1
//		ptof_dcUseBinNumUnits = 1
//		CheckBox PT_check_nm value =0
	else		// if using default selection
//		CheckBox PT_check_PToFTime value =0  	//1.60U
//		CheckBox PT_check_binNum value =0
//		CheckBox PT_check_nm value =1
	endif
	
End


// new in 1.52
// Checkbox control for switching between MS and PToF data
Function bk_ck_PToFMS(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar bk_ck_PToF = root:baselineFitting:bk_ck_PToF
	bk_ck_PToF = 1+WhichListItem(ctrlName, "check_MS;check_PToF;check_ePToFSum")

	CheckBox check_MS value = bk_ck_PToF==1
	CheckBox check_PToF value = bk_ck_PToF==2
	CheckBox check_ePToFSum value = bk_ck_PToF==3

	Checkbox PT_check_binNum disable = bk_ck_PToF!=2
	Button PT_buttonDva disable= bk_ck_PToF!=2
	TitleBox PT_TitleMSA disable= bk_ck_PToF!=2
	TitleBox PT_TitleMSB disable= bk_ck_PToF!=2
	SetVariable PT_setvar_SpectraAStart  disable= bk_ck_PToF!=2
	SetVariable PT_setvar_SpectraAStop  disable= bk_ck_PToF!=2
	SetVariable PT_setvar_SpectraBStart  disable= bk_ck_PToF!=2
	SetVariable PT_setvar_SpectraBStop  disable= bk_ck_PToF!=2
	Button PT_buttonSetToDCregion2 disable= bk_ck_PToF!=2
	TitleBox PToF_TitleSpecC disable= bk_ck_PToF!=2
	Button PT_buttonDCMarker disable= bk_ck_PToF!=2

End


// new in 1.52
// Tab control for right bottom tab in baseline panel 
Function bk_tab_grIterate(ctrlName,tabNum) : TabControl
String ctrlName
Variable tabNum

	abort "Please recreate the baseline panel"
End
//
//	string cont_list, cont_item
//	variable num, idex, cont_disp
//	
//	cont_list=ControlNameList("", ";", "it*")+ControlNameList("", ";", "gr*")
//	num=itemsinlist(cont_list)
//	for (idex=0;idex<num;idex+=1)
//		cont_item=stringfromlist(idex,cont_list)
//		strswitch (cont_item[0,1])
//			case "gr": 	//graph tweaks
//				cont_disp= tabNum==1
//				break
//			case "it":	//  iterate
//				cont_disp= tabNum==0
//				break
//			default:
//				cont_disp=-1				
//		endswitch
//		controlinfo $cont_item
//		if (cont_disp>=0 )
//			switch (abs(v_flag))
//				case 1:
//					button $cont_item disable=cont_disp
//					break
//				case 2:
//					checkbox  $cont_item disable=cont_disp
//					break
//				case 3:
//					popupmenu $cont_item disable=cont_disp
//					break
//				case 4:
//					valdisplay $cont_item disable=cont_disp
//					break
//				case 5:
//					setvariable $cont_item disable=cont_disp
//					break
//				case 9:
//					groupbox $cont_item disable=cont_disp
//					break
//				case 10:
//					titlebox $cont_item disable=cont_disp
//					break
//			endswitch
//		endif
//	endfor
//End


// new in 1.52
// Does the work of generating raw PToF spectra into baseline panel
Function bk_InputIntoBaseline(OpenOrClosedStr, AorBStr, PToFBinStart,PToFBinStop)
string OpenOrClosedStr, AorBStr
variable PToFBinStart,PToFBinStop

	wave PToFMatrix = $"root:PToF:PToF_"+AorBStr
	wave BL_OpenOrClosed = $"root:BaselineFitting:OneRunRawSpectra"+OpenOrClosedStr

	variable numPToFBins
	//PToF region of Interest
	numPToFBins = PToFBinStop -PToFBinStart + 1
	make/Free/n=(numPToFBins, dimsize(PToFMatrix,1)) PToFtemp= PToFMatrix[p+PToFBinStart][q]
	matrixOp/o/FREE BL_OpenOrClosedtemp = sumCols(PToFtemp)
	redimension/n=(dimsize(PToFMatrix,1)) BL_OpenOrClosed
	BL_OpenOrClosed = BL_OpenOrClosedtemp[0][p]/numPToFBins	
	Note/K   BL_OpenOrClosed, "PToFStart:"+num2str(PToFBinStart)+";PToFStop:"+num2str(PToFBinStop)+";"
	
End


// new in 1.52
// Button in baseline panel for automatically setting 'closed' to DC 2 marker region.
Function bk_butt_SetToDCRegion2(ctrlName) : ButtonControl
	String ctrlName

	nvar dc3=root:panel:cor3_dcmarker3
	nvar dc4=root:panel:cor3_dcmarker4
	nvar ptof_dcUseBinNumUnits = root:panel:ptof_dcUseBinNumUnits

	string unitStr
	unitStr = selectString(ptof_dcUseBinNumUnits, "PToFTime", "binNum") // value="nm;us;bin No."
 	bk_ck_PToFUnits(unitStr,1)
 
	SetVariable PT_Setvar_SpectraBStart value = dc3, win=SQ_Baseline_Panel
	SetVariable PT_Setvar_SpectraBStop value = dc4, win=SQ_Baseline_Panel

End


//  For a given set of PToF spectra start/stop regions translate unit into PToF bin numbers for later squirrel fetching of PToF data
// creates and fills in values in root:PToF:PToFRegionsPTnum
// only used for PToF baseline display
Function sq_GetPToFPointNums(runPos)
variable runPos

	variable unitType		//   0 = bin #, 1 = us   //, 2 = nm
	ControlInfo/w=Sq_baseline_panel PT_check_binNum
	if (V_value)
		unitType=0
	else
//		ControlInfo PT_check_PToFTime
//		if (V_value)
			unitType=1
//		else
//			unitType=2
//		endif
	endif	

	// instead of having global variables just get the value from the controls
	variable SpectraAStartPt, SpectraAStopPt, SpectraBStartPt, SpectraBStopPt
	ControlInfo/w=Sq_baseline_panel PT_setvar_SpectraAStart
	SpectraAStartPt = V_value
	ControlInfo/w=Sq_baseline_panel PT_setvar_SpectraAStop
	SpectraAStopPt = V_value
	ControlInfo/w=Sq_baseline_panel PT_setvar_SpectraBStart
	SpectraBStartPt = V_value
	ControlInfo/w=Sq_baseline_panel PT_setvar_SpectraBStop
	SpectraBStopPt = V_value

	//  check monotonicity
	if ( !(SpectraAStartPt<=SpectraAStopPt) || !(SpectraBStartPt<=SpectraBStopPt)  ) //|| !(SpectraAStopPt<SpectraBStartPt)  )  //1.57D
		abort "Code requires that starts are < stops and Spectra A stop < spectra B start aborting from GetPToFPointNums"
	endif

	// check ranges
	make/o/n=10/FREE DVa_wave			// 10 is arbitrary
	sq_GetPToFParams(DVa_wave, runPos)		

	nvar lc = root:panel:cor3_chamber
	variable num=DVa_wave[%NumPToFBins]
	make/o/FREE/n=(num) ptof_dVaSize, ptof_dVaTime
	ptof_dVaTime = DVa_wave[%t0] + p*DVa_wave[%step]
	ptof_dVaSize = sq_ptof2dva(lc,DVa_wave[%vl],DVa_wave[%vg],DVa_wave[%b],DVa_wave[%dx],ptof_dVaTime[p])

	make/o/n=4 root:PToF:PToFRegionsPTnum/wave=PToFRegionsPTnum
	if (unitType==0)	// PToF bin number
		if (SpectraBStopPt > DVa_wave[%NumPToFBins] || SpectraAStartPt <0)
			abort " Either the maximum Spectra B stop point is too big (max bin is "+num2str(DVa_wave[%NumPToFBins]) +") or the Spectra A startpoint is too small (min bin < 0) . Aborting from GetPToFPointNums"
		endif
		PToFRegionsPTnum[0]= SpectraAStartPt
		PToFRegionsPTnum[1]= SpectraAStopPt
		if (SpectraBStartPt<0)		//1.60U
			SpectraBStartPt=num+SpectraBStartPt
		endif
		if (SpectraBStopPt<0)
			SpectraBStopPt=num+SpectraBStopPt
		endif
		
		PToFRegionsPTnum[2]= SpectraBStartPt
		PToFRegionsPTnum[3]= SpectraBStopPt
	else		//if(unitType==1)	// PToF time
		if (SpectraBStopPt*10^-6 > ptof_dVaTime[num-1] || SpectraAStartPt*10^-6 <ptof_dVaTime[0])
			abort " Either the maximum Spectra B stop point in time is too big (max time is "+num2str(10^6*ptof_dVaTime[num-1]) +") or the Spectra A startpoint in time is too small (min size is "+num2str(ptof_dVaTime[0])+"). Aborting from GetPToFPointNums"
		endif			
		PToFRegionsPTnum[0]= round(BinarySearch(ptof_dVaTime, SpectraAStartPt*10^-6))
		PToFRegionsPTnum[1]= round(BinarySearch(ptof_dVaTime, SpectraAStopPt*10^-6))
		PToFRegionsPTnum[2]= round(BinarySearch(ptof_dVaTime, SpectraBStartPt*10^-6))
		PToFRegionsPTnum[3]= round(BinarySearch(ptof_dVaTime, SpectraBStopPt*10^-6))
//	else // PToF nm
//		if (SpectraBStopPt > ptof_dVaSize[num-1] || SpectraAStartPt <ptof_dVaSize[0])
//			abort " Either the maximum Spectra B stop point in time is too big (max size is "+num2str(ptof_dVaSize[num-1]) +") or the Spectra A startpoint in time is too small (min size is 1). Aborting from GetPToFPointNums"
//		endif					
//		PToFRegionsPTnum[0]= round(BinarySearch(ptof_dVaSize, SpectraAStartPt))
//		PToFRegionsPTnum[1]= round(BinarySearch(ptof_dVaSize, SpectraAStopPt))
//		PToFRegionsPTnum[2]= round(BinarySearch(ptof_dVaSize, SpectraBStartPt))
//		PToFRegionsPTnum[3]= round(BinarySearch(ptof_dVaSize, SpectraBStopPt))
	endif	

end	


// new in 1.52
// Function that retrieves raw PToF spectra
Function bk_getSumPToFForBaselinePanel()		// presumes that we already know that we want PToF and not MS data.

	nvar bk_currentRunNum = root:BaselineFitting:bk_currentRunNum
// 	nvar bk_UseRunningAvg = root:baselineFitting:bk_UseRunningAvg
// 	nvar bk_RunningAvgDeltaRunNum = root:baselineFitting:bk_RunningAvgDeltaRunNum
	nvar VWSwitching = root:diagnostics:VWSwitching
	wave/z toftypeVKey = root:diagnostics:toftypeVKey
	nvar chopper_duty = root:diagnostics:chopper_duty
	nvar bk_ck_PToF = root:baselineFitting:bk_ck_PToF		// 1 = MS, 2 = PToF, 3 = sumEPToF
	
	wave/z ePToF_enabled = root:diagnostics:ePToF_enabled

	wave OneRunRawSpectraOpen = root:BaselineFitting:OneRunRawSpectraOpen
	wave OneRunRawSpectraClosed = root:BaselineFitting:OneRunRawSpectraClosed
	wave OneRunRawSpectraDiff = root:BaselineFitting:OneRunRawSpectraDiff
	
	string runStr, str1, str2
	variable runPos
	
	sprintf runStr, "%d", bk_currentRunNum
	// first check if current run has PToF data
	if (	sq_doesPToFDataExist(bk_currentRunNum)!=1)
		abort "No PToF data exists for run "+runStr
	endif
//	if (bk_UseRunningAvg)
//		abort "Cannot do running average for summed ePToF at this time.  Aborting from bk_getSumPToFForBaselinePanel."
//	endif
	// next check if spectra A and B start and stop times make sense (consider different PToF bin units
	runPos = sq_findRun(root:index:rn_series,bk_currentRunNum)
//	sq_GetPToFPointNums(runPos)
//	if (bk_ck_PToF==2)
//		sq_GetPToFPointNums(runPos)
//	endif
	if ( !WaveExists(ePToF_enabled) || ePToF_enabled[runPos]!=1)
		abort "This is not an ePToF run.  Aborting from bk_getSumPToFForBaselinePanel."
	endif
	
	// deal with a single run or an average of a todo
	make/i/o/n=1 myTempTodo = bk_currentRunNum
	squirrel_fetch(myTempTodo,sq_MS_concentration, "timeweight_op:4;findBaseline_op:0;raw_flag:1;product_type:6;destlist:PToF_Matrix;chop_duty:0.5","PToF")
	killwaves/z myTempTodo
	
	wave PToF_Matrix = root:PToF_Matrix		// gets spit out as rows = mz, cols = PtoF size
	wave PToF_A = root:PToF:PToF_A

	MatrixTranspose PToF_Matrix
	Redimension/n=(dimsize(PToF_Matrix,0),dimsize(PToF_Matrix,1)) PToF_A
	PToF_A = PToF_Matrix
	killwaves/z PToF_Matrix

	wave PToFHey = $"root:PToF:PToF_"+"A"
//	wave PToFRegionsPTnum=root:PToF:PToFRegionsPTnum
//	variable closedA =PToFRegionsPTnum[2], closedB=PToFRegionsPTnum[3]

	bk_InputIntoBaseline("Open", "A", 0,dimsize(PToF_A,0)-1)		//1.57D
// 	bk_InputIntoBaseline("Closed", "A", PToFRegionsPTnum[2],PToFRegionsPTnum[3])	

	redimension/n=(numpnts(OneRunRawSpectraOpen))  OneRunRawSpectraDiff, OneRunRawSpectraClosed
	fastop OneRunRawSpectraDiff = (nan	)	
	fastop OneRunRawSpectraClosed = (nan)		

End


Function sq_butt_FindRunInTodo(ctrlName) : ButtonControl
	String ctrlName

	svar sq_toDoWvNm = root:panel:sq_toDoWvNm
	if (stringmatch(ctrlName[0,1], "HR"))
		nvar runVar = root:HR_panel:HR_runVar
	else
		nvar runVar = root:baselineFitting:bk_CurrentRunNum
	endif
	
	wave todo = $sq_toDoWvNm
	
	variable runLocation = sq_findRun(todo,runVar)
	variable numInTodo = numpnts(todo)
		
	if (runLocation<0)		// run not in current todo wave
		runLocation = binarysearch(todo, runVar)
		if (runLocation==-1) 
			runVar = todo[0]
			return 1
		elseif(runLocation ==-2)
			runVar = todo[numInTodo-1]
			return 1
		endif	
	endif

	if (strsearch(ctrlName, "next",0) >0)
		if (runLocation+1<numInTodo)
			runVar = todo[runLocation+1]
		endif
	else
		if (runLocation>0)
			runVar = todo[runLocation-1]
		endif
	endif

	if (stringmatch(ctrlName[0,1], "HR"))
		Execute "HR_SetVar_RunModeStr(\""+"\""+",nan,"+"\""+"\""+","+"\""+"\""+")"
	else
		bk_setVar_runNumberVW("setvar_CurrentRunNum",runVar,"root:baselineFitting:bk_CurrentRunNum","")
		bk_butt_rawSpectraThisRun("")  // 1.61B
	endif
End

Function bk_TofwerkBLGlobals()
	
	if (!DataFolderExists("root:baselineFitting:"))
		bk_createGlobalsBaseline()
	endif
	sq_initializeGlobalNVar("root:baselineFitting:bk_UseTofwerk", 0)

	sq_initializeGlobalNVar("root:baselineFitting:bk_twWidth", nan)		// from Mike C
	sq_initializeGlobalNVar("root:baselineFitting:bk_twNoiseScaling", 1)
	sq_initializeGlobalNVar("root:baselineFitting:bk_twckLoPass", 1)
	sq_initializeGlobalNVar("root:baselineFitting:bk_twf2", 0.02)
	sq_initializeGlobalNVar("root:baselineFitting:bk_twN", 20)
	nvar bk_twWidth  = root:baselineFitting:bk_twWidth
	if (numtype(bk_twWidth) != 0)
		bk_butt_setTWToDefault("")
	endif
End

Function bk_ck_useLinearOrSpline(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	nvar bk_UseLinear = root:baselineFitting:bk_UseLinear
	nvar bk_UseCubicSpline = root:baselineFitting:bk_UseCubicSpline
	nvar/z bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk
	if (!NVar_exists(bk_UseTofwerk))
		bk_TofwerkBLGlobals()
		nvar/z bk_UseTofwerk = root:baselineFitting:bk_UseTofwerk
		abort "Please recreate the baseline panel."
	endif

	variable type = WhichListItem(ctrlName,"check_Linear;check_CubicSpline;check_Tofwerk")
	
	bk_UseLinear = type==0
	bk_UseCubicSpline = type==1
	bk_UseTofwerk = type==2
	
	string cont_item,cont_list=controlnamelist("SQ_Baseline_Panel", ";", "bkfit*")
	variable ZeroBeyondMzFlag, cont_disp,idex, num=itemsinlist(cont_list)

	for (idex=0;idex<num;idex+=1)
		cont_item=stringfromlist(idex,cont_list)
		ZeroBeyondMzFlag = stringmatch("bkFitln_sp", cont_item[0,9])
		strswitch(cont_item[5,6])
			case "tw":
				cont_disp=!bk_UseTofwerk
				break
			case "ln":
				cont_disp=bk_UseTofwerk || (!bk_UseLinear &&!ZeroBeyondMzFlag )   // !bk_UseLinear
				break
			case "sp":
				cont_disp=bk_UseTofwerk || (!bk_UseCubicSpline &&!ZeroBeyondMzFlag ) 		// !bk_UseCubicSpline
				break
		endswitch
		controlinfo $cont_item
		switch (abs(v_flag))
			case 1:
				button $cont_item disable=cont_disp
				break
			case 2:
				checkbox  $cont_item disable=cont_disp
				break
			case 3:
				popupmenu $cont_item disable=cont_disp
				break
			case 4:
				valdisplay $cont_item disable=cont_disp
				break
			case 5:
				setvariable $cont_item disable=cont_disp
				break
			case 6:
				chart $cont_item disable=cont_disp
				break
			case 7:
				slider $cont_item disable=cont_disp
				break
			case 8:
				tabcontrol $cont_item disable=cont_disp
				break
			case 9:
				groupbox $cont_item disable=cont_disp
				break
			case 10:
				titlebox $cont_item disable=cont_disp
				break
			case 11:
				listbox $cont_item disable=cont_disp
				break
		endswitch	
	endfor
	
End


Function bk_ck_ShowOpenClosedDiff(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			Variable checked = cba.checked
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function bk_setVar_mzStartStop(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName
	
	nvar bk_MassAxisStart= root:baselineFitting:bk_MassAxisStart
//	nvar bk_MassAxisDelta= root:baselineFitting:bk_MassAxisDelta
	nvar bk_MassAxisStop= root:baselineFitting:bk_MassAxisStop
	Wave mFinish = root:diagnostics:mFinish
	
	if (bk_MassAxisStart==-1 || bk_MassAxisStop == -1)
		SetAxis/A/W=SQ_Baseline_Panel#RawSpectraGraph bottom
	endif

//	nvar bk_SliderSetVar = root:baselineFitting:bk_SliderSetVar

	bk_MassAxisStart = max(bk_MassAxisStart, 0)
	bk_MassAxisStop = min(WaveMax(mFinish), bk_MassAxisStop)

//	if (strsearch(ctrlName, "stop", 0 ,2)>=0)		// the start variable was modified
	SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStop
//	else
//		if(bk_SliderSetVar)
//			SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStart + bk_MassAxisDelta
//		else
//			SetAxis/W=SQ_Baseline_Panel#RawSpectraGraph bottom,  bk_MassAxisStart, bk_MassAxisStop
//		endif
//	endif

End

Function bk_setVar_DiffYAxis(ctrlName,varNum,varStr,varName) : SetVariableControl
	String ctrlName
	Variable varNum
	String varStr
	String varName

	SetActiveSubwindow SQ_Baseline_Panel#RawSpectraGraph
	SetAxis LDiff -varNum/4, varNum

End


Function bk_ck_ShowSpec(cba) : CheckBoxControl
	STRUCT WMCheckboxAction &cba

	switch( cba.eventCode )
		case 2: // mouse up
			Variable checked = cba.checked
			break
		case -1: // control being killed
			break
	endswitch

	return 0
End

Function bk_butt_rawSpectraThisRun(ctrlName) : ButtonControl
	String ctrlName

	setDataFolder root:		// 1.40D
	variable avgFlag = stringmatch(ctrlName, "it_button_calcBaselineInToDo")
	bk_setUpRawSpectraThisRun(avgFlag=avgFlag)
	sq_initializeGlobalNVar("root:baselineFitting:bk_ck_LockRange",0)
	nvar bk_ck_LockRange  = $"root:baselineFitting:bk_ck_LockRange"
	
	if (!bk_ck_LockRange)
		bk_autoAxis("gr_autoYaxis")	
	endif

	bk_butt_calcBkFit("")
End

Function bk_ck_subset(ctrlName,checked) : CheckBoxControl
	String ctrlName
	Variable checked

	SetVariable it_setvarRandomSubset disable = 2*!checked

End



Structure UMR_integration

wave runrawMS		// raw spectra length OR raw spectra length x PToFBins
wave runrawMSBL		// raw spectra length OR raw spectra length x PToFBins
wave runaxis			// raw spectra length
wave runBLMask		// raw spectra length

wave runStickMS		// maxMz OR maxMz x PToFBins
wave runStickMSBL

wave StartBL_Mz	// maxMz 
wave StopBL_Mz

wave Start_Mz	// maxMz 
wave Stop_Mz
wave Start_p
wave Stop_p

variable startMZVal
variable maxMzVal
variable kill
variable nSecMSsampling
variable DataTypeFlag
variable isWFlag
variable smoothpts
variable spline_op
variable stickBL_op
variable bk_UseTofwerk

EndStructure


Function sq_UMR_integration(UMR)		// sets UMR.runStickMS, UMR.runStickMSBL
struct UMR_integration &UMR

	//^ get peak integration start and end point values once, here. 
	sq_StickCalcPrepRegion(UMR.runrawMS,UMR.runaxis, UMR.startMZVal, UMR.maxMzVal, UMR.Start_Mz, UMR.Stop_Mz, UMR.Start_p, UMR.Stop_p)
			
	// step (4)
	sq_StickCalc(UMR.runrawMS, UMR.runStickMS, UMR.startMZVal, UMR.kill, UMR.Start_p, UMR.Stop_p, nSecMSsampling=UMR.nSecMSsampling)		//1.53H
	
	// step (5) 
	if (UMR.stickBL_op)		// calculate the baseline 
		if (!UMR.bk_UseTofwerk)
			bk_createStickComplimentMask(UMR.runBLMask, UMR.StartBL_Mz, UMR.StopBL_Mz, UMR.runaxis)
			if (UMR.DataTypeFlag==4)		// PToF
				matrixOP/o UMR.runrawMSBL = UMR.runrawMSBL x UMR.runBLMask
			else
				matrixOP/o UMR.runrawMSBL = UMR.runrawMSBL * UMR.runBLMask
			endif
			
			bk_makeBkZeroBeyondMassX(UMR.runaxis, UMR.runrawMSBL, UMR.DataTypeFlag)
			bk_fitStickCompliment(UMR.runrawMSBL, UMR.isWFlag, UMR.smoothpts, UMR.kill, UMR.smoothpts, UMR.spline_op)
		else
			struct Tofware#tw_bsl_smooth_var f	
			bk_twbaseline(UMR.runrawMS, UMR.runrawMSBL, f)
		endif

		// step (6) 
		sq_StickCalc(UMR.runrawMSBL, UMR.runStickMSBL, UMR.startMZVal, UMR.kill, UMR.Start_p, UMR.Stop_p, nSecMSsampling=UMR.nSecMSsampling)		//1.53H

	endif

End

// reworked in 1.60Y
Function bk_twbaseline(Spectra, SpectraFit, f)
wave Spectra,SpectraFit 
struct Tofware#tw_bsl_smooth_var &f	

	nvar bk_twWidth = $"root:baselineFitting:bk_twWidth"
	nvar bk_twNoiseScaling = $"root:baselineFitting:bk_twNoiseScaling"
	nvar bk_twckLoPass = $"root:baselineFitting:bk_twckLoPass"
	nvar bk_twf2 = $"root:baselineFitting:bk_twf2"
	nvar bk_twN = $"root:baselineFitting:bk_twN"
	Tofware#tw_bsl_smooth_varDef(f)
	f.width=bk_twWidth
	f.loPass_active=bk_twckLoPass
	f.loPass_f2=bk_twf2
	f.loPass_n=bk_twN
	f.noiseScaleFactor=bk_twNoiseScaling
//	variable pdex, PToFFlag = dimsize(Spectra,1)
	
	Tofware#tw_bsl_smooth_getBsl(Spectra,SpectraFit,f)
End


